""" Cisco_IOS_XR_ipv4_bgp_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-bgp package operational data.

This module contains definitions
for the following management objects\:
  bgp\: BGP operational data

Copyright (c) 2013\-2018 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class BgpAfi(Enum):
    """
    BgpAfi (Enum Class)

    BGP Address family

    .. data:: ipv4 = 0

    	IP v4 unicast

    .. data:: ipv4_multicast = 1

    	IP v4 multicast

    .. data:: ipv4_labeled = 2

    	IP v4 label

    .. data:: ipv4_tunnel = 3

    	IP v4 Tunnel

    .. data:: vpnv4 = 4

    	IP v4 virtual private network

    .. data:: ipv6 = 5

    	IP v6 unicast

    .. data:: ipv6_multicast = 6

    	IP v6 multicast

    .. data:: ipv6_labeled = 7

    	IP v6 label

    .. data:: vpnv6 = 8

    	IP v6 virtual private network

    .. data:: ipv4_mdt = 9

    	IP v4 Multicast  Distribution Tree

    .. data:: l2vpn_vpls = 10

    	L2VPN VPLS

    .. data:: rt_constraint = 11

    	IP RT-Constraint

    .. data:: ipv4_mvpn = 12

    	IP v4 mvpn

    .. data:: ipv6_mvpn = 13

    	IP v6 mvpn

    .. data:: l2vpn_evpn = 14

    	L2VPN EVPN

    .. data:: ls_ls = 15

    	Link-state Link-state

    .. data:: vpnv4_multicast = 16

    	IP v4 virtual private network for multicast

    .. data:: vpnv6_multicast = 17

    	IP v6 virtual private network for multicast

    .. data:: ipv4_flowspec = 18

    	IP v4 flowspec

    .. data:: ipv6_flowspec = 19

    	IP v6 flowspec

    .. data:: vpnv4_flowspec = 20

    	IP v4 vpn flowspec

    .. data:: vpnv6_flowspec = 21

    	IP v6 vpn flowspec

    .. data:: l2vpn_mspw = 22

    	L2VPN Multi-segment pseudowire

    .. data:: ipv4_sr_policy = 23

    	IP v4 SR Policy

    .. data:: ipv6_sr_policy = 24

    	IP v6 SR Policy

    .. data:: no_address_family = 25

    	Address-family not applicable

    .. data:: all_address_families = 26

    	All address-families

    """

    ipv4 = Enum.YLeaf(0, "ipv4")

    ipv4_multicast = Enum.YLeaf(1, "ipv4-multicast")

    ipv4_labeled = Enum.YLeaf(2, "ipv4-labeled")

    ipv4_tunnel = Enum.YLeaf(3, "ipv4-tunnel")

    vpnv4 = Enum.YLeaf(4, "vpnv4")

    ipv6 = Enum.YLeaf(5, "ipv6")

    ipv6_multicast = Enum.YLeaf(6, "ipv6-multicast")

    ipv6_labeled = Enum.YLeaf(7, "ipv6-labeled")

    vpnv6 = Enum.YLeaf(8, "vpnv6")

    ipv4_mdt = Enum.YLeaf(9, "ipv4-mdt")

    l2vpn_vpls = Enum.YLeaf(10, "l2vpn-vpls")

    rt_constraint = Enum.YLeaf(11, "rt-constraint")

    ipv4_mvpn = Enum.YLeaf(12, "ipv4-mvpn")

    ipv6_mvpn = Enum.YLeaf(13, "ipv6-mvpn")

    l2vpn_evpn = Enum.YLeaf(14, "l2vpn-evpn")

    ls_ls = Enum.YLeaf(15, "ls-ls")

    vpnv4_multicast = Enum.YLeaf(16, "vpnv4-multicast")

    vpnv6_multicast = Enum.YLeaf(17, "vpnv6-multicast")

    ipv4_flowspec = Enum.YLeaf(18, "ipv4-flowspec")

    ipv6_flowspec = Enum.YLeaf(19, "ipv6-flowspec")

    vpnv4_flowspec = Enum.YLeaf(20, "vpnv4-flowspec")

    vpnv6_flowspec = Enum.YLeaf(21, "vpnv6-flowspec")

    l2vpn_mspw = Enum.YLeaf(22, "l2vpn-mspw")

    ipv4_sr_policy = Enum.YLeaf(23, "ipv4-sr-policy")

    ipv6_sr_policy = Enum.YLeaf(24, "ipv6-sr-policy")

    no_address_family = Enum.YLeaf(25, "no-address-family")

    all_address_families = Enum.YLeaf(26, "all-address-families")


class BgpBagUpdErrAction(Enum):
    """
    BgpBagUpdErrAction (Enum Class)

    Bgp bag upd err action

    .. data:: bgp_bag_upd_err_action_none = 0

    	No Action

    .. data:: bgp_bag_upd_err_action_discard_msg = 1

    	Discard Message

    .. data:: bgp_bag_upd_err_action_reset = 2

    	Session Reset

    .. data:: bgp_bag_upd_err_action_wdr_or_reset = 3

    	Withdraw NLRI or Reset

    .. data:: bgp_bag_upd_err_action_wdr = 4

    	Withdraw NLRI

    .. data:: bgp_bag_upd_err_action_discard_attr = 5

    	Discard Attribute

    .. data:: bgp_bag_upd_err_action_local_repair = 6

    	Local Repair

    .. data:: bgp_bag_upd_err_action_max = 7

    	Maximum number of actions

    """

    bgp_bag_upd_err_action_none = Enum.YLeaf(0, "bgp-bag-upd-err-action-none")

    bgp_bag_upd_err_action_discard_msg = Enum.YLeaf(1, "bgp-bag-upd-err-action-discard-msg")

    bgp_bag_upd_err_action_reset = Enum.YLeaf(2, "bgp-bag-upd-err-action-reset")

    bgp_bag_upd_err_action_wdr_or_reset = Enum.YLeaf(3, "bgp-bag-upd-err-action-wdr-or-reset")

    bgp_bag_upd_err_action_wdr = Enum.YLeaf(4, "bgp-bag-upd-err-action-wdr")

    bgp_bag_upd_err_action_discard_attr = Enum.YLeaf(5, "bgp-bag-upd-err-action-discard-attr")

    bgp_bag_upd_err_action_local_repair = Enum.YLeaf(6, "bgp-bag-upd-err-action-local-repair")

    bgp_bag_upd_err_action_max = Enum.YLeaf(7, "bgp-bag-upd-err-action-max")


class BgpBagUpdFilterAction(Enum):
    """
    BgpBagUpdFilterAction (Enum Class)

    Bgp bag upd filter action

    .. data:: none = 0

    	No Action

    .. data:: withdraw = 1

    	Withdraw NLRI

    .. data:: attribute_discard = 2

    	Discard Attribute

    """

    none = Enum.YLeaf(0, "none")

    withdraw = Enum.YLeaf(1, "withdraw")

    attribute_discard = Enum.YLeaf(2, "attribute-discard")


class BgpBfdEnableMode(Enum):
    """
    BgpBfdEnableMode (Enum Class)

    BFD enable mode

    .. data:: bgp_bfd_enable_mode_disable = 0

    	BFD fast detect disabled 

    .. data:: bgp_bfd_enable_mode_def = 1

    	BFD fast detect default mode 

    .. data:: bgp_bfd_enable_mode_strict = 2

    	BFD fast detect hold down aka strict mode

    """

    bgp_bfd_enable_mode_disable = Enum.YLeaf(0, "bgp-bfd-enable-mode-disable")

    bgp_bfd_enable_mode_def = Enum.YLeaf(1, "bgp-bfd-enable-mode-def")

    bgp_bfd_enable_mode_strict = Enum.YLeaf(2, "bgp-bfd-enable-mode-strict")


class BgpBfdState(Enum):
    """
    BgpBfdState (Enum Class)

    BFD session state

    .. data:: bgp_bfd_state_not_configured = 0

    	BFD not configured

    .. data:: bgp_bfd_state_admin_down = 1

    	BFD session disabled (neighbor shutdown)

    .. data:: bgp_bfd_state_not_supported = 2

    	BFD session disabled (interface type not

    	supported)

    .. data:: bgp_bfd_state_not_created = 3

    	BFD session configured, not yet created

    .. data:: bgp_bfd_state_created = 4

    	BFD session created, state notification not

    	received

    .. data:: bgp_bfd_state_up = 5

    	BFD session up

    .. data:: bgp_bfd_state_down = 6

    	BFD session down

    .. data:: bgp_bfd_state_nbr_not_configured = 7

    	BFD session down (peer not configured)

    .. data:: bgp_bfd_state_none = 8

    	BFD session (yet ro rcv Notification)

    """

    bgp_bfd_state_not_configured = Enum.YLeaf(0, "bgp-bfd-state-not-configured")

    bgp_bfd_state_admin_down = Enum.YLeaf(1, "bgp-bfd-state-admin-down")

    bgp_bfd_state_not_supported = Enum.YLeaf(2, "bgp-bfd-state-not-supported")

    bgp_bfd_state_not_created = Enum.YLeaf(3, "bgp-bfd-state-not-created")

    bgp_bfd_state_created = Enum.YLeaf(4, "bgp-bfd-state-created")

    bgp_bfd_state_up = Enum.YLeaf(5, "bgp-bfd-state-up")

    bgp_bfd_state_down = Enum.YLeaf(6, "bgp-bfd-state-down")

    bgp_bfd_state_nbr_not_configured = Enum.YLeaf(7, "bgp-bfd-state-nbr-not-configured")

    bgp_bfd_state_none = Enum.YLeaf(8, "bgp-bfd-state-none")


class BgpBindingSid(Enum):
    """
    BgpBindingSid (Enum Class)

    BGP Binding SID type

    .. data:: none = 0

    	None

    .. data:: label = 1

    	Binding SID type MPLS label

    .. data:: v6 = 2

    	Binding SID type ipv6

    """

    none = Enum.YLeaf(0, "none")

    label = Enum.YLeaf(1, "label")

    v6 = Enum.YLeaf(2, "v6")


class BgpBmpState(Enum):
    """
    BgpBmpState (Enum Class)

    BMP Connection State

    .. data:: none = 0

    	BMP NOT Connected

    .. data:: connecting = 1

    	BMP Under Connection

    .. data:: established = 2

    	BMP Connection Established

    .. data:: closing = 3

    	BMP Connection Closing

    """

    none = Enum.YLeaf(0, "none")

    connecting = Enum.YLeaf(1, "connecting")

    established = Enum.YLeaf(2, "established")

    closing = Enum.YLeaf(3, "closing")


class BgpBmpUpdMode(Enum):
    """
    BgpBmpUpdMode (Enum Class)

    Bgp bmp upd mode

    .. data:: bgp_bmp_upd_n_either = 0

    	Neither of the modes are enabled

    .. data:: bgp_bmp_upd_route_mon = 1

    	Route Monotoring mode enabled

    .. data:: bgp_bmp_upd_route_mirr = 2

    	Route Mirroring mode is enabled

    """

    bgp_bmp_upd_n_either = Enum.YLeaf(0, "bgp-bmp-upd-n-either")

    bgp_bmp_upd_route_mon = Enum.YLeaf(1, "bgp-bmp-upd-route-mon")

    bgp_bmp_upd_route_mirr = Enum.YLeaf(2, "bgp-bmp-upd-route-mirr")


class BgpBpStage(Enum):
    """
    BgpBpStage (Enum Class)

    Bgp bp stage

    .. data:: bgp_bp_comp_not_compared = 0

    	Best path comparison not performed

    .. data:: bgp_bp_comp_imulti_path = 1

    	Path is an iBGP multipath

    .. data:: bgp_bp_comp_emulti_path = 2

    	Path is an eBGP multipath

    .. data:: bgp_bp_comp_eimulti_path = 3

    	Path is an eiBGP multipath

    .. data:: bgp_bp_invalid_path = 4

    	Invalid path

    .. data:: bgp_bp_comp_pre_cost_comm = 5

    	TODO

    .. data:: bgp_bp_comp_weight = 6

    	Path has a lower weight

    .. data:: bgp_bp_comp_locpref = 7

    	Path has a lower local preference

    .. data:: bgp_bp_comp_rpki = 8

    	Path has worse origin validation state

    .. data:: bgp_bp_comp_aigp = 9

    	TODO

    .. data:: bgp_bp_comp_local = 10

    	Path is not local

    .. data:: bgp_bp_comp_local_rib = 11

    	TODO

    .. data:: bgp_bp_comp_as_path_len = 12

    	Path has a longer AS path

    .. data:: bgp_bp_comp_origin = 13

    	Path has a less favorable origin

    .. data:: bgp_bp_comp_med = 14

    	Path has a lower MED

    .. data:: bgp_bp_comp_ebgp = 15

    	Path lost to an eBGP path

    .. data:: bgp_bp_comp_ao = 16

    	Path has Accept-Own community

    .. data:: bgp_bp_comp_igp_metric = 17

    	Path has a higher IGP metric

    .. data:: bgp_bp_comp_igp_cost_comm = 18

    	TODO

    .. data:: bgp_bp_comp_rtr_id = 19

    	Path has a higher router ID

    .. data:: bgp_bp_comp_clstr_len = 20

    	Path has a longer cluster length

    .. data:: bgp_bp_comp_nbr_addr = 21

    	Path has a higher neighbor address

    .. data:: bgp_bp_comp_suppressed = 22

    	Path is newer than best path

    .. data:: bgp_bp_comp_mismatch = 23

    	Best path comparison failed, perhaps due to

    	recent configuration changes

    .. data:: bgp_bp_comp_persistence = 24

    	Path is persistent

    """

    bgp_bp_comp_not_compared = Enum.YLeaf(0, "bgp-bp-comp-not-compared")

    bgp_bp_comp_imulti_path = Enum.YLeaf(1, "bgp-bp-comp-imulti-path")

    bgp_bp_comp_emulti_path = Enum.YLeaf(2, "bgp-bp-comp-emulti-path")

    bgp_bp_comp_eimulti_path = Enum.YLeaf(3, "bgp-bp-comp-eimulti-path")

    bgp_bp_invalid_path = Enum.YLeaf(4, "bgp-bp-invalid-path")

    bgp_bp_comp_pre_cost_comm = Enum.YLeaf(5, "bgp-bp-comp-pre-cost-comm")

    bgp_bp_comp_weight = Enum.YLeaf(6, "bgp-bp-comp-weight")

    bgp_bp_comp_locpref = Enum.YLeaf(7, "bgp-bp-comp-locpref")

    bgp_bp_comp_rpki = Enum.YLeaf(8, "bgp-bp-comp-rpki")

    bgp_bp_comp_aigp = Enum.YLeaf(9, "bgp-bp-comp-aigp")

    bgp_bp_comp_local = Enum.YLeaf(10, "bgp-bp-comp-local")

    bgp_bp_comp_local_rib = Enum.YLeaf(11, "bgp-bp-comp-local-rib")

    bgp_bp_comp_as_path_len = Enum.YLeaf(12, "bgp-bp-comp-as-path-len")

    bgp_bp_comp_origin = Enum.YLeaf(13, "bgp-bp-comp-origin")

    bgp_bp_comp_med = Enum.YLeaf(14, "bgp-bp-comp-med")

    bgp_bp_comp_ebgp = Enum.YLeaf(15, "bgp-bp-comp-ebgp")

    bgp_bp_comp_ao = Enum.YLeaf(16, "bgp-bp-comp-ao")

    bgp_bp_comp_igp_metric = Enum.YLeaf(17, "bgp-bp-comp-igp-metric")

    bgp_bp_comp_igp_cost_comm = Enum.YLeaf(18, "bgp-bp-comp-igp-cost-comm")

    bgp_bp_comp_rtr_id = Enum.YLeaf(19, "bgp-bp-comp-rtr-id")

    bgp_bp_comp_clstr_len = Enum.YLeaf(20, "bgp-bp-comp-clstr-len")

    bgp_bp_comp_nbr_addr = Enum.YLeaf(21, "bgp-bp-comp-nbr-addr")

    bgp_bp_comp_suppressed = Enum.YLeaf(22, "bgp-bp-comp-suppressed")

    bgp_bp_comp_mismatch = Enum.YLeaf(23, "bgp-bp-comp-mismatch")

    bgp_bp_comp_persistence = Enum.YLeaf(24, "bgp-bp-comp-persistence")


class BgpConnState(Enum):
    """
    BgpConnState (Enum Class)

    Bgp conn state

    .. data:: bgp_st_dont_care = 0

    	DontCare

    .. data:: bgp_st_idle = 1

    	Idle

    .. data:: bgp_st_connect = 2

    	Connect

    .. data:: bgp_st_active = 3

    	Active

    .. data:: bgp_st_open_sent = 4

    	OpenSent

    .. data:: bgp_st_open_confirm = 5

    	OpenConfirm

    .. data:: bgp_st_estab = 6

    	Established

    .. data:: bgp_st_closing = 7

    	Closing

    .. data:: bgp_st_closing_sync = 8

    	ClosingSync

    """

    bgp_st_dont_care = Enum.YLeaf(0, "bgp-st-dont-care")

    bgp_st_idle = Enum.YLeaf(1, "bgp-st-idle")

    bgp_st_connect = Enum.YLeaf(2, "bgp-st-connect")

    bgp_st_active = Enum.YLeaf(3, "bgp-st-active")

    bgp_st_open_sent = Enum.YLeaf(4, "bgp-st-open-sent")

    bgp_st_open_confirm = Enum.YLeaf(5, "bgp-st-open-confirm")

    bgp_st_estab = Enum.YLeaf(6, "bgp-st-estab")

    bgp_st_closing = Enum.YLeaf(7, "bgp-st-closing")

    bgp_st_closing_sync = Enum.YLeaf(8, "bgp-st-closing-sync")


class BgpDsConnState(Enum):
    """
    BgpDsConnState (Enum Class)

    Bgp ds conn state

    .. data:: none = 0

    	DS connection not initiated - ST 0

    .. data:: connect_init = 1

    	DS connection initiated - ST 1

    .. data:: connect_fail = 2

    	DS connection failed - ST 2

    .. data:: connect_estb = 3

    	DS connection established - ST 3

    .. data:: disconnect_init = 4

    	DS disconnect initiated - ST 4

    .. data:: disconnect_fail = 5

    	DS disconnect failed - ST 5

    .. data:: disconnect_done = 6

    	DS disconnect done - ST 6

    """

    none = Enum.YLeaf(0, "none")

    connect_init = Enum.YLeaf(1, "connect-init")

    connect_fail = Enum.YLeaf(2, "connect-fail")

    connect_estb = Enum.YLeaf(3, "connect-estb")

    disconnect_init = Enum.YLeaf(4, "disconnect-init")

    disconnect_fail = Enum.YLeaf(5, "disconnect-fail")

    disconnect_done = Enum.YLeaf(6, "disconnect-done")


class BgpEbgpSendDmzEnableMode(Enum):
    """
    BgpEbgpSendDmzEnableMode (Enum Class)

    EBGP send extended community dmz link bandwidth

    enable mode

    .. data:: bgp_ebgp_send_dmz_disable = 0

    	EBGP send extended community dmz link bandwidth

    	disabled 

    .. data:: bgp_ebgp_send_dmz_dflt = 1

    	EBGP send extended community dmz link bandwidth

    	default mode 

    .. data:: bgp_ebgp_send_dmz_cumulative = 2

    	EBGP send extended community dmz link bandwidth

    	cumulative mode

    """

    bgp_ebgp_send_dmz_disable = Enum.YLeaf(0, "bgp-ebgp-send-dmz-disable")

    bgp_ebgp_send_dmz_dflt = Enum.YLeaf(1, "bgp-ebgp-send-dmz-dflt")

    bgp_ebgp_send_dmz_cumulative = Enum.YLeaf(2, "bgp-ebgp-send-dmz-cumulative")


class BgpEntities(Enum):
    """
    BgpEntities (Enum Class)

    Entity type

    .. data:: af_group = 0

    	AF groups

    .. data:: session_group = 1

    	Session Groups

    .. data:: neighbor_group = 2

    	Neighbor Groups

    .. data:: neighbor = 3

    	Neighbors

    """

    af_group = Enum.YLeaf(0, "af-group")

    session_group = Enum.YLeaf(1, "session-group")

    neighbor_group = Enum.YLeaf(2, "neighbor-group")

    neighbor = Enum.YLeaf(3, "neighbor")


class BgpEntity(Enum):
    """
    BgpEntity (Enum Class)

    Bgp entity

    .. data:: af_group = 0

    	Address family group

    .. data:: session_group = 1

    	Session group

    .. data:: neighbor_group = 2

    	Neighbor group

    .. data:: neighbor = 3

    	Neighbor

    """

    af_group = Enum.YLeaf(0, "af-group")

    session_group = Enum.YLeaf(1, "session-group")

    neighbor_group = Enum.YLeaf(2, "neighbor-group")

    neighbor = Enum.YLeaf(3, "neighbor")


class BgpIsmConnState(Enum):
    """
    BgpIsmConnState (Enum Class)

    Bgp ism conn state

    .. data:: none = 0

    	None - ST 0

    .. data:: connect_done = 1

    	ISSUMgr connection done - ST 1

    """

    none = Enum.YLeaf(0, "none")

    connect_done = Enum.YLeaf(1, "connect-done")


class BgpLabelRpfInstall(Enum):
    """
    BgpLabelRpfInstall (Enum Class)

    BGP Label RPF Install Path

    .. data:: bgp_label_rpf_install_rib = 0

    	Install via RIB

    .. data:: bgp_label_rpf_install_lsd = 1

    	Install via LSD

    """

    bgp_label_rpf_install_rib = Enum.YLeaf(0, "bgp-label-rpf-install-rib")

    bgp_label_rpf_install_lsd = Enum.YLeaf(1, "bgp-label-rpf-install-lsd")


class BgpNhEvent(Enum):
    """
    BgpNhEvent (Enum Class)

    Bgp nh event

    .. data:: bgp_nh_event_crit_not_f = 0

    	Last event received is a crit notf

    .. data:: bgp_nh_event_non_crit_not_f = 1

    	Last event received is a non-crit notf

    .. data:: bgp_nh_event_registration = 2

    	Last event sent is a registration

    """

    bgp_nh_event_crit_not_f = Enum.YLeaf(0, "bgp-nh-event-crit-not-f")

    bgp_nh_event_non_crit_not_f = Enum.YLeaf(1, "bgp-nh-event-non-crit-not-f")

    bgp_nh_event_registration = Enum.YLeaf(2, "bgp-nh-event-registration")


class BgpNhUpdate(Enum):
    """
    BgpNhUpdate (Enum Class)

    Bgp nh update

    .. data:: bgp_nh_update_none = 0

    	No nh update yet

    .. data:: bgp_nh_update_crit_not_f = 1

    	Last nh update is crit notf

    .. data:: bgp_nh_update_crit_sync = 2

    	Last nh update is crit sync update

    .. data:: bgp_nh_update_crit_rib_conv = 3

    	Last nh update is crit update caused by rib

    	converge

    .. data:: bgp_nh_update_crit_table_down = 4

    	Last nh update is crit update caused by table

    	down

    .. data:: bgp_nh_update_non_crit_not_f = 5

    	Last nh update is non-crit notf

    .. data:: bgp_nh_update_non_crit_sync = 6

    	Last nh update is non-crit sync update

    .. data:: bgp_nh_update_non_crit_rib_conv = 7

    	Last nh update is non-crit update caused by rib

    	converge

    .. data:: bgp_nh_update_non_crit_table_down = 8

    	Last nh update is non-crit update caused by

    	table down

    """

    bgp_nh_update_none = Enum.YLeaf(0, "bgp-nh-update-none")

    bgp_nh_update_crit_not_f = Enum.YLeaf(1, "bgp-nh-update-crit-not-f")

    bgp_nh_update_crit_sync = Enum.YLeaf(2, "bgp-nh-update-crit-sync")

    bgp_nh_update_crit_rib_conv = Enum.YLeaf(3, "bgp-nh-update-crit-rib-conv")

    bgp_nh_update_crit_table_down = Enum.YLeaf(4, "bgp-nh-update-crit-table-down")

    bgp_nh_update_non_crit_not_f = Enum.YLeaf(5, "bgp-nh-update-non-crit-not-f")

    bgp_nh_update_non_crit_sync = Enum.YLeaf(6, "bgp-nh-update-non-crit-sync")

    bgp_nh_update_non_crit_rib_conv = Enum.YLeaf(7, "bgp-nh-update-non-crit-rib-conv")

    bgp_nh_update_non_crit_table_down = Enum.YLeaf(8, "bgp-nh-update-non-crit-table-down")


class BgpNhValidate(Enum):
    """
    BgpNhValidate (Enum Class)

    Bgp nh validate

    .. data:: bgp_nh_validate_sync = 0

    	bgp nh validate sync

    .. data:: bgp_nh_validate_async = 1

    	bgp nh validate async

    .. data:: bgp_nh_validate_none = 2

    	bgp nh validate none

    """

    bgp_nh_validate_sync = Enum.YLeaf(0, "bgp-nh-validate-sync")

    bgp_nh_validate_async = Enum.YLeaf(1, "bgp-nh-validate-async")

    bgp_nh_validate_none = Enum.YLeaf(2, "bgp-nh-validate-none")


class BgpOpenCheckErr(Enum):
    """
    BgpOpenCheckErr (Enum Class)

    BGP open check error types

    .. data:: none = 0

    	No error

    .. data:: neighbor_down = 1

    	Neighbor down

    .. data:: no_update_group_set = 2

    	No update-group set

    .. data:: no_af_config = 3

    	No AF configured

    .. data:: update_group_pending = 4

    	Update-group pending

    .. data:: low_memory = 5

    	Low memory

    .. data:: neighbor_shutdown = 6

    	Neighbor shutdown

    .. data:: ebgp_neighbor_remote = 7

    	eBGP neighbor is remote

    .. data:: update_source_interface_null = 8

    	Update source invalid

    .. data:: no_ipv6_address = 9

    	No global IPv6 address found

    .. data:: first_hop_interface_null = 10

    	First-hop interface invalid

    .. data:: no_ipv6ll_address = 11

    	No LL IPv6 address found

    .. data:: no_update_source_config = 12

    	No update-source configured

    .. data:: no_router_id = 13

    	No router-identifier

    .. data:: update_source_interface_get_failed = 14

    	Update-source interface get failed

    .. data:: update_source_interface_state_get_failed = 15

    	Update-source interface state get failed

    .. data:: update_source_interface_down = 16

    	Update-source interface down

    .. data:: update_source_interface_ll_get_failed = 17

    	Update-source interface LL get failed

    .. data:: update_source_interface_address_get_failed = 18

    	Update-source interface address get failed

    .. data:: source_address_af_invalid = 19

    	Source-address AF invalid

    .. data:: no_update_source_ll_peering = 20

    	No update-source for LL peering

    .. data:: local_address_get_failed = 21

    	Local-address get failed

    .. data:: no_best_local_address = 22

    	No best local-address

    .. data:: neighbor_address_equals_local_address = 23

    	Neighbor address is local address

    .. data:: neighbor_closing = 24

    	Neighbor in closing state

    .. data:: neighbor_pending_reset = 25

    	Neighbor in pending reset state

    .. data:: out_interface_set_failed = 26

    	Out-interface set failed

    .. data:: local_address_mismatch = 27

    	Local-address mismatch

    .. data:: neighbor_active_only = 28

    	Neighbor in active only mode

    .. data:: socket_init_failed = 29

    	Socket init failed

    .. data:: socket_operation_failed = 30

    	Socket operation failed

    .. data:: local_neighbor = 31

    	Neighbor is local

    .. data:: multi_hop_neighbor = 32

    	No router to multi-hop neighbor

    """

    none = Enum.YLeaf(0, "none")

    neighbor_down = Enum.YLeaf(1, "neighbor-down")

    no_update_group_set = Enum.YLeaf(2, "no-update-group-set")

    no_af_config = Enum.YLeaf(3, "no-af-config")

    update_group_pending = Enum.YLeaf(4, "update-group-pending")

    low_memory = Enum.YLeaf(5, "low-memory")

    neighbor_shutdown = Enum.YLeaf(6, "neighbor-shutdown")

    ebgp_neighbor_remote = Enum.YLeaf(7, "ebgp-neighbor-remote")

    update_source_interface_null = Enum.YLeaf(8, "update-source-interface-null")

    no_ipv6_address = Enum.YLeaf(9, "no-ipv6-address")

    first_hop_interface_null = Enum.YLeaf(10, "first-hop-interface-null")

    no_ipv6ll_address = Enum.YLeaf(11, "no-ipv6ll-address")

    no_update_source_config = Enum.YLeaf(12, "no-update-source-config")

    no_router_id = Enum.YLeaf(13, "no-router-id")

    update_source_interface_get_failed = Enum.YLeaf(14, "update-source-interface-get-failed")

    update_source_interface_state_get_failed = Enum.YLeaf(15, "update-source-interface-state-get-failed")

    update_source_interface_down = Enum.YLeaf(16, "update-source-interface-down")

    update_source_interface_ll_get_failed = Enum.YLeaf(17, "update-source-interface-ll-get-failed")

    update_source_interface_address_get_failed = Enum.YLeaf(18, "update-source-interface-address-get-failed")

    source_address_af_invalid = Enum.YLeaf(19, "source-address-af-invalid")

    no_update_source_ll_peering = Enum.YLeaf(20, "no-update-source-ll-peering")

    local_address_get_failed = Enum.YLeaf(21, "local-address-get-failed")

    no_best_local_address = Enum.YLeaf(22, "no-best-local-address")

    neighbor_address_equals_local_address = Enum.YLeaf(23, "neighbor-address-equals-local-address")

    neighbor_closing = Enum.YLeaf(24, "neighbor-closing")

    neighbor_pending_reset = Enum.YLeaf(25, "neighbor-pending-reset")

    out_interface_set_failed = Enum.YLeaf(26, "out-interface-set-failed")

    local_address_mismatch = Enum.YLeaf(27, "local-address-mismatch")

    neighbor_active_only = Enum.YLeaf(28, "neighbor-active-only")

    socket_init_failed = Enum.YLeaf(29, "socket-init-failed")

    socket_operation_failed = Enum.YLeaf(30, "socket-operation-failed")

    local_neighbor = Enum.YLeaf(31, "local-neighbor")

    multi_hop_neighbor = Enum.YLeaf(32, "multi-hop-neighbor")


class BgpPeerResetReasonIndex(Enum):
    """
    BgpPeerResetReasonIndex (Enum Class)

    Bgp peer reset reason index

    .. data:: bgp_read_remote_closed = 1

    	Remote closed the session

    .. data:: bgp_read_failed = 2

    	Read failed

    .. data:: bgp_write_failed = 3

    	Write failed

    .. data:: bgp_sock_disconnected = 4

    	Socket disconnected

    .. data:: bgp_sock_select_failed = 5

    	Socket select failed

    .. data:: bgp_peer_reset_reason_none = 6

    	None

    """

    bgp_read_remote_closed = Enum.YLeaf(1, "bgp-read-remote-closed")

    bgp_read_failed = Enum.YLeaf(2, "bgp-read-failed")

    bgp_write_failed = Enum.YLeaf(3, "bgp-write-failed")

    bgp_sock_disconnected = Enum.YLeaf(4, "bgp-sock-disconnected")

    bgp_sock_select_failed = Enum.YLeaf(5, "bgp-sock-select-failed")

    bgp_peer_reset_reason_none = Enum.YLeaf(6, "bgp-peer-reset-reason-none")


class BgpPrefixSid(Enum):
    """
    BgpPrefixSid (Enum Class)

    Prefix SID type

    .. data:: prefix_sid_label_index = 1

    	Label index type

    .. data:: prefix_sid_ipv6_sid = 2

    	IPV6 SID type

    .. data:: prefix_sid_origin_at_or_srgb = 3

    	SRGB type

    .. data:: prefix_sid_srv6 = 4

    	SRV6 SID type

    """

    prefix_sid_label_index = Enum.YLeaf(1, "prefix-sid-label-index")

    prefix_sid_ipv6_sid = Enum.YLeaf(2, "prefix-sid-ipv6-sid")

    prefix_sid_origin_at_or_srgb = Enum.YLeaf(3, "prefix-sid-origin-at-or-srgb")

    prefix_sid_srv6 = Enum.YLeaf(4, "prefix-sid-srv6")


class BgpResetReasonIndex(Enum):
    """
    BgpResetReasonIndex (Enum Class)

    Bgp reset reason index

    .. data:: bgp_none = 0

    	None

    .. data:: bgp_init = 1

    	BGP neighbor initialized

    .. data:: bgp_no_memory = 2

    	No memory

    .. data:: not_received = 3

    	BGP Notification received

    .. data:: not_sent = 4

    	BGP Notification sent

    .. data:: conn_collision = 5

    	Error during connection collision

    .. data:: peer_closed = 6

    	Peer closing down the session

    .. data:: max_prefix_exceeded = 7

    	Peer exceeding maximum prefix limit

    .. data:: interface_flap = 8

    	Interface flap

    .. data:: neighbor_deleted = 9

    	Neighbor deleted

    .. data:: admin_shutdown = 10

    	Admin. shutdown

    .. data:: af_activated = 11

    	Address family activated

    .. data:: af_deactivated = 12

    	Address family removed

    .. data:: protocol_error = 13

    	Protocol Error

    .. data:: listen_closed = 14

    	Listen socket was closed

    .. data:: rib_failed = 15

    	Routing Table process not responding

    .. data:: user_clear = 16

    	User clear requested

    .. data:: user_clear_gr = 17

    	User clear with graceful restart requested

    .. data:: router_id_changed = 18

    	Router ID changed

    .. data:: remote_as_changed = 19

    	Remote AS configuration changed

    .. data:: orf_changed = 20

    	Outbound route filter configuration changed

    .. data:: rr_client_changed = 21

    	RR client configuration changed

    .. data:: legacy_pe_rt_changed = 22

    	Legacy-pe-RT configuration changed

    .. data:: softre_config_changed = 23

    	Soft reconfiguration configuration changed

    .. data:: local_as_changed = 24

    	Local AS configuration changed

    .. data:: low_memory = 25

    	Shutdown during SEVERE low memory condition

    .. data:: bfd_down = 26

    	BFD (Bidirectional forwarding detection)

    	session down

    .. data:: allow_as_in_changed = 27

    	Allowas-in configuration has changed

    .. data:: recv_dmz_cfg = 28

    	Recv DMZ Config changed

    .. data:: cap_4byteas_changed = 29

    	Capablity 4-byte-as configuration has changed

    .. data:: tcp_oper_down = 30

    	Received tcp oper down

    .. data:: scoped_sync_retry = 31

    	Scoped sync is repeated due to strict          

    	prefix check failure

    .. data:: cluster_id_changed = 32

    	Neighbor moved to a new cluster

    .. data:: rr_disable_changed = 33

    	Client-to-client reflection disabled/enabled   

    	for cluster to which neighbor belongs

    .. data:: aigp_changed = 34

    	AIGP configuration has changed                 

    	for cluster to which neighbor belongs

    .. data:: signalling_changed = 35

    	L2VPN Signalling Changed

    .. data:: open_check_s_failed = 36

    	Session open checks failed

    .. data:: ao_changed = 37

    	Accept-own changed

    .. data:: llgr_staletime_changed = 38

    	Long-lived graceful-restart stale-time

    	configuration changed

    .. data:: llgr_capable_changed = 39

    	Long-lived graceful-restart capable

    	configuration changed

    .. data:: nbr_local_addr_changed = 40

    	Neighbor local address configuration changed

    .. data:: internal_vpn_client_changed = 41

    	Internal-vpn-client configuration changed

    .. data:: cap_suppress_all_changed = 42

    	All capabilities suppression changed

    .. data:: next_hop_changed = 43

    	Next hop configuration changed

    """

    bgp_none = Enum.YLeaf(0, "bgp-none")

    bgp_init = Enum.YLeaf(1, "bgp-init")

    bgp_no_memory = Enum.YLeaf(2, "bgp-no-memory")

    not_received = Enum.YLeaf(3, "not-received")

    not_sent = Enum.YLeaf(4, "not-sent")

    conn_collision = Enum.YLeaf(5, "conn-collision")

    peer_closed = Enum.YLeaf(6, "peer-closed")

    max_prefix_exceeded = Enum.YLeaf(7, "max-prefix-exceeded")

    interface_flap = Enum.YLeaf(8, "interface-flap")

    neighbor_deleted = Enum.YLeaf(9, "neighbor-deleted")

    admin_shutdown = Enum.YLeaf(10, "admin-shutdown")

    af_activated = Enum.YLeaf(11, "af-activated")

    af_deactivated = Enum.YLeaf(12, "af-deactivated")

    protocol_error = Enum.YLeaf(13, "protocol-error")

    listen_closed = Enum.YLeaf(14, "listen-closed")

    rib_failed = Enum.YLeaf(15, "rib-failed")

    user_clear = Enum.YLeaf(16, "user-clear")

    user_clear_gr = Enum.YLeaf(17, "user-clear-gr")

    router_id_changed = Enum.YLeaf(18, "router-id-changed")

    remote_as_changed = Enum.YLeaf(19, "remote-as-changed")

    orf_changed = Enum.YLeaf(20, "orf-changed")

    rr_client_changed = Enum.YLeaf(21, "rr-client-changed")

    legacy_pe_rt_changed = Enum.YLeaf(22, "legacy-pe-rt-changed")

    softre_config_changed = Enum.YLeaf(23, "softre-config-changed")

    local_as_changed = Enum.YLeaf(24, "local-as-changed")

    low_memory = Enum.YLeaf(25, "low-memory")

    bfd_down = Enum.YLeaf(26, "bfd-down")

    allow_as_in_changed = Enum.YLeaf(27, "allow-as-in-changed")

    recv_dmz_cfg = Enum.YLeaf(28, "recv-dmz-cfg")

    cap_4byteas_changed = Enum.YLeaf(29, "cap-4byteas-changed")

    tcp_oper_down = Enum.YLeaf(30, "tcp-oper-down")

    scoped_sync_retry = Enum.YLeaf(31, "scoped-sync-retry")

    cluster_id_changed = Enum.YLeaf(32, "cluster-id-changed")

    rr_disable_changed = Enum.YLeaf(33, "rr-disable-changed")

    aigp_changed = Enum.YLeaf(34, "aigp-changed")

    signalling_changed = Enum.YLeaf(35, "signalling-changed")

    open_check_s_failed = Enum.YLeaf(36, "open-check-s-failed")

    ao_changed = Enum.YLeaf(37, "ao-changed")

    llgr_staletime_changed = Enum.YLeaf(38, "llgr-staletime-changed")

    llgr_capable_changed = Enum.YLeaf(39, "llgr-capable-changed")

    nbr_local_addr_changed = Enum.YLeaf(40, "nbr-local-addr-changed")

    internal_vpn_client_changed = Enum.YLeaf(41, "internal-vpn-client-changed")

    cap_suppress_all_changed = Enum.YLeaf(42, "cap-suppress-all-changed")

    next_hop_changed = Enum.YLeaf(43, "next-hop-changed")


class BgpRnhAddrLen(Enum):
    """
    BgpRnhAddrLen (Enum Class)

    BGP RNH Address Length

    .. data:: none = 0

    	NO address length

    .. data:: v4 = 4

    	IP v4 address length

    .. data:: mac = 6

    	MAC address length

    .. data:: v6 = 16

    	IP v6 address length

    """

    none = Enum.YLeaf(0, "none")

    v4 = Enum.YLeaf(4, "v4")

    mac = Enum.YLeaf(6, "mac")

    v6 = Enum.YLeaf(16, "v6")


class BgpRoute(Enum):
    """
    BgpRoute (Enum Class)

    Bgp route

    .. data:: used = 0

    	Used path from neighbor

    .. data:: received_only = 1

    	Received only path from neighbor

    .. data:: safi_labeled_unicast_used = 2

    	Used path from neighbor received via

    	labeled-unicast SAFI

    .. data:: safi_labeled_unicast_received_only = 3

    	Received only path from neighbor received via

    	labeled-unicast SAFI

    .. data:: rib = 4

    	Redistributed from the RIB

    .. data:: aggregate = 5

    	Locally generated aggregate

    """

    used = Enum.YLeaf(0, "used")

    received_only = Enum.YLeaf(1, "received-only")

    safi_labeled_unicast_used = Enum.YLeaf(2, "safi-labeled-unicast-used")

    safi_labeled_unicast_received_only = Enum.YLeaf(3, "safi-labeled-unicast-received-only")

    rib = Enum.YLeaf(4, "rib")

    aggregate = Enum.YLeaf(5, "aggregate")


class BgpRoute1(Enum):
    """
    BgpRoute1 (Enum Class)

    Bgp route1

    .. data:: bgp_route_type_used = 0

    	Used path from neighbor

    .. data:: bgp_route_type_rcvd_only = 1

    	Received only path from neighbor

    .. data:: bgp_route_type_safi_label_ed_ucast_used = 2

    	Used path from neighbor received via

    	labeled-unicast SAFI

    .. data:: bgp_route_type_safi_label_ed_ucast_rcvd_only = 3

    	Received only path from neighbor received via

    	labeled-unicast SAFI

    .. data:: bgp_route_type_rib = 4

    	Redistributed from the RIB

    .. data:: bgp_route_type_aggregate = 5

    	Locally generated aggregate

    .. data:: bgp_route_type_max = 6

    	Number of route types

    """

    bgp_route_type_used = Enum.YLeaf(0, "bgp-route-type-used")

    bgp_route_type_rcvd_only = Enum.YLeaf(1, "bgp-route-type-rcvd-only")

    bgp_route_type_safi_label_ed_ucast_used = Enum.YLeaf(2, "bgp-route-type-safi-label-ed-ucast-used")

    bgp_route_type_safi_label_ed_ucast_rcvd_only = Enum.YLeaf(3, "bgp-route-type-safi-label-ed-ucast-rcvd-only")

    bgp_route_type_rib = Enum.YLeaf(4, "bgp-route-type-rib")

    bgp_route_type_aggregate = Enum.YLeaf(5, "bgp-route-type-aggregate")

    bgp_route_type_max = Enum.YLeaf(6, "bgp-route-type-max")


class BgpRpkiAf(Enum):
    """
    BgpRpkiAf (Enum Class)

    Bgp rpki af

    .. data:: ipv4 = 2

    	IPv4

    .. data:: ipv6 = 26

    	IPv6

    """

    ipv4 = Enum.YLeaf(2, "ipv4")

    ipv6 = Enum.YLeaf(26, "ipv6")


class BgpRpkiCreason(Enum):
    """
    BgpRpkiCreason (Enum Class)

    Bgp rpki creason

    .. data:: no_close_reason = 0

    	No close reason

    .. data:: read_error = 1

    	Socket Read error

    .. data:: write_error = 2

    	Socket Write error

    .. data:: proto_error = 3

    	Protocol error

    .. data:: config_shutdown = 4

    	Shutdown by configuration

    .. data:: config_removed = 5

    	Configuration removed

    .. data:: config_changed = 6

    	Configuration changed

    .. data:: nsr_disabled = 7

    	NSR disabled

    .. data:: user_clear = 8

    	Explicity user clear

    .. data:: ssh_died = 9

    	SSH process died

    .. data:: tcp_died = 10

    	TCP process died

    """

    no_close_reason = Enum.YLeaf(0, "no-close-reason")

    read_error = Enum.YLeaf(1, "read-error")

    write_error = Enum.YLeaf(2, "write-error")

    proto_error = Enum.YLeaf(3, "proto-error")

    config_shutdown = Enum.YLeaf(4, "config-shutdown")

    config_removed = Enum.YLeaf(5, "config-removed")

    config_changed = Enum.YLeaf(6, "config-changed")

    nsr_disabled = Enum.YLeaf(7, "nsr-disabled")

    user_clear = Enum.YLeaf(8, "user-clear")

    ssh_died = Enum.YLeaf(9, "ssh-died")

    tcp_died = Enum.YLeaf(10, "tcp-died")


class BgpRpkiEdmAf(Enum):
    """
    BgpRpkiEdmAf (Enum Class)

    Bgp rpki edm af

    .. data:: ipv4 = 2

    	IPv4

    .. data:: ipv6 = 10

    	IPv6

    """

    ipv4 = Enum.YLeaf(2, "ipv4")

    ipv6 = Enum.YLeaf(10, "ipv6")


class BgpRpkiPerror(Enum):
    """
    BgpRpkiPerror (Enum Class)

    Bgp rpki perror

    .. data:: none = 0

    	No protocol error

    .. data:: message_version = 1

    	Message version error

    .. data:: message_type = 2

    	Message type error

    .. data:: message_length = 3

    	Message length error

    .. data:: nonce_mismatch = 4

    	Server nonce mismatch

    .. data:: bad_prefix = 5

    	Bad ROA

    .. data:: fsm = 6

    	FSM error

    .. data:: no_response = 7

    	No response from server

    .. data:: error_report = 8

    	Server sent error-report

    """

    none = Enum.YLeaf(0, "none")

    message_version = Enum.YLeaf(1, "message-version")

    message_type = Enum.YLeaf(2, "message-type")

    message_length = Enum.YLeaf(3, "message-length")

    nonce_mismatch = Enum.YLeaf(4, "nonce-mismatch")

    bad_prefix = Enum.YLeaf(5, "bad-prefix")

    fsm = Enum.YLeaf(6, "fsm")

    no_response = Enum.YLeaf(7, "no-response")

    error_report = Enum.YLeaf(8, "error-report")


class BgpRpkiPstate(Enum):
    """
    BgpRpkiPstate (Enum Class)

    Bgp rpki pstate

    .. data:: not_started = 0

    	Server protocol has not started

    .. data:: reset = 1

    	Server protocol reset

    .. data:: refresh = 2

    	Server protocol resumed

    .. data:: reset_query_sent = 3

    	Reset query sent to server

    .. data:: serial_query_sent = 4

    	Serial query sent to server

    .. data:: data_start = 5

    	Server started sending data

    .. data:: data_end = 6

    	Server ended sending data

    """

    not_started = Enum.YLeaf(0, "not-started")

    reset = Enum.YLeaf(1, "reset")

    refresh = Enum.YLeaf(2, "refresh")

    reset_query_sent = Enum.YLeaf(3, "reset-query-sent")

    serial_query_sent = Enum.YLeaf(4, "serial-query-sent")

    data_start = Enum.YLeaf(5, "data-start")

    data_end = Enum.YLeaf(6, "data-end")


class BgpRpkiState(Enum):
    """
    BgpRpkiState (Enum Class)

    Bgp rpki state

    .. data:: idle = 0

    	Server is idle

    .. data:: attempt_connect = 1

    	Connect attempt made to server

    .. data:: connected = 2

    	Server is connected

    """

    idle = Enum.YLeaf(0, "idle")

    attempt_connect = Enum.YLeaf(1, "attempt-connect")

    connected = Enum.YLeaf(2, "connected")


class BgpRtrState(Enum):
    """
    BgpRtrState (Enum Class)

    Bgp rtr state

    .. data:: bgp_router_read_only = 0

    	Read only mode

    .. data:: bgp_router_do_best_path = 1

    	Bestpath calculation mode

    .. data:: bgp_router_do_tunnel_update = 2

    	Tunnel update mode

    .. data:: bgp_router_do_import = 3

    	Import mode

    .. data:: bgp_router_do_label_alloc = 4

    	Label Allocation mode

    .. data:: bgp_router_do_ribupd = 5

    	RIB update mode

    .. data:: bgp_router_read_write = 6

    	Normal (read/write) mode

    .. data:: bgp_router_mode_count = 7

    	Number of router modes

    """

    bgp_router_read_only = Enum.YLeaf(0, "bgp-router-read-only")

    bgp_router_do_best_path = Enum.YLeaf(1, "bgp-router-do-best-path")

    bgp_router_do_tunnel_update = Enum.YLeaf(2, "bgp-router-do-tunnel-update")

    bgp_router_do_import = Enum.YLeaf(3, "bgp-router-do-import")

    bgp_router_do_label_alloc = Enum.YLeaf(4, "bgp-router-do-label-alloc")

    bgp_router_do_ribupd = Enum.YLeaf(5, "bgp-router-do-ribupd")

    bgp_router_read_write = Enum.YLeaf(6, "bgp-router-read-write")

    bgp_router_mode_count = Enum.YLeaf(7, "bgp-router-mode-count")


class BgpScopedSyncState(Enum):
    """
    BgpScopedSyncState (Enum Class)

    Bgp scoped sync state

    .. data:: bgp_scope_sync_state_none = 0

    	State none

    .. data:: bgp_scope_sync_state_not_nsr_ready = 1

    	Oper Down when NSR not ready

    .. data:: bgp_scope_sync_state_timer_start = 2

    	Timer started for active batch

    .. data:: bgp_scope_sync_state_add_list = 3

    	Start adding neighbors to pending batch

    .. data:: bgp_scope_sync_state_batch_acitve = 4

    	Active batch

    """

    bgp_scope_sync_state_none = Enum.YLeaf(0, "bgp-scope-sync-state-none")

    bgp_scope_sync_state_not_nsr_ready = Enum.YLeaf(1, "bgp-scope-sync-state-not-nsr-ready")

    bgp_scope_sync_state_timer_start = Enum.YLeaf(2, "bgp-scope-sync-state-timer-start")

    bgp_scope_sync_state_add_list = Enum.YLeaf(3, "bgp-scope-sync-state-add-list")

    bgp_scope_sync_state_batch_acitve = Enum.YLeaf(4, "bgp-scope-sync-state-batch-acitve")


class BgpSrpolicyReqState(Enum):
    """
    BgpSrpolicyReqState (Enum Class)

    BGP SR Policy Internal State

    .. data:: request_pending = 0

    	SR policy install in dataplane not requested

    	yet

    .. data:: requested = 1

    	Requested SR policy install  dataplane

    .. data:: notified_up = 2

    	SR policy is UP

    .. data:: notified_down = 4

    	SR policy is notified down by XTC

    .. data:: marked_stale = 8

    	SR policy is marked stale due to XTC agent down

    .. data:: marked_disable = 16

    	SR policy is marked disabled from the config in

    	XTC

    """

    request_pending = Enum.YLeaf(0, "request-pending")

    requested = Enum.YLeaf(1, "requested")

    notified_up = Enum.YLeaf(2, "notified-up")

    notified_down = Enum.YLeaf(4, "notified-down")

    marked_stale = Enum.YLeaf(8, "marked-stale")

    marked_disable = Enum.YLeaf(16, "marked-disable")


class BgpSyncNbrNsrState(Enum):
    """
    BgpSyncNbrNsrState (Enum Class)

    Bgp sync nbr nsr state

    .. data:: bgp_nbr_nsr_st_none = 0

    	None - ST 0

    .. data:: bgp_nbr_nsr_st_oper_down = 1

    	TCP OPER_DOWN notfn received - ST 1

    .. data:: bgp_nbr_nsr_st_tcp_init_sync = 2

    	TCP initial sync in progress - ST 2

    .. data:: bgp_nbr_nsr_st_tcp_phase_two = 3

    	TCP initial sync phase two in progress - ST 3

    .. data:: bgp_nbr_nsr_st_bgp_init_sync = 4

    	BGP initial sync in progress - ST 4

    .. data:: bgp_nbr_nsr_st_nsr_ready = 5

    	Neighbor NSR ready - ST 5

    """

    bgp_nbr_nsr_st_none = Enum.YLeaf(0, "bgp-nbr-nsr-st-none")

    bgp_nbr_nsr_st_oper_down = Enum.YLeaf(1, "bgp-nbr-nsr-st-oper-down")

    bgp_nbr_nsr_st_tcp_init_sync = Enum.YLeaf(2, "bgp-nbr-nsr-st-tcp-init-sync")

    bgp_nbr_nsr_st_tcp_phase_two = Enum.YLeaf(3, "bgp-nbr-nsr-st-tcp-phase-two")

    bgp_nbr_nsr_st_bgp_init_sync = Enum.YLeaf(4, "bgp-nbr-nsr-st-bgp-init-sync")

    bgp_nbr_nsr_st_nsr_ready = Enum.YLeaf(5, "bgp-nbr-nsr-st-nsr-ready")


class BgpTcpMode(Enum):
    """
    BgpTcpMode (Enum Class)

    Bgp tcp mode

    .. data:: bgp_tcp_mode_type_either = 0

    	Use either active or passive mode

    .. data:: bgp_tcp_mode_type_active_only = 1

    	Use active mode only

    .. data:: bgp_tcp_mode_type_passive_only = 2

    	Use passive mode only

    """

    bgp_tcp_mode_type_either = Enum.YLeaf(0, "bgp-tcp-mode-type-either")

    bgp_tcp_mode_type_active_only = Enum.YLeaf(1, "bgp-tcp-mode-type-active-only")

    bgp_tcp_mode_type_passive_only = Enum.YLeaf(2, "bgp-tcp-mode-type-passive-only")


class BgpTunnel(Enum):
    """
    BgpTunnel (Enum Class)

    BGP tunnel type

    .. data:: tunnel_none = 0

    	Tunnel not applicable

    .. data:: attrset = 1

    	Attribute set TE tunnel

    .. data:: sr_policy = 2

    	SR Policy

    .. data:: odn_policy = 4

    	ODN  color

    """

    tunnel_none = Enum.YLeaf(0, "tunnel-none")

    attrset = Enum.YLeaf(1, "attrset")

    sr_policy = Enum.YLeaf(2, "sr-policy")

    odn_policy = Enum.YLeaf(4, "odn-policy")


class BgpV4V6Len(Enum):
    """
    BgpV4V6Len (Enum Class)

    BGP GW Address Length

    .. data:: gwnone = 0

    	NO address length

    .. data:: gwipv4 = 4

    	IP v4 address length

    .. data:: gwipv6 = 16

    	IP v6 address length

    """

    gwnone = Enum.YLeaf(0, "gwnone")

    gwipv4 = Enum.YLeaf(4, "gwipv4")

    gwipv6 = Enum.YLeaf(16, "gwipv6")


class SrSid(Enum):
    """
    SrSid (Enum Class)

    Segment id type

    .. data:: label = 1

    	MPLS Label sid

    .. data:: ipv4 = 2

    	IPv4 address

    .. data:: ipv6 = 3

    	IPv6 address

    """

    label = Enum.YLeaf(1, "label")

    ipv4 = Enum.YLeaf(2, "ipv4")

    ipv6 = Enum.YLeaf(3, "ipv6")



class Bgp(Entity):
    """
    BGP operational data
    
    .. attribute:: config_instances
    
    	Instance specific BGP data
    	**type**\:  :py:class:`ConfigInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances>`
    
    .. attribute:: instances
    
    	Instance specific BGP data
    	**type**\:  :py:class:`Instances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances>`
    
    .. attribute:: bpm_instances_table
    
    	BGP instances information
    	**type**\:  :py:class:`BpmInstancesTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable>`
    
    

    """

    _prefix = 'ipv4-bgp-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(Bgp, self).__init__()
        self._top_entity = None

        self.yang_name = "bgp"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-bgp-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("config-instances", ("config_instances", Bgp.ConfigInstances)), ("instances", ("instances", Bgp.Instances)), ("bpm-instances-table", ("bpm_instances_table", Bgp.BpmInstancesTable))])
        self._leafs = OrderedDict()

        self.config_instances = Bgp.ConfigInstances()
        self.config_instances.parent = self
        self._children_name_map["config_instances"] = "config-instances"

        self.instances = Bgp.Instances()
        self.instances.parent = self
        self._children_name_map["instances"] = "instances"

        self.bpm_instances_table = Bgp.BpmInstancesTable()
        self.bpm_instances_table.parent = self
        self._children_name_map["bpm_instances_table"] = "bpm-instances-table"
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Bgp, [], name, value)


    class ConfigInstances(Entity):
        """
        Instance specific BGP data
        
        .. attribute:: config_instance
        
        	Instance specific BGP data
        	**type**\: list of  		 :py:class:`ConfigInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance>`
        
        

        """

        _prefix = 'ipv4-bgp-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Bgp.ConfigInstances, self).__init__()

            self.yang_name = "config-instances"
            self.yang_parent_name = "bgp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("config-instance", ("config_instance", Bgp.ConfigInstances.ConfigInstance))])
            self._leafs = OrderedDict()

            self.config_instance = YList(self)
            self._segment_path = lambda: "config-instances"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Bgp.ConfigInstances, [], name, value)


        class ConfigInstance(Entity):
            """
            Instance specific BGP data
            
            .. attribute:: instance_name  (key)
            
            	Name of the BGP instance
            	**type**\: str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: config_instance_default_vrf
            
            	Default VRF related configuration data
            	**type**\:  :py:class:`ConfigInstanceDefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf>`
            
            .. attribute:: config_vrfs
            
            	VRF related configuration data
            	**type**\:  :py:class:`ConfigVrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs>`
            
            

            """

            _prefix = 'ipv4-bgp-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Bgp.ConfigInstances.ConfigInstance, self).__init__()

                self.yang_name = "config-instance"
                self.yang_parent_name = "config-instances"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['instance_name']
                self._child_classes = OrderedDict([("config-instance-default-vrf", ("config_instance_default_vrf", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf)), ("config-vrfs", ("config_vrfs", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs))])
                self._leafs = OrderedDict([
                    ('instance_name', (YLeaf(YType.str, 'instance-name'), ['str'])),
                ])
                self.instance_name = None

                self.config_instance_default_vrf = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf()
                self.config_instance_default_vrf.parent = self
                self._children_name_map["config_instance_default_vrf"] = "config-instance-default-vrf"

                self.config_vrfs = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs()
                self.config_vrfs.parent = self
                self._children_name_map["config_vrfs"] = "config-vrfs"
                self._segment_path = lambda: "config-instance" + "[instance-name='" + str(self.instance_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/config-instances/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance, ['instance_name'], name, value)


            class ConfigInstanceDefaultVrf(Entity):
                """
                Default VRF related configuration data
                
                .. attribute:: entity_configurations
                
                	The BGP Entity Configuration table
                	**type**\:  :py:class:`EntityConfigurations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations>`
                
                .. attribute:: configuration_users
                
                	The BGP configuration users table
                	**type**\:  :py:class:`ConfigurationUsers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers>`
                
                .. attribute:: configuration_inheritances
                
                	The BGP configurataion inheritance table
                	**type**\:  :py:class:`ConfigurationInheritances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf, self).__init__()

                    self.yang_name = "config-instance-default-vrf"
                    self.yang_parent_name = "config-instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("entity-configurations", ("entity_configurations", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations)), ("configuration-users", ("configuration_users", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers)), ("configuration-inheritances", ("configuration_inheritances", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances))])
                    self._leafs = OrderedDict()

                    self.entity_configurations = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations()
                    self.entity_configurations.parent = self
                    self._children_name_map["entity_configurations"] = "entity-configurations"

                    self.configuration_users = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers()
                    self.configuration_users.parent = self
                    self._children_name_map["configuration_users"] = "configuration-users"

                    self.configuration_inheritances = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances()
                    self.configuration_inheritances.parent = self
                    self._children_name_map["configuration_inheritances"] = "configuration-inheritances"
                    self._segment_path = lambda: "config-instance-default-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf, [], name, value)


                class EntityConfigurations(Entity):
                    """
                    The BGP Entity Configuration table
                    
                    .. attribute:: entity_configuration
                    
                    	A BGP Entity Configuration table entry
                    	**type**\: list of  		 :py:class:`EntityConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations, self).__init__()

                        self.yang_name = "entity-configurations"
                        self.yang_parent_name = "config-instance-default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("entity-configuration", ("entity_configuration", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration))])
                        self._leafs = OrderedDict()

                        self.entity_configuration = YList(self)
                        self._segment_path = lambda: "entity-configurations"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations, [], name, value)


                    class EntityConfiguration(Entity):
                        """
                        A BGP Entity Configuration table entry
                        
                        .. attribute:: entity_type
                        
                        	Entity type
                        	**type**\:  :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: entity_name
                        
                        	Entity name
                        	**type**\: str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor Address
                        	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr>`
                        
                        .. attribute:: af_independent_config
                        
                        	AF\-independent config
                        	**type**\:  :py:class:`AfIndependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig>`
                        
                        .. attribute:: group_name
                        
                        	Entity/group name
                        	**type**\: str
                        
                        .. attribute:: configuration_type
                        
                        	Entity type
                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                        
                        .. attribute:: address_family_identifier
                        
                        	AF identifier
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: af_dependent_config
                        
                        	Af\-dependent config
                        	**type**\: list of  		 :py:class:`AfDependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration, self).__init__()

                            self.yang_name = "entity-configuration"
                            self.yang_parent_name = "entity-configurations"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr)), ("af-independent-config", ("af_independent_config", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig)), ("af-dependent-config", ("af_dependent_config", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig))])
                            self._leafs = OrderedDict([
                                ('entity_type', (YLeaf(YType.enumeration, 'entity-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntity', '')])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                ('entity_name', (YLeaf(YType.str, 'entity-name'), ['str'])),
                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                            ])
                            self.entity_type = None
                            self.neighbor_address = None
                            self.entity_name = None
                            self.group_name = None
                            self.configuration_type = None
                            self.address_family_identifier = None

                            self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr()
                            self.neighbor_address_xr.parent = self
                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                            self.af_independent_config = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig()
                            self.af_independent_config.parent = self
                            self._children_name_map["af_independent_config"] = "af-independent-config"

                            self.af_dependent_config = YList(self)
                            self._segment_path = lambda: "entity-configuration"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration, ['entity_type', 'neighbor_address', 'entity_name', u'group_name', u'configuration_type', u'address_family_identifier'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            Neighbor Address
                            
                            .. attribute:: l2vpn_vpls_address
                            
                            	L2VPN VPLS Addr
                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnVplsAddress>`
                            
                            .. attribute:: l2vpn_mspw_address
                            
                            	L2VPN MSPW Addr
                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnMspwAddress>`
                            
                            .. attribute:: ipv4_sr_policy_address
                            
                            	IPV4 Policy Addr
                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress>`
                            
                            .. attribute:: ipv6_sr_policy_address
                            
                            	IPV6 Policy Addr
                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress>`
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mcast_address
                            
                            	IPv4 Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_label_address
                            
                            	IPv4 Label Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_tunnel_address
                            
                            	IPv4 Tunnel
                            	**type**\: str
                            
                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4_mdt_address
                            
                            	IPv4 MDT Addr
                            	**type**\: str
                            
                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4vpn_address
                            
                            	IPv4 VPN Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4vpna_mcastddress
                            
                            	IPv4 VPN Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_mcast_address
                            
                            	IPV6 Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_label_address
                            
                            	IPv6 Label Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_address
                            
                            	IPv6 VPN Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_mcast_address
                            
                            	IPv6 VPN Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rt_constraint_address
                            
                            	RT Constrt Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{24}
                            
                            .. attribute:: ipv6mvpn_address
                            
                            	MVPN addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{104}
                            
                            .. attribute:: ipv4mvpn_address
                            
                            	MVPN4 addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{56}
                            
                            .. attribute:: l2vpn_evpn_address
                            
                            	L2VPN EVPN Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{58}
                            
                            .. attribute:: ls_ls_address
                            
                            	LINKSTATE LINKSTATE Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]+
                            
                            .. attribute:: ipv4_flowspec_address
                            
                            	IPV4 Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6_flowspec_address
                            
                            	IPV6 Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4vpn_flowspec_address
                            
                            	IPV4 VPN Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6vpn_flowspec_address
                            
                            	IPV6 VPN Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "entity-configuration"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                self._leafs = OrderedDict([
                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                ])
                                self.afi = None
                                self.ipv4_address = None
                                self.ipv4_mcast_address = None
                                self.ipv4_label_address = None
                                self.ipv4_tunnel_address = None
                                self.ipv4_mdt_address = None
                                self.ipv4vpn_address = None
                                self.ipv4vpna_mcastddress = None
                                self.ipv6_address = None
                                self.ipv6_mcast_address = None
                                self.ipv6_label_address = None
                                self.ipv6vpn_address = None
                                self.ipv6vpn_mcast_address = None
                                self.rt_constraint_address = None
                                self.ipv6mvpn_address = None
                                self.ipv4mvpn_address = None
                                self.l2vpn_evpn_address = None
                                self.ls_ls_address = None
                                self.ipv4_flowspec_address = None
                                self.ipv6_flowspec_address = None
                                self.ipv4vpn_flowspec_address = None
                                self.ipv6vpn_flowspec_address = None

                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnVplsAddress()
                                self.l2vpn_vpls_address.parent = self
                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnMspwAddress()
                                self.l2vpn_mspw_address.parent = self
                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress()
                                self.ipv4_sr_policy_address.parent = self
                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress()
                                self.ipv6_sr_policy_address.parent = self
                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                self._segment_path = lambda: "neighbor-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                            class L2vpnVplsAddress(Entity):
                                """
                                L2VPN VPLS Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                    self.yang_name = "l2vpn-vpls-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                    ])
                                    self.l2vpn_address = None
                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                            class L2vpnMspwAddress(Entity):
                                """
                                L2VPN MSPW Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                    self.yang_name = "l2vpn-mspw-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                    ])
                                    self.l2vpn_address = None
                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                            class Ipv4SrPolicyAddress(Entity):
                                """
                                IPV4 Policy Addr
                                
                                .. attribute:: ipv4_srpolicy_address
                                
                                	ipv4 srpolicy address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv4-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                    ])
                                    self.ipv4_srpolicy_address = None
                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                            class Ipv6SrPolicyAddress(Entity):
                                """
                                IPV6 Policy Addr
                                
                                .. attribute:: ipv6_srpolicy_address
                                
                                	ipv6 srpolicy address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv6-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                    ])
                                    self.ipv6_srpolicy_address = None
                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class AfIndependentConfig(Entity):
                            """
                            AF\-independent config
                            
                            .. attribute:: local_ip_address
                            
                            	Local ipv4 or ipv6 address for neighbor connection
                            	**type**\:  :py:class:`LocalIpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress>`
                            
                            .. attribute:: remote_as_info
                            
                            	Remote AS number item info
                            	**type**\:  :py:class:`RemoteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo>`
                            
                            .. attribute:: speaker_id_info
                            
                            	Configured speaker ID item info
                            	**type**\:  :py:class:`SpeakerIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo>`
                            
                            .. attribute:: min_advertisement_info
                            
                            	Minimum advertisement interval item info
                            	**type**\:  :py:class:`MinAdvertisementInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo>`
                            
                            .. attribute:: description_info
                            
                            	Description item info
                            	**type**\:  :py:class:`DescriptionInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo>`
                            
                            .. attribute:: ebgp_hop_count_info
                            
                            	EBGP neighbors hop count item info
                            	**type**\:  :py:class:`EbgpHopCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo>`
                            
                            .. attribute:: tcpmss_info
                            
                            	TCP Maximum Segment Size item info
                            	**type**\:  :py:class:`TcpmssInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo>`
                            
                            .. attribute:: bmp_servers_info
                            
                            	BMP Servers Configuredinfo
                            	**type**\:  :py:class:`BmpServersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo>`
                            
                            .. attribute:: keychain_info
                            
                            	Neighbor Keychain item info
                            	**type**\:  :py:class:`KeychainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo>`
                            
                            .. attribute:: local_as_info
                            
                            	Local AS number item info
                            	**type**\:  :py:class:`LocalAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo>`
                            
                            .. attribute:: password_info
                            
                            	Neighbor password item info
                            	**type**\:  :py:class:`PasswordInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo>`
                            
                            .. attribute:: receive_buffer_info
                            
                            	Receive buffer sizes item info
                            	**type**\:  :py:class:`ReceiveBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo>`
                            
                            .. attribute:: send_buffer_info
                            
                            	Send buffer sizes item info
                            	**type**\:  :py:class:`SendBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo>`
                            
                            .. attribute:: shutdown_info
                            
                            	Shutdown item info
                            	**type**\:  :py:class:`ShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo>`
                            
                            .. attribute:: timers_info
                            
                            	Timers item info
                            	**type**\:  :py:class:`TimersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo>`
                            
                            .. attribute:: local_address_info
                            
                            	Local address item info
                            	**type**\:  :py:class:`LocalAddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo>`
                            
                            .. attribute:: msg_log_in_info
                            
                            	Message Log Inbound item info
                            	**type**\:  :py:class:`MsgLogInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo>`
                            
                            .. attribute:: msg_log_out_info
                            
                            	Message Log Outbound item info
                            	**type**\:  :py:class:`MsgLogOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo>`
                            
                            .. attribute:: update_source_info
                            
                            	Update source item info
                            	**type**\:  :py:class:`UpdateSourceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo>`
                            
                            .. attribute:: dmz_link_bandwidth_info
                            
                            	DMZ link bandwidth item 
                            	**type**\:  :py:class:`DmzLinkBandwidthInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo>`
                            
                            .. attribute:: ebgp_recv_dmz_info
                            
                            	EBGP receive DMZ link bandwidth item info
                            	**type**\:  :py:class:`EbgpRecvDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo>`
                            
                            .. attribute:: ebgp_send_dmz_info
                            
                            	EBGP send DMZ link bandwidth item info
                            	**type**\:  :py:class:`EbgpSendDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo>`
                            
                            .. attribute:: ttl_security_info
                            
                            	BGP TTL Security item info
                            	**type**\:  :py:class:`TtlSecurityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo>`
                            
                            .. attribute:: suppress4_bbyte_as_info
                            
                            	BGP suppress 4byte\-as item info
                            	**type**\:  :py:class:`Suppress4BbyteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo>`
                            
                            .. attribute:: session_open_mode_info
                            
                            	TCP conn open mode info
                            	**type**\:  :py:class:`SessionOpenModeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo>`
                            
                            .. attribute:: bfd_info
                            
                            	BFD item info
                            	**type**\:  :py:class:`BfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo>`
                            
                            .. attribute:: bfd_mininterval_info
                            
                            	BFD Mininterval item info
                            	**type**\:  :py:class:`BfdMinintervalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo>`
                            
                            .. attribute:: bfd_multiplier_info
                            
                            	BFD Multiplier item info
                            	**type**\:  :py:class:`BfdMultiplierInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo>`
                            
                            .. attribute:: tos_info
                            
                            	TOS item info
                            	**type**\:  :py:class:`TosInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo>`
                            
                            .. attribute:: nsr_disabled_info
                            
                            	NSR item info
                            	**type**\:  :py:class:`NsrDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo>`
                            
                            .. attribute:: graceful_restart_disabled_info
                            
                            	Graceful\-restart item info
                            	**type**\:  :py:class:`GracefulRestartDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo>`
                            
                            .. attribute:: nbr_restart_time_info
                            
                            	Restart time item info
                            	**type**\:  :py:class:`NbrRestartTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo>`
                            
                            .. attribute:: nbr_stale_path_time_info
                            
                            	Stale\-path time item info
                            	**type**\:  :py:class:`NbrStalePathTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo>`
                            
                            .. attribute:: nbr_enforce_first_as_info
                            
                            	Neighbor enforce first AS info
                            	**type**\:  :py:class:`NbrEnforceFirstAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo>`
                            
                            .. attribute:: cluster_id_info
                            
                            	Cluster ID item info
                            	**type**\:  :py:class:`ClusterIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo>`
                            
                            .. attribute:: ignore_connected_info
                            
                            	Ignore Connected Info
                            	**type**\:  :py:class:`IgnoreConnectedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo>`
                            
                            .. attribute:: internal_vpn_client_info
                            
                            	Internal VPN Client Info
                            	**type**\:  :py:class:`InternalVpnClientInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo>`
                            
                            .. attribute:: addpath_send_capability_info
                            
                            	Addpath send capability info
                            	**type**\:  :py:class:`AddpathSendCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo>`
                            
                            .. attribute:: addpath_receive_capability_info
                            
                            	Addpath receive capability info
                            	**type**\:  :py:class:`AddpathReceiveCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo>`
                            
                            .. attribute:: egress_peer_engineering_info
                            
                            	Egress Peer Engineering info
                            	**type**\:  :py:class:`EgressPeerEngineeringInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo>`
                            
                            .. attribute:: update_error_handling_no_reset_info
                            
                            	Error\-handling avoid\-reset config info
                            	**type**\:  :py:class:`UpdateErrorHandlingNoResetInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo>`
                            
                            .. attribute:: prefix_validation_disable_info
                            
                            	RPKI disable info
                            	**type**\:  :py:class:`PrefixValidationDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo>`
                            
                            .. attribute:: prefix_validation_use_validit_info
                            
                            	RPKI use validity
                            	**type**\:  :py:class:`PrefixValidationUseValiditInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo>`
                            
                            .. attribute:: prefix_validation_allow_invalid_info
                            
                            	RPKI allow invalid info
                            	**type**\:  :py:class:`PrefixValidationAllowInvalidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo>`
                            
                            .. attribute:: prefix_validation_signal_ibgp_info
                            
                            	RPKI signal ibgp info
                            	**type**\:  :py:class:`PrefixValidationSignalIbgpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo>`
                            
                            .. attribute:: neighbor_update_filter_exists_info
                            
                            	Neighbor update filter configuration info
                            	**type**\:  :py:class:`NeighborUpdateFilterExistsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo>`
                            
                            .. attribute:: neighbor_update_filter_message_buffer_count_info
                            
                            	Neighbor update filter message buffer count info
                            	**type**\:  :py:class:`NeighborUpdateFilterMessageBufferCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo>`
                            
                            .. attribute:: neighbor_update_filter_syslog_disable_info
                            
                            	Neighbor update filter syslog disable info
                            	**type**\:  :py:class:`NeighborUpdateFilterSyslogDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo>`
                            
                            .. attribute:: neighbor_update_filter_attribute_info
                            
                            	Neighbor update filter attribute\-filter group info
                            	**type**\:  :py:class:`NeighborUpdateFilterAttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo>`
                            
                            .. attribute:: graceful_shutdown_info
                            
                            	GracefulShutdown info
                            	**type**\:  :py:class:`GracefulShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo>`
                            
                            .. attribute:: graceful_shutdown_loc_pref_info
                            
                            	GracefulShutdownLocPref info
                            	**type**\:  :py:class:`GracefulShutdownLocPrefInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo>`
                            
                            .. attribute:: graceful_shutdown_as_prepends_info
                            
                            	GracefulShutdownASPrepends info
                            	**type**\:  :py:class:`GracefulShutdownAsPrependsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo>`
                            
                            .. attribute:: graceful_shutdown_activate_info
                            
                            	GracefulShutdownAcivate info
                            	**type**\:  :py:class:`GracefulShutdownActivateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo>`
                            
                            .. attribute:: capability_negotiation_suppressed_info
                            
                            	Capability negotiation suppressed info
                            	**type**\:  :py:class:`CapabilityNegotiationSuppressedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo>`
                            
                            .. attribute:: neighbor_remote_as_list_info
                            
                            	Neighbor range  remote\-as\-list group info
                            	**type**\:  :py:class:`NeighborRemoteAsListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo>`
                            
                            .. attribute:: max_peers_info
                            
                            	Max dynamic nbrs in range info
                            	**type**\:  :py:class:`MaxPeersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo>`
                            
                            .. attribute:: idle_watch_time_info
                            
                            	Idle Watch time item info
                            	**type**\:  :py:class:`IdleWatchTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo>`
                            
                            .. attribute:: ao_keychain_info
                            
                            	Neighbor AO keychain item info
                            	**type**\:  :py:class:`AoKeychainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo>`
                            
                            .. attribute:: remote_as_number_xx
                            
                            	First half of Remote ASN
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_number_yy
                            
                            	Second half of Remote ASN
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_speaker_id
                            
                            	Configured speaker ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tcp_mss
                            
                            	Maximum Segment Size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_advertisement_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertisement_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\: str
                            
                            .. attribute:: ebgp_hop_count
                            
                            	EBGP neighbors hop count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bmp_servers
                            
                            	BMP Servers activated
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\: bool
                            
                            .. attribute:: keychain
                            
                            	Neighbor keychain Name
                            	**type**\: str
                            
                            .. attribute:: local_as_number_xx
                            
                            	First half of Local ASN
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_number_yy
                            
                            	Second half of Local ASN
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Local AS no\-prepend option
                            	**type**\: bool
                            
                            .. attribute:: password
                            
                            	Neighbor password
                            	**type**\: str
                            
                            .. attribute:: socket_buffer_receive_size
                            
                            	Socket receive buffer size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bgp_buffer_receive_size
                            
                            	BGP receive buffer size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: socket_buffer_send_size
                            
                            	Socket send buffer size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bgp_buffer_send_size
                            
                            	BGP send buffer size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adminstrative_shutdown
                            
                            	Administrative shutdown
                            	**type**\: bool
                            
                            .. attribute:: keepalive_interval
                            
                            	Keepalive interval
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: hold_time_value
                            
                            	Holdtime
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: min_acc_hold_time_value
                            
                            	Min acceptable holdtimefrom neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_in_buf_count
                            
                            	Message Log Inbound buffer count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out_buf_count
                            
                            	Message Log Outbound buffer count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_updates_source
                            
                            	Source of routing updates
                            	**type**\: str
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Propagate the DMZ link bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Send DMZ link bandwidthto ebgp peer
                            	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                            
                            .. attribute:: ttl_security
                            
                            	Enable BGP TTL Security
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress BGP 4byteas Cap
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: capability_negotiation_suppressed
                            
                            	Capability negotiation is suppressed
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: session_open_mode
                            
                            	TCP open mode to be used 
                            	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                            
                            .. attribute:: bfd
                            
                            	Fast failure detection using BFD
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_mininterval
                            
                            	BFD Minimum Interval
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplier
                            
                            	BFD Multiplier
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos_type_info
                            
                            	Precedence or DSCP type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value_info
                            
                            	Precedence or DSCP value
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_disabled
                            
                            	Support for NSR
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_restart_disabled
                            
                            	Support for graceful\-restart
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_restart_time
                            
                            	Restart time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nbr_stale_path_time
                            
                            	Stale\-path time(in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nbr_enforce_first_as_status
                            
                            	Neighbor enforce first AS status
                            	**type**\: bool
                            
                            .. attribute:: nbr_cluster_id_type_info
                            
                            	Cluster ID Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nbr_cluster_id_info
                            
                            	Cluster ID value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ignore_connected_check
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\: bool
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, the VPN client isan iBGP CE peer
                            	**type**\: bool
                            
                            .. attribute:: addpath_send_capability
                            
                            	Indicates if addpath send capability is enabled or disabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_error_handling_no_reset
                            
                            	Indicates if avoid\-reset behavior is enabled during update error\-handling
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: addpath_receive_capability
                            
                            	Indicates if addpath receive capability is enabled or disabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: egress_peer_engineering
                            
                            	Indicates egress peer engineering is enabled
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_validation_disable
                            
                            	Prefix validation disable
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bestpath_use_origin_as_validity
                            
                            	Bestpath Use Origin\-AS Va
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_validation_allow_invalid
                            
                            	Prefix validation allow invalid
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_validation_signal_ibgp
                            
                            	Prefix validation signal ibgp
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_update_filter_exists
                            
                            	Indicates if neighbor filter configuration exists
                            	**type**\: bool
                            
                            .. attribute:: neighbor_update_filter_message_buffer_count
                            
                            	Count of neighbor filter message buffers
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_update_filter_message_buffer_is_non_circular
                            
                            	Indicates if neighbor update filter message buffer is circular or not
                            	**type**\: bool
                            
                            .. attribute:: neighbor_update_filter_logging_disable
                            
                            	Indicates if neighbor filter logging is disabled
                            	**type**\: bool
                            
                            .. attribute:: neighbor_update_filter_attribute_filter_group_name
                            
                            	Neighbor filter attribute\-filter group name
                            	**type**\: str
                            
                            .. attribute:: graceful_shutdown_exists
                            
                            	re\-advertise all routes to and from this neighbor with the GSHUT community during Shutdown or bring\-up
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_loc_pref
                            
                            	Local Preference to advertise routes with during Graceful Shutdown to IBGP. Default=No Touch
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_as_prepends
                            
                            	Prepend the local AS this many times to the AS path of routes advertised during Graceful Shutdown
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_activate
                            
                            	Graceful Shutdown state is activated
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_remote_as_list_group_name
                            
                            	Neighbor Range remote\-as\-list group name
                            	**type**\: str
                            
                            .. attribute:: max_peers
                            
                            	Maximum dynamic nbrs in range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: idle_watch_time
                            
                            	Idle Watch time(in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: ao_keychain
                            
                            	Neighbor AO keychain name
                            	**type**\: str
                            
                            .. attribute:: ao_include_tcp_options
                            
                            	Include TCP options AO
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ao_accept_mismatch_connection
                            
                            	Accept AO mismatched connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\: bool
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig, self).__init__()

                                self.yang_name = "af-independent-config"
                                self.yang_parent_name = "entity-configuration"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("local-ip-address", ("local_ip_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress)), ("remote-as-info", ("remote_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo)), ("speaker-id-info", ("speaker_id_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo)), ("min-advertisement-info", ("min_advertisement_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo)), ("description-info", ("description_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo)), ("ebgp-hop-count-info", ("ebgp_hop_count_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo)), ("tcpmss-info", ("tcpmss_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo)), ("bmp-servers-info", ("bmp_servers_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo)), ("keychain-info", ("keychain_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo)), ("local-as-info", ("local_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo)), ("password-info", ("password_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo)), ("receive-buffer-info", ("receive_buffer_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo)), ("send-buffer-info", ("send_buffer_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo)), ("shutdown-info", ("shutdown_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo)), ("timers-info", ("timers_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo)), ("local-address-info", ("local_address_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo)), ("msg-log-in-info", ("msg_log_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo)), ("msg-log-out-info", ("msg_log_out_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo)), ("update-source-info", ("update_source_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo)), ("dmz-link-bandwidth-info", ("dmz_link_bandwidth_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo)), ("ebgp-recv-dmz-info", ("ebgp_recv_dmz_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo)), ("ebgp-send-dmz-info", ("ebgp_send_dmz_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo)), ("ttl-security-info", ("ttl_security_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo)), ("suppress4-bbyte-as-info", ("suppress4_bbyte_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo)), ("session-open-mode-info", ("session_open_mode_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo)), ("bfd-info", ("bfd_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo)), ("bfd-mininterval-info", ("bfd_mininterval_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo)), ("bfd-multiplier-info", ("bfd_multiplier_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo)), ("tos-info", ("tos_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo)), ("nsr-disabled-info", ("nsr_disabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo)), ("graceful-restart-disabled-info", ("graceful_restart_disabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo)), ("nbr-restart-time-info", ("nbr_restart_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo)), ("nbr-stale-path-time-info", ("nbr_stale_path_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo)), ("nbr-enforce-first-as-info", ("nbr_enforce_first_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo)), ("cluster-id-info", ("cluster_id_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo)), ("ignore-connected-info", ("ignore_connected_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo)), ("internal-vpn-client-info", ("internal_vpn_client_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo)), ("addpath-send-capability-info", ("addpath_send_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo)), ("addpath-receive-capability-info", ("addpath_receive_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo)), ("egress-peer-engineering-info", ("egress_peer_engineering_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo)), ("update-error-handling-no-reset-info", ("update_error_handling_no_reset_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo)), ("prefix-validation-disable-info", ("prefix_validation_disable_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo)), ("prefix-validation-use-validit-info", ("prefix_validation_use_validit_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo)), ("prefix-validation-allow-invalid-info", ("prefix_validation_allow_invalid_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo)), ("prefix-validation-signal-ibgp-info", ("prefix_validation_signal_ibgp_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo)), ("neighbor-update-filter-exists-info", ("neighbor_update_filter_exists_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo)), ("neighbor-update-filter-message-buffer-count-info", ("neighbor_update_filter_message_buffer_count_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo)), ("neighbor-update-filter-syslog-disable-info", ("neighbor_update_filter_syslog_disable_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo)), ("neighbor-update-filter-attribute-info", ("neighbor_update_filter_attribute_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo)), ("graceful-shutdown-info", ("graceful_shutdown_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo)), ("graceful-shutdown-loc-pref-info", ("graceful_shutdown_loc_pref_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo)), ("graceful-shutdown-as-prepends-info", ("graceful_shutdown_as_prepends_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo)), ("graceful-shutdown-activate-info", ("graceful_shutdown_activate_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo)), ("capability-negotiation-suppressed-info", ("capability_negotiation_suppressed_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo)), ("neighbor-remote-as-list-info", ("neighbor_remote_as_list_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo)), ("max-peers-info", ("max_peers_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo)), ("idle-watch-time-info", ("idle_watch_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo)), ("ao-keychain-info", ("ao_keychain_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo))])
                                self._leafs = OrderedDict([
                                    ('remote_as_number_xx', (YLeaf(YType.uint32, 'remote-as-number-xx'), ['int'])),
                                    ('remote_as_number_yy', (YLeaf(YType.uint32, 'remote-as-number-yy'), ['int'])),
                                    ('configured_speaker_id', (YLeaf(YType.uint32, 'configured-speaker-id'), ['int'])),
                                    ('tcp_mss', (YLeaf(YType.uint32, 'tcp-mss'), ['int'])),
                                    ('min_advertisement_interval', (YLeaf(YType.uint32, 'min-advertisement-interval'), ['int'])),
                                    ('min_advertisement_interval_msecs', (YLeaf(YType.uint32, 'min-advertisement-interval-msecs'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('ebgp_hop_count', (YLeaf(YType.uint32, 'ebgp-hop-count'), ['int'])),
                                    ('bmp_servers', (YLeaf(YType.uint32, 'bmp-servers'), ['int'])),
                                    ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                    ('keychain', (YLeaf(YType.str, 'keychain'), ['str'])),
                                    ('local_as_number_xx', (YLeaf(YType.uint32, 'local-as-number-xx'), ['int'])),
                                    ('local_as_number_yy', (YLeaf(YType.uint32, 'local-as-number-yy'), ['int'])),
                                    ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                    ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                    ('socket_buffer_receive_size', (YLeaf(YType.uint32, 'socket-buffer-receive-size'), ['int'])),
                                    ('bgp_buffer_receive_size', (YLeaf(YType.uint32, 'bgp-buffer-receive-size'), ['int'])),
                                    ('socket_buffer_send_size', (YLeaf(YType.uint32, 'socket-buffer-send-size'), ['int'])),
                                    ('bgp_buffer_send_size', (YLeaf(YType.uint32, 'bgp-buffer-send-size'), ['int'])),
                                    ('adminstrative_shutdown', (YLeaf(YType.boolean, 'adminstrative-shutdown'), ['bool'])),
                                    ('keepalive_interval', (YLeaf(YType.uint32, 'keepalive-interval'), ['int'])),
                                    ('hold_time_value', (YLeaf(YType.uint32, 'hold-time-value'), ['int'])),
                                    ('min_acc_hold_time_value', (YLeaf(YType.uint32, 'min-acc-hold-time-value'), ['int'])),
                                    ('msg_log_in_buf_count', (YLeaf(YType.uint32, 'msg-log-in-buf-count'), ['int'])),
                                    ('msg_log_out_buf_count', (YLeaf(YType.uint32, 'msg-log-out-buf-count'), ['int'])),
                                    ('route_updates_source', (YLeaf(YType.str, 'route-updates-source'), ['str'])),
                                    ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                    ('ebgp_recv_dmz', (YLeaf(YType.uint32, 'ebgp-recv-dmz'), ['int'])),
                                    ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                    ('ttl_security', (YLeaf(YType.uint32, 'ttl-security'), ['int'])),
                                    ('suppress4_byte_as', (YLeaf(YType.uint32, 'suppress4-byte-as'), ['int'])),
                                    ('capability_negotiation_suppressed', (YLeaf(YType.uint32, 'capability-negotiation-suppressed'), ['int'])),
                                    ('session_open_mode', (YLeaf(YType.enumeration, 'session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                    ('bfd', (YLeaf(YType.uint32, 'bfd'), ['int'])),
                                    ('bfd_mininterval', (YLeaf(YType.uint32, 'bfd-mininterval'), ['int'])),
                                    ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                    ('tos_type_info', (YLeaf(YType.uint8, 'tos-type-info'), ['int'])),
                                    ('tos_value_info', (YLeaf(YType.uint8, 'tos-value-info'), ['int'])),
                                    ('nsr_disabled', (YLeaf(YType.uint32, 'nsr-disabled'), ['int'])),
                                    ('graceful_restart_disabled', (YLeaf(YType.uint32, 'graceful-restart-disabled'), ['int'])),
                                    ('nbr_restart_time', (YLeaf(YType.uint32, 'nbr-restart-time'), ['int'])),
                                    ('nbr_stale_path_time', (YLeaf(YType.uint32, 'nbr-stale-path-time'), ['int'])),
                                    ('nbr_enforce_first_as_status', (YLeaf(YType.boolean, 'nbr-enforce-first-as-status'), ['bool'])),
                                    ('nbr_cluster_id_type_info', (YLeaf(YType.uint8, 'nbr-cluster-id-type-info'), ['int'])),
                                    ('nbr_cluster_id_info', (YLeaf(YType.uint32, 'nbr-cluster-id-info'), ['int'])),
                                    ('ignore_connected_check', (YLeaf(YType.boolean, 'ignore-connected-check'), ['bool'])),
                                    ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                    ('addpath_send_capability', (YLeaf(YType.uint32, 'addpath-send-capability'), ['int'])),
                                    ('update_error_handling_no_reset', (YLeaf(YType.uint32, 'update-error-handling-no-reset'), ['int'])),
                                    ('addpath_receive_capability', (YLeaf(YType.uint32, 'addpath-receive-capability'), ['int'])),
                                    ('egress_peer_engineering', (YLeaf(YType.uint32, 'egress-peer-engineering'), ['int'])),
                                    ('prefix_validation_disable', (YLeaf(YType.uint32, 'prefix-validation-disable'), ['int'])),
                                    ('bestpath_use_origin_as_validity', (YLeaf(YType.uint32, 'bestpath-use-origin-as-validity'), ['int'])),
                                    ('prefix_validation_allow_invalid', (YLeaf(YType.uint32, 'prefix-validation-allow-invalid'), ['int'])),
                                    ('prefix_validation_signal_ibgp', (YLeaf(YType.uint32, 'prefix-validation-signal-ibgp'), ['int'])),
                                    ('neighbor_update_filter_exists', (YLeaf(YType.boolean, 'neighbor-update-filter-exists'), ['bool'])),
                                    ('neighbor_update_filter_message_buffer_count', (YLeaf(YType.uint32, 'neighbor-update-filter-message-buffer-count'), ['int'])),
                                    ('neighbor_update_filter_message_buffer_is_non_circular', (YLeaf(YType.boolean, 'neighbor-update-filter-message-buffer-is-non-circular'), ['bool'])),
                                    ('neighbor_update_filter_logging_disable', (YLeaf(YType.boolean, 'neighbor-update-filter-logging-disable'), ['bool'])),
                                    ('neighbor_update_filter_attribute_filter_group_name', (YLeaf(YType.str, 'neighbor-update-filter-attribute-filter-group-name'), ['str'])),
                                    ('graceful_shutdown_exists', (YLeaf(YType.uint32, 'graceful-shutdown-exists'), ['int'])),
                                    ('graceful_shutdown_loc_pref', (YLeaf(YType.uint32, 'graceful-shutdown-loc-pref'), ['int'])),
                                    ('graceful_shutdown_as_prepends', (YLeaf(YType.uint32, 'graceful-shutdown-as-prepends'), ['int'])),
                                    ('graceful_shutdown_activate', (YLeaf(YType.uint32, 'graceful-shutdown-activate'), ['int'])),
                                    ('neighbor_remote_as_list_group_name', (YLeaf(YType.str, 'neighbor-remote-as-list-group-name'), ['str'])),
                                    ('max_peers', (YLeaf(YType.uint32, 'max-peers'), ['int'])),
                                    ('idle_watch_time', (YLeaf(YType.uint32, 'idle-watch-time'), ['int'])),
                                    ('ao_keychain', (YLeaf(YType.str, 'ao-keychain'), ['str'])),
                                    ('ao_include_tcp_options', (YLeaf(YType.uint32, 'ao-include-tcp-options'), ['int'])),
                                    ('ao_accept_mismatch_connection', (YLeaf(YType.uint32, 'ao-accept-mismatch-connection'), ['int'])),
                                    ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                    ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                ])
                                self.remote_as_number_xx = None
                                self.remote_as_number_yy = None
                                self.configured_speaker_id = None
                                self.tcp_mss = None
                                self.min_advertisement_interval = None
                                self.min_advertisement_interval_msecs = None
                                self.description = None
                                self.ebgp_hop_count = None
                                self.bmp_servers = None
                                self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                self.keychain = None
                                self.local_as_number_xx = None
                                self.local_as_number_yy = None
                                self.local_as_no_prepend = None
                                self.password = None
                                self.socket_buffer_receive_size = None
                                self.bgp_buffer_receive_size = None
                                self.socket_buffer_send_size = None
                                self.bgp_buffer_send_size = None
                                self.adminstrative_shutdown = None
                                self.keepalive_interval = None
                                self.hold_time_value = None
                                self.min_acc_hold_time_value = None
                                self.msg_log_in_buf_count = None
                                self.msg_log_out_buf_count = None
                                self.route_updates_source = None
                                self.dmz_link_bandwidth = None
                                self.ebgp_recv_dmz = None
                                self.ebgp_send_dmz_mode = None
                                self.ttl_security = None
                                self.suppress4_byte_as = None
                                self.capability_negotiation_suppressed = None
                                self.session_open_mode = None
                                self.bfd = None
                                self.bfd_mininterval = None
                                self.bfd_multiplier = None
                                self.tos_type_info = None
                                self.tos_value_info = None
                                self.nsr_disabled = None
                                self.graceful_restart_disabled = None
                                self.nbr_restart_time = None
                                self.nbr_stale_path_time = None
                                self.nbr_enforce_first_as_status = None
                                self.nbr_cluster_id_type_info = None
                                self.nbr_cluster_id_info = None
                                self.ignore_connected_check = None
                                self.internal_vpn_client = None
                                self.addpath_send_capability = None
                                self.update_error_handling_no_reset = None
                                self.addpath_receive_capability = None
                                self.egress_peer_engineering = None
                                self.prefix_validation_disable = None
                                self.bestpath_use_origin_as_validity = None
                                self.prefix_validation_allow_invalid = None
                                self.prefix_validation_signal_ibgp = None
                                self.neighbor_update_filter_exists = None
                                self.neighbor_update_filter_message_buffer_count = None
                                self.neighbor_update_filter_message_buffer_is_non_circular = None
                                self.neighbor_update_filter_logging_disable = None
                                self.neighbor_update_filter_attribute_filter_group_name = None
                                self.graceful_shutdown_exists = None
                                self.graceful_shutdown_loc_pref = None
                                self.graceful_shutdown_as_prepends = None
                                self.graceful_shutdown_activate = None
                                self.neighbor_remote_as_list_group_name = None
                                self.max_peers = None
                                self.idle_watch_time = None
                                self.ao_keychain = None
                                self.ao_include_tcp_options = None
                                self.ao_accept_mismatch_connection = None
                                self.local_as_replace_as = None
                                self.local_as_dual_as = None

                                self.local_ip_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress()
                                self.local_ip_address.parent = self
                                self._children_name_map["local_ip_address"] = "local-ip-address"

                                self.remote_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo()
                                self.remote_as_info.parent = self
                                self._children_name_map["remote_as_info"] = "remote-as-info"

                                self.speaker_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo()
                                self.speaker_id_info.parent = self
                                self._children_name_map["speaker_id_info"] = "speaker-id-info"

                                self.min_advertisement_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo()
                                self.min_advertisement_info.parent = self
                                self._children_name_map["min_advertisement_info"] = "min-advertisement-info"

                                self.description_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo()
                                self.description_info.parent = self
                                self._children_name_map["description_info"] = "description-info"

                                self.ebgp_hop_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo()
                                self.ebgp_hop_count_info.parent = self
                                self._children_name_map["ebgp_hop_count_info"] = "ebgp-hop-count-info"

                                self.tcpmss_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo()
                                self.tcpmss_info.parent = self
                                self._children_name_map["tcpmss_info"] = "tcpmss-info"

                                self.bmp_servers_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo()
                                self.bmp_servers_info.parent = self
                                self._children_name_map["bmp_servers_info"] = "bmp-servers-info"

                                self.keychain_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo()
                                self.keychain_info.parent = self
                                self._children_name_map["keychain_info"] = "keychain-info"

                                self.local_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo()
                                self.local_as_info.parent = self
                                self._children_name_map["local_as_info"] = "local-as-info"

                                self.password_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo()
                                self.password_info.parent = self
                                self._children_name_map["password_info"] = "password-info"

                                self.receive_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo()
                                self.receive_buffer_info.parent = self
                                self._children_name_map["receive_buffer_info"] = "receive-buffer-info"

                                self.send_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo()
                                self.send_buffer_info.parent = self
                                self._children_name_map["send_buffer_info"] = "send-buffer-info"

                                self.shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo()
                                self.shutdown_info.parent = self
                                self._children_name_map["shutdown_info"] = "shutdown-info"

                                self.timers_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo()
                                self.timers_info.parent = self
                                self._children_name_map["timers_info"] = "timers-info"

                                self.local_address_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo()
                                self.local_address_info.parent = self
                                self._children_name_map["local_address_info"] = "local-address-info"

                                self.msg_log_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo()
                                self.msg_log_in_info.parent = self
                                self._children_name_map["msg_log_in_info"] = "msg-log-in-info"

                                self.msg_log_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo()
                                self.msg_log_out_info.parent = self
                                self._children_name_map["msg_log_out_info"] = "msg-log-out-info"

                                self.update_source_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo()
                                self.update_source_info.parent = self
                                self._children_name_map["update_source_info"] = "update-source-info"

                                self.dmz_link_bandwidth_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo()
                                self.dmz_link_bandwidth_info.parent = self
                                self._children_name_map["dmz_link_bandwidth_info"] = "dmz-link-bandwidth-info"

                                self.ebgp_recv_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo()
                                self.ebgp_recv_dmz_info.parent = self
                                self._children_name_map["ebgp_recv_dmz_info"] = "ebgp-recv-dmz-info"

                                self.ebgp_send_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo()
                                self.ebgp_send_dmz_info.parent = self
                                self._children_name_map["ebgp_send_dmz_info"] = "ebgp-send-dmz-info"

                                self.ttl_security_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo()
                                self.ttl_security_info.parent = self
                                self._children_name_map["ttl_security_info"] = "ttl-security-info"

                                self.suppress4_bbyte_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo()
                                self.suppress4_bbyte_as_info.parent = self
                                self._children_name_map["suppress4_bbyte_as_info"] = "suppress4-bbyte-as-info"

                                self.session_open_mode_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo()
                                self.session_open_mode_info.parent = self
                                self._children_name_map["session_open_mode_info"] = "session-open-mode-info"

                                self.bfd_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo()
                                self.bfd_info.parent = self
                                self._children_name_map["bfd_info"] = "bfd-info"

                                self.bfd_mininterval_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo()
                                self.bfd_mininterval_info.parent = self
                                self._children_name_map["bfd_mininterval_info"] = "bfd-mininterval-info"

                                self.bfd_multiplier_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo()
                                self.bfd_multiplier_info.parent = self
                                self._children_name_map["bfd_multiplier_info"] = "bfd-multiplier-info"

                                self.tos_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo()
                                self.tos_info.parent = self
                                self._children_name_map["tos_info"] = "tos-info"

                                self.nsr_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo()
                                self.nsr_disabled_info.parent = self
                                self._children_name_map["nsr_disabled_info"] = "nsr-disabled-info"

                                self.graceful_restart_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo()
                                self.graceful_restart_disabled_info.parent = self
                                self._children_name_map["graceful_restart_disabled_info"] = "graceful-restart-disabled-info"

                                self.nbr_restart_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo()
                                self.nbr_restart_time_info.parent = self
                                self._children_name_map["nbr_restart_time_info"] = "nbr-restart-time-info"

                                self.nbr_stale_path_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo()
                                self.nbr_stale_path_time_info.parent = self
                                self._children_name_map["nbr_stale_path_time_info"] = "nbr-stale-path-time-info"

                                self.nbr_enforce_first_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo()
                                self.nbr_enforce_first_as_info.parent = self
                                self._children_name_map["nbr_enforce_first_as_info"] = "nbr-enforce-first-as-info"

                                self.cluster_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo()
                                self.cluster_id_info.parent = self
                                self._children_name_map["cluster_id_info"] = "cluster-id-info"

                                self.ignore_connected_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo()
                                self.ignore_connected_info.parent = self
                                self._children_name_map["ignore_connected_info"] = "ignore-connected-info"

                                self.internal_vpn_client_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo()
                                self.internal_vpn_client_info.parent = self
                                self._children_name_map["internal_vpn_client_info"] = "internal-vpn-client-info"

                                self.addpath_send_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo()
                                self.addpath_send_capability_info.parent = self
                                self._children_name_map["addpath_send_capability_info"] = "addpath-send-capability-info"

                                self.addpath_receive_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo()
                                self.addpath_receive_capability_info.parent = self
                                self._children_name_map["addpath_receive_capability_info"] = "addpath-receive-capability-info"

                                self.egress_peer_engineering_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo()
                                self.egress_peer_engineering_info.parent = self
                                self._children_name_map["egress_peer_engineering_info"] = "egress-peer-engineering-info"

                                self.update_error_handling_no_reset_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo()
                                self.update_error_handling_no_reset_info.parent = self
                                self._children_name_map["update_error_handling_no_reset_info"] = "update-error-handling-no-reset-info"

                                self.prefix_validation_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo()
                                self.prefix_validation_disable_info.parent = self
                                self._children_name_map["prefix_validation_disable_info"] = "prefix-validation-disable-info"

                                self.prefix_validation_use_validit_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo()
                                self.prefix_validation_use_validit_info.parent = self
                                self._children_name_map["prefix_validation_use_validit_info"] = "prefix-validation-use-validit-info"

                                self.prefix_validation_allow_invalid_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo()
                                self.prefix_validation_allow_invalid_info.parent = self
                                self._children_name_map["prefix_validation_allow_invalid_info"] = "prefix-validation-allow-invalid-info"

                                self.prefix_validation_signal_ibgp_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo()
                                self.prefix_validation_signal_ibgp_info.parent = self
                                self._children_name_map["prefix_validation_signal_ibgp_info"] = "prefix-validation-signal-ibgp-info"

                                self.neighbor_update_filter_exists_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo()
                                self.neighbor_update_filter_exists_info.parent = self
                                self._children_name_map["neighbor_update_filter_exists_info"] = "neighbor-update-filter-exists-info"

                                self.neighbor_update_filter_message_buffer_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo()
                                self.neighbor_update_filter_message_buffer_count_info.parent = self
                                self._children_name_map["neighbor_update_filter_message_buffer_count_info"] = "neighbor-update-filter-message-buffer-count-info"

                                self.neighbor_update_filter_syslog_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo()
                                self.neighbor_update_filter_syslog_disable_info.parent = self
                                self._children_name_map["neighbor_update_filter_syslog_disable_info"] = "neighbor-update-filter-syslog-disable-info"

                                self.neighbor_update_filter_attribute_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo()
                                self.neighbor_update_filter_attribute_info.parent = self
                                self._children_name_map["neighbor_update_filter_attribute_info"] = "neighbor-update-filter-attribute-info"

                                self.graceful_shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo()
                                self.graceful_shutdown_info.parent = self
                                self._children_name_map["graceful_shutdown_info"] = "graceful-shutdown-info"

                                self.graceful_shutdown_loc_pref_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo()
                                self.graceful_shutdown_loc_pref_info.parent = self
                                self._children_name_map["graceful_shutdown_loc_pref_info"] = "graceful-shutdown-loc-pref-info"

                                self.graceful_shutdown_as_prepends_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo()
                                self.graceful_shutdown_as_prepends_info.parent = self
                                self._children_name_map["graceful_shutdown_as_prepends_info"] = "graceful-shutdown-as-prepends-info"

                                self.graceful_shutdown_activate_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo()
                                self.graceful_shutdown_activate_info.parent = self
                                self._children_name_map["graceful_shutdown_activate_info"] = "graceful-shutdown-activate-info"

                                self.capability_negotiation_suppressed_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo()
                                self.capability_negotiation_suppressed_info.parent = self
                                self._children_name_map["capability_negotiation_suppressed_info"] = "capability-negotiation-suppressed-info"

                                self.neighbor_remote_as_list_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo()
                                self.neighbor_remote_as_list_info.parent = self
                                self._children_name_map["neighbor_remote_as_list_info"] = "neighbor-remote-as-list-info"

                                self.max_peers_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo()
                                self.max_peers_info.parent = self
                                self._children_name_map["max_peers_info"] = "max-peers-info"

                                self.idle_watch_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo()
                                self.idle_watch_time_info.parent = self
                                self._children_name_map["idle_watch_time_info"] = "idle-watch-time-info"

                                self.ao_keychain_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo()
                                self.ao_keychain_info.parent = self
                                self._children_name_map["ao_keychain_info"] = "ao-keychain-info"
                                self._segment_path = lambda: "af-independent-config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig, [u'remote_as_number_xx', u'remote_as_number_yy', u'configured_speaker_id', u'tcp_mss', u'min_advertisement_interval', u'min_advertisement_interval_msecs', u'description', u'ebgp_hop_count', u'bmp_servers', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'keychain', u'local_as_number_xx', u'local_as_number_yy', u'local_as_no_prepend', u'password', u'socket_buffer_receive_size', u'bgp_buffer_receive_size', u'socket_buffer_send_size', u'bgp_buffer_send_size', u'adminstrative_shutdown', u'keepalive_interval', u'hold_time_value', u'min_acc_hold_time_value', u'msg_log_in_buf_count', u'msg_log_out_buf_count', u'route_updates_source', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'ttl_security', u'suppress4_byte_as', u'capability_negotiation_suppressed', u'session_open_mode', u'bfd', u'bfd_mininterval', u'bfd_multiplier', u'tos_type_info', u'tos_value_info', u'nsr_disabled', u'graceful_restart_disabled', u'nbr_restart_time', u'nbr_stale_path_time', u'nbr_enforce_first_as_status', u'nbr_cluster_id_type_info', u'nbr_cluster_id_info', u'ignore_connected_check', u'internal_vpn_client', u'addpath_send_capability', u'update_error_handling_no_reset', u'addpath_receive_capability', u'egress_peer_engineering', u'prefix_validation_disable', u'bestpath_use_origin_as_validity', u'prefix_validation_allow_invalid', u'prefix_validation_signal_ibgp', u'neighbor_update_filter_exists', u'neighbor_update_filter_message_buffer_count', u'neighbor_update_filter_message_buffer_is_non_circular', u'neighbor_update_filter_logging_disable', u'neighbor_update_filter_attribute_filter_group_name', u'graceful_shutdown_exists', u'graceful_shutdown_loc_pref', u'graceful_shutdown_as_prepends', u'graceful_shutdown_activate', u'neighbor_remote_as_list_group_name', u'max_peers', u'idle_watch_time', u'ao_keychain', u'ao_include_tcp_options', u'ao_accept_mismatch_connection', u'local_as_replace_as', u'local_as_dual_as'], name, value)


                            class LocalIpAddress(Entity):
                                """
                                Local ipv4 or ipv6 address for neighbor
                                connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress, self).__init__()

                                    self.yang_name = "local-ip-address"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "local-ip-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "local-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "local-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "local-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "local-ip-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class RemoteAsInfo(Entity):
                                """
                                Remote AS number item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo, self).__init__()

                                    self.yang_name = "remote-as-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "remote-as-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "remote-as-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SpeakerIdInfo(Entity):
                                """
                                Configured speaker ID item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo, self).__init__()

                                    self.yang_name = "speaker-id-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "speaker-id-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "speaker-id-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class MinAdvertisementInfo(Entity):
                                """
                                Minimum advertisement interval item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo, self).__init__()

                                    self.yang_name = "min-advertisement-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "min-advertisement-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "min-advertisement-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class DescriptionInfo(Entity):
                                """
                                Description item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo, self).__init__()

                                    self.yang_name = "description-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "description-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "description-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class EbgpHopCountInfo(Entity):
                                """
                                EBGP neighbors hop count item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo, self).__init__()

                                    self.yang_name = "ebgp-hop-count-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "ebgp-hop-count-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "ebgp-hop-count-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class TcpmssInfo(Entity):
                                """
                                TCP Maximum Segment Size item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo, self).__init__()

                                    self.yang_name = "tcpmss-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "tcpmss-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "tcpmss-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class BmpServersInfo(Entity):
                                """
                                BMP Servers Configuredinfo
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo, self).__init__()

                                    self.yang_name = "bmp-servers-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "bmp-servers-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "bmp-servers-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class KeychainInfo(Entity):
                                """
                                Neighbor Keychain item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo, self).__init__()

                                    self.yang_name = "keychain-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "keychain-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "keychain-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class LocalAsInfo(Entity):
                                """
                                Local AS number item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo, self).__init__()

                                    self.yang_name = "local-as-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "local-as-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "local-as-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class PasswordInfo(Entity):
                                """
                                Neighbor password item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo, self).__init__()

                                    self.yang_name = "password-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "password-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "password-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ReceiveBufferInfo(Entity):
                                """
                                Receive buffer sizes item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo, self).__init__()

                                    self.yang_name = "receive-buffer-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "receive-buffer-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "receive-buffer-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SendBufferInfo(Entity):
                                """
                                Send buffer sizes item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo, self).__init__()

                                    self.yang_name = "send-buffer-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "send-buffer-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "send-buffer-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ShutdownInfo(Entity):
                                """
                                Shutdown item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo, self).__init__()

                                    self.yang_name = "shutdown-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "shutdown-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "shutdown-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class TimersInfo(Entity):
                                """
                                Timers item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo, self).__init__()

                                    self.yang_name = "timers-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "timers-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "timers-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class LocalAddressInfo(Entity):
                                """
                                Local address item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo, self).__init__()

                                    self.yang_name = "local-address-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "local-address-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "local-address-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class MsgLogInInfo(Entity):
                                """
                                Message Log Inbound item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo, self).__init__()

                                    self.yang_name = "msg-log-in-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "msg-log-in-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "msg-log-in-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class MsgLogOutInfo(Entity):
                                """
                                Message Log Outbound item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo, self).__init__()

                                    self.yang_name = "msg-log-out-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "msg-log-out-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "msg-log-out-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class UpdateSourceInfo(Entity):
                                """
                                Update source item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo, self).__init__()

                                    self.yang_name = "update-source-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "update-source-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "update-source-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class DmzLinkBandwidthInfo(Entity):
                                """
                                DMZ link bandwidth item 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo, self).__init__()

                                    self.yang_name = "dmz-link-bandwidth-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "dmz-link-bandwidth-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "dmz-link-bandwidth-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class EbgpRecvDmzInfo(Entity):
                                """
                                EBGP receive DMZ link bandwidth item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo, self).__init__()

                                    self.yang_name = "ebgp-recv-dmz-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "ebgp-recv-dmz-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "ebgp-recv-dmz-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class EbgpSendDmzInfo(Entity):
                                """
                                EBGP send DMZ link bandwidth item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo, self).__init__()

                                    self.yang_name = "ebgp-send-dmz-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "ebgp-send-dmz-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "ebgp-send-dmz-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class TtlSecurityInfo(Entity):
                                """
                                BGP TTL Security item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo, self).__init__()

                                    self.yang_name = "ttl-security-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "ttl-security-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "ttl-security-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class Suppress4BbyteAsInfo(Entity):
                                """
                                BGP suppress 4byte\-as item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo, self).__init__()

                                    self.yang_name = "suppress4-bbyte-as-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "suppress4-bbyte-as-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "suppress4-bbyte-as-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SessionOpenModeInfo(Entity):
                                """
                                TCP conn open mode info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo, self).__init__()

                                    self.yang_name = "session-open-mode-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "session-open-mode-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "session-open-mode-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class BfdInfo(Entity):
                                """
                                BFD item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo, self).__init__()

                                    self.yang_name = "bfd-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "bfd-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "bfd-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class BfdMinintervalInfo(Entity):
                                """
                                BFD Mininterval item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo, self).__init__()

                                    self.yang_name = "bfd-mininterval-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "bfd-mininterval-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "bfd-mininterval-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class BfdMultiplierInfo(Entity):
                                """
                                BFD Multiplier item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo, self).__init__()

                                    self.yang_name = "bfd-multiplier-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "bfd-multiplier-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "bfd-multiplier-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class TosInfo(Entity):
                                """
                                TOS item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo, self).__init__()

                                    self.yang_name = "tos-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "tos-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "tos-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NsrDisabledInfo(Entity):
                                """
                                NSR item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo, self).__init__()

                                    self.yang_name = "nsr-disabled-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "nsr-disabled-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "nsr-disabled-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class GracefulRestartDisabledInfo(Entity):
                                """
                                Graceful\-restart item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo, self).__init__()

                                    self.yang_name = "graceful-restart-disabled-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "graceful-restart-disabled-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "graceful-restart-disabled-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NbrRestartTimeInfo(Entity):
                                """
                                Restart time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo, self).__init__()

                                    self.yang_name = "nbr-restart-time-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "nbr-restart-time-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "nbr-restart-time-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NbrStalePathTimeInfo(Entity):
                                """
                                Stale\-path time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo, self).__init__()

                                    self.yang_name = "nbr-stale-path-time-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "nbr-stale-path-time-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "nbr-stale-path-time-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NbrEnforceFirstAsInfo(Entity):
                                """
                                Neighbor enforce first AS info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo, self).__init__()

                                    self.yang_name = "nbr-enforce-first-as-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "nbr-enforce-first-as-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "nbr-enforce-first-as-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ClusterIdInfo(Entity):
                                """
                                Cluster ID item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo, self).__init__()

                                    self.yang_name = "cluster-id-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "cluster-id-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "cluster-id-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class IgnoreConnectedInfo(Entity):
                                """
                                Ignore Connected Info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo, self).__init__()

                                    self.yang_name = "ignore-connected-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "ignore-connected-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "ignore-connected-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class InternalVpnClientInfo(Entity):
                                """
                                Internal VPN Client Info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo, self).__init__()

                                    self.yang_name = "internal-vpn-client-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "internal-vpn-client-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "internal-vpn-client-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AddpathSendCapabilityInfo(Entity):
                                """
                                Addpath send capability info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo, self).__init__()

                                    self.yang_name = "addpath-send-capability-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "addpath-send-capability-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "addpath-send-capability-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AddpathReceiveCapabilityInfo(Entity):
                                """
                                Addpath receive capability info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo, self).__init__()

                                    self.yang_name = "addpath-receive-capability-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "addpath-receive-capability-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "addpath-receive-capability-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class EgressPeerEngineeringInfo(Entity):
                                """
                                Egress Peer Engineering info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo, self).__init__()

                                    self.yang_name = "egress-peer-engineering-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "egress-peer-engineering-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "egress-peer-engineering-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class UpdateErrorHandlingNoResetInfo(Entity):
                                """
                                Error\-handling avoid\-reset config info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo, self).__init__()

                                    self.yang_name = "update-error-handling-no-reset-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "update-error-handling-no-reset-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "update-error-handling-no-reset-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class PrefixValidationDisableInfo(Entity):
                                """
                                RPKI disable info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo, self).__init__()

                                    self.yang_name = "prefix-validation-disable-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "prefix-validation-disable-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "prefix-validation-disable-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class PrefixValidationUseValiditInfo(Entity):
                                """
                                RPKI use validity
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo, self).__init__()

                                    self.yang_name = "prefix-validation-use-validit-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "prefix-validation-use-validit-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "prefix-validation-use-validit-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class PrefixValidationAllowInvalidInfo(Entity):
                                """
                                RPKI allow invalid info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo, self).__init__()

                                    self.yang_name = "prefix-validation-allow-invalid-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "prefix-validation-allow-invalid-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "prefix-validation-allow-invalid-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class PrefixValidationSignalIbgpInfo(Entity):
                                """
                                RPKI signal ibgp info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo, self).__init__()

                                    self.yang_name = "prefix-validation-signal-ibgp-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "prefix-validation-signal-ibgp-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "prefix-validation-signal-ibgp-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NeighborUpdateFilterExistsInfo(Entity):
                                """
                                Neighbor update filter configuration info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo, self).__init__()

                                    self.yang_name = "neighbor-update-filter-exists-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "neighbor-update-filter-exists-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "neighbor-update-filter-exists-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NeighborUpdateFilterMessageBufferCountInfo(Entity):
                                """
                                Neighbor update filter message buffer count info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo, self).__init__()

                                    self.yang_name = "neighbor-update-filter-message-buffer-count-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "neighbor-update-filter-message-buffer-count-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "neighbor-update-filter-message-buffer-count-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NeighborUpdateFilterSyslogDisableInfo(Entity):
                                """
                                Neighbor update filter syslog disable info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo, self).__init__()

                                    self.yang_name = "neighbor-update-filter-syslog-disable-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "neighbor-update-filter-syslog-disable-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "neighbor-update-filter-syslog-disable-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NeighborUpdateFilterAttributeInfo(Entity):
                                """
                                Neighbor update filter attribute\-filter group
                                info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo, self).__init__()

                                    self.yang_name = "neighbor-update-filter-attribute-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "neighbor-update-filter-attribute-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "neighbor-update-filter-attribute-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class GracefulShutdownInfo(Entity):
                                """
                                GracefulShutdown info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo, self).__init__()

                                    self.yang_name = "graceful-shutdown-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "graceful-shutdown-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "graceful-shutdown-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class GracefulShutdownLocPrefInfo(Entity):
                                """
                                GracefulShutdownLocPref info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo, self).__init__()

                                    self.yang_name = "graceful-shutdown-loc-pref-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "graceful-shutdown-loc-pref-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "graceful-shutdown-loc-pref-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class GracefulShutdownAsPrependsInfo(Entity):
                                """
                                GracefulShutdownASPrepends info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo, self).__init__()

                                    self.yang_name = "graceful-shutdown-as-prepends-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "graceful-shutdown-as-prepends-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "graceful-shutdown-as-prepends-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class GracefulShutdownActivateInfo(Entity):
                                """
                                GracefulShutdownAcivate info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo, self).__init__()

                                    self.yang_name = "graceful-shutdown-activate-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "graceful-shutdown-activate-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "graceful-shutdown-activate-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class CapabilityNegotiationSuppressedInfo(Entity):
                                """
                                Capability negotiation suppressed info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo, self).__init__()

                                    self.yang_name = "capability-negotiation-suppressed-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "capability-negotiation-suppressed-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "capability-negotiation-suppressed-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NeighborRemoteAsListInfo(Entity):
                                """
                                Neighbor range  remote\-as\-list group info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo, self).__init__()

                                    self.yang_name = "neighbor-remote-as-list-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "neighbor-remote-as-list-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "neighbor-remote-as-list-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class MaxPeersInfo(Entity):
                                """
                                Max dynamic nbrs in range info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo, self).__init__()

                                    self.yang_name = "max-peers-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "max-peers-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "max-peers-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class IdleWatchTimeInfo(Entity):
                                """
                                Idle Watch time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo, self).__init__()

                                    self.yang_name = "idle-watch-time-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "idle-watch-time-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "idle-watch-time-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AoKeychainInfo(Entity):
                                """
                                Neighbor AO keychain item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo, self).__init__()

                                    self.yang_name = "ao-keychain-info"
                                    self.yang_parent_name = "af-independent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "ao-keychain-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "ao-keychain-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class AfDependentConfig(Entity):
                            """
                            Af\-dependent config
                            
                            .. attribute:: orr_root_address
                            
                            	ORR Root Address
                            	**type**\:  :py:class:`OrrRootAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress>`
                            
                            .. attribute:: orf_capability_info
                            
                            	ORF capability item info
                            	**type**\:  :py:class:`OrfCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo>`
                            
                            .. attribute:: default_originate_info
                            
                            	Default\-originate item info
                            	**type**\:  :py:class:`DefaultOriginateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo>`
                            
                            .. attribute:: max_prefixes_info
                            
                            	Maximum prefixes to accept item info
                            	**type**\:  :py:class:`MaxPrefixesInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo>`
                            
                            .. attribute:: orr_info
                            
                            	Orr item info
                            	**type**\:  :py:class:`OrrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo>`
                            
                            .. attribute:: next_hop_self_info
                            
                            	Next hop self item info
                            	**type**\:  :py:class:`NextHopSelfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo>`
                            
                            .. attribute:: next_hop_unchanged_info
                            
                            	Next hop unchanged info
                            	**type**\:  :py:class:`NextHopUnchangedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo>`
                            
                            .. attribute:: route_policy_in_info
                            
                            	Inbound route policy item info
                            	**type**\:  :py:class:`RoutePolicyInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo>`
                            
                            .. attribute:: route_policy_out_info
                            
                            	Outbound route policy item info
                            	**type**\:  :py:class:`RoutePolicyOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo>`
                            
                            .. attribute:: prefix_filter_info
                            
                            	Inbound prefix based filter item info
                            	**type**\:  :py:class:`PrefixFilterInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo>`
                            
                            .. attribute:: remove_private_as_info
                            
                            	Outbound private\-AS removal item info
                            	**type**\:  :py:class:`RemovePrivateAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo>`
                            
                            .. attribute:: remove_private_as_in_info
                            
                            	Inbound private\-AS removal item info
                            	**type**\:  :py:class:`RemovePrivateAsInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo>`
                            
                            .. attribute:: route_reflector_info
                            
                            	Route\-reflector client item info
                            	**type**\:  :py:class:`RouteReflectorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo>`
                            
                            .. attribute:: legacy_pe_rt_info
                            
                            	Accept\-legacy\-pe\-RT item info
                            	**type**\:  :py:class:`LegacyPeRtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo>`
                            
                            .. attribute:: af_enabled_info
                            
                            	Address family activate item info
                            	**type**\:  :py:class:`AfEnabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo>`
                            
                            .. attribute:: send_community_info
                            
                            	Send community attribute item info
                            	**type**\:  :py:class:`SendCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo>`
                            
                            .. attribute:: send_graceful_shutdown_community_info
                            
                            	Send Graceful shutdown related community attribute item info
                            	**type**\:  :py:class:`SendGracefulShutdownCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo>`
                            
                            .. attribute:: send_extended_community_info
                            
                            	Send extended community  item info
                            	**type**\:  :py:class:`SendExtendedCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo>`
                            
                            .. attribute:: soft_reconfig_info
                            
                            	Soft reconf item info
                            	**type**\:  :py:class:`SoftReconfigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo>`
                            
                            .. attribute:: so_o_info
                            
                            	BGP Site\-of\-Origin info
                            	**type**\:  :py:class:`SoOInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo>`
                            
                            .. attribute:: weight_info
                            
                            	Default weight item info
                            	**type**\:  :py:class:`WeightInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo>`
                            
                            .. attribute:: allowas_in_info
                            
                            	Allowas\-in item info
                            	**type**\:  :py:class:`AllowasInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo>`
                            
                            .. attribute:: af_long_lived_graceful_start_stale_time_info
                            
                            	Long\-lived\-time item info
                            	**type**\:  :py:class:`AfLongLivedGracefulStartStaleTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo>`
                            
                            .. attribute:: af_long_lived_graceful_start_capable_info
                            
                            	Long\-lived\-time item info
                            	**type**\:  :py:class:`AfLongLivedGracefulStartCapableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo>`
                            
                            .. attribute:: as_override_info
                            
                            	As\-override info 
                            	**type**\:  :py:class:`AsOverrideInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo>`
                            
                            .. attribute:: aigp_info
                            
                            	AIGP info 
                            	**type**\:  :py:class:`AigpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo>`
                            
                            .. attribute:: aigp_cost_community_info
                            
                            	AIGP Cost Community info 
                            	**type**\:  :py:class:`AigpCostCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo>`
                            
                            .. attribute:: aigp_med
                            
                            	AIGP MED info 
                            	**type**\:  :py:class:`AigpMed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed>`
                            
                            .. attribute:: accept_own_info
                            
                            	Accept\-Own info
                            	**type**\:  :py:class:`AcceptOwnInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo>`
                            
                            .. attribute:: multipath_info
                            
                            	Multipath info
                            	**type**\:  :py:class:`MultipathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo>`
                            
                            .. attribute:: fspec_valid_info
                            
                            	FSPEC Valid info
                            	**type**\:  :py:class:`FspecValidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo>`
                            
                            .. attribute:: next_hop_unchanged_mpath_info
                            
                            	Next hop unchanged mpath info
                            	**type**\:  :py:class:`NextHopUnchangedMpathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo>`
                            
                            .. attribute:: permanent_network_info
                            
                            	Permanent network Info 
                            	**type**\:  :py:class:`PermanentNetworkInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo>`
                            
                            .. attribute:: send_mcast_attr_info
                            
                            	Send mcast attr info
                            	**type**\:  :py:class:`SendMcastAttrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo>`
                            
                            .. attribute:: advertise_v4_afi_info
                            
                            	Advertise Afi Info 
                            	**type**\:  :py:class:`AdvertiseV4AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo>`
                            
                            .. attribute:: advertise_v6_afi_info
                            
                            	Advertise Afi Info 
                            	**type**\:  :py:class:`AdvertiseV6AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo>`
                            
                            .. attribute:: advertise_l2vpn_evpn_afi_info
                            
                            	Advertise Afi Info 
                            	**type**\:  :py:class:`AdvertiseL2vpnEvpnAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo>`
                            
                            .. attribute:: advertise_dis_info
                            
                            	Advertise Afi Info 
                            	**type**\:  :py:class:`AdvertiseDisInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo>`
                            
                            .. attribute:: advertise_def_vrf_imp_disable_afi_v4_info
                            
                            	Advertise Afi Info 
                            	**type**\:  :py:class:`AdvertiseDefVrfImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info>`
                            
                            .. attribute:: advertise_def_vrf_imp_disable_afi_v6_info
                            
                            	Advertise Afi Info 
                            	**type**\:  :py:class:`AdvertiseDefVrfImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info>`
                            
                            .. attribute:: advertise_vrf_re_imp_disable_afi_v4_info
                            
                            	Advertise Afi Info 
                            	**type**\:  :py:class:`AdvertiseVrfReImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info>`
                            
                            .. attribute:: advertise_vrf_re_imp_disable_afi_v6_info
                            
                            	Advertise Afi Info 
                            	**type**\:  :py:class:`AdvertiseVrfReImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info>`
                            
                            .. attribute:: af_encapsulation_type_info
                            
                            	Encapsulation type Info 
                            	**type**\:  :py:class:`AfEncapsulationTypeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo>`
                            
                            .. attribute:: import_afi_info
                            
                            	Import Afi Info 
                            	**type**\:  :py:class:`ImportAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo>`
                            
                            .. attribute:: advertise_local_labeled_route_info
                            
                            	Advertise routes with local\-label
                            	**type**\:  :py:class:`AdvertiseLocalLabeledRouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo>`
                            
                            .. attribute:: enforce_multiple_labels_info
                            
                            	Enforce multiple labels
                            	**type**\:  :py:class:`EnforceMultipleLabelsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo>`
                            
                            .. attribute:: has_orf_capability
                            
                            	ORF capability
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_default_originate_not_disabled
                            
                            	TRUE if default\-originate is not disabled
                            	**type**\: bool
                            
                            .. attribute:: default_originate_route_policy
                            
                            	Default\-originate route policy name
                            	**type**\: str
                            
                            .. attribute:: max_prefixes
                            
                            	Maximum prefixes to accept
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_prefix_warn_threshold
                            
                            	Warning message threshhold
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_max_prefix_warn_only
                            
                            	Warning messages only
                            	**type**\: bool
                            
                            .. attribute:: max_prefix_restart_time
                            
                            	Restart time Value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_max_prefix_discard_extra_paths
                            
                            	Discard extra paths
                            	**type**\: bool
                            
                            .. attribute:: is_next_hop_self_disabled
                            
                            	Disable next\-hop calc
                            	**type**\: bool
                            
                            .. attribute:: is_next_hop_unchanged
                            
                            	Don't change next\-hop
                            	**type**\: bool
                            
                            .. attribute:: permanent_network
                            
                            	Permanent Network
                            	**type**\: bool
                            
                            .. attribute:: route_policy_in
                            
                            	Inbound route policy name
                            	**type**\: str
                            
                            .. attribute:: route_policy_out
                            
                            	Outbound route policy name
                            	**type**\: str
                            
                            .. attribute:: prefix_orf_filter
                            
                            	Inbound prefix based filter
                            	**type**\: str
                            
                            .. attribute:: remove_private_as_out
                            
                            	Outbound private\-AS removal
                            	**type**\: bool
                            
                            .. attribute:: entire_aspath_out
                            
                            	Outbound private\-AS removalif the entire AS Path hasprivate ASes
                            	**type**\: bool
                            
                            .. attribute:: remove_private_asin
                            
                            	Inbound private\-AS removal
                            	**type**\: bool
                            
                            .. attribute:: entire_aspath_in
                            
                            	Inbound private\-AS removal if the entire AS Path has private ASes
                            	**type**\: bool
                            
                            .. attribute:: client_route_reflector
                            
                            	Route\-reflector client
                            	**type**\: bool
                            
                            .. attribute:: accept_route_legacy_pe_rt
                            
                            	accept\-legacy\-pe RT route
                            	**type**\: bool
                            
                            .. attribute:: is_af_enabled
                            
                            	Entity is activated for this address family
                            	**type**\: bool
                            
                            .. attribute:: send_community_attribute
                            
                            	Send community attribute
                            	**type**\: bool
                            
                            .. attribute:: send_graceful_shut_community_attributes
                            
                            	Send Graceful shutdown related community attributes
                            	**type**\: bool
                            
                            .. attribute:: send_extended_community_attribute
                            
                            	Send extended community attribute
                            	**type**\: bool
                            
                            .. attribute:: soft_reconfig_not_disabled
                            
                            	TRUE if soft reconf is not disabled
                            	**type**\: bool
                            
                            .. attribute:: alway_use_soft_reconfig
                            
                            	Always use soft reconfig
                            	**type**\: bool
                            
                            .. attribute:: site_of_origin
                            
                            	Site of Origin
                            	**type**\: str
                            
                            .. attribute:: default_weight
                            
                            	Default weight
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_allowas
                            
                            	Default allowas\_in count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_long_lived_graceful_restart_stale_time_send
                            
                            	Stale time to be sent in long\-lived graceful\-restart capability
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_long_lived_graceful_restart_stale_time_accept
                            
                            	Maxmimum acceptable long\-lived stale time acceptable from neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_long_lived_graceful_restart_capable
                            
                            	Long\-lived graceful\-restart capable
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_as_override_disabled
                            
                            	Disable as override
                            	**type**\: bool
                            
                            .. attribute:: is_aigp_enabled
                            
                            	AIGP enabled
                            	**type**\: bool
                            
                            .. attribute:: is_aigp_cost_community_enabled
                            
                            	AIGP cost community enabled
                            	**type**\: bool
                            
                            .. attribute:: is_aigp_cost_community_id
                            
                            	AIGP cost community ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_aigp_cost_community_transitive
                            
                            	AIGP cost community ID is transitive
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: aigp_cost_community_poi
                            
                            	Point of insertion for AIGP cost community
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_aigp_med_enabled
                            
                            	AIGP to MED enabled
                            	**type**\: bool
                            
                            .. attribute:: accept_own
                            
                            	Accept Own
                            	**type**\: bool
                            
                            .. attribute:: multipath
                            
                            	multipath
                            	**type**\: bool
                            
                            .. attribute:: is_fspec_valid_enabled
                            
                            	FSPEC VALID enabled
                            	**type**\: bool
                            
                            .. attribute:: is_next_hop_unchanged_mpath
                            
                            	Don't change mpath next\-hop
                            	**type**\: bool
                            
                            .. attribute:: is_send_mcast_attr_enabled
                            
                            	Send mcast attr enabled
                            	**type**\: bool
                            
                            .. attribute:: advertise_v4
                            
                            	Advertise afi
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_v6
                            
                            	Advertise afi
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_l2vpn_evpn
                            
                            	Advertise afi
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_disable
                            
                            	Advertise afi
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_def_vrf_imp_disable_v4
                            
                            	Advertise afi
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_def_vrf_imp_disable_v6
                            
                            	Advertise afi
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_vrf_re_imp_disable_v4
                            
                            	Advertise afi
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: advertise_vrf_re_imp_disable_v6
                            
                            	Advertise afi
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: encapsulation_type
                            
                            	Encapsulation type
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: import_
                            
                            	Import
                            	**type**\: bool
                            
                            .. attribute:: import_stitching
                            
                            	Import stitching RTs
                            	**type**\: bool
                            
                            .. attribute:: import_reoriginate
                            
                            	Import reoriginate
                            	**type**\: bool
                            
                            .. attribute:: import_reoriginate_stitching
                            
                            	Import reoriginate stitching RTs
                            	**type**\: bool
                            
                            .. attribute:: advertise_local_labeled_route
                            
                            	Advertise routes with local\-label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: enforce_multiple_labels
                            
                            	Enforce multiple labels
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig, self).__init__()

                                self.yang_name = "af-dependent-config"
                                self.yang_parent_name = "entity-configuration"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("orr-root-address", ("orr_root_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress)), ("orf-capability-info", ("orf_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo)), ("default-originate-info", ("default_originate_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo)), ("max-prefixes-info", ("max_prefixes_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo)), ("orr-info", ("orr_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo)), ("next-hop-self-info", ("next_hop_self_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo)), ("next-hop-unchanged-info", ("next_hop_unchanged_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo)), ("route-policy-in-info", ("route_policy_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo)), ("route-policy-out-info", ("route_policy_out_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo)), ("prefix-filter-info", ("prefix_filter_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo)), ("remove-private-as-info", ("remove_private_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo)), ("remove-private-as-in-info", ("remove_private_as_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo)), ("route-reflector-info", ("route_reflector_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo)), ("legacy-pe-rt-info", ("legacy_pe_rt_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo)), ("af-enabled-info", ("af_enabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo)), ("send-community-info", ("send_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo)), ("send-graceful-shutdown-community-info", ("send_graceful_shutdown_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo)), ("send-extended-community-info", ("send_extended_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo)), ("soft-reconfig-info", ("soft_reconfig_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo)), ("so-o-info", ("so_o_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo)), ("weight-info", ("weight_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo)), ("allowas-in-info", ("allowas_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo)), ("af-long-lived-graceful-start-stale-time-info", ("af_long_lived_graceful_start_stale_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo)), ("af-long-lived-graceful-start-capable-info", ("af_long_lived_graceful_start_capable_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo)), ("as-override-info", ("as_override_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo)), ("aigp-info", ("aigp_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo)), ("aigp-cost-community-info", ("aigp_cost_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo)), ("aigp-med", ("aigp_med", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed)), ("accept-own-info", ("accept_own_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo)), ("multipath-info", ("multipath_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo)), ("fspec-valid-info", ("fspec_valid_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo)), ("next-hop-unchanged-mpath-info", ("next_hop_unchanged_mpath_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo)), ("permanent-network-info", ("permanent_network_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo)), ("send-mcast-attr-info", ("send_mcast_attr_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo)), ("advertise-v4-afi-info", ("advertise_v4_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo)), ("advertise-v6-afi-info", ("advertise_v6_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo)), ("advertise-l2vpn-evpn-afi-info", ("advertise_l2vpn_evpn_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo)), ("advertise-dis-info", ("advertise_dis_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo)), ("advertise-def-vrf-imp-disable-afi-v4-info", ("advertise_def_vrf_imp_disable_afi_v4_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info)), ("advertise-def-vrf-imp-disable-afi-v6-info", ("advertise_def_vrf_imp_disable_afi_v6_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info)), ("advertise-vrf-re-imp-disable-afi-v4-info", ("advertise_vrf_re_imp_disable_afi_v4_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info)), ("advertise-vrf-re-imp-disable-afi-v6-info", ("advertise_vrf_re_imp_disable_afi_v6_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info)), ("af-encapsulation-type-info", ("af_encapsulation_type_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo)), ("import-afi-info", ("import_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo)), ("advertise-local-labeled-route-info", ("advertise_local_labeled_route_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo)), ("enforce-multiple-labels-info", ("enforce_multiple_labels_info", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo))])
                                self._leafs = OrderedDict([
                                    ('has_orf_capability', (YLeaf(YType.uint32, 'has-orf-capability'), ['int'])),
                                    ('is_default_originate_not_disabled', (YLeaf(YType.boolean, 'is-default-originate-not-disabled'), ['bool'])),
                                    ('default_originate_route_policy', (YLeaf(YType.str, 'default-originate-route-policy'), ['str'])),
                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                    ('max_prefix_warn_threshold', (YLeaf(YType.uint32, 'max-prefix-warn-threshold'), ['int'])),
                                    ('is_max_prefix_warn_only', (YLeaf(YType.boolean, 'is-max-prefix-warn-only'), ['bool'])),
                                    ('max_prefix_restart_time', (YLeaf(YType.uint32, 'max-prefix-restart-time'), ['int'])),
                                    ('is_max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'is-max-prefix-discard-extra-paths'), ['bool'])),
                                    ('is_next_hop_self_disabled', (YLeaf(YType.boolean, 'is-next-hop-self-disabled'), ['bool'])),
                                    ('is_next_hop_unchanged', (YLeaf(YType.boolean, 'is-next-hop-unchanged'), ['bool'])),
                                    ('permanent_network', (YLeaf(YType.boolean, 'permanent-network'), ['bool'])),
                                    ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                    ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                    ('prefix_orf_filter', (YLeaf(YType.str, 'prefix-orf-filter'), ['str'])),
                                    ('remove_private_as_out', (YLeaf(YType.boolean, 'remove-private-as-out'), ['bool'])),
                                    ('entire_aspath_out', (YLeaf(YType.boolean, 'entire-aspath-out'), ['bool'])),
                                    ('remove_private_asin', (YLeaf(YType.boolean, 'remove-private-asin'), ['bool'])),
                                    ('entire_aspath_in', (YLeaf(YType.boolean, 'entire-aspath-in'), ['bool'])),
                                    ('client_route_reflector', (YLeaf(YType.boolean, 'client-route-reflector'), ['bool'])),
                                    ('accept_route_legacy_pe_rt', (YLeaf(YType.boolean, 'accept-route-legacy-pe-rt'), ['bool'])),
                                    ('is_af_enabled', (YLeaf(YType.boolean, 'is-af-enabled'), ['bool'])),
                                    ('send_community_attribute', (YLeaf(YType.boolean, 'send-community-attribute'), ['bool'])),
                                    ('send_graceful_shut_community_attributes', (YLeaf(YType.boolean, 'send-graceful-shut-community-attributes'), ['bool'])),
                                    ('send_extended_community_attribute', (YLeaf(YType.boolean, 'send-extended-community-attribute'), ['bool'])),
                                    ('soft_reconfig_not_disabled', (YLeaf(YType.boolean, 'soft-reconfig-not-disabled'), ['bool'])),
                                    ('alway_use_soft_reconfig', (YLeaf(YType.boolean, 'alway-use-soft-reconfig'), ['bool'])),
                                    ('site_of_origin', (YLeaf(YType.str, 'site-of-origin'), ['str'])),
                                    ('default_weight', (YLeaf(YType.uint32, 'default-weight'), ['int'])),
                                    ('default_allowas', (YLeaf(YType.uint32, 'default-allowas'), ['int'])),
                                    ('af_long_lived_graceful_restart_stale_time_send', (YLeaf(YType.uint32, 'af-long-lived-graceful-restart-stale-time-send'), ['int'])),
                                    ('af_long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'af-long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                    ('af_long_lived_graceful_restart_capable', (YLeaf(YType.uint32, 'af-long-lived-graceful-restart-capable'), ['int'])),
                                    ('is_as_override_disabled', (YLeaf(YType.boolean, 'is-as-override-disabled'), ['bool'])),
                                    ('is_aigp_enabled', (YLeaf(YType.boolean, 'is-aigp-enabled'), ['bool'])),
                                    ('is_aigp_cost_community_enabled', (YLeaf(YType.boolean, 'is-aigp-cost-community-enabled'), ['bool'])),
                                    ('is_aigp_cost_community_id', (YLeaf(YType.uint32, 'is-aigp-cost-community-id'), ['int'])),
                                    ('is_aigp_cost_community_transitive', (YLeaf(YType.uint32, 'is-aigp-cost-community-transitive'), ['int'])),
                                    ('aigp_cost_community_poi', (YLeaf(YType.uint32, 'aigp-cost-community-poi'), ['int'])),
                                    ('is_aigp_med_enabled', (YLeaf(YType.boolean, 'is-aigp-med-enabled'), ['bool'])),
                                    ('accept_own', (YLeaf(YType.boolean, 'accept-own'), ['bool'])),
                                    ('multipath', (YLeaf(YType.boolean, 'multipath'), ['bool'])),
                                    ('is_fspec_valid_enabled', (YLeaf(YType.boolean, 'is-fspec-valid-enabled'), ['bool'])),
                                    ('is_next_hop_unchanged_mpath', (YLeaf(YType.boolean, 'is-next-hop-unchanged-mpath'), ['bool'])),
                                    ('is_send_mcast_attr_enabled', (YLeaf(YType.boolean, 'is-send-mcast-attr-enabled'), ['bool'])),
                                    ('advertise_v4', (YLeaf(YType.uint8, 'advertise-v4'), ['int'])),
                                    ('advertise_v6', (YLeaf(YType.uint8, 'advertise-v6'), ['int'])),
                                    ('advertise_l2vpn_evpn', (YLeaf(YType.uint8, 'advertise-l2vpn-evpn'), ['int'])),
                                    ('advertise_disable', (YLeaf(YType.uint8, 'advertise-disable'), ['int'])),
                                    ('advertise_def_vrf_imp_disable_v4', (YLeaf(YType.uint8, 'advertise-def-vrf-imp-disable-v4'), ['int'])),
                                    ('advertise_def_vrf_imp_disable_v6', (YLeaf(YType.uint8, 'advertise-def-vrf-imp-disable-v6'), ['int'])),
                                    ('advertise_vrf_re_imp_disable_v4', (YLeaf(YType.uint8, 'advertise-vrf-re-imp-disable-v4'), ['int'])),
                                    ('advertise_vrf_re_imp_disable_v6', (YLeaf(YType.uint8, 'advertise-vrf-re-imp-disable-v6'), ['int'])),
                                    ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                    ('import_', (YLeaf(YType.boolean, 'import'), ['bool'])),
                                    ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                    ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                    ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                    ('advertise_local_labeled_route', (YLeaf(YType.uint32, 'advertise-local-labeled-route'), ['int'])),
                                    ('enforce_multiple_labels', (YLeaf(YType.uint32, 'enforce-multiple-labels'), ['int'])),
                                ])
                                self.has_orf_capability = None
                                self.is_default_originate_not_disabled = None
                                self.default_originate_route_policy = None
                                self.max_prefixes = None
                                self.max_prefix_warn_threshold = None
                                self.is_max_prefix_warn_only = None
                                self.max_prefix_restart_time = None
                                self.is_max_prefix_discard_extra_paths = None
                                self.is_next_hop_self_disabled = None
                                self.is_next_hop_unchanged = None
                                self.permanent_network = None
                                self.route_policy_in = None
                                self.route_policy_out = None
                                self.prefix_orf_filter = None
                                self.remove_private_as_out = None
                                self.entire_aspath_out = None
                                self.remove_private_asin = None
                                self.entire_aspath_in = None
                                self.client_route_reflector = None
                                self.accept_route_legacy_pe_rt = None
                                self.is_af_enabled = None
                                self.send_community_attribute = None
                                self.send_graceful_shut_community_attributes = None
                                self.send_extended_community_attribute = None
                                self.soft_reconfig_not_disabled = None
                                self.alway_use_soft_reconfig = None
                                self.site_of_origin = None
                                self.default_weight = None
                                self.default_allowas = None
                                self.af_long_lived_graceful_restart_stale_time_send = None
                                self.af_long_lived_graceful_restart_stale_time_accept = None
                                self.af_long_lived_graceful_restart_capable = None
                                self.is_as_override_disabled = None
                                self.is_aigp_enabled = None
                                self.is_aigp_cost_community_enabled = None
                                self.is_aigp_cost_community_id = None
                                self.is_aigp_cost_community_transitive = None
                                self.aigp_cost_community_poi = None
                                self.is_aigp_med_enabled = None
                                self.accept_own = None
                                self.multipath = None
                                self.is_fspec_valid_enabled = None
                                self.is_next_hop_unchanged_mpath = None
                                self.is_send_mcast_attr_enabled = None
                                self.advertise_v4 = None
                                self.advertise_v6 = None
                                self.advertise_l2vpn_evpn = None
                                self.advertise_disable = None
                                self.advertise_def_vrf_imp_disable_v4 = None
                                self.advertise_def_vrf_imp_disable_v6 = None
                                self.advertise_vrf_re_imp_disable_v4 = None
                                self.advertise_vrf_re_imp_disable_v6 = None
                                self.encapsulation_type = None
                                self.import_ = None
                                self.import_stitching = None
                                self.import_reoriginate = None
                                self.import_reoriginate_stitching = None
                                self.advertise_local_labeled_route = None
                                self.enforce_multiple_labels = None

                                self.orr_root_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress()
                                self.orr_root_address.parent = self
                                self._children_name_map["orr_root_address"] = "orr-root-address"

                                self.orf_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo()
                                self.orf_capability_info.parent = self
                                self._children_name_map["orf_capability_info"] = "orf-capability-info"

                                self.default_originate_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo()
                                self.default_originate_info.parent = self
                                self._children_name_map["default_originate_info"] = "default-originate-info"

                                self.max_prefixes_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo()
                                self.max_prefixes_info.parent = self
                                self._children_name_map["max_prefixes_info"] = "max-prefixes-info"

                                self.orr_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo()
                                self.orr_info.parent = self
                                self._children_name_map["orr_info"] = "orr-info"

                                self.next_hop_self_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo()
                                self.next_hop_self_info.parent = self
                                self._children_name_map["next_hop_self_info"] = "next-hop-self-info"

                                self.next_hop_unchanged_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo()
                                self.next_hop_unchanged_info.parent = self
                                self._children_name_map["next_hop_unchanged_info"] = "next-hop-unchanged-info"

                                self.route_policy_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo()
                                self.route_policy_in_info.parent = self
                                self._children_name_map["route_policy_in_info"] = "route-policy-in-info"

                                self.route_policy_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo()
                                self.route_policy_out_info.parent = self
                                self._children_name_map["route_policy_out_info"] = "route-policy-out-info"

                                self.prefix_filter_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo()
                                self.prefix_filter_info.parent = self
                                self._children_name_map["prefix_filter_info"] = "prefix-filter-info"

                                self.remove_private_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo()
                                self.remove_private_as_info.parent = self
                                self._children_name_map["remove_private_as_info"] = "remove-private-as-info"

                                self.remove_private_as_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo()
                                self.remove_private_as_in_info.parent = self
                                self._children_name_map["remove_private_as_in_info"] = "remove-private-as-in-info"

                                self.route_reflector_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo()
                                self.route_reflector_info.parent = self
                                self._children_name_map["route_reflector_info"] = "route-reflector-info"

                                self.legacy_pe_rt_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo()
                                self.legacy_pe_rt_info.parent = self
                                self._children_name_map["legacy_pe_rt_info"] = "legacy-pe-rt-info"

                                self.af_enabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo()
                                self.af_enabled_info.parent = self
                                self._children_name_map["af_enabled_info"] = "af-enabled-info"

                                self.send_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo()
                                self.send_community_info.parent = self
                                self._children_name_map["send_community_info"] = "send-community-info"

                                self.send_graceful_shutdown_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo()
                                self.send_graceful_shutdown_community_info.parent = self
                                self._children_name_map["send_graceful_shutdown_community_info"] = "send-graceful-shutdown-community-info"

                                self.send_extended_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo()
                                self.send_extended_community_info.parent = self
                                self._children_name_map["send_extended_community_info"] = "send-extended-community-info"

                                self.soft_reconfig_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo()
                                self.soft_reconfig_info.parent = self
                                self._children_name_map["soft_reconfig_info"] = "soft-reconfig-info"

                                self.so_o_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo()
                                self.so_o_info.parent = self
                                self._children_name_map["so_o_info"] = "so-o-info"

                                self.weight_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo()
                                self.weight_info.parent = self
                                self._children_name_map["weight_info"] = "weight-info"

                                self.allowas_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo()
                                self.allowas_in_info.parent = self
                                self._children_name_map["allowas_in_info"] = "allowas-in-info"

                                self.af_long_lived_graceful_start_stale_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo()
                                self.af_long_lived_graceful_start_stale_time_info.parent = self
                                self._children_name_map["af_long_lived_graceful_start_stale_time_info"] = "af-long-lived-graceful-start-stale-time-info"

                                self.af_long_lived_graceful_start_capable_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo()
                                self.af_long_lived_graceful_start_capable_info.parent = self
                                self._children_name_map["af_long_lived_graceful_start_capable_info"] = "af-long-lived-graceful-start-capable-info"

                                self.as_override_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo()
                                self.as_override_info.parent = self
                                self._children_name_map["as_override_info"] = "as-override-info"

                                self.aigp_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo()
                                self.aigp_info.parent = self
                                self._children_name_map["aigp_info"] = "aigp-info"

                                self.aigp_cost_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo()
                                self.aigp_cost_community_info.parent = self
                                self._children_name_map["aigp_cost_community_info"] = "aigp-cost-community-info"

                                self.aigp_med = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed()
                                self.aigp_med.parent = self
                                self._children_name_map["aigp_med"] = "aigp-med"

                                self.accept_own_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo()
                                self.accept_own_info.parent = self
                                self._children_name_map["accept_own_info"] = "accept-own-info"

                                self.multipath_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo()
                                self.multipath_info.parent = self
                                self._children_name_map["multipath_info"] = "multipath-info"

                                self.fspec_valid_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo()
                                self.fspec_valid_info.parent = self
                                self._children_name_map["fspec_valid_info"] = "fspec-valid-info"

                                self.next_hop_unchanged_mpath_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo()
                                self.next_hop_unchanged_mpath_info.parent = self
                                self._children_name_map["next_hop_unchanged_mpath_info"] = "next-hop-unchanged-mpath-info"

                                self.permanent_network_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo()
                                self.permanent_network_info.parent = self
                                self._children_name_map["permanent_network_info"] = "permanent-network-info"

                                self.send_mcast_attr_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo()
                                self.send_mcast_attr_info.parent = self
                                self._children_name_map["send_mcast_attr_info"] = "send-mcast-attr-info"

                                self.advertise_v4_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo()
                                self.advertise_v4_afi_info.parent = self
                                self._children_name_map["advertise_v4_afi_info"] = "advertise-v4-afi-info"

                                self.advertise_v6_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo()
                                self.advertise_v6_afi_info.parent = self
                                self._children_name_map["advertise_v6_afi_info"] = "advertise-v6-afi-info"

                                self.advertise_l2vpn_evpn_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo()
                                self.advertise_l2vpn_evpn_afi_info.parent = self
                                self._children_name_map["advertise_l2vpn_evpn_afi_info"] = "advertise-l2vpn-evpn-afi-info"

                                self.advertise_dis_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo()
                                self.advertise_dis_info.parent = self
                                self._children_name_map["advertise_dis_info"] = "advertise-dis-info"

                                self.advertise_def_vrf_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info()
                                self.advertise_def_vrf_imp_disable_afi_v4_info.parent = self
                                self._children_name_map["advertise_def_vrf_imp_disable_afi_v4_info"] = "advertise-def-vrf-imp-disable-afi-v4-info"

                                self.advertise_def_vrf_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info()
                                self.advertise_def_vrf_imp_disable_afi_v6_info.parent = self
                                self._children_name_map["advertise_def_vrf_imp_disable_afi_v6_info"] = "advertise-def-vrf-imp-disable-afi-v6-info"

                                self.advertise_vrf_re_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info()
                                self.advertise_vrf_re_imp_disable_afi_v4_info.parent = self
                                self._children_name_map["advertise_vrf_re_imp_disable_afi_v4_info"] = "advertise-vrf-re-imp-disable-afi-v4-info"

                                self.advertise_vrf_re_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info()
                                self.advertise_vrf_re_imp_disable_afi_v6_info.parent = self
                                self._children_name_map["advertise_vrf_re_imp_disable_afi_v6_info"] = "advertise-vrf-re-imp-disable-afi-v6-info"

                                self.af_encapsulation_type_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo()
                                self.af_encapsulation_type_info.parent = self
                                self._children_name_map["af_encapsulation_type_info"] = "af-encapsulation-type-info"

                                self.import_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo()
                                self.import_afi_info.parent = self
                                self._children_name_map["import_afi_info"] = "import-afi-info"

                                self.advertise_local_labeled_route_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo()
                                self.advertise_local_labeled_route_info.parent = self
                                self._children_name_map["advertise_local_labeled_route_info"] = "advertise-local-labeled-route-info"

                                self.enforce_multiple_labels_info = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo()
                                self.enforce_multiple_labels_info.parent = self
                                self._children_name_map["enforce_multiple_labels_info"] = "enforce-multiple-labels-info"
                                self._segment_path = lambda: "af-dependent-config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig, [u'has_orf_capability', u'is_default_originate_not_disabled', u'default_originate_route_policy', u'max_prefixes', u'max_prefix_warn_threshold', u'is_max_prefix_warn_only', u'max_prefix_restart_time', u'is_max_prefix_discard_extra_paths', u'is_next_hop_self_disabled', u'is_next_hop_unchanged', u'permanent_network', u'route_policy_in', u'route_policy_out', u'prefix_orf_filter', u'remove_private_as_out', u'entire_aspath_out', u'remove_private_asin', u'entire_aspath_in', u'client_route_reflector', u'accept_route_legacy_pe_rt', u'is_af_enabled', u'send_community_attribute', u'send_graceful_shut_community_attributes', u'send_extended_community_attribute', u'soft_reconfig_not_disabled', u'alway_use_soft_reconfig', u'site_of_origin', u'default_weight', u'default_allowas', u'af_long_lived_graceful_restart_stale_time_send', u'af_long_lived_graceful_restart_stale_time_accept', u'af_long_lived_graceful_restart_capable', u'is_as_override_disabled', u'is_aigp_enabled', u'is_aigp_cost_community_enabled', u'is_aigp_cost_community_id', u'is_aigp_cost_community_transitive', u'aigp_cost_community_poi', u'is_aigp_med_enabled', u'accept_own', u'multipath', u'is_fspec_valid_enabled', u'is_next_hop_unchanged_mpath', u'is_send_mcast_attr_enabled', u'advertise_v4', u'advertise_v6', u'advertise_l2vpn_evpn', u'advertise_disable', u'advertise_def_vrf_imp_disable_v4', u'advertise_def_vrf_imp_disable_v6', u'advertise_vrf_re_imp_disable_v4', u'advertise_vrf_re_imp_disable_v6', u'encapsulation_type', u'import_', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_local_labeled_route', u'enforce_multiple_labels'], name, value)


                            class OrrRootAddress(Entity):
                                """
                                ORR Root Address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress, self).__init__()

                                    self.yang_name = "orr-root-address"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "orr-root-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "orr-root-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "orr-root-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "orr-root-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "orr-root-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class OrfCapabilityInfo(Entity):
                                """
                                ORF capability item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo, self).__init__()

                                    self.yang_name = "orf-capability-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "orf-capability-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "orf-capability-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class DefaultOriginateInfo(Entity):
                                """
                                Default\-originate item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo, self).__init__()

                                    self.yang_name = "default-originate-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "default-originate-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "default-originate-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class MaxPrefixesInfo(Entity):
                                """
                                Maximum prefixes to accept item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo, self).__init__()

                                    self.yang_name = "max-prefixes-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "max-prefixes-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "max-prefixes-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class OrrInfo(Entity):
                                """
                                Orr item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo, self).__init__()

                                    self.yang_name = "orr-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "orr-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "orr-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NextHopSelfInfo(Entity):
                                """
                                Next hop self item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo, self).__init__()

                                    self.yang_name = "next-hop-self-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "next-hop-self-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "next-hop-self-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NextHopUnchangedInfo(Entity):
                                """
                                Next hop unchanged info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo, self).__init__()

                                    self.yang_name = "next-hop-unchanged-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "next-hop-unchanged-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "next-hop-unchanged-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class RoutePolicyInInfo(Entity):
                                """
                                Inbound route policy item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo, self).__init__()

                                    self.yang_name = "route-policy-in-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "route-policy-in-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "route-policy-in-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class RoutePolicyOutInfo(Entity):
                                """
                                Outbound route policy item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo, self).__init__()

                                    self.yang_name = "route-policy-out-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "route-policy-out-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "route-policy-out-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class PrefixFilterInfo(Entity):
                                """
                                Inbound prefix based filter item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo, self).__init__()

                                    self.yang_name = "prefix-filter-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "prefix-filter-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "prefix-filter-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class RemovePrivateAsInfo(Entity):
                                """
                                Outbound private\-AS removal item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo, self).__init__()

                                    self.yang_name = "remove-private-as-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "remove-private-as-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "remove-private-as-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class RemovePrivateAsInInfo(Entity):
                                """
                                Inbound private\-AS removal item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo, self).__init__()

                                    self.yang_name = "remove-private-as-in-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "remove-private-as-in-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "remove-private-as-in-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class RouteReflectorInfo(Entity):
                                """
                                Route\-reflector client item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo, self).__init__()

                                    self.yang_name = "route-reflector-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "route-reflector-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "route-reflector-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class LegacyPeRtInfo(Entity):
                                """
                                Accept\-legacy\-pe\-RT item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo, self).__init__()

                                    self.yang_name = "legacy-pe-rt-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "legacy-pe-rt-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "legacy-pe-rt-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfEnabledInfo(Entity):
                                """
                                Address family activate item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo, self).__init__()

                                    self.yang_name = "af-enabled-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "af-enabled-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "af-enabled-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SendCommunityInfo(Entity):
                                """
                                Send community attribute item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo, self).__init__()

                                    self.yang_name = "send-community-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "send-community-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "send-community-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SendGracefulShutdownCommunityInfo(Entity):
                                """
                                Send Graceful shutdown related community
                                attribute item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo, self).__init__()

                                    self.yang_name = "send-graceful-shutdown-community-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "send-graceful-shutdown-community-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "send-graceful-shutdown-community-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SendExtendedCommunityInfo(Entity):
                                """
                                Send extended community  item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo, self).__init__()

                                    self.yang_name = "send-extended-community-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "send-extended-community-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "send-extended-community-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SoftReconfigInfo(Entity):
                                """
                                Soft reconf item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo, self).__init__()

                                    self.yang_name = "soft-reconfig-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "soft-reconfig-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "soft-reconfig-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SoOInfo(Entity):
                                """
                                BGP Site\-of\-Origin info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo, self).__init__()

                                    self.yang_name = "so-o-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "so-o-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "so-o-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class WeightInfo(Entity):
                                """
                                Default weight item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo, self).__init__()

                                    self.yang_name = "weight-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "weight-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "weight-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AllowasInInfo(Entity):
                                """
                                Allowas\-in item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo, self).__init__()

                                    self.yang_name = "allowas-in-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "allowas-in-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "allowas-in-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfLongLivedGracefulStartStaleTimeInfo(Entity):
                                """
                                Long\-lived\-time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo, self).__init__()

                                    self.yang_name = "af-long-lived-graceful-start-stale-time-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "af-long-lived-graceful-start-stale-time-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "af-long-lived-graceful-start-stale-time-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfLongLivedGracefulStartCapableInfo(Entity):
                                """
                                Long\-lived\-time item info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo, self).__init__()

                                    self.yang_name = "af-long-lived-graceful-start-capable-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "af-long-lived-graceful-start-capable-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "af-long-lived-graceful-start-capable-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AsOverrideInfo(Entity):
                                """
                                As\-override info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo, self).__init__()

                                    self.yang_name = "as-override-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "as-override-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "as-override-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AigpInfo(Entity):
                                """
                                AIGP info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo, self).__init__()

                                    self.yang_name = "aigp-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "aigp-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "aigp-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AigpCostCommunityInfo(Entity):
                                """
                                AIGP Cost Community info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo, self).__init__()

                                    self.yang_name = "aigp-cost-community-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "aigp-cost-community-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "aigp-cost-community-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AigpMed(Entity):
                                """
                                AIGP MED info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed, self).__init__()

                                    self.yang_name = "aigp-med"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "aigp-med"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "aigp-med"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AcceptOwnInfo(Entity):
                                """
                                Accept\-Own info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo, self).__init__()

                                    self.yang_name = "accept-own-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "accept-own-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "accept-own-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class MultipathInfo(Entity):
                                """
                                Multipath info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo, self).__init__()

                                    self.yang_name = "multipath-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "multipath-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "multipath-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class FspecValidInfo(Entity):
                                """
                                FSPEC Valid info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo, self).__init__()

                                    self.yang_name = "fspec-valid-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "fspec-valid-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "fspec-valid-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NextHopUnchangedMpathInfo(Entity):
                                """
                                Next hop unchanged mpath info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo, self).__init__()

                                    self.yang_name = "next-hop-unchanged-mpath-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "next-hop-unchanged-mpath-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "next-hop-unchanged-mpath-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class PermanentNetworkInfo(Entity):
                                """
                                Permanent network Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo, self).__init__()

                                    self.yang_name = "permanent-network-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "permanent-network-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "permanent-network-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SendMcastAttrInfo(Entity):
                                """
                                Send mcast attr info
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo, self).__init__()

                                    self.yang_name = "send-mcast-attr-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "send-mcast-attr-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "send-mcast-attr-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertiseV4AfiInfo(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo, self).__init__()

                                    self.yang_name = "advertise-v4-afi-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "advertise-v4-afi-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-v4-afi-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertiseV6AfiInfo(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo, self).__init__()

                                    self.yang_name = "advertise-v6-afi-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "advertise-v6-afi-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-v6-afi-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertiseL2vpnEvpnAfiInfo(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo, self).__init__()

                                    self.yang_name = "advertise-l2vpn-evpn-afi-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "advertise-l2vpn-evpn-afi-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-l2vpn-evpn-afi-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertiseDisInfo(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo, self).__init__()

                                    self.yang_name = "advertise-dis-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "advertise-dis-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-dis-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertiseDefVrfImpDisableAfiV4Info(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info, self).__init__()

                                    self.yang_name = "advertise-def-vrf-imp-disable-afi-v4-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "advertise-def-vrf-imp-disable-afi-v4-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-def-vrf-imp-disable-afi-v4-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertiseDefVrfImpDisableAfiV6Info(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info, self).__init__()

                                    self.yang_name = "advertise-def-vrf-imp-disable-afi-v6-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "advertise-def-vrf-imp-disable-afi-v6-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-def-vrf-imp-disable-afi-v6-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertiseVrfReImpDisableAfiV4Info(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info, self).__init__()

                                    self.yang_name = "advertise-vrf-re-imp-disable-afi-v4-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "advertise-vrf-re-imp-disable-afi-v4-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-vrf-re-imp-disable-afi-v4-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertiseVrfReImpDisableAfiV6Info(Entity):
                                """
                                Advertise Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info, self).__init__()

                                    self.yang_name = "advertise-vrf-re-imp-disable-afi-v6-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "advertise-vrf-re-imp-disable-afi-v6-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-vrf-re-imp-disable-afi-v6-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfEncapsulationTypeInfo(Entity):
                                """
                                Encapsulation type Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo, self).__init__()

                                    self.yang_name = "af-encapsulation-type-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "af-encapsulation-type-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "af-encapsulation-type-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ImportAfiInfo(Entity):
                                """
                                Import Afi Info 
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo, self).__init__()

                                    self.yang_name = "import-afi-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "import-afi-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "import-afi-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertiseLocalLabeledRouteInfo(Entity):
                                """
                                Advertise routes with local\-label
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo, self).__init__()

                                    self.yang_name = "advertise-local-labeled-route-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "advertise-local-labeled-route-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "advertise-local-labeled-route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class EnforceMultipleLabelsInfo(Entity):
                                """
                                Enforce multiple labels
                                
                                .. attribute:: inheritance_chain
                                
                                	Pointer to the inheritance chain
                                	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain>`
                                
                                .. attribute:: is_item_configured
                                
                                	TRUE if the item value is a configured value different from the default
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo, self).__init__()

                                    self.yang_name = "enforce-multiple-labels-info"
                                    self.yang_parent_name = "af-dependent-config"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain))])
                                    self._leafs = OrderedDict([
                                        ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                    ])
                                    self.is_item_configured = None

                                    self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain()
                                    self.inheritance_chain.parent = self
                                    self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                    self._segment_path = lambda: "enforce-multiple-labels-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo, [u'is_item_configured'], name, value)


                                class InheritanceChain(Entity):
                                    """
                                    Pointer to the inheritance chain
                                    
                                    .. attribute:: bgp_config_entid
                                    
                                    	bgp config entid
                                    	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain, self).__init__()

                                        self.yang_name = "inheritance-chain"
                                        self.yang_parent_name = "enforce-multiple-labels-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid))])
                                        self._leafs = OrderedDict()

                                        self.bgp_config_entid = YList(self)
                                        self._segment_path = lambda: "inheritance-chain"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain, [], name, value)


                                    class BgpConfigEntid(Entity):
                                        """
                                        bgp config entid
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                        
                                        .. attribute:: address_family_identifier
                                        
                                        	Address family identfier
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: configuration_type
                                        
                                        	Entity type
                                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                        
                                        .. attribute:: group_name
                                        
                                        	Group name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                            self.yang_name = "bgp-config-entid"
                                            self.yang_parent_name = "inheritance-chain"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                            ])
                                            self.address_family_identifier = None
                                            self.configuration_type = None
                                            self.group_name = None

                                            self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "bgp-config-entid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bgp-config-entid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                class ConfigurationUsers(Entity):
                    """
                    The BGP configuration users table
                    
                    .. attribute:: configuration_user
                    
                    	A BGP configuration user table entry
                    	**type**\: list of  		 :py:class:`ConfigurationUser <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers, self).__init__()

                        self.yang_name = "configuration-users"
                        self.yang_parent_name = "config-instance-default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("configuration-user", ("configuration_user", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser))])
                        self._leafs = OrderedDict()

                        self.configuration_user = YList(self)
                        self._segment_path = lambda: "configuration-users"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers, [], name, value)


                    class ConfigurationUser(Entity):
                        """
                        A BGP configuration user table entry
                        
                        .. attribute:: entity_type
                        
                        	Entity type
                        	**type**\:  :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: entity_name
                        
                        	Entity name
                        	**type**\: str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor Address
                        	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr>`
                        
                        .. attribute:: af_independent_relatives
                        
                        	AF\-independent relatives
                        	**type**\:  :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives>`
                        
                        .. attribute:: group_name
                        
                        	Entity/group name
                        	**type**\: str
                        
                        .. attribute:: configuration_type
                        
                        	Entity type
                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                        
                        .. attribute:: address_family_identifier
                        
                        	AF identifier
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: af_dependent_relative
                        
                        	AF\-dependent relatives
                        	**type**\: list of  		 :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser, self).__init__()

                            self.yang_name = "configuration-user"
                            self.yang_parent_name = "configuration-users"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr)), ("af-independent-relatives", ("af_independent_relatives", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives)), ("af-dependent-relative", ("af_dependent_relative", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative))])
                            self._leafs = OrderedDict([
                                ('entity_type', (YLeaf(YType.enumeration, 'entity-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntity', '')])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                ('entity_name', (YLeaf(YType.str, 'entity-name'), ['str'])),
                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                            ])
                            self.entity_type = None
                            self.neighbor_address = None
                            self.entity_name = None
                            self.group_name = None
                            self.configuration_type = None
                            self.address_family_identifier = None

                            self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr()
                            self.neighbor_address_xr.parent = self
                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                            self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives()
                            self.af_independent_relatives.parent = self
                            self._children_name_map["af_independent_relatives"] = "af-independent-relatives"

                            self.af_dependent_relative = YList(self)
                            self._segment_path = lambda: "configuration-user"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser, ['entity_type', 'neighbor_address', 'entity_name', u'group_name', u'configuration_type', u'address_family_identifier'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            Neighbor Address
                            
                            .. attribute:: l2vpn_vpls_address
                            
                            	L2VPN VPLS Addr
                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnVplsAddress>`
                            
                            .. attribute:: l2vpn_mspw_address
                            
                            	L2VPN MSPW Addr
                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnMspwAddress>`
                            
                            .. attribute:: ipv4_sr_policy_address
                            
                            	IPV4 Policy Addr
                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress>`
                            
                            .. attribute:: ipv6_sr_policy_address
                            
                            	IPV6 Policy Addr
                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress>`
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mcast_address
                            
                            	IPv4 Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_label_address
                            
                            	IPv4 Label Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_tunnel_address
                            
                            	IPv4 Tunnel
                            	**type**\: str
                            
                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4_mdt_address
                            
                            	IPv4 MDT Addr
                            	**type**\: str
                            
                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4vpn_address
                            
                            	IPv4 VPN Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4vpna_mcastddress
                            
                            	IPv4 VPN Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_mcast_address
                            
                            	IPV6 Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_label_address
                            
                            	IPv6 Label Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_address
                            
                            	IPv6 VPN Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_mcast_address
                            
                            	IPv6 VPN Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rt_constraint_address
                            
                            	RT Constrt Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{24}
                            
                            .. attribute:: ipv6mvpn_address
                            
                            	MVPN addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{104}
                            
                            .. attribute:: ipv4mvpn_address
                            
                            	MVPN4 addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{56}
                            
                            .. attribute:: l2vpn_evpn_address
                            
                            	L2VPN EVPN Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{58}
                            
                            .. attribute:: ls_ls_address
                            
                            	LINKSTATE LINKSTATE Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]+
                            
                            .. attribute:: ipv4_flowspec_address
                            
                            	IPV4 Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6_flowspec_address
                            
                            	IPV6 Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4vpn_flowspec_address
                            
                            	IPV4 VPN Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6vpn_flowspec_address
                            
                            	IPV6 VPN Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "configuration-user"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                self._leafs = OrderedDict([
                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                ])
                                self.afi = None
                                self.ipv4_address = None
                                self.ipv4_mcast_address = None
                                self.ipv4_label_address = None
                                self.ipv4_tunnel_address = None
                                self.ipv4_mdt_address = None
                                self.ipv4vpn_address = None
                                self.ipv4vpna_mcastddress = None
                                self.ipv6_address = None
                                self.ipv6_mcast_address = None
                                self.ipv6_label_address = None
                                self.ipv6vpn_address = None
                                self.ipv6vpn_mcast_address = None
                                self.rt_constraint_address = None
                                self.ipv6mvpn_address = None
                                self.ipv4mvpn_address = None
                                self.l2vpn_evpn_address = None
                                self.ls_ls_address = None
                                self.ipv4_flowspec_address = None
                                self.ipv6_flowspec_address = None
                                self.ipv4vpn_flowspec_address = None
                                self.ipv6vpn_flowspec_address = None

                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnVplsAddress()
                                self.l2vpn_vpls_address.parent = self
                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnMspwAddress()
                                self.l2vpn_mspw_address.parent = self
                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress()
                                self.ipv4_sr_policy_address.parent = self
                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress()
                                self.ipv6_sr_policy_address.parent = self
                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                self._segment_path = lambda: "neighbor-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                            class L2vpnVplsAddress(Entity):
                                """
                                L2VPN VPLS Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                    self.yang_name = "l2vpn-vpls-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                    ])
                                    self.l2vpn_address = None
                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                            class L2vpnMspwAddress(Entity):
                                """
                                L2VPN MSPW Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                    self.yang_name = "l2vpn-mspw-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                    ])
                                    self.l2vpn_address = None
                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                            class Ipv4SrPolicyAddress(Entity):
                                """
                                IPV4 Policy Addr
                                
                                .. attribute:: ipv4_srpolicy_address
                                
                                	ipv4 srpolicy address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv4-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                    ])
                                    self.ipv4_srpolicy_address = None
                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                            class Ipv6SrPolicyAddress(Entity):
                                """
                                IPV6 Policy Addr
                                
                                .. attribute:: ipv6_srpolicy_address
                                
                                	ipv6 srpolicy address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv6-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                    ])
                                    self.ipv6_srpolicy_address = None
                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class AfIndependentRelatives(Entity):
                            """
                            AF\-independent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives, self).__init__()

                                self.yang_name = "af-independent-relatives"
                                self.yang_parent_name = "configuration-user"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid))])
                                self._leafs = OrderedDict()

                                self.bgp_config_entid = YList(self)
                                self._segment_path = lambda: "af-independent-relatives"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives, [], name, value)


                            class BgpConfigEntid(Entity):
                                """
                                bgp config entid
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid, self).__init__()

                                    self.yang_name = "bgp-config-entid"
                                    self.yang_parent_name = "af-independent-relatives"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress))])
                                    self._leafs = OrderedDict([
                                        ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                        ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                        ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                    ])
                                    self.address_family_identifier = None
                                    self.configuration_type = None
                                    self.group_name = None

                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                    self._segment_path = lambda: "bgp-config-entid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "bgp-config-entid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "neighbor-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class AfDependentRelative(Entity):
                            """
                            AF\-dependent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative, self).__init__()

                                self.yang_name = "af-dependent-relative"
                                self.yang_parent_name = "configuration-user"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid))])
                                self._leafs = OrderedDict()

                                self.bgp_config_entid = YList(self)
                                self._segment_path = lambda: "af-dependent-relative"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative, [], name, value)


                            class BgpConfigEntid(Entity):
                                """
                                bgp config entid
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid, self).__init__()

                                    self.yang_name = "bgp-config-entid"
                                    self.yang_parent_name = "af-dependent-relative"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress))])
                                    self._leafs = OrderedDict([
                                        ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                        ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                        ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                    ])
                                    self.address_family_identifier = None
                                    self.configuration_type = None
                                    self.group_name = None

                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                    self._segment_path = lambda: "bgp-config-entid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "bgp-config-entid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "neighbor-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                class ConfigurationInheritances(Entity):
                    """
                    The BGP configurataion inheritance table
                    
                    .. attribute:: configuration_inheritance
                    
                    	A BGP configuration inheritance table entry
                    	**type**\: list of  		 :py:class:`ConfigurationInheritance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances, self).__init__()

                        self.yang_name = "configuration-inheritances"
                        self.yang_parent_name = "config-instance-default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("configuration-inheritance", ("configuration_inheritance", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance))])
                        self._leafs = OrderedDict()

                        self.configuration_inheritance = YList(self)
                        self._segment_path = lambda: "configuration-inheritances"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances, [], name, value)


                    class ConfigurationInheritance(Entity):
                        """
                        A BGP configuration inheritance table entry
                        
                        .. attribute:: entity_type
                        
                        	Entity type
                        	**type**\:  :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: entity_name
                        
                        	Entity name
                        	**type**\: str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor Address
                        	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr>`
                        
                        .. attribute:: af_independent_relatives
                        
                        	AF\-independent relatives
                        	**type**\:  :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives>`
                        
                        .. attribute:: group_name
                        
                        	Entity/group name
                        	**type**\: str
                        
                        .. attribute:: configuration_type
                        
                        	Entity type
                        	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                        
                        .. attribute:: address_family_identifier
                        
                        	AF identifier
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: af_dependent_relative
                        
                        	AF\-dependent relatives
                        	**type**\: list of  		 :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance, self).__init__()

                            self.yang_name = "configuration-inheritance"
                            self.yang_parent_name = "configuration-inheritances"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr)), ("af-independent-relatives", ("af_independent_relatives", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives)), ("af-dependent-relative", ("af_dependent_relative", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative))])
                            self._leafs = OrderedDict([
                                ('entity_type', (YLeaf(YType.enumeration, 'entity-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntity', '')])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                ('entity_name', (YLeaf(YType.str, 'entity-name'), ['str'])),
                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                            ])
                            self.entity_type = None
                            self.neighbor_address = None
                            self.entity_name = None
                            self.group_name = None
                            self.configuration_type = None
                            self.address_family_identifier = None

                            self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr()
                            self.neighbor_address_xr.parent = self
                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                            self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives()
                            self.af_independent_relatives.parent = self
                            self._children_name_map["af_independent_relatives"] = "af-independent-relatives"

                            self.af_dependent_relative = YList(self)
                            self._segment_path = lambda: "configuration-inheritance"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance, ['entity_type', 'neighbor_address', 'entity_name', u'group_name', u'configuration_type', u'address_family_identifier'], name, value)


                        class NeighborAddressXr(Entity):
                            """
                            Neighbor Address
                            
                            .. attribute:: l2vpn_vpls_address
                            
                            	L2VPN VPLS Addr
                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnVplsAddress>`
                            
                            .. attribute:: l2vpn_mspw_address
                            
                            	L2VPN MSPW Addr
                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnMspwAddress>`
                            
                            .. attribute:: ipv4_sr_policy_address
                            
                            	IPV4 Policy Addr
                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress>`
                            
                            .. attribute:: ipv6_sr_policy_address
                            
                            	IPV6 Policy Addr
                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress>`
                            
                            .. attribute:: afi
                            
                            	AFI
                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_mcast_address
                            
                            	IPv4 Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_label_address
                            
                            	IPv4 Label Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4_tunnel_address
                            
                            	IPv4 Tunnel
                            	**type**\: str
                            
                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4_mdt_address
                            
                            	IPv4 MDT Addr
                            	**type**\: str
                            
                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                            
                            .. attribute:: ipv4vpn_address
                            
                            	IPv4 VPN Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv4vpna_mcastddress
                            
                            	IPv4 VPN Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_mcast_address
                            
                            	IPV6 Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_label_address
                            
                            	IPv6 Label Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_address
                            
                            	IPv6 VPN Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6vpn_mcast_address
                            
                            	IPv6 VPN Mcast Addr
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rt_constraint_address
                            
                            	RT Constrt Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{24}
                            
                            .. attribute:: ipv6mvpn_address
                            
                            	MVPN addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{104}
                            
                            .. attribute:: ipv4mvpn_address
                            
                            	MVPN4 addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{56}
                            
                            .. attribute:: l2vpn_evpn_address
                            
                            	L2VPN EVPN Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{58}
                            
                            .. attribute:: ls_ls_address
                            
                            	LINKSTATE LINKSTATE Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]+
                            
                            .. attribute:: ipv4_flowspec_address
                            
                            	IPV4 Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6_flowspec_address
                            
                            	IPV6 Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv4vpn_flowspec_address
                            
                            	IPV4 VPN Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            .. attribute:: ipv6vpn_flowspec_address
                            
                            	IPV6 VPN Flowspec Addr
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4096}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr, self).__init__()

                                self.yang_name = "neighbor-address-xr"
                                self.yang_parent_name = "configuration-inheritance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                self._leafs = OrderedDict([
                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                ])
                                self.afi = None
                                self.ipv4_address = None
                                self.ipv4_mcast_address = None
                                self.ipv4_label_address = None
                                self.ipv4_tunnel_address = None
                                self.ipv4_mdt_address = None
                                self.ipv4vpn_address = None
                                self.ipv4vpna_mcastddress = None
                                self.ipv6_address = None
                                self.ipv6_mcast_address = None
                                self.ipv6_label_address = None
                                self.ipv6vpn_address = None
                                self.ipv6vpn_mcast_address = None
                                self.rt_constraint_address = None
                                self.ipv6mvpn_address = None
                                self.ipv4mvpn_address = None
                                self.l2vpn_evpn_address = None
                                self.ls_ls_address = None
                                self.ipv4_flowspec_address = None
                                self.ipv6_flowspec_address = None
                                self.ipv4vpn_flowspec_address = None
                                self.ipv6vpn_flowspec_address = None

                                self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnVplsAddress()
                                self.l2vpn_vpls_address.parent = self
                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnMspwAddress()
                                self.l2vpn_mspw_address.parent = self
                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress()
                                self.ipv4_sr_policy_address.parent = self
                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress()
                                self.ipv6_sr_policy_address.parent = self
                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                self._segment_path = lambda: "neighbor-address-xr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                            class L2vpnVplsAddress(Entity):
                                """
                                L2VPN VPLS Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                    self.yang_name = "l2vpn-vpls-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                    ])
                                    self.l2vpn_address = None
                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                            class L2vpnMspwAddress(Entity):
                                """
                                L2VPN MSPW Addr
                                
                                .. attribute:: l2vpn_address
                                
                                	l2vpn address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                    self.yang_name = "l2vpn-mspw-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                    ])
                                    self.l2vpn_address = None
                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                            class Ipv4SrPolicyAddress(Entity):
                                """
                                IPV4 Policy Addr
                                
                                .. attribute:: ipv4_srpolicy_address
                                
                                	ipv4 srpolicy address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv4-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                    ])
                                    self.ipv4_srpolicy_address = None
                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                            class Ipv6SrPolicyAddress(Entity):
                                """
                                IPV6 Policy Addr
                                
                                .. attribute:: ipv6_srpolicy_address
                                
                                	ipv6 srpolicy address
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                    self.yang_name = "ipv6-sr-policy-address"
                                    self.yang_parent_name = "neighbor-address-xr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                    ])
                                    self.ipv6_srpolicy_address = None
                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class AfIndependentRelatives(Entity):
                            """
                            AF\-independent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives, self).__init__()

                                self.yang_name = "af-independent-relatives"
                                self.yang_parent_name = "configuration-inheritance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid))])
                                self._leafs = OrderedDict()

                                self.bgp_config_entid = YList(self)
                                self._segment_path = lambda: "af-independent-relatives"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives, [], name, value)


                            class BgpConfigEntid(Entity):
                                """
                                bgp config entid
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid, self).__init__()

                                    self.yang_name = "bgp-config-entid"
                                    self.yang_parent_name = "af-independent-relatives"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress))])
                                    self._leafs = OrderedDict([
                                        ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                        ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                        ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                    ])
                                    self.address_family_identifier = None
                                    self.configuration_type = None
                                    self.group_name = None

                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                    self._segment_path = lambda: "bgp-config-entid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "bgp-config-entid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "neighbor-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class AfDependentRelative(Entity):
                            """
                            AF\-dependent relatives
                            
                            .. attribute:: bgp_config_entid
                            
                            	bgp config entid
                            	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative, self).__init__()

                                self.yang_name = "af-dependent-relative"
                                self.yang_parent_name = "configuration-inheritance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid))])
                                self._leafs = OrderedDict()

                                self.bgp_config_entid = YList(self)
                                self._segment_path = lambda: "af-dependent-relative"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative, [], name, value)


                            class BgpConfigEntid(Entity):
                                """
                                bgp config entid
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor Address
                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                
                                .. attribute:: address_family_identifier
                                
                                	Address family identfier
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: configuration_type
                                
                                	Entity type
                                	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                
                                .. attribute:: group_name
                                
                                	Group name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid, self).__init__()

                                    self.yang_name = "bgp-config-entid"
                                    self.yang_parent_name = "af-dependent-relative"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress))])
                                    self._leafs = OrderedDict([
                                        ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                        ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                        ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                    ])
                                    self.address_family_identifier = None
                                    self.configuration_type = None
                                    self.group_name = None

                                    self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                    self._segment_path = lambda: "bgp-config-entid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Neighbor Address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "bgp-config-entid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "neighbor-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigInstanceDefaultVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


            class ConfigVrfs(Entity):
                """
                VRF related configuration data
                
                .. attribute:: config_vrf
                
                	Configuration data for a particular VRF
                	**type**\: list of  		 :py:class:`ConfigVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs, self).__init__()

                    self.yang_name = "config-vrfs"
                    self.yang_parent_name = "config-instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("config-vrf", ("config_vrf", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf))])
                    self._leafs = OrderedDict()

                    self.config_vrf = YList(self)
                    self._segment_path = lambda: "config-vrfs"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs, [], name, value)


                class ConfigVrf(Entity):
                    """
                    Configuration data for a particular VRF
                    
                    .. attribute:: vrf_name  (key)
                    
                    	Name of the VRF
                    	**type**\: str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: entity_configurations
                    
                    	The BGP Entity Configuration table
                    	**type**\:  :py:class:`EntityConfigurations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations>`
                    
                    .. attribute:: configuration_users
                    
                    	The BGP configuration users table
                    	**type**\:  :py:class:`ConfigurationUsers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers>`
                    
                    .. attribute:: configuration_inheritances
                    
                    	The BGP configurataion inheritance table
                    	**type**\:  :py:class:`ConfigurationInheritances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf, self).__init__()

                        self.yang_name = "config-vrf"
                        self.yang_parent_name = "config-vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vrf_name']
                        self._child_classes = OrderedDict([("entity-configurations", ("entity_configurations", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations)), ("configuration-users", ("configuration_users", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers)), ("configuration-inheritances", ("configuration_inheritances", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances))])
                        self._leafs = OrderedDict([
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.vrf_name = None

                        self.entity_configurations = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations()
                        self.entity_configurations.parent = self
                        self._children_name_map["entity_configurations"] = "entity-configurations"

                        self.configuration_users = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers()
                        self.configuration_users.parent = self
                        self._children_name_map["configuration_users"] = "configuration-users"

                        self.configuration_inheritances = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances()
                        self.configuration_inheritances.parent = self
                        self._children_name_map["configuration_inheritances"] = "configuration-inheritances"
                        self._segment_path = lambda: "config-vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf, ['vrf_name'], name, value)


                    class EntityConfigurations(Entity):
                        """
                        The BGP Entity Configuration table
                        
                        .. attribute:: entity_configuration
                        
                        	A BGP Entity Configuration table entry
                        	**type**\: list of  		 :py:class:`EntityConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations, self).__init__()

                            self.yang_name = "entity-configurations"
                            self.yang_parent_name = "config-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("entity-configuration", ("entity_configuration", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration))])
                            self._leafs = OrderedDict()

                            self.entity_configuration = YList(self)
                            self._segment_path = lambda: "entity-configurations"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations, [], name, value)


                        class EntityConfiguration(Entity):
                            """
                            A BGP Entity Configuration table entry
                            
                            .. attribute:: entity_type
                            
                            	Entity type
                            	**type**\:  :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: entity_name
                            
                            	Entity name
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor Address
                            	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr>`
                            
                            .. attribute:: af_independent_config
                            
                            	AF\-independent config
                            	**type**\:  :py:class:`AfIndependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig>`
                            
                            .. attribute:: group_name
                            
                            	Entity/group name
                            	**type**\: str
                            
                            .. attribute:: configuration_type
                            
                            	Entity type
                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                            
                            .. attribute:: address_family_identifier
                            
                            	AF identifier
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: af_dependent_config
                            
                            	Af\-dependent config
                            	**type**\: list of  		 :py:class:`AfDependentConfig <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration, self).__init__()

                                self.yang_name = "entity-configuration"
                                self.yang_parent_name = "entity-configurations"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr)), ("af-independent-config", ("af_independent_config", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig)), ("af-dependent-config", ("af_dependent_config", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig))])
                                self._leafs = OrderedDict([
                                    ('entity_type', (YLeaf(YType.enumeration, 'entity-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntity', '')])),
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('entity_name', (YLeaf(YType.str, 'entity-name'), ['str'])),
                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                ])
                                self.entity_type = None
                                self.neighbor_address = None
                                self.entity_name = None
                                self.group_name = None
                                self.configuration_type = None
                                self.address_family_identifier = None

                                self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr()
                                self.neighbor_address_xr.parent = self
                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                self.af_independent_config = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig()
                                self.af_independent_config.parent = self
                                self._children_name_map["af_independent_config"] = "af-independent-config"

                                self.af_dependent_config = YList(self)
                                self._segment_path = lambda: "entity-configuration"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration, ['entity_type', 'neighbor_address', 'entity_name', u'group_name', u'configuration_type', u'address_family_identifier'], name, value)


                            class NeighborAddressXr(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr, self).__init__()

                                    self.yang_name = "neighbor-address-xr"
                                    self.yang_parent_name = "entity-configuration"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "neighbor-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfIndependentConfig(Entity):
                                """
                                AF\-independent config
                                
                                .. attribute:: local_ip_address
                                
                                	Local ipv4 or ipv6 address for neighbor connection
                                	**type**\:  :py:class:`LocalIpAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress>`
                                
                                .. attribute:: remote_as_info
                                
                                	Remote AS number item info
                                	**type**\:  :py:class:`RemoteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo>`
                                
                                .. attribute:: speaker_id_info
                                
                                	Configured speaker ID item info
                                	**type**\:  :py:class:`SpeakerIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo>`
                                
                                .. attribute:: min_advertisement_info
                                
                                	Minimum advertisement interval item info
                                	**type**\:  :py:class:`MinAdvertisementInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo>`
                                
                                .. attribute:: description_info
                                
                                	Description item info
                                	**type**\:  :py:class:`DescriptionInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo>`
                                
                                .. attribute:: ebgp_hop_count_info
                                
                                	EBGP neighbors hop count item info
                                	**type**\:  :py:class:`EbgpHopCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo>`
                                
                                .. attribute:: tcpmss_info
                                
                                	TCP Maximum Segment Size item info
                                	**type**\:  :py:class:`TcpmssInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo>`
                                
                                .. attribute:: bmp_servers_info
                                
                                	BMP Servers Configuredinfo
                                	**type**\:  :py:class:`BmpServersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo>`
                                
                                .. attribute:: keychain_info
                                
                                	Neighbor Keychain item info
                                	**type**\:  :py:class:`KeychainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo>`
                                
                                .. attribute:: local_as_info
                                
                                	Local AS number item info
                                	**type**\:  :py:class:`LocalAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo>`
                                
                                .. attribute:: password_info
                                
                                	Neighbor password item info
                                	**type**\:  :py:class:`PasswordInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo>`
                                
                                .. attribute:: receive_buffer_info
                                
                                	Receive buffer sizes item info
                                	**type**\:  :py:class:`ReceiveBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo>`
                                
                                .. attribute:: send_buffer_info
                                
                                	Send buffer sizes item info
                                	**type**\:  :py:class:`SendBufferInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo>`
                                
                                .. attribute:: shutdown_info
                                
                                	Shutdown item info
                                	**type**\:  :py:class:`ShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo>`
                                
                                .. attribute:: timers_info
                                
                                	Timers item info
                                	**type**\:  :py:class:`TimersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo>`
                                
                                .. attribute:: local_address_info
                                
                                	Local address item info
                                	**type**\:  :py:class:`LocalAddressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo>`
                                
                                .. attribute:: msg_log_in_info
                                
                                	Message Log Inbound item info
                                	**type**\:  :py:class:`MsgLogInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo>`
                                
                                .. attribute:: msg_log_out_info
                                
                                	Message Log Outbound item info
                                	**type**\:  :py:class:`MsgLogOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo>`
                                
                                .. attribute:: update_source_info
                                
                                	Update source item info
                                	**type**\:  :py:class:`UpdateSourceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo>`
                                
                                .. attribute:: dmz_link_bandwidth_info
                                
                                	DMZ link bandwidth item 
                                	**type**\:  :py:class:`DmzLinkBandwidthInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo>`
                                
                                .. attribute:: ebgp_recv_dmz_info
                                
                                	EBGP receive DMZ link bandwidth item info
                                	**type**\:  :py:class:`EbgpRecvDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo>`
                                
                                .. attribute:: ebgp_send_dmz_info
                                
                                	EBGP send DMZ link bandwidth item info
                                	**type**\:  :py:class:`EbgpSendDmzInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo>`
                                
                                .. attribute:: ttl_security_info
                                
                                	BGP TTL Security item info
                                	**type**\:  :py:class:`TtlSecurityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo>`
                                
                                .. attribute:: suppress4_bbyte_as_info
                                
                                	BGP suppress 4byte\-as item info
                                	**type**\:  :py:class:`Suppress4BbyteAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo>`
                                
                                .. attribute:: session_open_mode_info
                                
                                	TCP conn open mode info
                                	**type**\:  :py:class:`SessionOpenModeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo>`
                                
                                .. attribute:: bfd_info
                                
                                	BFD item info
                                	**type**\:  :py:class:`BfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo>`
                                
                                .. attribute:: bfd_mininterval_info
                                
                                	BFD Mininterval item info
                                	**type**\:  :py:class:`BfdMinintervalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo>`
                                
                                .. attribute:: bfd_multiplier_info
                                
                                	BFD Multiplier item info
                                	**type**\:  :py:class:`BfdMultiplierInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo>`
                                
                                .. attribute:: tos_info
                                
                                	TOS item info
                                	**type**\:  :py:class:`TosInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo>`
                                
                                .. attribute:: nsr_disabled_info
                                
                                	NSR item info
                                	**type**\:  :py:class:`NsrDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo>`
                                
                                .. attribute:: graceful_restart_disabled_info
                                
                                	Graceful\-restart item info
                                	**type**\:  :py:class:`GracefulRestartDisabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo>`
                                
                                .. attribute:: nbr_restart_time_info
                                
                                	Restart time item info
                                	**type**\:  :py:class:`NbrRestartTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo>`
                                
                                .. attribute:: nbr_stale_path_time_info
                                
                                	Stale\-path time item info
                                	**type**\:  :py:class:`NbrStalePathTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo>`
                                
                                .. attribute:: nbr_enforce_first_as_info
                                
                                	Neighbor enforce first AS info
                                	**type**\:  :py:class:`NbrEnforceFirstAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo>`
                                
                                .. attribute:: cluster_id_info
                                
                                	Cluster ID item info
                                	**type**\:  :py:class:`ClusterIdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo>`
                                
                                .. attribute:: ignore_connected_info
                                
                                	Ignore Connected Info
                                	**type**\:  :py:class:`IgnoreConnectedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo>`
                                
                                .. attribute:: internal_vpn_client_info
                                
                                	Internal VPN Client Info
                                	**type**\:  :py:class:`InternalVpnClientInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo>`
                                
                                .. attribute:: addpath_send_capability_info
                                
                                	Addpath send capability info
                                	**type**\:  :py:class:`AddpathSendCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo>`
                                
                                .. attribute:: addpath_receive_capability_info
                                
                                	Addpath receive capability info
                                	**type**\:  :py:class:`AddpathReceiveCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo>`
                                
                                .. attribute:: egress_peer_engineering_info
                                
                                	Egress Peer Engineering info
                                	**type**\:  :py:class:`EgressPeerEngineeringInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo>`
                                
                                .. attribute:: update_error_handling_no_reset_info
                                
                                	Error\-handling avoid\-reset config info
                                	**type**\:  :py:class:`UpdateErrorHandlingNoResetInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo>`
                                
                                .. attribute:: prefix_validation_disable_info
                                
                                	RPKI disable info
                                	**type**\:  :py:class:`PrefixValidationDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo>`
                                
                                .. attribute:: prefix_validation_use_validit_info
                                
                                	RPKI use validity
                                	**type**\:  :py:class:`PrefixValidationUseValiditInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo>`
                                
                                .. attribute:: prefix_validation_allow_invalid_info
                                
                                	RPKI allow invalid info
                                	**type**\:  :py:class:`PrefixValidationAllowInvalidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo>`
                                
                                .. attribute:: prefix_validation_signal_ibgp_info
                                
                                	RPKI signal ibgp info
                                	**type**\:  :py:class:`PrefixValidationSignalIbgpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo>`
                                
                                .. attribute:: neighbor_update_filter_exists_info
                                
                                	Neighbor update filter configuration info
                                	**type**\:  :py:class:`NeighborUpdateFilterExistsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo>`
                                
                                .. attribute:: neighbor_update_filter_message_buffer_count_info
                                
                                	Neighbor update filter message buffer count info
                                	**type**\:  :py:class:`NeighborUpdateFilterMessageBufferCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo>`
                                
                                .. attribute:: neighbor_update_filter_syslog_disable_info
                                
                                	Neighbor update filter syslog disable info
                                	**type**\:  :py:class:`NeighborUpdateFilterSyslogDisableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo>`
                                
                                .. attribute:: neighbor_update_filter_attribute_info
                                
                                	Neighbor update filter attribute\-filter group info
                                	**type**\:  :py:class:`NeighborUpdateFilterAttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo>`
                                
                                .. attribute:: graceful_shutdown_info
                                
                                	GracefulShutdown info
                                	**type**\:  :py:class:`GracefulShutdownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo>`
                                
                                .. attribute:: graceful_shutdown_loc_pref_info
                                
                                	GracefulShutdownLocPref info
                                	**type**\:  :py:class:`GracefulShutdownLocPrefInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo>`
                                
                                .. attribute:: graceful_shutdown_as_prepends_info
                                
                                	GracefulShutdownASPrepends info
                                	**type**\:  :py:class:`GracefulShutdownAsPrependsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo>`
                                
                                .. attribute:: graceful_shutdown_activate_info
                                
                                	GracefulShutdownAcivate info
                                	**type**\:  :py:class:`GracefulShutdownActivateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo>`
                                
                                .. attribute:: capability_negotiation_suppressed_info
                                
                                	Capability negotiation suppressed info
                                	**type**\:  :py:class:`CapabilityNegotiationSuppressedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo>`
                                
                                .. attribute:: neighbor_remote_as_list_info
                                
                                	Neighbor range  remote\-as\-list group info
                                	**type**\:  :py:class:`NeighborRemoteAsListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo>`
                                
                                .. attribute:: max_peers_info
                                
                                	Max dynamic nbrs in range info
                                	**type**\:  :py:class:`MaxPeersInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo>`
                                
                                .. attribute:: idle_watch_time_info
                                
                                	Idle Watch time item info
                                	**type**\:  :py:class:`IdleWatchTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo>`
                                
                                .. attribute:: ao_keychain_info
                                
                                	Neighbor AO keychain item info
                                	**type**\:  :py:class:`AoKeychainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo>`
                                
                                .. attribute:: remote_as_number_xx
                                
                                	First half of Remote ASN
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_number_yy
                                
                                	Second half of Remote ASN
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_speaker_id
                                
                                	Configured speaker ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_mss
                                
                                	Maximum Segment Size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_advertisement_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertisement_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\: str
                                
                                .. attribute:: ebgp_hop_count
                                
                                	EBGP neighbors hop count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_servers
                                
                                	BMP Servers activated
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\: bool
                                
                                .. attribute:: keychain
                                
                                	Neighbor keychain Name
                                	**type**\: str
                                
                                .. attribute:: local_as_number_xx
                                
                                	First half of Local ASN
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_number_yy
                                
                                	Second half of Local ASN
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Local AS no\-prepend option
                                	**type**\: bool
                                
                                .. attribute:: password
                                
                                	Neighbor password
                                	**type**\: str
                                
                                .. attribute:: socket_buffer_receive_size
                                
                                	Socket receive buffer size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bgp_buffer_receive_size
                                
                                	BGP receive buffer size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: socket_buffer_send_size
                                
                                	Socket send buffer size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bgp_buffer_send_size
                                
                                	BGP send buffer size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: adminstrative_shutdown
                                
                                	Administrative shutdown
                                	**type**\: bool
                                
                                .. attribute:: keepalive_interval
                                
                                	Keepalive interval
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: hold_time_value
                                
                                	Holdtime
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: min_acc_hold_time_value
                                
                                	Min acceptable holdtimefrom neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_in_buf_count
                                
                                	Message Log Inbound buffer count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out_buf_count
                                
                                	Message Log Outbound buffer count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_updates_source
                                
                                	Source of routing updates
                                	**type**\: str
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Propagate the DMZ link bandwidth
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Send DMZ link bandwidthto ebgp peer
                                	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: ttl_security
                                
                                	Enable BGP TTL Security
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress BGP 4byteas Cap
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: capability_negotiation_suppressed
                                
                                	Capability negotiation is suppressed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: session_open_mode
                                
                                	TCP open mode to be used 
                                	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                
                                .. attribute:: bfd
                                
                                	Fast failure detection using BFD
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_mininterval
                                
                                	BFD Minimum Interval
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplier
                                
                                	BFD Multiplier
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos_type_info
                                
                                	Precedence or DSCP type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value_info
                                
                                	Precedence or DSCP value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_disabled
                                
                                	Support for NSR
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_restart_disabled
                                
                                	Support for graceful\-restart
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_restart_time
                                
                                	Restart time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nbr_stale_path_time
                                
                                	Stale\-path time(in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nbr_enforce_first_as_status
                                
                                	Neighbor enforce first AS status
                                	**type**\: bool
                                
                                .. attribute:: nbr_cluster_id_type_info
                                
                                	Cluster ID Type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nbr_cluster_id_info
                                
                                	Cluster ID value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ignore_connected_check
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\: bool
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, the VPN client isan iBGP CE peer
                                	**type**\: bool
                                
                                .. attribute:: addpath_send_capability
                                
                                	Indicates if addpath send capability is enabled or disabled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_handling_no_reset
                                
                                	Indicates if avoid\-reset behavior is enabled during update error\-handling
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: addpath_receive_capability
                                
                                	Indicates if addpath receive capability is enabled or disabled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: egress_peer_engineering
                                
                                	Indicates egress peer engineering is enabled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_validation_disable
                                
                                	Prefix validation disable
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bestpath_use_origin_as_validity
                                
                                	Bestpath Use Origin\-AS Va
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_validation_allow_invalid
                                
                                	Prefix validation allow invalid
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix_validation_signal_ibgp
                                
                                	Prefix validation signal ibgp
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_update_filter_exists
                                
                                	Indicates if neighbor filter configuration exists
                                	**type**\: bool
                                
                                .. attribute:: neighbor_update_filter_message_buffer_count
                                
                                	Count of neighbor filter message buffers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_update_filter_message_buffer_is_non_circular
                                
                                	Indicates if neighbor update filter message buffer is circular or not
                                	**type**\: bool
                                
                                .. attribute:: neighbor_update_filter_logging_disable
                                
                                	Indicates if neighbor filter logging is disabled
                                	**type**\: bool
                                
                                .. attribute:: neighbor_update_filter_attribute_filter_group_name
                                
                                	Neighbor filter attribute\-filter group name
                                	**type**\: str
                                
                                .. attribute:: graceful_shutdown_exists
                                
                                	re\-advertise all routes to and from this neighbor with the GSHUT community during Shutdown or bring\-up
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_shutdown_loc_pref
                                
                                	Local Preference to advertise routes with during Graceful Shutdown to IBGP. Default=No Touch
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_shutdown_as_prepends
                                
                                	Prepend the local AS this many times to the AS path of routes advertised during Graceful Shutdown
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_shutdown_activate
                                
                                	Graceful Shutdown state is activated
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_remote_as_list_group_name
                                
                                	Neighbor Range remote\-as\-list group name
                                	**type**\: str
                                
                                .. attribute:: max_peers
                                
                                	Maximum dynamic nbrs in range
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: idle_watch_time
                                
                                	Idle Watch time(in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: ao_keychain
                                
                                	Neighbor AO keychain name
                                	**type**\: str
                                
                                .. attribute:: ao_include_tcp_options
                                
                                	Include TCP options AO
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ao_accept_mismatch_connection
                                
                                	Accept AO mismatched connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\: bool
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig, self).__init__()

                                    self.yang_name = "af-independent-config"
                                    self.yang_parent_name = "entity-configuration"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-ip-address", ("local_ip_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress)), ("remote-as-info", ("remote_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo)), ("speaker-id-info", ("speaker_id_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo)), ("min-advertisement-info", ("min_advertisement_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo)), ("description-info", ("description_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo)), ("ebgp-hop-count-info", ("ebgp_hop_count_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo)), ("tcpmss-info", ("tcpmss_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo)), ("bmp-servers-info", ("bmp_servers_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo)), ("keychain-info", ("keychain_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo)), ("local-as-info", ("local_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo)), ("password-info", ("password_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo)), ("receive-buffer-info", ("receive_buffer_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo)), ("send-buffer-info", ("send_buffer_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo)), ("shutdown-info", ("shutdown_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo)), ("timers-info", ("timers_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo)), ("local-address-info", ("local_address_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo)), ("msg-log-in-info", ("msg_log_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo)), ("msg-log-out-info", ("msg_log_out_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo)), ("update-source-info", ("update_source_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo)), ("dmz-link-bandwidth-info", ("dmz_link_bandwidth_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo)), ("ebgp-recv-dmz-info", ("ebgp_recv_dmz_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo)), ("ebgp-send-dmz-info", ("ebgp_send_dmz_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo)), ("ttl-security-info", ("ttl_security_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo)), ("suppress4-bbyte-as-info", ("suppress4_bbyte_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo)), ("session-open-mode-info", ("session_open_mode_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo)), ("bfd-info", ("bfd_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo)), ("bfd-mininterval-info", ("bfd_mininterval_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo)), ("bfd-multiplier-info", ("bfd_multiplier_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo)), ("tos-info", ("tos_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo)), ("nsr-disabled-info", ("nsr_disabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo)), ("graceful-restart-disabled-info", ("graceful_restart_disabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo)), ("nbr-restart-time-info", ("nbr_restart_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo)), ("nbr-stale-path-time-info", ("nbr_stale_path_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo)), ("nbr-enforce-first-as-info", ("nbr_enforce_first_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo)), ("cluster-id-info", ("cluster_id_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo)), ("ignore-connected-info", ("ignore_connected_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo)), ("internal-vpn-client-info", ("internal_vpn_client_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo)), ("addpath-send-capability-info", ("addpath_send_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo)), ("addpath-receive-capability-info", ("addpath_receive_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo)), ("egress-peer-engineering-info", ("egress_peer_engineering_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo)), ("update-error-handling-no-reset-info", ("update_error_handling_no_reset_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo)), ("prefix-validation-disable-info", ("prefix_validation_disable_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo)), ("prefix-validation-use-validit-info", ("prefix_validation_use_validit_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo)), ("prefix-validation-allow-invalid-info", ("prefix_validation_allow_invalid_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo)), ("prefix-validation-signal-ibgp-info", ("prefix_validation_signal_ibgp_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo)), ("neighbor-update-filter-exists-info", ("neighbor_update_filter_exists_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo)), ("neighbor-update-filter-message-buffer-count-info", ("neighbor_update_filter_message_buffer_count_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo)), ("neighbor-update-filter-syslog-disable-info", ("neighbor_update_filter_syslog_disable_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo)), ("neighbor-update-filter-attribute-info", ("neighbor_update_filter_attribute_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo)), ("graceful-shutdown-info", ("graceful_shutdown_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo)), ("graceful-shutdown-loc-pref-info", ("graceful_shutdown_loc_pref_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo)), ("graceful-shutdown-as-prepends-info", ("graceful_shutdown_as_prepends_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo)), ("graceful-shutdown-activate-info", ("graceful_shutdown_activate_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo)), ("capability-negotiation-suppressed-info", ("capability_negotiation_suppressed_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo)), ("neighbor-remote-as-list-info", ("neighbor_remote_as_list_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo)), ("max-peers-info", ("max_peers_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo)), ("idle-watch-time-info", ("idle_watch_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo)), ("ao-keychain-info", ("ao_keychain_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo))])
                                    self._leafs = OrderedDict([
                                        ('remote_as_number_xx', (YLeaf(YType.uint32, 'remote-as-number-xx'), ['int'])),
                                        ('remote_as_number_yy', (YLeaf(YType.uint32, 'remote-as-number-yy'), ['int'])),
                                        ('configured_speaker_id', (YLeaf(YType.uint32, 'configured-speaker-id'), ['int'])),
                                        ('tcp_mss', (YLeaf(YType.uint32, 'tcp-mss'), ['int'])),
                                        ('min_advertisement_interval', (YLeaf(YType.uint32, 'min-advertisement-interval'), ['int'])),
                                        ('min_advertisement_interval_msecs', (YLeaf(YType.uint32, 'min-advertisement-interval-msecs'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('ebgp_hop_count', (YLeaf(YType.uint32, 'ebgp-hop-count'), ['int'])),
                                        ('bmp_servers', (YLeaf(YType.uint32, 'bmp-servers'), ['int'])),
                                        ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                        ('keychain', (YLeaf(YType.str, 'keychain'), ['str'])),
                                        ('local_as_number_xx', (YLeaf(YType.uint32, 'local-as-number-xx'), ['int'])),
                                        ('local_as_number_yy', (YLeaf(YType.uint32, 'local-as-number-yy'), ['int'])),
                                        ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                        ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                        ('socket_buffer_receive_size', (YLeaf(YType.uint32, 'socket-buffer-receive-size'), ['int'])),
                                        ('bgp_buffer_receive_size', (YLeaf(YType.uint32, 'bgp-buffer-receive-size'), ['int'])),
                                        ('socket_buffer_send_size', (YLeaf(YType.uint32, 'socket-buffer-send-size'), ['int'])),
                                        ('bgp_buffer_send_size', (YLeaf(YType.uint32, 'bgp-buffer-send-size'), ['int'])),
                                        ('adminstrative_shutdown', (YLeaf(YType.boolean, 'adminstrative-shutdown'), ['bool'])),
                                        ('keepalive_interval', (YLeaf(YType.uint32, 'keepalive-interval'), ['int'])),
                                        ('hold_time_value', (YLeaf(YType.uint32, 'hold-time-value'), ['int'])),
                                        ('min_acc_hold_time_value', (YLeaf(YType.uint32, 'min-acc-hold-time-value'), ['int'])),
                                        ('msg_log_in_buf_count', (YLeaf(YType.uint32, 'msg-log-in-buf-count'), ['int'])),
                                        ('msg_log_out_buf_count', (YLeaf(YType.uint32, 'msg-log-out-buf-count'), ['int'])),
                                        ('route_updates_source', (YLeaf(YType.str, 'route-updates-source'), ['str'])),
                                        ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                        ('ebgp_recv_dmz', (YLeaf(YType.uint32, 'ebgp-recv-dmz'), ['int'])),
                                        ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                        ('ttl_security', (YLeaf(YType.uint32, 'ttl-security'), ['int'])),
                                        ('suppress4_byte_as', (YLeaf(YType.uint32, 'suppress4-byte-as'), ['int'])),
                                        ('capability_negotiation_suppressed', (YLeaf(YType.uint32, 'capability-negotiation-suppressed'), ['int'])),
                                        ('session_open_mode', (YLeaf(YType.enumeration, 'session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                        ('bfd', (YLeaf(YType.uint32, 'bfd'), ['int'])),
                                        ('bfd_mininterval', (YLeaf(YType.uint32, 'bfd-mininterval'), ['int'])),
                                        ('bfd_multiplier', (YLeaf(YType.uint32, 'bfd-multiplier'), ['int'])),
                                        ('tos_type_info', (YLeaf(YType.uint8, 'tos-type-info'), ['int'])),
                                        ('tos_value_info', (YLeaf(YType.uint8, 'tos-value-info'), ['int'])),
                                        ('nsr_disabled', (YLeaf(YType.uint32, 'nsr-disabled'), ['int'])),
                                        ('graceful_restart_disabled', (YLeaf(YType.uint32, 'graceful-restart-disabled'), ['int'])),
                                        ('nbr_restart_time', (YLeaf(YType.uint32, 'nbr-restart-time'), ['int'])),
                                        ('nbr_stale_path_time', (YLeaf(YType.uint32, 'nbr-stale-path-time'), ['int'])),
                                        ('nbr_enforce_first_as_status', (YLeaf(YType.boolean, 'nbr-enforce-first-as-status'), ['bool'])),
                                        ('nbr_cluster_id_type_info', (YLeaf(YType.uint8, 'nbr-cluster-id-type-info'), ['int'])),
                                        ('nbr_cluster_id_info', (YLeaf(YType.uint32, 'nbr-cluster-id-info'), ['int'])),
                                        ('ignore_connected_check', (YLeaf(YType.boolean, 'ignore-connected-check'), ['bool'])),
                                        ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                        ('addpath_send_capability', (YLeaf(YType.uint32, 'addpath-send-capability'), ['int'])),
                                        ('update_error_handling_no_reset', (YLeaf(YType.uint32, 'update-error-handling-no-reset'), ['int'])),
                                        ('addpath_receive_capability', (YLeaf(YType.uint32, 'addpath-receive-capability'), ['int'])),
                                        ('egress_peer_engineering', (YLeaf(YType.uint32, 'egress-peer-engineering'), ['int'])),
                                        ('prefix_validation_disable', (YLeaf(YType.uint32, 'prefix-validation-disable'), ['int'])),
                                        ('bestpath_use_origin_as_validity', (YLeaf(YType.uint32, 'bestpath-use-origin-as-validity'), ['int'])),
                                        ('prefix_validation_allow_invalid', (YLeaf(YType.uint32, 'prefix-validation-allow-invalid'), ['int'])),
                                        ('prefix_validation_signal_ibgp', (YLeaf(YType.uint32, 'prefix-validation-signal-ibgp'), ['int'])),
                                        ('neighbor_update_filter_exists', (YLeaf(YType.boolean, 'neighbor-update-filter-exists'), ['bool'])),
                                        ('neighbor_update_filter_message_buffer_count', (YLeaf(YType.uint32, 'neighbor-update-filter-message-buffer-count'), ['int'])),
                                        ('neighbor_update_filter_message_buffer_is_non_circular', (YLeaf(YType.boolean, 'neighbor-update-filter-message-buffer-is-non-circular'), ['bool'])),
                                        ('neighbor_update_filter_logging_disable', (YLeaf(YType.boolean, 'neighbor-update-filter-logging-disable'), ['bool'])),
                                        ('neighbor_update_filter_attribute_filter_group_name', (YLeaf(YType.str, 'neighbor-update-filter-attribute-filter-group-name'), ['str'])),
                                        ('graceful_shutdown_exists', (YLeaf(YType.uint32, 'graceful-shutdown-exists'), ['int'])),
                                        ('graceful_shutdown_loc_pref', (YLeaf(YType.uint32, 'graceful-shutdown-loc-pref'), ['int'])),
                                        ('graceful_shutdown_as_prepends', (YLeaf(YType.uint32, 'graceful-shutdown-as-prepends'), ['int'])),
                                        ('graceful_shutdown_activate', (YLeaf(YType.uint32, 'graceful-shutdown-activate'), ['int'])),
                                        ('neighbor_remote_as_list_group_name', (YLeaf(YType.str, 'neighbor-remote-as-list-group-name'), ['str'])),
                                        ('max_peers', (YLeaf(YType.uint32, 'max-peers'), ['int'])),
                                        ('idle_watch_time', (YLeaf(YType.uint32, 'idle-watch-time'), ['int'])),
                                        ('ao_keychain', (YLeaf(YType.str, 'ao-keychain'), ['str'])),
                                        ('ao_include_tcp_options', (YLeaf(YType.uint32, 'ao-include-tcp-options'), ['int'])),
                                        ('ao_accept_mismatch_connection', (YLeaf(YType.uint32, 'ao-accept-mismatch-connection'), ['int'])),
                                        ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                        ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                    ])
                                    self.remote_as_number_xx = None
                                    self.remote_as_number_yy = None
                                    self.configured_speaker_id = None
                                    self.tcp_mss = None
                                    self.min_advertisement_interval = None
                                    self.min_advertisement_interval_msecs = None
                                    self.description = None
                                    self.ebgp_hop_count = None
                                    self.bmp_servers = None
                                    self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                    self.keychain = None
                                    self.local_as_number_xx = None
                                    self.local_as_number_yy = None
                                    self.local_as_no_prepend = None
                                    self.password = None
                                    self.socket_buffer_receive_size = None
                                    self.bgp_buffer_receive_size = None
                                    self.socket_buffer_send_size = None
                                    self.bgp_buffer_send_size = None
                                    self.adminstrative_shutdown = None
                                    self.keepalive_interval = None
                                    self.hold_time_value = None
                                    self.min_acc_hold_time_value = None
                                    self.msg_log_in_buf_count = None
                                    self.msg_log_out_buf_count = None
                                    self.route_updates_source = None
                                    self.dmz_link_bandwidth = None
                                    self.ebgp_recv_dmz = None
                                    self.ebgp_send_dmz_mode = None
                                    self.ttl_security = None
                                    self.suppress4_byte_as = None
                                    self.capability_negotiation_suppressed = None
                                    self.session_open_mode = None
                                    self.bfd = None
                                    self.bfd_mininterval = None
                                    self.bfd_multiplier = None
                                    self.tos_type_info = None
                                    self.tos_value_info = None
                                    self.nsr_disabled = None
                                    self.graceful_restart_disabled = None
                                    self.nbr_restart_time = None
                                    self.nbr_stale_path_time = None
                                    self.nbr_enforce_first_as_status = None
                                    self.nbr_cluster_id_type_info = None
                                    self.nbr_cluster_id_info = None
                                    self.ignore_connected_check = None
                                    self.internal_vpn_client = None
                                    self.addpath_send_capability = None
                                    self.update_error_handling_no_reset = None
                                    self.addpath_receive_capability = None
                                    self.egress_peer_engineering = None
                                    self.prefix_validation_disable = None
                                    self.bestpath_use_origin_as_validity = None
                                    self.prefix_validation_allow_invalid = None
                                    self.prefix_validation_signal_ibgp = None
                                    self.neighbor_update_filter_exists = None
                                    self.neighbor_update_filter_message_buffer_count = None
                                    self.neighbor_update_filter_message_buffer_is_non_circular = None
                                    self.neighbor_update_filter_logging_disable = None
                                    self.neighbor_update_filter_attribute_filter_group_name = None
                                    self.graceful_shutdown_exists = None
                                    self.graceful_shutdown_loc_pref = None
                                    self.graceful_shutdown_as_prepends = None
                                    self.graceful_shutdown_activate = None
                                    self.neighbor_remote_as_list_group_name = None
                                    self.max_peers = None
                                    self.idle_watch_time = None
                                    self.ao_keychain = None
                                    self.ao_include_tcp_options = None
                                    self.ao_accept_mismatch_connection = None
                                    self.local_as_replace_as = None
                                    self.local_as_dual_as = None

                                    self.local_ip_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress()
                                    self.local_ip_address.parent = self
                                    self._children_name_map["local_ip_address"] = "local-ip-address"

                                    self.remote_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo()
                                    self.remote_as_info.parent = self
                                    self._children_name_map["remote_as_info"] = "remote-as-info"

                                    self.speaker_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo()
                                    self.speaker_id_info.parent = self
                                    self._children_name_map["speaker_id_info"] = "speaker-id-info"

                                    self.min_advertisement_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo()
                                    self.min_advertisement_info.parent = self
                                    self._children_name_map["min_advertisement_info"] = "min-advertisement-info"

                                    self.description_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo()
                                    self.description_info.parent = self
                                    self._children_name_map["description_info"] = "description-info"

                                    self.ebgp_hop_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo()
                                    self.ebgp_hop_count_info.parent = self
                                    self._children_name_map["ebgp_hop_count_info"] = "ebgp-hop-count-info"

                                    self.tcpmss_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo()
                                    self.tcpmss_info.parent = self
                                    self._children_name_map["tcpmss_info"] = "tcpmss-info"

                                    self.bmp_servers_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo()
                                    self.bmp_servers_info.parent = self
                                    self._children_name_map["bmp_servers_info"] = "bmp-servers-info"

                                    self.keychain_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo()
                                    self.keychain_info.parent = self
                                    self._children_name_map["keychain_info"] = "keychain-info"

                                    self.local_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo()
                                    self.local_as_info.parent = self
                                    self._children_name_map["local_as_info"] = "local-as-info"

                                    self.password_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo()
                                    self.password_info.parent = self
                                    self._children_name_map["password_info"] = "password-info"

                                    self.receive_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo()
                                    self.receive_buffer_info.parent = self
                                    self._children_name_map["receive_buffer_info"] = "receive-buffer-info"

                                    self.send_buffer_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo()
                                    self.send_buffer_info.parent = self
                                    self._children_name_map["send_buffer_info"] = "send-buffer-info"

                                    self.shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo()
                                    self.shutdown_info.parent = self
                                    self._children_name_map["shutdown_info"] = "shutdown-info"

                                    self.timers_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo()
                                    self.timers_info.parent = self
                                    self._children_name_map["timers_info"] = "timers-info"

                                    self.local_address_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo()
                                    self.local_address_info.parent = self
                                    self._children_name_map["local_address_info"] = "local-address-info"

                                    self.msg_log_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo()
                                    self.msg_log_in_info.parent = self
                                    self._children_name_map["msg_log_in_info"] = "msg-log-in-info"

                                    self.msg_log_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo()
                                    self.msg_log_out_info.parent = self
                                    self._children_name_map["msg_log_out_info"] = "msg-log-out-info"

                                    self.update_source_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo()
                                    self.update_source_info.parent = self
                                    self._children_name_map["update_source_info"] = "update-source-info"

                                    self.dmz_link_bandwidth_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo()
                                    self.dmz_link_bandwidth_info.parent = self
                                    self._children_name_map["dmz_link_bandwidth_info"] = "dmz-link-bandwidth-info"

                                    self.ebgp_recv_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo()
                                    self.ebgp_recv_dmz_info.parent = self
                                    self._children_name_map["ebgp_recv_dmz_info"] = "ebgp-recv-dmz-info"

                                    self.ebgp_send_dmz_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo()
                                    self.ebgp_send_dmz_info.parent = self
                                    self._children_name_map["ebgp_send_dmz_info"] = "ebgp-send-dmz-info"

                                    self.ttl_security_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo()
                                    self.ttl_security_info.parent = self
                                    self._children_name_map["ttl_security_info"] = "ttl-security-info"

                                    self.suppress4_bbyte_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo()
                                    self.suppress4_bbyte_as_info.parent = self
                                    self._children_name_map["suppress4_bbyte_as_info"] = "suppress4-bbyte-as-info"

                                    self.session_open_mode_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo()
                                    self.session_open_mode_info.parent = self
                                    self._children_name_map["session_open_mode_info"] = "session-open-mode-info"

                                    self.bfd_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo()
                                    self.bfd_info.parent = self
                                    self._children_name_map["bfd_info"] = "bfd-info"

                                    self.bfd_mininterval_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo()
                                    self.bfd_mininterval_info.parent = self
                                    self._children_name_map["bfd_mininterval_info"] = "bfd-mininterval-info"

                                    self.bfd_multiplier_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo()
                                    self.bfd_multiplier_info.parent = self
                                    self._children_name_map["bfd_multiplier_info"] = "bfd-multiplier-info"

                                    self.tos_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo()
                                    self.tos_info.parent = self
                                    self._children_name_map["tos_info"] = "tos-info"

                                    self.nsr_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo()
                                    self.nsr_disabled_info.parent = self
                                    self._children_name_map["nsr_disabled_info"] = "nsr-disabled-info"

                                    self.graceful_restart_disabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo()
                                    self.graceful_restart_disabled_info.parent = self
                                    self._children_name_map["graceful_restart_disabled_info"] = "graceful-restart-disabled-info"

                                    self.nbr_restart_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo()
                                    self.nbr_restart_time_info.parent = self
                                    self._children_name_map["nbr_restart_time_info"] = "nbr-restart-time-info"

                                    self.nbr_stale_path_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo()
                                    self.nbr_stale_path_time_info.parent = self
                                    self._children_name_map["nbr_stale_path_time_info"] = "nbr-stale-path-time-info"

                                    self.nbr_enforce_first_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo()
                                    self.nbr_enforce_first_as_info.parent = self
                                    self._children_name_map["nbr_enforce_first_as_info"] = "nbr-enforce-first-as-info"

                                    self.cluster_id_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo()
                                    self.cluster_id_info.parent = self
                                    self._children_name_map["cluster_id_info"] = "cluster-id-info"

                                    self.ignore_connected_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo()
                                    self.ignore_connected_info.parent = self
                                    self._children_name_map["ignore_connected_info"] = "ignore-connected-info"

                                    self.internal_vpn_client_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo()
                                    self.internal_vpn_client_info.parent = self
                                    self._children_name_map["internal_vpn_client_info"] = "internal-vpn-client-info"

                                    self.addpath_send_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo()
                                    self.addpath_send_capability_info.parent = self
                                    self._children_name_map["addpath_send_capability_info"] = "addpath-send-capability-info"

                                    self.addpath_receive_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo()
                                    self.addpath_receive_capability_info.parent = self
                                    self._children_name_map["addpath_receive_capability_info"] = "addpath-receive-capability-info"

                                    self.egress_peer_engineering_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo()
                                    self.egress_peer_engineering_info.parent = self
                                    self._children_name_map["egress_peer_engineering_info"] = "egress-peer-engineering-info"

                                    self.update_error_handling_no_reset_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo()
                                    self.update_error_handling_no_reset_info.parent = self
                                    self._children_name_map["update_error_handling_no_reset_info"] = "update-error-handling-no-reset-info"

                                    self.prefix_validation_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo()
                                    self.prefix_validation_disable_info.parent = self
                                    self._children_name_map["prefix_validation_disable_info"] = "prefix-validation-disable-info"

                                    self.prefix_validation_use_validit_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo()
                                    self.prefix_validation_use_validit_info.parent = self
                                    self._children_name_map["prefix_validation_use_validit_info"] = "prefix-validation-use-validit-info"

                                    self.prefix_validation_allow_invalid_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo()
                                    self.prefix_validation_allow_invalid_info.parent = self
                                    self._children_name_map["prefix_validation_allow_invalid_info"] = "prefix-validation-allow-invalid-info"

                                    self.prefix_validation_signal_ibgp_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo()
                                    self.prefix_validation_signal_ibgp_info.parent = self
                                    self._children_name_map["prefix_validation_signal_ibgp_info"] = "prefix-validation-signal-ibgp-info"

                                    self.neighbor_update_filter_exists_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo()
                                    self.neighbor_update_filter_exists_info.parent = self
                                    self._children_name_map["neighbor_update_filter_exists_info"] = "neighbor-update-filter-exists-info"

                                    self.neighbor_update_filter_message_buffer_count_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo()
                                    self.neighbor_update_filter_message_buffer_count_info.parent = self
                                    self._children_name_map["neighbor_update_filter_message_buffer_count_info"] = "neighbor-update-filter-message-buffer-count-info"

                                    self.neighbor_update_filter_syslog_disable_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo()
                                    self.neighbor_update_filter_syslog_disable_info.parent = self
                                    self._children_name_map["neighbor_update_filter_syslog_disable_info"] = "neighbor-update-filter-syslog-disable-info"

                                    self.neighbor_update_filter_attribute_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo()
                                    self.neighbor_update_filter_attribute_info.parent = self
                                    self._children_name_map["neighbor_update_filter_attribute_info"] = "neighbor-update-filter-attribute-info"

                                    self.graceful_shutdown_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo()
                                    self.graceful_shutdown_info.parent = self
                                    self._children_name_map["graceful_shutdown_info"] = "graceful-shutdown-info"

                                    self.graceful_shutdown_loc_pref_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo()
                                    self.graceful_shutdown_loc_pref_info.parent = self
                                    self._children_name_map["graceful_shutdown_loc_pref_info"] = "graceful-shutdown-loc-pref-info"

                                    self.graceful_shutdown_as_prepends_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo()
                                    self.graceful_shutdown_as_prepends_info.parent = self
                                    self._children_name_map["graceful_shutdown_as_prepends_info"] = "graceful-shutdown-as-prepends-info"

                                    self.graceful_shutdown_activate_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo()
                                    self.graceful_shutdown_activate_info.parent = self
                                    self._children_name_map["graceful_shutdown_activate_info"] = "graceful-shutdown-activate-info"

                                    self.capability_negotiation_suppressed_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo()
                                    self.capability_negotiation_suppressed_info.parent = self
                                    self._children_name_map["capability_negotiation_suppressed_info"] = "capability-negotiation-suppressed-info"

                                    self.neighbor_remote_as_list_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo()
                                    self.neighbor_remote_as_list_info.parent = self
                                    self._children_name_map["neighbor_remote_as_list_info"] = "neighbor-remote-as-list-info"

                                    self.max_peers_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo()
                                    self.max_peers_info.parent = self
                                    self._children_name_map["max_peers_info"] = "max-peers-info"

                                    self.idle_watch_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo()
                                    self.idle_watch_time_info.parent = self
                                    self._children_name_map["idle_watch_time_info"] = "idle-watch-time-info"

                                    self.ao_keychain_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo()
                                    self.ao_keychain_info.parent = self
                                    self._children_name_map["ao_keychain_info"] = "ao-keychain-info"
                                    self._segment_path = lambda: "af-independent-config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig, [u'remote_as_number_xx', u'remote_as_number_yy', u'configured_speaker_id', u'tcp_mss', u'min_advertisement_interval', u'min_advertisement_interval_msecs', u'description', u'ebgp_hop_count', u'bmp_servers', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'keychain', u'local_as_number_xx', u'local_as_number_yy', u'local_as_no_prepend', u'password', u'socket_buffer_receive_size', u'bgp_buffer_receive_size', u'socket_buffer_send_size', u'bgp_buffer_send_size', u'adminstrative_shutdown', u'keepalive_interval', u'hold_time_value', u'min_acc_hold_time_value', u'msg_log_in_buf_count', u'msg_log_out_buf_count', u'route_updates_source', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'ttl_security', u'suppress4_byte_as', u'capability_negotiation_suppressed', u'session_open_mode', u'bfd', u'bfd_mininterval', u'bfd_multiplier', u'tos_type_info', u'tos_value_info', u'nsr_disabled', u'graceful_restart_disabled', u'nbr_restart_time', u'nbr_stale_path_time', u'nbr_enforce_first_as_status', u'nbr_cluster_id_type_info', u'nbr_cluster_id_info', u'ignore_connected_check', u'internal_vpn_client', u'addpath_send_capability', u'update_error_handling_no_reset', u'addpath_receive_capability', u'egress_peer_engineering', u'prefix_validation_disable', u'bestpath_use_origin_as_validity', u'prefix_validation_allow_invalid', u'prefix_validation_signal_ibgp', u'neighbor_update_filter_exists', u'neighbor_update_filter_message_buffer_count', u'neighbor_update_filter_message_buffer_is_non_circular', u'neighbor_update_filter_logging_disable', u'neighbor_update_filter_attribute_filter_group_name', u'graceful_shutdown_exists', u'graceful_shutdown_loc_pref', u'graceful_shutdown_as_prepends', u'graceful_shutdown_activate', u'neighbor_remote_as_list_group_name', u'max_peers', u'idle_watch_time', u'ao_keychain', u'ao_include_tcp_options', u'ao_accept_mismatch_connection', u'local_as_replace_as', u'local_as_dual_as'], name, value)


                                class LocalIpAddress(Entity):
                                    """
                                    Local ipv4 or ipv6 address for neighbor
                                    connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress, self).__init__()

                                        self.yang_name = "local-ip-address"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "local-ip-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "local-ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "local-ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "local-ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "local-ip-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalIpAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class RemoteAsInfo(Entity):
                                    """
                                    Remote AS number item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo, self).__init__()

                                        self.yang_name = "remote-as-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "remote-as-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "remote-as-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.RemoteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SpeakerIdInfo(Entity):
                                    """
                                    Configured speaker ID item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo, self).__init__()

                                        self.yang_name = "speaker-id-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "speaker-id-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "speaker-id-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SpeakerIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class MinAdvertisementInfo(Entity):
                                    """
                                    Minimum advertisement interval item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo, self).__init__()

                                        self.yang_name = "min-advertisement-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "min-advertisement-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "min-advertisement-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MinAdvertisementInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class DescriptionInfo(Entity):
                                    """
                                    Description item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo, self).__init__()

                                        self.yang_name = "description-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "description-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "description-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DescriptionInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class EbgpHopCountInfo(Entity):
                                    """
                                    EBGP neighbors hop count item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo, self).__init__()

                                        self.yang_name = "ebgp-hop-count-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "ebgp-hop-count-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "ebgp-hop-count-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpHopCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class TcpmssInfo(Entity):
                                    """
                                    TCP Maximum Segment Size item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo, self).__init__()

                                        self.yang_name = "tcpmss-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "tcpmss-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "tcpmss-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TcpmssInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class BmpServersInfo(Entity):
                                    """
                                    BMP Servers Configuredinfo
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo, self).__init__()

                                        self.yang_name = "bmp-servers-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "bmp-servers-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "bmp-servers-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BmpServersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class KeychainInfo(Entity):
                                    """
                                    Neighbor Keychain item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo, self).__init__()

                                        self.yang_name = "keychain-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "keychain-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "keychain-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.KeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class LocalAsInfo(Entity):
                                    """
                                    Local AS number item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo, self).__init__()

                                        self.yang_name = "local-as-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "local-as-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "local-as-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class PasswordInfo(Entity):
                                    """
                                    Neighbor password item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo, self).__init__()

                                        self.yang_name = "password-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "password-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "password-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PasswordInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class ReceiveBufferInfo(Entity):
                                    """
                                    Receive buffer sizes item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo, self).__init__()

                                        self.yang_name = "receive-buffer-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "receive-buffer-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "receive-buffer-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ReceiveBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SendBufferInfo(Entity):
                                    """
                                    Send buffer sizes item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo, self).__init__()

                                        self.yang_name = "send-buffer-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "send-buffer-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "send-buffer-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SendBufferInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class ShutdownInfo(Entity):
                                    """
                                    Shutdown item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo, self).__init__()

                                        self.yang_name = "shutdown-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "shutdown-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "shutdown-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class TimersInfo(Entity):
                                    """
                                    Timers item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo, self).__init__()

                                        self.yang_name = "timers-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "timers-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "timers-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TimersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class LocalAddressInfo(Entity):
                                    """
                                    Local address item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo, self).__init__()

                                        self.yang_name = "local-address-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "local-address-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "local-address-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.LocalAddressInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class MsgLogInInfo(Entity):
                                    """
                                    Message Log Inbound item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo, self).__init__()

                                        self.yang_name = "msg-log-in-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "msg-log-in-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "msg-log-in-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class MsgLogOutInfo(Entity):
                                    """
                                    Message Log Outbound item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo, self).__init__()

                                        self.yang_name = "msg-log-out-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "msg-log-out-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "msg-log-out-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MsgLogOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class UpdateSourceInfo(Entity):
                                    """
                                    Update source item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo, self).__init__()

                                        self.yang_name = "update-source-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "update-source-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "update-source-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateSourceInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class DmzLinkBandwidthInfo(Entity):
                                    """
                                    DMZ link bandwidth item 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo, self).__init__()

                                        self.yang_name = "dmz-link-bandwidth-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "dmz-link-bandwidth-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "dmz-link-bandwidth-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.DmzLinkBandwidthInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class EbgpRecvDmzInfo(Entity):
                                    """
                                    EBGP receive DMZ link bandwidth item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo, self).__init__()

                                        self.yang_name = "ebgp-recv-dmz-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "ebgp-recv-dmz-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "ebgp-recv-dmz-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpRecvDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class EbgpSendDmzInfo(Entity):
                                    """
                                    EBGP send DMZ link bandwidth item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo, self).__init__()

                                        self.yang_name = "ebgp-send-dmz-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "ebgp-send-dmz-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "ebgp-send-dmz-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EbgpSendDmzInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class TtlSecurityInfo(Entity):
                                    """
                                    BGP TTL Security item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo, self).__init__()

                                        self.yang_name = "ttl-security-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "ttl-security-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "ttl-security-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TtlSecurityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class Suppress4BbyteAsInfo(Entity):
                                    """
                                    BGP suppress 4byte\-as item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo, self).__init__()

                                        self.yang_name = "suppress4-bbyte-as-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "suppress4-bbyte-as-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "suppress4-bbyte-as-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.Suppress4BbyteAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SessionOpenModeInfo(Entity):
                                    """
                                    TCP conn open mode info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo, self).__init__()

                                        self.yang_name = "session-open-mode-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "session-open-mode-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "session-open-mode-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.SessionOpenModeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class BfdInfo(Entity):
                                    """
                                    BFD item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo, self).__init__()

                                        self.yang_name = "bfd-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "bfd-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "bfd-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class BfdMinintervalInfo(Entity):
                                    """
                                    BFD Mininterval item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo, self).__init__()

                                        self.yang_name = "bfd-mininterval-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "bfd-mininterval-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "bfd-mininterval-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMinintervalInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class BfdMultiplierInfo(Entity):
                                    """
                                    BFD Multiplier item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo, self).__init__()

                                        self.yang_name = "bfd-multiplier-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "bfd-multiplier-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "bfd-multiplier-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.BfdMultiplierInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class TosInfo(Entity):
                                    """
                                    TOS item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo, self).__init__()

                                        self.yang_name = "tos-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "tos-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "tos-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.TosInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NsrDisabledInfo(Entity):
                                    """
                                    NSR item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo, self).__init__()

                                        self.yang_name = "nsr-disabled-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "nsr-disabled-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "nsr-disabled-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NsrDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class GracefulRestartDisabledInfo(Entity):
                                    """
                                    Graceful\-restart item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo, self).__init__()

                                        self.yang_name = "graceful-restart-disabled-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "graceful-restart-disabled-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "graceful-restart-disabled-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulRestartDisabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NbrRestartTimeInfo(Entity):
                                    """
                                    Restart time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo, self).__init__()

                                        self.yang_name = "nbr-restart-time-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "nbr-restart-time-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "nbr-restart-time-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrRestartTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NbrStalePathTimeInfo(Entity):
                                    """
                                    Stale\-path time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo, self).__init__()

                                        self.yang_name = "nbr-stale-path-time-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "nbr-stale-path-time-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "nbr-stale-path-time-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrStalePathTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NbrEnforceFirstAsInfo(Entity):
                                    """
                                    Neighbor enforce first AS info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo, self).__init__()

                                        self.yang_name = "nbr-enforce-first-as-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "nbr-enforce-first-as-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "nbr-enforce-first-as-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NbrEnforceFirstAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class ClusterIdInfo(Entity):
                                    """
                                    Cluster ID item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo, self).__init__()

                                        self.yang_name = "cluster-id-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "cluster-id-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "cluster-id-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.ClusterIdInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class IgnoreConnectedInfo(Entity):
                                    """
                                    Ignore Connected Info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo, self).__init__()

                                        self.yang_name = "ignore-connected-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "ignore-connected-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "ignore-connected-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IgnoreConnectedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class InternalVpnClientInfo(Entity):
                                    """
                                    Internal VPN Client Info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo, self).__init__()

                                        self.yang_name = "internal-vpn-client-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "internal-vpn-client-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "internal-vpn-client-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.InternalVpnClientInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AddpathSendCapabilityInfo(Entity):
                                    """
                                    Addpath send capability info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo, self).__init__()

                                        self.yang_name = "addpath-send-capability-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "addpath-send-capability-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "addpath-send-capability-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathSendCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AddpathReceiveCapabilityInfo(Entity):
                                    """
                                    Addpath receive capability info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo, self).__init__()

                                        self.yang_name = "addpath-receive-capability-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "addpath-receive-capability-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "addpath-receive-capability-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AddpathReceiveCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class EgressPeerEngineeringInfo(Entity):
                                    """
                                    Egress Peer Engineering info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo, self).__init__()

                                        self.yang_name = "egress-peer-engineering-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "egress-peer-engineering-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "egress-peer-engineering-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.EgressPeerEngineeringInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class UpdateErrorHandlingNoResetInfo(Entity):
                                    """
                                    Error\-handling avoid\-reset config info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo, self).__init__()

                                        self.yang_name = "update-error-handling-no-reset-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "update-error-handling-no-reset-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "update-error-handling-no-reset-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.UpdateErrorHandlingNoResetInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class PrefixValidationDisableInfo(Entity):
                                    """
                                    RPKI disable info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo, self).__init__()

                                        self.yang_name = "prefix-validation-disable-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "prefix-validation-disable-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "prefix-validation-disable-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class PrefixValidationUseValiditInfo(Entity):
                                    """
                                    RPKI use validity
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo, self).__init__()

                                        self.yang_name = "prefix-validation-use-validit-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "prefix-validation-use-validit-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "prefix-validation-use-validit-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationUseValiditInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class PrefixValidationAllowInvalidInfo(Entity):
                                    """
                                    RPKI allow invalid info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo, self).__init__()

                                        self.yang_name = "prefix-validation-allow-invalid-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "prefix-validation-allow-invalid-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "prefix-validation-allow-invalid-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationAllowInvalidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class PrefixValidationSignalIbgpInfo(Entity):
                                    """
                                    RPKI signal ibgp info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo, self).__init__()

                                        self.yang_name = "prefix-validation-signal-ibgp-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "prefix-validation-signal-ibgp-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "prefix-validation-signal-ibgp-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.PrefixValidationSignalIbgpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NeighborUpdateFilterExistsInfo(Entity):
                                    """
                                    Neighbor update filter configuration info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo, self).__init__()

                                        self.yang_name = "neighbor-update-filter-exists-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "neighbor-update-filter-exists-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "neighbor-update-filter-exists-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterExistsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NeighborUpdateFilterMessageBufferCountInfo(Entity):
                                    """
                                    Neighbor update filter message buffer count info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo, self).__init__()

                                        self.yang_name = "neighbor-update-filter-message-buffer-count-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "neighbor-update-filter-message-buffer-count-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "neighbor-update-filter-message-buffer-count-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterMessageBufferCountInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NeighborUpdateFilterSyslogDisableInfo(Entity):
                                    """
                                    Neighbor update filter syslog disable info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo, self).__init__()

                                        self.yang_name = "neighbor-update-filter-syslog-disable-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "neighbor-update-filter-syslog-disable-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "neighbor-update-filter-syslog-disable-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterSyslogDisableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NeighborUpdateFilterAttributeInfo(Entity):
                                    """
                                    Neighbor update filter attribute\-filter group
                                    info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo, self).__init__()

                                        self.yang_name = "neighbor-update-filter-attribute-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "neighbor-update-filter-attribute-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "neighbor-update-filter-attribute-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborUpdateFilterAttributeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class GracefulShutdownInfo(Entity):
                                    """
                                    GracefulShutdown info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo, self).__init__()

                                        self.yang_name = "graceful-shutdown-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "graceful-shutdown-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "graceful-shutdown-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class GracefulShutdownLocPrefInfo(Entity):
                                    """
                                    GracefulShutdownLocPref info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo, self).__init__()

                                        self.yang_name = "graceful-shutdown-loc-pref-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "graceful-shutdown-loc-pref-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "graceful-shutdown-loc-pref-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownLocPrefInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class GracefulShutdownAsPrependsInfo(Entity):
                                    """
                                    GracefulShutdownASPrepends info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo, self).__init__()

                                        self.yang_name = "graceful-shutdown-as-prepends-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "graceful-shutdown-as-prepends-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "graceful-shutdown-as-prepends-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownAsPrependsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class GracefulShutdownActivateInfo(Entity):
                                    """
                                    GracefulShutdownAcivate info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo, self).__init__()

                                        self.yang_name = "graceful-shutdown-activate-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "graceful-shutdown-activate-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "graceful-shutdown-activate-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.GracefulShutdownActivateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class CapabilityNegotiationSuppressedInfo(Entity):
                                    """
                                    Capability negotiation suppressed info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo, self).__init__()

                                        self.yang_name = "capability-negotiation-suppressed-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "capability-negotiation-suppressed-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "capability-negotiation-suppressed-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.CapabilityNegotiationSuppressedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NeighborRemoteAsListInfo(Entity):
                                    """
                                    Neighbor range  remote\-as\-list group info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo, self).__init__()

                                        self.yang_name = "neighbor-remote-as-list-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "neighbor-remote-as-list-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "neighbor-remote-as-list-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.NeighborRemoteAsListInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class MaxPeersInfo(Entity):
                                    """
                                    Max dynamic nbrs in range info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo, self).__init__()

                                        self.yang_name = "max-peers-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "max-peers-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "max-peers-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.MaxPeersInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class IdleWatchTimeInfo(Entity):
                                    """
                                    Idle Watch time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo, self).__init__()

                                        self.yang_name = "idle-watch-time-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "idle-watch-time-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "idle-watch-time-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.IdleWatchTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AoKeychainInfo(Entity):
                                    """
                                    Neighbor AO keychain item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo, self).__init__()

                                        self.yang_name = "ao-keychain-info"
                                        self.yang_parent_name = "af-independent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "ao-keychain-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "ao-keychain-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfIndependentConfig.AoKeychainInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfDependentConfig(Entity):
                                """
                                Af\-dependent config
                                
                                .. attribute:: orr_root_address
                                
                                	ORR Root Address
                                	**type**\:  :py:class:`OrrRootAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress>`
                                
                                .. attribute:: orf_capability_info
                                
                                	ORF capability item info
                                	**type**\:  :py:class:`OrfCapabilityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo>`
                                
                                .. attribute:: default_originate_info
                                
                                	Default\-originate item info
                                	**type**\:  :py:class:`DefaultOriginateInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo>`
                                
                                .. attribute:: max_prefixes_info
                                
                                	Maximum prefixes to accept item info
                                	**type**\:  :py:class:`MaxPrefixesInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo>`
                                
                                .. attribute:: orr_info
                                
                                	Orr item info
                                	**type**\:  :py:class:`OrrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo>`
                                
                                .. attribute:: next_hop_self_info
                                
                                	Next hop self item info
                                	**type**\:  :py:class:`NextHopSelfInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo>`
                                
                                .. attribute:: next_hop_unchanged_info
                                
                                	Next hop unchanged info
                                	**type**\:  :py:class:`NextHopUnchangedInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo>`
                                
                                .. attribute:: route_policy_in_info
                                
                                	Inbound route policy item info
                                	**type**\:  :py:class:`RoutePolicyInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo>`
                                
                                .. attribute:: route_policy_out_info
                                
                                	Outbound route policy item info
                                	**type**\:  :py:class:`RoutePolicyOutInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo>`
                                
                                .. attribute:: prefix_filter_info
                                
                                	Inbound prefix based filter item info
                                	**type**\:  :py:class:`PrefixFilterInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo>`
                                
                                .. attribute:: remove_private_as_info
                                
                                	Outbound private\-AS removal item info
                                	**type**\:  :py:class:`RemovePrivateAsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo>`
                                
                                .. attribute:: remove_private_as_in_info
                                
                                	Inbound private\-AS removal item info
                                	**type**\:  :py:class:`RemovePrivateAsInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo>`
                                
                                .. attribute:: route_reflector_info
                                
                                	Route\-reflector client item info
                                	**type**\:  :py:class:`RouteReflectorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo>`
                                
                                .. attribute:: legacy_pe_rt_info
                                
                                	Accept\-legacy\-pe\-RT item info
                                	**type**\:  :py:class:`LegacyPeRtInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo>`
                                
                                .. attribute:: af_enabled_info
                                
                                	Address family activate item info
                                	**type**\:  :py:class:`AfEnabledInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo>`
                                
                                .. attribute:: send_community_info
                                
                                	Send community attribute item info
                                	**type**\:  :py:class:`SendCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo>`
                                
                                .. attribute:: send_graceful_shutdown_community_info
                                
                                	Send Graceful shutdown related community attribute item info
                                	**type**\:  :py:class:`SendGracefulShutdownCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo>`
                                
                                .. attribute:: send_extended_community_info
                                
                                	Send extended community  item info
                                	**type**\:  :py:class:`SendExtendedCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo>`
                                
                                .. attribute:: soft_reconfig_info
                                
                                	Soft reconf item info
                                	**type**\:  :py:class:`SoftReconfigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo>`
                                
                                .. attribute:: so_o_info
                                
                                	BGP Site\-of\-Origin info
                                	**type**\:  :py:class:`SoOInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo>`
                                
                                .. attribute:: weight_info
                                
                                	Default weight item info
                                	**type**\:  :py:class:`WeightInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo>`
                                
                                .. attribute:: allowas_in_info
                                
                                	Allowas\-in item info
                                	**type**\:  :py:class:`AllowasInInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo>`
                                
                                .. attribute:: af_long_lived_graceful_start_stale_time_info
                                
                                	Long\-lived\-time item info
                                	**type**\:  :py:class:`AfLongLivedGracefulStartStaleTimeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo>`
                                
                                .. attribute:: af_long_lived_graceful_start_capable_info
                                
                                	Long\-lived\-time item info
                                	**type**\:  :py:class:`AfLongLivedGracefulStartCapableInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo>`
                                
                                .. attribute:: as_override_info
                                
                                	As\-override info 
                                	**type**\:  :py:class:`AsOverrideInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo>`
                                
                                .. attribute:: aigp_info
                                
                                	AIGP info 
                                	**type**\:  :py:class:`AigpInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo>`
                                
                                .. attribute:: aigp_cost_community_info
                                
                                	AIGP Cost Community info 
                                	**type**\:  :py:class:`AigpCostCommunityInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo>`
                                
                                .. attribute:: aigp_med
                                
                                	AIGP MED info 
                                	**type**\:  :py:class:`AigpMed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed>`
                                
                                .. attribute:: accept_own_info
                                
                                	Accept\-Own info
                                	**type**\:  :py:class:`AcceptOwnInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo>`
                                
                                .. attribute:: multipath_info
                                
                                	Multipath info
                                	**type**\:  :py:class:`MultipathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo>`
                                
                                .. attribute:: fspec_valid_info
                                
                                	FSPEC Valid info
                                	**type**\:  :py:class:`FspecValidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo>`
                                
                                .. attribute:: next_hop_unchanged_mpath_info
                                
                                	Next hop unchanged mpath info
                                	**type**\:  :py:class:`NextHopUnchangedMpathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo>`
                                
                                .. attribute:: permanent_network_info
                                
                                	Permanent network Info 
                                	**type**\:  :py:class:`PermanentNetworkInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo>`
                                
                                .. attribute:: send_mcast_attr_info
                                
                                	Send mcast attr info
                                	**type**\:  :py:class:`SendMcastAttrInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo>`
                                
                                .. attribute:: advertise_v4_afi_info
                                
                                	Advertise Afi Info 
                                	**type**\:  :py:class:`AdvertiseV4AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo>`
                                
                                .. attribute:: advertise_v6_afi_info
                                
                                	Advertise Afi Info 
                                	**type**\:  :py:class:`AdvertiseV6AfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo>`
                                
                                .. attribute:: advertise_l2vpn_evpn_afi_info
                                
                                	Advertise Afi Info 
                                	**type**\:  :py:class:`AdvertiseL2vpnEvpnAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo>`
                                
                                .. attribute:: advertise_dis_info
                                
                                	Advertise Afi Info 
                                	**type**\:  :py:class:`AdvertiseDisInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo>`
                                
                                .. attribute:: advertise_def_vrf_imp_disable_afi_v4_info
                                
                                	Advertise Afi Info 
                                	**type**\:  :py:class:`AdvertiseDefVrfImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info>`
                                
                                .. attribute:: advertise_def_vrf_imp_disable_afi_v6_info
                                
                                	Advertise Afi Info 
                                	**type**\:  :py:class:`AdvertiseDefVrfImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info>`
                                
                                .. attribute:: advertise_vrf_re_imp_disable_afi_v4_info
                                
                                	Advertise Afi Info 
                                	**type**\:  :py:class:`AdvertiseVrfReImpDisableAfiV4Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info>`
                                
                                .. attribute:: advertise_vrf_re_imp_disable_afi_v6_info
                                
                                	Advertise Afi Info 
                                	**type**\:  :py:class:`AdvertiseVrfReImpDisableAfiV6Info <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info>`
                                
                                .. attribute:: af_encapsulation_type_info
                                
                                	Encapsulation type Info 
                                	**type**\:  :py:class:`AfEncapsulationTypeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo>`
                                
                                .. attribute:: import_afi_info
                                
                                	Import Afi Info 
                                	**type**\:  :py:class:`ImportAfiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo>`
                                
                                .. attribute:: advertise_local_labeled_route_info
                                
                                	Advertise routes with local\-label
                                	**type**\:  :py:class:`AdvertiseLocalLabeledRouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo>`
                                
                                .. attribute:: enforce_multiple_labels_info
                                
                                	Enforce multiple labels
                                	**type**\:  :py:class:`EnforceMultipleLabelsInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo>`
                                
                                .. attribute:: has_orf_capability
                                
                                	ORF capability
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_default_originate_not_disabled
                                
                                	TRUE if default\-originate is not disabled
                                	**type**\: bool
                                
                                .. attribute:: default_originate_route_policy
                                
                                	Default\-originate route policy name
                                	**type**\: str
                                
                                .. attribute:: max_prefixes
                                
                                	Maximum prefixes to accept
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_warn_threshold
                                
                                	Warning message threshhold
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_max_prefix_warn_only
                                
                                	Warning messages only
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Restart time Value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_max_prefix_discard_extra_paths
                                
                                	Discard extra paths
                                	**type**\: bool
                                
                                .. attribute:: is_next_hop_self_disabled
                                
                                	Disable next\-hop calc
                                	**type**\: bool
                                
                                .. attribute:: is_next_hop_unchanged
                                
                                	Don't change next\-hop
                                	**type**\: bool
                                
                                .. attribute:: permanent_network
                                
                                	Permanent Network
                                	**type**\: bool
                                
                                .. attribute:: route_policy_in
                                
                                	Inbound route policy name
                                	**type**\: str
                                
                                .. attribute:: route_policy_out
                                
                                	Outbound route policy name
                                	**type**\: str
                                
                                .. attribute:: prefix_orf_filter
                                
                                	Inbound prefix based filter
                                	**type**\: str
                                
                                .. attribute:: remove_private_as_out
                                
                                	Outbound private\-AS removal
                                	**type**\: bool
                                
                                .. attribute:: entire_aspath_out
                                
                                	Outbound private\-AS removalif the entire AS Path hasprivate ASes
                                	**type**\: bool
                                
                                .. attribute:: remove_private_asin
                                
                                	Inbound private\-AS removal
                                	**type**\: bool
                                
                                .. attribute:: entire_aspath_in
                                
                                	Inbound private\-AS removal if the entire AS Path has private ASes
                                	**type**\: bool
                                
                                .. attribute:: client_route_reflector
                                
                                	Route\-reflector client
                                	**type**\: bool
                                
                                .. attribute:: accept_route_legacy_pe_rt
                                
                                	accept\-legacy\-pe RT route
                                	**type**\: bool
                                
                                .. attribute:: is_af_enabled
                                
                                	Entity is activated for this address family
                                	**type**\: bool
                                
                                .. attribute:: send_community_attribute
                                
                                	Send community attribute
                                	**type**\: bool
                                
                                .. attribute:: send_graceful_shut_community_attributes
                                
                                	Send Graceful shutdown related community attributes
                                	**type**\: bool
                                
                                .. attribute:: send_extended_community_attribute
                                
                                	Send extended community attribute
                                	**type**\: bool
                                
                                .. attribute:: soft_reconfig_not_disabled
                                
                                	TRUE if soft reconf is not disabled
                                	**type**\: bool
                                
                                .. attribute:: alway_use_soft_reconfig
                                
                                	Always use soft reconfig
                                	**type**\: bool
                                
                                .. attribute:: site_of_origin
                                
                                	Site of Origin
                                	**type**\: str
                                
                                .. attribute:: default_weight
                                
                                	Default weight
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: default_allowas
                                
                                	Default allowas\_in count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_long_lived_graceful_restart_stale_time_send
                                
                                	Stale time to be sent in long\-lived graceful\-restart capability
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_long_lived_graceful_restart_stale_time_accept
                                
                                	Maxmimum acceptable long\-lived stale time acceptable from neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_long_lived_graceful_restart_capable
                                
                                	Long\-lived graceful\-restart capable
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_as_override_disabled
                                
                                	Disable as override
                                	**type**\: bool
                                
                                .. attribute:: is_aigp_enabled
                                
                                	AIGP enabled
                                	**type**\: bool
                                
                                .. attribute:: is_aigp_cost_community_enabled
                                
                                	AIGP cost community enabled
                                	**type**\: bool
                                
                                .. attribute:: is_aigp_cost_community_id
                                
                                	AIGP cost community ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_aigp_cost_community_transitive
                                
                                	AIGP cost community ID is transitive
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aigp_cost_community_poi
                                
                                	Point of insertion for AIGP cost community
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_aigp_med_enabled
                                
                                	AIGP to MED enabled
                                	**type**\: bool
                                
                                .. attribute:: accept_own
                                
                                	Accept Own
                                	**type**\: bool
                                
                                .. attribute:: multipath
                                
                                	multipath
                                	**type**\: bool
                                
                                .. attribute:: is_fspec_valid_enabled
                                
                                	FSPEC VALID enabled
                                	**type**\: bool
                                
                                .. attribute:: is_next_hop_unchanged_mpath
                                
                                	Don't change mpath next\-hop
                                	**type**\: bool
                                
                                .. attribute:: is_send_mcast_attr_enabled
                                
                                	Send mcast attr enabled
                                	**type**\: bool
                                
                                .. attribute:: advertise_v4
                                
                                	Advertise afi
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_v6
                                
                                	Advertise afi
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_l2vpn_evpn
                                
                                	Advertise afi
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_disable
                                
                                	Advertise afi
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_def_vrf_imp_disable_v4
                                
                                	Advertise afi
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_def_vrf_imp_disable_v6
                                
                                	Advertise afi
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_vrf_re_imp_disable_v4
                                
                                	Advertise afi
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_vrf_re_imp_disable_v6
                                
                                	Advertise afi
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: import_
                                
                                	Import
                                	**type**\: bool
                                
                                .. attribute:: import_stitching
                                
                                	Import stitching RTs
                                	**type**\: bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import reoriginate
                                	**type**\: bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import reoriginate stitching RTs
                                	**type**\: bool
                                
                                .. attribute:: advertise_local_labeled_route
                                
                                	Advertise routes with local\-label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: enforce_multiple_labels
                                
                                	Enforce multiple labels
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig, self).__init__()

                                    self.yang_name = "af-dependent-config"
                                    self.yang_parent_name = "entity-configuration"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("orr-root-address", ("orr_root_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress)), ("orf-capability-info", ("orf_capability_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo)), ("default-originate-info", ("default_originate_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo)), ("max-prefixes-info", ("max_prefixes_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo)), ("orr-info", ("orr_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo)), ("next-hop-self-info", ("next_hop_self_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo)), ("next-hop-unchanged-info", ("next_hop_unchanged_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo)), ("route-policy-in-info", ("route_policy_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo)), ("route-policy-out-info", ("route_policy_out_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo)), ("prefix-filter-info", ("prefix_filter_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo)), ("remove-private-as-info", ("remove_private_as_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo)), ("remove-private-as-in-info", ("remove_private_as_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo)), ("route-reflector-info", ("route_reflector_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo)), ("legacy-pe-rt-info", ("legacy_pe_rt_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo)), ("af-enabled-info", ("af_enabled_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo)), ("send-community-info", ("send_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo)), ("send-graceful-shutdown-community-info", ("send_graceful_shutdown_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo)), ("send-extended-community-info", ("send_extended_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo)), ("soft-reconfig-info", ("soft_reconfig_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo)), ("so-o-info", ("so_o_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo)), ("weight-info", ("weight_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo)), ("allowas-in-info", ("allowas_in_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo)), ("af-long-lived-graceful-start-stale-time-info", ("af_long_lived_graceful_start_stale_time_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo)), ("af-long-lived-graceful-start-capable-info", ("af_long_lived_graceful_start_capable_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo)), ("as-override-info", ("as_override_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo)), ("aigp-info", ("aigp_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo)), ("aigp-cost-community-info", ("aigp_cost_community_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo)), ("aigp-med", ("aigp_med", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed)), ("accept-own-info", ("accept_own_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo)), ("multipath-info", ("multipath_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo)), ("fspec-valid-info", ("fspec_valid_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo)), ("next-hop-unchanged-mpath-info", ("next_hop_unchanged_mpath_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo)), ("permanent-network-info", ("permanent_network_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo)), ("send-mcast-attr-info", ("send_mcast_attr_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo)), ("advertise-v4-afi-info", ("advertise_v4_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo)), ("advertise-v6-afi-info", ("advertise_v6_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo)), ("advertise-l2vpn-evpn-afi-info", ("advertise_l2vpn_evpn_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo)), ("advertise-dis-info", ("advertise_dis_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo)), ("advertise-def-vrf-imp-disable-afi-v4-info", ("advertise_def_vrf_imp_disable_afi_v4_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info)), ("advertise-def-vrf-imp-disable-afi-v6-info", ("advertise_def_vrf_imp_disable_afi_v6_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info)), ("advertise-vrf-re-imp-disable-afi-v4-info", ("advertise_vrf_re_imp_disable_afi_v4_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info)), ("advertise-vrf-re-imp-disable-afi-v6-info", ("advertise_vrf_re_imp_disable_afi_v6_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info)), ("af-encapsulation-type-info", ("af_encapsulation_type_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo)), ("import-afi-info", ("import_afi_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo)), ("advertise-local-labeled-route-info", ("advertise_local_labeled_route_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo)), ("enforce-multiple-labels-info", ("enforce_multiple_labels_info", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo))])
                                    self._leafs = OrderedDict([
                                        ('has_orf_capability', (YLeaf(YType.uint32, 'has-orf-capability'), ['int'])),
                                        ('is_default_originate_not_disabled', (YLeaf(YType.boolean, 'is-default-originate-not-disabled'), ['bool'])),
                                        ('default_originate_route_policy', (YLeaf(YType.str, 'default-originate-route-policy'), ['str'])),
                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                        ('max_prefix_warn_threshold', (YLeaf(YType.uint32, 'max-prefix-warn-threshold'), ['int'])),
                                        ('is_max_prefix_warn_only', (YLeaf(YType.boolean, 'is-max-prefix-warn-only'), ['bool'])),
                                        ('max_prefix_restart_time', (YLeaf(YType.uint32, 'max-prefix-restart-time'), ['int'])),
                                        ('is_max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'is-max-prefix-discard-extra-paths'), ['bool'])),
                                        ('is_next_hop_self_disabled', (YLeaf(YType.boolean, 'is-next-hop-self-disabled'), ['bool'])),
                                        ('is_next_hop_unchanged', (YLeaf(YType.boolean, 'is-next-hop-unchanged'), ['bool'])),
                                        ('permanent_network', (YLeaf(YType.boolean, 'permanent-network'), ['bool'])),
                                        ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                        ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                        ('prefix_orf_filter', (YLeaf(YType.str, 'prefix-orf-filter'), ['str'])),
                                        ('remove_private_as_out', (YLeaf(YType.boolean, 'remove-private-as-out'), ['bool'])),
                                        ('entire_aspath_out', (YLeaf(YType.boolean, 'entire-aspath-out'), ['bool'])),
                                        ('remove_private_asin', (YLeaf(YType.boolean, 'remove-private-asin'), ['bool'])),
                                        ('entire_aspath_in', (YLeaf(YType.boolean, 'entire-aspath-in'), ['bool'])),
                                        ('client_route_reflector', (YLeaf(YType.boolean, 'client-route-reflector'), ['bool'])),
                                        ('accept_route_legacy_pe_rt', (YLeaf(YType.boolean, 'accept-route-legacy-pe-rt'), ['bool'])),
                                        ('is_af_enabled', (YLeaf(YType.boolean, 'is-af-enabled'), ['bool'])),
                                        ('send_community_attribute', (YLeaf(YType.boolean, 'send-community-attribute'), ['bool'])),
                                        ('send_graceful_shut_community_attributes', (YLeaf(YType.boolean, 'send-graceful-shut-community-attributes'), ['bool'])),
                                        ('send_extended_community_attribute', (YLeaf(YType.boolean, 'send-extended-community-attribute'), ['bool'])),
                                        ('soft_reconfig_not_disabled', (YLeaf(YType.boolean, 'soft-reconfig-not-disabled'), ['bool'])),
                                        ('alway_use_soft_reconfig', (YLeaf(YType.boolean, 'alway-use-soft-reconfig'), ['bool'])),
                                        ('site_of_origin', (YLeaf(YType.str, 'site-of-origin'), ['str'])),
                                        ('default_weight', (YLeaf(YType.uint32, 'default-weight'), ['int'])),
                                        ('default_allowas', (YLeaf(YType.uint32, 'default-allowas'), ['int'])),
                                        ('af_long_lived_graceful_restart_stale_time_send', (YLeaf(YType.uint32, 'af-long-lived-graceful-restart-stale-time-send'), ['int'])),
                                        ('af_long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'af-long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                        ('af_long_lived_graceful_restart_capable', (YLeaf(YType.uint32, 'af-long-lived-graceful-restart-capable'), ['int'])),
                                        ('is_as_override_disabled', (YLeaf(YType.boolean, 'is-as-override-disabled'), ['bool'])),
                                        ('is_aigp_enabled', (YLeaf(YType.boolean, 'is-aigp-enabled'), ['bool'])),
                                        ('is_aigp_cost_community_enabled', (YLeaf(YType.boolean, 'is-aigp-cost-community-enabled'), ['bool'])),
                                        ('is_aigp_cost_community_id', (YLeaf(YType.uint32, 'is-aigp-cost-community-id'), ['int'])),
                                        ('is_aigp_cost_community_transitive', (YLeaf(YType.uint32, 'is-aigp-cost-community-transitive'), ['int'])),
                                        ('aigp_cost_community_poi', (YLeaf(YType.uint32, 'aigp-cost-community-poi'), ['int'])),
                                        ('is_aigp_med_enabled', (YLeaf(YType.boolean, 'is-aigp-med-enabled'), ['bool'])),
                                        ('accept_own', (YLeaf(YType.boolean, 'accept-own'), ['bool'])),
                                        ('multipath', (YLeaf(YType.boolean, 'multipath'), ['bool'])),
                                        ('is_fspec_valid_enabled', (YLeaf(YType.boolean, 'is-fspec-valid-enabled'), ['bool'])),
                                        ('is_next_hop_unchanged_mpath', (YLeaf(YType.boolean, 'is-next-hop-unchanged-mpath'), ['bool'])),
                                        ('is_send_mcast_attr_enabled', (YLeaf(YType.boolean, 'is-send-mcast-attr-enabled'), ['bool'])),
                                        ('advertise_v4', (YLeaf(YType.uint8, 'advertise-v4'), ['int'])),
                                        ('advertise_v6', (YLeaf(YType.uint8, 'advertise-v6'), ['int'])),
                                        ('advertise_l2vpn_evpn', (YLeaf(YType.uint8, 'advertise-l2vpn-evpn'), ['int'])),
                                        ('advertise_disable', (YLeaf(YType.uint8, 'advertise-disable'), ['int'])),
                                        ('advertise_def_vrf_imp_disable_v4', (YLeaf(YType.uint8, 'advertise-def-vrf-imp-disable-v4'), ['int'])),
                                        ('advertise_def_vrf_imp_disable_v6', (YLeaf(YType.uint8, 'advertise-def-vrf-imp-disable-v6'), ['int'])),
                                        ('advertise_vrf_re_imp_disable_v4', (YLeaf(YType.uint8, 'advertise-vrf-re-imp-disable-v4'), ['int'])),
                                        ('advertise_vrf_re_imp_disable_v6', (YLeaf(YType.uint8, 'advertise-vrf-re-imp-disable-v6'), ['int'])),
                                        ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                        ('import_', (YLeaf(YType.boolean, 'import'), ['bool'])),
                                        ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                        ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                        ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                        ('advertise_local_labeled_route', (YLeaf(YType.uint32, 'advertise-local-labeled-route'), ['int'])),
                                        ('enforce_multiple_labels', (YLeaf(YType.uint32, 'enforce-multiple-labels'), ['int'])),
                                    ])
                                    self.has_orf_capability = None
                                    self.is_default_originate_not_disabled = None
                                    self.default_originate_route_policy = None
                                    self.max_prefixes = None
                                    self.max_prefix_warn_threshold = None
                                    self.is_max_prefix_warn_only = None
                                    self.max_prefix_restart_time = None
                                    self.is_max_prefix_discard_extra_paths = None
                                    self.is_next_hop_self_disabled = None
                                    self.is_next_hop_unchanged = None
                                    self.permanent_network = None
                                    self.route_policy_in = None
                                    self.route_policy_out = None
                                    self.prefix_orf_filter = None
                                    self.remove_private_as_out = None
                                    self.entire_aspath_out = None
                                    self.remove_private_asin = None
                                    self.entire_aspath_in = None
                                    self.client_route_reflector = None
                                    self.accept_route_legacy_pe_rt = None
                                    self.is_af_enabled = None
                                    self.send_community_attribute = None
                                    self.send_graceful_shut_community_attributes = None
                                    self.send_extended_community_attribute = None
                                    self.soft_reconfig_not_disabled = None
                                    self.alway_use_soft_reconfig = None
                                    self.site_of_origin = None
                                    self.default_weight = None
                                    self.default_allowas = None
                                    self.af_long_lived_graceful_restart_stale_time_send = None
                                    self.af_long_lived_graceful_restart_stale_time_accept = None
                                    self.af_long_lived_graceful_restart_capable = None
                                    self.is_as_override_disabled = None
                                    self.is_aigp_enabled = None
                                    self.is_aigp_cost_community_enabled = None
                                    self.is_aigp_cost_community_id = None
                                    self.is_aigp_cost_community_transitive = None
                                    self.aigp_cost_community_poi = None
                                    self.is_aigp_med_enabled = None
                                    self.accept_own = None
                                    self.multipath = None
                                    self.is_fspec_valid_enabled = None
                                    self.is_next_hop_unchanged_mpath = None
                                    self.is_send_mcast_attr_enabled = None
                                    self.advertise_v4 = None
                                    self.advertise_v6 = None
                                    self.advertise_l2vpn_evpn = None
                                    self.advertise_disable = None
                                    self.advertise_def_vrf_imp_disable_v4 = None
                                    self.advertise_def_vrf_imp_disable_v6 = None
                                    self.advertise_vrf_re_imp_disable_v4 = None
                                    self.advertise_vrf_re_imp_disable_v6 = None
                                    self.encapsulation_type = None
                                    self.import_ = None
                                    self.import_stitching = None
                                    self.import_reoriginate = None
                                    self.import_reoriginate_stitching = None
                                    self.advertise_local_labeled_route = None
                                    self.enforce_multiple_labels = None

                                    self.orr_root_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress()
                                    self.orr_root_address.parent = self
                                    self._children_name_map["orr_root_address"] = "orr-root-address"

                                    self.orf_capability_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo()
                                    self.orf_capability_info.parent = self
                                    self._children_name_map["orf_capability_info"] = "orf-capability-info"

                                    self.default_originate_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo()
                                    self.default_originate_info.parent = self
                                    self._children_name_map["default_originate_info"] = "default-originate-info"

                                    self.max_prefixes_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo()
                                    self.max_prefixes_info.parent = self
                                    self._children_name_map["max_prefixes_info"] = "max-prefixes-info"

                                    self.orr_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo()
                                    self.orr_info.parent = self
                                    self._children_name_map["orr_info"] = "orr-info"

                                    self.next_hop_self_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo()
                                    self.next_hop_self_info.parent = self
                                    self._children_name_map["next_hop_self_info"] = "next-hop-self-info"

                                    self.next_hop_unchanged_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo()
                                    self.next_hop_unchanged_info.parent = self
                                    self._children_name_map["next_hop_unchanged_info"] = "next-hop-unchanged-info"

                                    self.route_policy_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo()
                                    self.route_policy_in_info.parent = self
                                    self._children_name_map["route_policy_in_info"] = "route-policy-in-info"

                                    self.route_policy_out_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo()
                                    self.route_policy_out_info.parent = self
                                    self._children_name_map["route_policy_out_info"] = "route-policy-out-info"

                                    self.prefix_filter_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo()
                                    self.prefix_filter_info.parent = self
                                    self._children_name_map["prefix_filter_info"] = "prefix-filter-info"

                                    self.remove_private_as_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo()
                                    self.remove_private_as_info.parent = self
                                    self._children_name_map["remove_private_as_info"] = "remove-private-as-info"

                                    self.remove_private_as_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo()
                                    self.remove_private_as_in_info.parent = self
                                    self._children_name_map["remove_private_as_in_info"] = "remove-private-as-in-info"

                                    self.route_reflector_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo()
                                    self.route_reflector_info.parent = self
                                    self._children_name_map["route_reflector_info"] = "route-reflector-info"

                                    self.legacy_pe_rt_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo()
                                    self.legacy_pe_rt_info.parent = self
                                    self._children_name_map["legacy_pe_rt_info"] = "legacy-pe-rt-info"

                                    self.af_enabled_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo()
                                    self.af_enabled_info.parent = self
                                    self._children_name_map["af_enabled_info"] = "af-enabled-info"

                                    self.send_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo()
                                    self.send_community_info.parent = self
                                    self._children_name_map["send_community_info"] = "send-community-info"

                                    self.send_graceful_shutdown_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo()
                                    self.send_graceful_shutdown_community_info.parent = self
                                    self._children_name_map["send_graceful_shutdown_community_info"] = "send-graceful-shutdown-community-info"

                                    self.send_extended_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo()
                                    self.send_extended_community_info.parent = self
                                    self._children_name_map["send_extended_community_info"] = "send-extended-community-info"

                                    self.soft_reconfig_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo()
                                    self.soft_reconfig_info.parent = self
                                    self._children_name_map["soft_reconfig_info"] = "soft-reconfig-info"

                                    self.so_o_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo()
                                    self.so_o_info.parent = self
                                    self._children_name_map["so_o_info"] = "so-o-info"

                                    self.weight_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo()
                                    self.weight_info.parent = self
                                    self._children_name_map["weight_info"] = "weight-info"

                                    self.allowas_in_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo()
                                    self.allowas_in_info.parent = self
                                    self._children_name_map["allowas_in_info"] = "allowas-in-info"

                                    self.af_long_lived_graceful_start_stale_time_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo()
                                    self.af_long_lived_graceful_start_stale_time_info.parent = self
                                    self._children_name_map["af_long_lived_graceful_start_stale_time_info"] = "af-long-lived-graceful-start-stale-time-info"

                                    self.af_long_lived_graceful_start_capable_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo()
                                    self.af_long_lived_graceful_start_capable_info.parent = self
                                    self._children_name_map["af_long_lived_graceful_start_capable_info"] = "af-long-lived-graceful-start-capable-info"

                                    self.as_override_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo()
                                    self.as_override_info.parent = self
                                    self._children_name_map["as_override_info"] = "as-override-info"

                                    self.aigp_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo()
                                    self.aigp_info.parent = self
                                    self._children_name_map["aigp_info"] = "aigp-info"

                                    self.aigp_cost_community_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo()
                                    self.aigp_cost_community_info.parent = self
                                    self._children_name_map["aigp_cost_community_info"] = "aigp-cost-community-info"

                                    self.aigp_med = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed()
                                    self.aigp_med.parent = self
                                    self._children_name_map["aigp_med"] = "aigp-med"

                                    self.accept_own_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo()
                                    self.accept_own_info.parent = self
                                    self._children_name_map["accept_own_info"] = "accept-own-info"

                                    self.multipath_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo()
                                    self.multipath_info.parent = self
                                    self._children_name_map["multipath_info"] = "multipath-info"

                                    self.fspec_valid_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo()
                                    self.fspec_valid_info.parent = self
                                    self._children_name_map["fspec_valid_info"] = "fspec-valid-info"

                                    self.next_hop_unchanged_mpath_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo()
                                    self.next_hop_unchanged_mpath_info.parent = self
                                    self._children_name_map["next_hop_unchanged_mpath_info"] = "next-hop-unchanged-mpath-info"

                                    self.permanent_network_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo()
                                    self.permanent_network_info.parent = self
                                    self._children_name_map["permanent_network_info"] = "permanent-network-info"

                                    self.send_mcast_attr_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo()
                                    self.send_mcast_attr_info.parent = self
                                    self._children_name_map["send_mcast_attr_info"] = "send-mcast-attr-info"

                                    self.advertise_v4_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo()
                                    self.advertise_v4_afi_info.parent = self
                                    self._children_name_map["advertise_v4_afi_info"] = "advertise-v4-afi-info"

                                    self.advertise_v6_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo()
                                    self.advertise_v6_afi_info.parent = self
                                    self._children_name_map["advertise_v6_afi_info"] = "advertise-v6-afi-info"

                                    self.advertise_l2vpn_evpn_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo()
                                    self.advertise_l2vpn_evpn_afi_info.parent = self
                                    self._children_name_map["advertise_l2vpn_evpn_afi_info"] = "advertise-l2vpn-evpn-afi-info"

                                    self.advertise_dis_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo()
                                    self.advertise_dis_info.parent = self
                                    self._children_name_map["advertise_dis_info"] = "advertise-dis-info"

                                    self.advertise_def_vrf_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info()
                                    self.advertise_def_vrf_imp_disable_afi_v4_info.parent = self
                                    self._children_name_map["advertise_def_vrf_imp_disable_afi_v4_info"] = "advertise-def-vrf-imp-disable-afi-v4-info"

                                    self.advertise_def_vrf_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info()
                                    self.advertise_def_vrf_imp_disable_afi_v6_info.parent = self
                                    self._children_name_map["advertise_def_vrf_imp_disable_afi_v6_info"] = "advertise-def-vrf-imp-disable-afi-v6-info"

                                    self.advertise_vrf_re_imp_disable_afi_v4_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info()
                                    self.advertise_vrf_re_imp_disable_afi_v4_info.parent = self
                                    self._children_name_map["advertise_vrf_re_imp_disable_afi_v4_info"] = "advertise-vrf-re-imp-disable-afi-v4-info"

                                    self.advertise_vrf_re_imp_disable_afi_v6_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info()
                                    self.advertise_vrf_re_imp_disable_afi_v6_info.parent = self
                                    self._children_name_map["advertise_vrf_re_imp_disable_afi_v6_info"] = "advertise-vrf-re-imp-disable-afi-v6-info"

                                    self.af_encapsulation_type_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo()
                                    self.af_encapsulation_type_info.parent = self
                                    self._children_name_map["af_encapsulation_type_info"] = "af-encapsulation-type-info"

                                    self.import_afi_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo()
                                    self.import_afi_info.parent = self
                                    self._children_name_map["import_afi_info"] = "import-afi-info"

                                    self.advertise_local_labeled_route_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo()
                                    self.advertise_local_labeled_route_info.parent = self
                                    self._children_name_map["advertise_local_labeled_route_info"] = "advertise-local-labeled-route-info"

                                    self.enforce_multiple_labels_info = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo()
                                    self.enforce_multiple_labels_info.parent = self
                                    self._children_name_map["enforce_multiple_labels_info"] = "enforce-multiple-labels-info"
                                    self._segment_path = lambda: "af-dependent-config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig, [u'has_orf_capability', u'is_default_originate_not_disabled', u'default_originate_route_policy', u'max_prefixes', u'max_prefix_warn_threshold', u'is_max_prefix_warn_only', u'max_prefix_restart_time', u'is_max_prefix_discard_extra_paths', u'is_next_hop_self_disabled', u'is_next_hop_unchanged', u'permanent_network', u'route_policy_in', u'route_policy_out', u'prefix_orf_filter', u'remove_private_as_out', u'entire_aspath_out', u'remove_private_asin', u'entire_aspath_in', u'client_route_reflector', u'accept_route_legacy_pe_rt', u'is_af_enabled', u'send_community_attribute', u'send_graceful_shut_community_attributes', u'send_extended_community_attribute', u'soft_reconfig_not_disabled', u'alway_use_soft_reconfig', u'site_of_origin', u'default_weight', u'default_allowas', u'af_long_lived_graceful_restart_stale_time_send', u'af_long_lived_graceful_restart_stale_time_accept', u'af_long_lived_graceful_restart_capable', u'is_as_override_disabled', u'is_aigp_enabled', u'is_aigp_cost_community_enabled', u'is_aigp_cost_community_id', u'is_aigp_cost_community_transitive', u'aigp_cost_community_poi', u'is_aigp_med_enabled', u'accept_own', u'multipath', u'is_fspec_valid_enabled', u'is_next_hop_unchanged_mpath', u'is_send_mcast_attr_enabled', u'advertise_v4', u'advertise_v6', u'advertise_l2vpn_evpn', u'advertise_disable', u'advertise_def_vrf_imp_disable_v4', u'advertise_def_vrf_imp_disable_v6', u'advertise_vrf_re_imp_disable_v4', u'advertise_vrf_re_imp_disable_v6', u'encapsulation_type', u'import_', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_local_labeled_route', u'enforce_multiple_labels'], name, value)


                                class OrrRootAddress(Entity):
                                    """
                                    ORR Root Address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress, self).__init__()

                                        self.yang_name = "orr-root-address"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "orr-root-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "orr-root-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "orr-root-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "orr-root-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "orr-root-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrRootAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class OrfCapabilityInfo(Entity):
                                    """
                                    ORF capability item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo, self).__init__()

                                        self.yang_name = "orf-capability-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "orf-capability-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "orf-capability-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrfCapabilityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class DefaultOriginateInfo(Entity):
                                    """
                                    Default\-originate item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo, self).__init__()

                                        self.yang_name = "default-originate-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "default-originate-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "default-originate-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.DefaultOriginateInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class MaxPrefixesInfo(Entity):
                                    """
                                    Maximum prefixes to accept item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo, self).__init__()

                                        self.yang_name = "max-prefixes-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "max-prefixes-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "max-prefixes-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MaxPrefixesInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class OrrInfo(Entity):
                                    """
                                    Orr item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo, self).__init__()

                                        self.yang_name = "orr-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "orr-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "orr-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.OrrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NextHopSelfInfo(Entity):
                                    """
                                    Next hop self item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo, self).__init__()

                                        self.yang_name = "next-hop-self-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "next-hop-self-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "next-hop-self-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopSelfInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NextHopUnchangedInfo(Entity):
                                    """
                                    Next hop unchanged info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo, self).__init__()

                                        self.yang_name = "next-hop-unchanged-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "next-hop-unchanged-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "next-hop-unchanged-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class RoutePolicyInInfo(Entity):
                                    """
                                    Inbound route policy item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo, self).__init__()

                                        self.yang_name = "route-policy-in-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "route-policy-in-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "route-policy-in-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class RoutePolicyOutInfo(Entity):
                                    """
                                    Outbound route policy item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo, self).__init__()

                                        self.yang_name = "route-policy-out-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "route-policy-out-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "route-policy-out-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RoutePolicyOutInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class PrefixFilterInfo(Entity):
                                    """
                                    Inbound prefix based filter item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo, self).__init__()

                                        self.yang_name = "prefix-filter-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "prefix-filter-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "prefix-filter-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PrefixFilterInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class RemovePrivateAsInfo(Entity):
                                    """
                                    Outbound private\-AS removal item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo, self).__init__()

                                        self.yang_name = "remove-private-as-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "remove-private-as-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "remove-private-as-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class RemovePrivateAsInInfo(Entity):
                                    """
                                    Inbound private\-AS removal item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo, self).__init__()

                                        self.yang_name = "remove-private-as-in-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "remove-private-as-in-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "remove-private-as-in-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RemovePrivateAsInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class RouteReflectorInfo(Entity):
                                    """
                                    Route\-reflector client item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo, self).__init__()

                                        self.yang_name = "route-reflector-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "route-reflector-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "route-reflector-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.RouteReflectorInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class LegacyPeRtInfo(Entity):
                                    """
                                    Accept\-legacy\-pe\-RT item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo, self).__init__()

                                        self.yang_name = "legacy-pe-rt-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "legacy-pe-rt-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "legacy-pe-rt-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.LegacyPeRtInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AfEnabledInfo(Entity):
                                    """
                                    Address family activate item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo, self).__init__()

                                        self.yang_name = "af-enabled-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "af-enabled-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "af-enabled-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEnabledInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SendCommunityInfo(Entity):
                                    """
                                    Send community attribute item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo, self).__init__()

                                        self.yang_name = "send-community-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "send-community-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "send-community-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SendGracefulShutdownCommunityInfo(Entity):
                                    """
                                    Send Graceful shutdown related community
                                    attribute item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo, self).__init__()

                                        self.yang_name = "send-graceful-shutdown-community-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "send-graceful-shutdown-community-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "send-graceful-shutdown-community-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendGracefulShutdownCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SendExtendedCommunityInfo(Entity):
                                    """
                                    Send extended community  item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo, self).__init__()

                                        self.yang_name = "send-extended-community-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "send-extended-community-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "send-extended-community-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendExtendedCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SoftReconfigInfo(Entity):
                                    """
                                    Soft reconf item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo, self).__init__()

                                        self.yang_name = "soft-reconfig-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "soft-reconfig-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "soft-reconfig-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoftReconfigInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SoOInfo(Entity):
                                    """
                                    BGP Site\-of\-Origin info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo, self).__init__()

                                        self.yang_name = "so-o-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "so-o-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "so-o-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SoOInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class WeightInfo(Entity):
                                    """
                                    Default weight item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo, self).__init__()

                                        self.yang_name = "weight-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "weight-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "weight-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.WeightInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AllowasInInfo(Entity):
                                    """
                                    Allowas\-in item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo, self).__init__()

                                        self.yang_name = "allowas-in-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "allowas-in-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "allowas-in-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AllowasInInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AfLongLivedGracefulStartStaleTimeInfo(Entity):
                                    """
                                    Long\-lived\-time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo, self).__init__()

                                        self.yang_name = "af-long-lived-graceful-start-stale-time-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "af-long-lived-graceful-start-stale-time-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "af-long-lived-graceful-start-stale-time-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartStaleTimeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AfLongLivedGracefulStartCapableInfo(Entity):
                                    """
                                    Long\-lived\-time item info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo, self).__init__()

                                        self.yang_name = "af-long-lived-graceful-start-capable-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "af-long-lived-graceful-start-capable-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "af-long-lived-graceful-start-capable-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfLongLivedGracefulStartCapableInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AsOverrideInfo(Entity):
                                    """
                                    As\-override info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo, self).__init__()

                                        self.yang_name = "as-override-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "as-override-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "as-override-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AsOverrideInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AigpInfo(Entity):
                                    """
                                    AIGP info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo, self).__init__()

                                        self.yang_name = "aigp-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "aigp-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "aigp-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AigpCostCommunityInfo(Entity):
                                    """
                                    AIGP Cost Community info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo, self).__init__()

                                        self.yang_name = "aigp-cost-community-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "aigp-cost-community-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "aigp-cost-community-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpCostCommunityInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AigpMed(Entity):
                                    """
                                    AIGP MED info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed, self).__init__()

                                        self.yang_name = "aigp-med"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "aigp-med"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "aigp-med"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AigpMed.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AcceptOwnInfo(Entity):
                                    """
                                    Accept\-Own info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo, self).__init__()

                                        self.yang_name = "accept-own-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "accept-own-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "accept-own-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AcceptOwnInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class MultipathInfo(Entity):
                                    """
                                    Multipath info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo, self).__init__()

                                        self.yang_name = "multipath-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "multipath-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "multipath-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.MultipathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class FspecValidInfo(Entity):
                                    """
                                    FSPEC Valid info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo, self).__init__()

                                        self.yang_name = "fspec-valid-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "fspec-valid-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "fspec-valid-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.FspecValidInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NextHopUnchangedMpathInfo(Entity):
                                    """
                                    Next hop unchanged mpath info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo, self).__init__()

                                        self.yang_name = "next-hop-unchanged-mpath-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "next-hop-unchanged-mpath-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "next-hop-unchanged-mpath-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.NextHopUnchangedMpathInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class PermanentNetworkInfo(Entity):
                                    """
                                    Permanent network Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo, self).__init__()

                                        self.yang_name = "permanent-network-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "permanent-network-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "permanent-network-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.PermanentNetworkInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SendMcastAttrInfo(Entity):
                                    """
                                    Send mcast attr info
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo, self).__init__()

                                        self.yang_name = "send-mcast-attr-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "send-mcast-attr-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "send-mcast-attr-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.SendMcastAttrInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertiseV4AfiInfo(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo, self).__init__()

                                        self.yang_name = "advertise-v4-afi-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "advertise-v4-afi-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-v4-afi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV4AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertiseV6AfiInfo(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo, self).__init__()

                                        self.yang_name = "advertise-v6-afi-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "advertise-v6-afi-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-v6-afi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseV6AfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertiseL2vpnEvpnAfiInfo(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo, self).__init__()

                                        self.yang_name = "advertise-l2vpn-evpn-afi-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "advertise-l2vpn-evpn-afi-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-l2vpn-evpn-afi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseL2vpnEvpnAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertiseDisInfo(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo, self).__init__()

                                        self.yang_name = "advertise-dis-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "advertise-dis-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-dis-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDisInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertiseDefVrfImpDisableAfiV4Info(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info, self).__init__()

                                        self.yang_name = "advertise-def-vrf-imp-disable-afi-v4-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "advertise-def-vrf-imp-disable-afi-v4-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-def-vrf-imp-disable-afi-v4-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertiseDefVrfImpDisableAfiV6Info(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info, self).__init__()

                                        self.yang_name = "advertise-def-vrf-imp-disable-afi-v6-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "advertise-def-vrf-imp-disable-afi-v6-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-def-vrf-imp-disable-afi-v6-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseDefVrfImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertiseVrfReImpDisableAfiV4Info(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info, self).__init__()

                                        self.yang_name = "advertise-vrf-re-imp-disable-afi-v4-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "advertise-vrf-re-imp-disable-afi-v4-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-vrf-re-imp-disable-afi-v4-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV4Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertiseVrfReImpDisableAfiV6Info(Entity):
                                    """
                                    Advertise Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info, self).__init__()

                                        self.yang_name = "advertise-vrf-re-imp-disable-afi-v6-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "advertise-vrf-re-imp-disable-afi-v6-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-vrf-re-imp-disable-afi-v6-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseVrfReImpDisableAfiV6Info.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AfEncapsulationTypeInfo(Entity):
                                    """
                                    Encapsulation type Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo, self).__init__()

                                        self.yang_name = "af-encapsulation-type-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "af-encapsulation-type-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "af-encapsulation-type-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AfEncapsulationTypeInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class ImportAfiInfo(Entity):
                                    """
                                    Import Afi Info 
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo, self).__init__()

                                        self.yang_name = "import-afi-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "import-afi-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "import-afi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.ImportAfiInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertiseLocalLabeledRouteInfo(Entity):
                                    """
                                    Advertise routes with local\-label
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo, self).__init__()

                                        self.yang_name = "advertise-local-labeled-route-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "advertise-local-labeled-route-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "advertise-local-labeled-route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.AdvertiseLocalLabeledRouteInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class EnforceMultipleLabelsInfo(Entity):
                                    """
                                    Enforce multiple labels
                                    
                                    .. attribute:: inheritance_chain
                                    
                                    	Pointer to the inheritance chain
                                    	**type**\:  :py:class:`InheritanceChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain>`
                                    
                                    .. attribute:: is_item_configured
                                    
                                    	TRUE if the item value is a configured value different from the default
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo, self).__init__()

                                        self.yang_name = "enforce-multiple-labels-info"
                                        self.yang_parent_name = "af-dependent-config"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("inheritance-chain", ("inheritance_chain", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain))])
                                        self._leafs = OrderedDict([
                                            ('is_item_configured', (YLeaf(YType.boolean, 'is-item-configured'), ['bool'])),
                                        ])
                                        self.is_item_configured = None

                                        self.inheritance_chain = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain()
                                        self.inheritance_chain.parent = self
                                        self._children_name_map["inheritance_chain"] = "inheritance-chain"
                                        self._segment_path = lambda: "enforce-multiple-labels-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo, [u'is_item_configured'], name, value)


                                    class InheritanceChain(Entity):
                                        """
                                        Pointer to the inheritance chain
                                        
                                        .. attribute:: bgp_config_entid
                                        
                                        	bgp config entid
                                        	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain, self).__init__()

                                            self.yang_name = "inheritance-chain"
                                            self.yang_parent_name = "enforce-multiple-labels-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid))])
                                            self._leafs = OrderedDict()

                                            self.bgp_config_entid = YList(self)
                                            self._segment_path = lambda: "inheritance-chain"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain, [], name, value)


                                        class BgpConfigEntid(Entity):
                                            """
                                            bgp config entid
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress>`
                                            
                                            .. attribute:: address_family_identifier
                                            
                                            	Address family identfier
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: configuration_type
                                            
                                            	Entity type
                                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                            
                                            .. attribute:: group_name
                                            
                                            	Group name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid, self).__init__()

                                                self.yang_name = "bgp-config-entid"
                                                self.yang_parent_name = "inheritance-chain"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                                ])
                                                self.address_family_identifier = None
                                                self.configuration_type = None
                                                self.group_name = None

                                                self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "bgp-config-entid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bgp-config-entid"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.EntityConfigurations.EntityConfiguration.AfDependentConfig.EnforceMultipleLabelsInfo.InheritanceChain.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                    class ConfigurationUsers(Entity):
                        """
                        The BGP configuration users table
                        
                        .. attribute:: configuration_user
                        
                        	A BGP configuration user table entry
                        	**type**\: list of  		 :py:class:`ConfigurationUser <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers, self).__init__()

                            self.yang_name = "configuration-users"
                            self.yang_parent_name = "config-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("configuration-user", ("configuration_user", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser))])
                            self._leafs = OrderedDict()

                            self.configuration_user = YList(self)
                            self._segment_path = lambda: "configuration-users"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers, [], name, value)


                        class ConfigurationUser(Entity):
                            """
                            A BGP configuration user table entry
                            
                            .. attribute:: entity_type
                            
                            	Entity type
                            	**type**\:  :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: entity_name
                            
                            	Entity name
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor Address
                            	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr>`
                            
                            .. attribute:: af_independent_relatives
                            
                            	AF\-independent relatives
                            	**type**\:  :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives>`
                            
                            .. attribute:: group_name
                            
                            	Entity/group name
                            	**type**\: str
                            
                            .. attribute:: configuration_type
                            
                            	Entity type
                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                            
                            .. attribute:: address_family_identifier
                            
                            	AF identifier
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: af_dependent_relative
                            
                            	AF\-dependent relatives
                            	**type**\: list of  		 :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser, self).__init__()

                                self.yang_name = "configuration-user"
                                self.yang_parent_name = "configuration-users"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr)), ("af-independent-relatives", ("af_independent_relatives", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives)), ("af-dependent-relative", ("af_dependent_relative", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative))])
                                self._leafs = OrderedDict([
                                    ('entity_type', (YLeaf(YType.enumeration, 'entity-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntity', '')])),
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('entity_name', (YLeaf(YType.str, 'entity-name'), ['str'])),
                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                ])
                                self.entity_type = None
                                self.neighbor_address = None
                                self.entity_name = None
                                self.group_name = None
                                self.configuration_type = None
                                self.address_family_identifier = None

                                self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr()
                                self.neighbor_address_xr.parent = self
                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives()
                                self.af_independent_relatives.parent = self
                                self._children_name_map["af_independent_relatives"] = "af-independent-relatives"

                                self.af_dependent_relative = YList(self)
                                self._segment_path = lambda: "configuration-user"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser, ['entity_type', 'neighbor_address', 'entity_name', u'group_name', u'configuration_type', u'address_family_identifier'], name, value)


                            class NeighborAddressXr(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr, self).__init__()

                                    self.yang_name = "neighbor-address-xr"
                                    self.yang_parent_name = "configuration-user"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "neighbor-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfIndependentRelatives(Entity):
                                """
                                AF\-independent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives, self).__init__()

                                    self.yang_name = "af-independent-relatives"
                                    self.yang_parent_name = "configuration-user"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid))])
                                    self._leafs = OrderedDict()

                                    self.bgp_config_entid = YList(self)
                                    self._segment_path = lambda: "af-independent-relatives"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives, [], name, value)


                                class BgpConfigEntid(Entity):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid, self).__init__()

                                        self.yang_name = "bgp-config-entid"
                                        self.yang_parent_name = "af-independent-relatives"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress))])
                                        self._leafs = OrderedDict([
                                            ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                            ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                            ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                        ])
                                        self.address_family_identifier = None
                                        self.configuration_type = None
                                        self.group_name = None

                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._segment_path = lambda: "bgp-config-entid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "bgp-config-entid"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfDependentRelative(Entity):
                                """
                                AF\-dependent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative, self).__init__()

                                    self.yang_name = "af-dependent-relative"
                                    self.yang_parent_name = "configuration-user"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid))])
                                    self._leafs = OrderedDict()

                                    self.bgp_config_entid = YList(self)
                                    self._segment_path = lambda: "af-dependent-relative"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative, [], name, value)


                                class BgpConfigEntid(Entity):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid, self).__init__()

                                        self.yang_name = "bgp-config-entid"
                                        self.yang_parent_name = "af-dependent-relative"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress))])
                                        self._leafs = OrderedDict([
                                            ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                            ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                            ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                        ])
                                        self.address_family_identifier = None
                                        self.configuration_type = None
                                        self.group_name = None

                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._segment_path = lambda: "bgp-config-entid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "bgp-config-entid"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationUsers.ConfigurationUser.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                    class ConfigurationInheritances(Entity):
                        """
                        The BGP configurataion inheritance table
                        
                        .. attribute:: configuration_inheritance
                        
                        	A BGP configuration inheritance table entry
                        	**type**\: list of  		 :py:class:`ConfigurationInheritance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances, self).__init__()

                            self.yang_name = "configuration-inheritances"
                            self.yang_parent_name = "config-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("configuration-inheritance", ("configuration_inheritance", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance))])
                            self._leafs = OrderedDict()

                            self.configuration_inheritance = YList(self)
                            self._segment_path = lambda: "configuration-inheritances"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances, [], name, value)


                        class ConfigurationInheritance(Entity):
                            """
                            A BGP configuration inheritance table entry
                            
                            .. attribute:: entity_type
                            
                            	Entity type
                            	**type**\:  :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntity>`
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: entity_name
                            
                            	Entity name
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor Address
                            	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr>`
                            
                            .. attribute:: af_independent_relatives
                            
                            	AF\-independent relatives
                            	**type**\:  :py:class:`AfIndependentRelatives <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives>`
                            
                            .. attribute:: group_name
                            
                            	Entity/group name
                            	**type**\: str
                            
                            .. attribute:: configuration_type
                            
                            	Entity type
                            	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                            
                            .. attribute:: address_family_identifier
                            
                            	AF identifier
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: af_dependent_relative
                            
                            	AF\-dependent relatives
                            	**type**\: list of  		 :py:class:`AfDependentRelative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance, self).__init__()

                                self.yang_name = "configuration-inheritance"
                                self.yang_parent_name = "configuration-inheritances"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr)), ("af-independent-relatives", ("af_independent_relatives", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives)), ("af-dependent-relative", ("af_dependent_relative", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative))])
                                self._leafs = OrderedDict([
                                    ('entity_type', (YLeaf(YType.enumeration, 'entity-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntity', '')])),
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('entity_name', (YLeaf(YType.str, 'entity-name'), ['str'])),
                                    ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                    ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                    ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                ])
                                self.entity_type = None
                                self.neighbor_address = None
                                self.entity_name = None
                                self.group_name = None
                                self.configuration_type = None
                                self.address_family_identifier = None

                                self.neighbor_address_xr = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr()
                                self.neighbor_address_xr.parent = self
                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                self.af_independent_relatives = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives()
                                self.af_independent_relatives.parent = self
                                self._children_name_map["af_independent_relatives"] = "af-independent-relatives"

                                self.af_dependent_relative = YList(self)
                                self._segment_path = lambda: "configuration-inheritance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance, ['entity_type', 'neighbor_address', 'entity_name', u'group_name', u'configuration_type', u'address_family_identifier'], name, value)


                            class NeighborAddressXr(Entity):
                                """
                                Neighbor Address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr, self).__init__()

                                    self.yang_name = "neighbor-address-xr"
                                    self.yang_parent_name = "configuration-inheritance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "neighbor-address-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "neighbor-address-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfIndependentRelatives(Entity):
                                """
                                AF\-independent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives, self).__init__()

                                    self.yang_name = "af-independent-relatives"
                                    self.yang_parent_name = "configuration-inheritance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid))])
                                    self._leafs = OrderedDict()

                                    self.bgp_config_entid = YList(self)
                                    self._segment_path = lambda: "af-independent-relatives"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives, [], name, value)


                                class BgpConfigEntid(Entity):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress>`
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid, self).__init__()

                                        self.yang_name = "bgp-config-entid"
                                        self.yang_parent_name = "af-independent-relatives"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress))])
                                        self._leafs = OrderedDict([
                                            ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                            ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                            ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                        ])
                                        self.address_family_identifier = None
                                        self.configuration_type = None
                                        self.group_name = None

                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._segment_path = lambda: "bgp-config-entid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "bgp-config-entid"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfIndependentRelatives.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfDependentRelative(Entity):
                                """
                                AF\-dependent relatives
                                
                                .. attribute:: bgp_config_entid
                                
                                	bgp config entid
                                	**type**\: list of  		 :py:class:`BgpConfigEntid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative, self).__init__()

                                    self.yang_name = "af-dependent-relative"
                                    self.yang_parent_name = "configuration-inheritance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bgp-config-entid", ("bgp_config_entid", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid))])
                                    self._leafs = OrderedDict()

                                    self.bgp_config_entid = YList(self)
                                    self._segment_path = lambda: "af-dependent-relative"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative, [], name, value)


                                class BgpConfigEntid(Entity):
                                    """
                                    bgp config entid
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress>`
                                    
                                    .. attribute:: address_family_identifier
                                    
                                    	Address family identfier
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: configuration_type
                                    
                                    	Entity type
                                    	**type**\:  :py:class:`BgpEntities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEntities>`
                                    
                                    .. attribute:: group_name
                                    
                                    	Group name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid, self).__init__()

                                        self.yang_name = "bgp-config-entid"
                                        self.yang_parent_name = "af-dependent-relative"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress))])
                                        self._leafs = OrderedDict([
                                            ('address_family_identifier', (YLeaf(YType.uint8, 'address-family-identifier'), ['int'])),
                                            ('configuration_type', (YLeaf(YType.enumeration, 'configuration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEntities', '')])),
                                            ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                        ])
                                        self.address_family_identifier = None
                                        self.configuration_type = None
                                        self.group_name = None

                                        self.neighbor_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._segment_path = lambda: "bgp-config-entid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid, [u'address_family_identifier', u'configuration_type', u'group_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "bgp-config-entid"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.ConfigInstances.ConfigInstance.ConfigVrfs.ConfigVrf.ConfigurationInheritances.ConfigurationInheritance.AfDependentRelative.BgpConfigEntid.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


    class Instances(Entity):
        """
        Instance specific BGP data
        
        .. attribute:: instance
        
        	Instance specific BGP data
        	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance>`
        
        

        """

        _prefix = 'ipv4-bgp-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Bgp.Instances, self).__init__()

            self.yang_name = "instances"
            self.yang_parent_name = "bgp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("instance", ("instance", Bgp.Instances.Instance))])
            self._leafs = OrderedDict()

            self.instance = YList(self)
            self._segment_path = lambda: "instances"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Bgp.Instances, [], name, value)


        class Instance(Entity):
            """
            Instance specific BGP data
            
            .. attribute:: instance_name  (key)
            
            	Name of the BGP instance
            	**type**\: str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: instance_active
            
            	Active BGP operational data
            	**type**\:  :py:class:`InstanceActive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive>`
            
            .. attribute:: instance_standby
            
            	Standby BGP operational data
            	**type**\:  :py:class:`InstanceStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby>`
            
            

            """

            _prefix = 'ipv4-bgp-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Bgp.Instances.Instance, self).__init__()

                self.yang_name = "instance"
                self.yang_parent_name = "instances"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['instance_name']
                self._child_classes = OrderedDict([("instance-active", ("instance_active", Bgp.Instances.Instance.InstanceActive)), ("instance-standby", ("instance_standby", Bgp.Instances.Instance.InstanceStandby))])
                self._leafs = OrderedDict([
                    ('instance_name', (YLeaf(YType.str, 'instance-name'), ['str'])),
                ])
                self.instance_name = None

                self.instance_active = Bgp.Instances.Instance.InstanceActive()
                self.instance_active.parent = self
                self._children_name_map["instance_active"] = "instance-active"

                self.instance_standby = Bgp.Instances.Instance.InstanceStandby()
                self.instance_standby.parent = self
                self._children_name_map["instance_standby"] = "instance-standby"
                self._segment_path = lambda: "instance" + "[instance-name='" + str(self.instance_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/instances/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Bgp.Instances.Instance, ['instance_name'], name, value)


            class InstanceActive(Entity):
                """
                Active BGP operational data
                
                .. attribute:: label_entries
                
                	BGP Label Table
                	**type**\:  :py:class:`LabelEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelEntries>`
                
                .. attribute:: label_summary
                
                	BGP Label Summary
                	**type**\:  :py:class:`LabelSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelSummary>`
                
                .. attribute:: label_rpf_entries
                
                	BGP Label RPF Table
                	**type**\:  :py:class:`LabelRpfEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries>`
                
                .. attribute:: update_generation_process
                
                	Update generation for the process
                	**type**\:  :py:class:`UpdateGenerationProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess>`
                
                .. attribute:: vrfs
                
                	VRF related operational data
                	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs>`
                
                .. attribute:: default_vrf
                
                	Default VRF related operational data
                	**type**\:  :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf>`
                
                .. attribute:: update_inbound_filter_process
                
                	Update inbound filtering information for the process
                	**type**\:  :py:class:`UpdateInboundFilterProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess>`
                
                .. attribute:: attributes
                
                	The BGP Attribute table
                	**type**\:  :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes>`
                
                .. attribute:: rt_entries
                
                	BGP Route Target Sets Table
                	**type**\:  :py:class:`RtEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RtEntries>`
                
                .. attribute:: attribute_filter_groups
                
                	All attribute\-filter groups in this instance
                	**type**\:  :py:class:`AttributeFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups>`
                
                .. attribute:: rpki_server_list
                
                	RPKI Server Table
                	**type**\:  :py:class:`RpkiServerList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiServerList>`
                
                .. attribute:: rpki_routes
                
                	BGP RPKI ROA table
                	**type**\:  :py:class:`RpkiRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRoutes>`
                
                .. attribute:: update_inbound_error_process
                
                	Update inbound error information for the process
                	**type**\:  :py:class:`UpdateInboundErrorProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess>`
                
                .. attribute:: rpki_summary
                
                	RPKI Summary Info
                	**type**\:  :py:class:`RpkiSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiSummary>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Bgp.Instances.Instance.InstanceActive, self).__init__()

                    self.yang_name = "instance-active"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("label-entries", ("label_entries", Bgp.Instances.Instance.InstanceActive.LabelEntries)), ("label-summary", ("label_summary", Bgp.Instances.Instance.InstanceActive.LabelSummary)), ("label-rpf-entries", ("label_rpf_entries", Bgp.Instances.Instance.InstanceActive.LabelRpfEntries)), ("update-generation-process", ("update_generation_process", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess)), ("vrfs", ("vrfs", Bgp.Instances.Instance.InstanceActive.Vrfs)), ("default-vrf", ("default_vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf)), ("update-inbound-filter-process", ("update_inbound_filter_process", Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess)), ("attributes", ("attributes", Bgp.Instances.Instance.InstanceActive.Attributes)), ("rt-entries", ("rt_entries", Bgp.Instances.Instance.InstanceActive.RtEntries)), ("attribute-filter-groups", ("attribute_filter_groups", Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups)), ("rpki-server-list", ("rpki_server_list", Bgp.Instances.Instance.InstanceActive.RpkiServerList)), ("rpki-routes", ("rpki_routes", Bgp.Instances.Instance.InstanceActive.RpkiRoutes)), ("update-inbound-error-process", ("update_inbound_error_process", Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess)), ("rpki-summary", ("rpki_summary", Bgp.Instances.Instance.InstanceActive.RpkiSummary))])
                    self._leafs = OrderedDict()

                    self.label_entries = Bgp.Instances.Instance.InstanceActive.LabelEntries()
                    self.label_entries.parent = self
                    self._children_name_map["label_entries"] = "label-entries"

                    self.label_summary = Bgp.Instances.Instance.InstanceActive.LabelSummary()
                    self.label_summary.parent = self
                    self._children_name_map["label_summary"] = "label-summary"

                    self.label_rpf_entries = Bgp.Instances.Instance.InstanceActive.LabelRpfEntries()
                    self.label_rpf_entries.parent = self
                    self._children_name_map["label_rpf_entries"] = "label-rpf-entries"

                    self.update_generation_process = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess()
                    self.update_generation_process.parent = self
                    self._children_name_map["update_generation_process"] = "update-generation-process"

                    self.vrfs = Bgp.Instances.Instance.InstanceActive.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"

                    self.default_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf()
                    self.default_vrf.parent = self
                    self._children_name_map["default_vrf"] = "default-vrf"

                    self.update_inbound_filter_process = Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess()
                    self.update_inbound_filter_process.parent = self
                    self._children_name_map["update_inbound_filter_process"] = "update-inbound-filter-process"

                    self.attributes = Bgp.Instances.Instance.InstanceActive.Attributes()
                    self.attributes.parent = self
                    self._children_name_map["attributes"] = "attributes"

                    self.rt_entries = Bgp.Instances.Instance.InstanceActive.RtEntries()
                    self.rt_entries.parent = self
                    self._children_name_map["rt_entries"] = "rt-entries"

                    self.attribute_filter_groups = Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups()
                    self.attribute_filter_groups.parent = self
                    self._children_name_map["attribute_filter_groups"] = "attribute-filter-groups"

                    self.rpki_server_list = Bgp.Instances.Instance.InstanceActive.RpkiServerList()
                    self.rpki_server_list.parent = self
                    self._children_name_map["rpki_server_list"] = "rpki-server-list"

                    self.rpki_routes = Bgp.Instances.Instance.InstanceActive.RpkiRoutes()
                    self.rpki_routes.parent = self
                    self._children_name_map["rpki_routes"] = "rpki-routes"

                    self.update_inbound_error_process = Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess()
                    self.update_inbound_error_process.parent = self
                    self._children_name_map["update_inbound_error_process"] = "update-inbound-error-process"

                    self.rpki_summary = Bgp.Instances.Instance.InstanceActive.RpkiSummary()
                    self.rpki_summary.parent = self
                    self._children_name_map["rpki_summary"] = "rpki-summary"
                    self._segment_path = lambda: "instance-active"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive, [], name, value)


                class LabelEntries(Entity):
                    """
                    BGP Label Table
                    
                    .. attribute:: label_entry
                    
                    	BGP Label Entry
                    	**type**\: list of  		 :py:class:`LabelEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.LabelEntries, self).__init__()

                        self.yang_name = "label-entries"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("label-entry", ("label_entry", Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry))])
                        self._leafs = OrderedDict()

                        self.label_entry = YList(self)
                        self._segment_path = lambda: "label-entries"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelEntries, [], name, value)


                    class LabelEntry(Entity):
                        """
                        BGP Label Entry
                        
                        .. attribute:: label  (key)
                        
                        	Label index
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: entry
                        
                        	entry
                        	**type**\:  :py:class:`Entry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry, self).__init__()

                            self.yang_name = "label-entry"
                            self.yang_parent_name = "label-entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['label']
                            self._child_classes = OrderedDict([("entry", ("entry", Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry))])
                            self._leafs = OrderedDict([
                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                            ])
                            self.label = None

                            self.entry = Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry()
                            self.entry.parent = self
                            self._children_name_map["entry"] = "entry"
                            self._segment_path = lambda: "label-entry" + "[label='" + str(self.label) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry, ['label'], name, value)


                        class Entry(Entity):
                            """
                            entry
                            
                            .. attribute:: label
                            
                            	label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rds
                            
                            	rds
                            	**type**\: str
                            
                            .. attribute:: vrf
                            
                            	vrf
                            	**type**\: str
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ip6
                            
                            	ip6
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rpc_set_id
                            
                            	rpc set id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: masklen
                            
                            	masklen
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ts_sec
                            
                            	ts sec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ts_ssec
                            
                            	ts ssec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: info
                            
                            	info
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: refcount
                            
                            	refcount
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inactive
                            
                            	inactive
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry, self).__init__()

                                self.yang_name = "entry"
                                self.yang_parent_name = "label-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                    ('rds', (YLeaf(YType.str, 'rds'), ['str'])),
                                    ('vrf', (YLeaf(YType.str, 'vrf'), ['str'])),
                                    ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                    ('ip6', (YLeaf(YType.str, 'ip6'), ['str'])),
                                    ('rpc_set_id', (YLeaf(YType.uint32, 'rpc-set-id'), ['int'])),
                                    ('masklen', (YLeaf(YType.uint16, 'masklen'), ['int'])),
                                    ('ts_sec', (YLeaf(YType.uint32, 'ts-sec'), ['int'])),
                                    ('ts_ssec', (YLeaf(YType.uint32, 'ts-ssec'), ['int'])),
                                    ('info', (YLeaf(YType.uint16, 'info'), ['int'])),
                                    ('refcount', (YLeaf(YType.uint32, 'refcount'), ['int'])),
                                    ('inactive', (YLeaf(YType.boolean, 'inactive'), ['bool'])),
                                ])
                                self.label = None
                                self.rds = None
                                self.vrf = None
                                self.ip = None
                                self.ip6 = None
                                self.rpc_set_id = None
                                self.masklen = None
                                self.ts_sec = None
                                self.ts_ssec = None
                                self.info = None
                                self.refcount = None
                                self.inactive = None
                                self._segment_path = lambda: "entry"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelEntries.LabelEntry.Entry, [u'label', u'rds', u'vrf', u'ip', u'ip6', u'rpc_set_id', u'masklen', u'ts_sec', u'ts_ssec', u'info', u'refcount', u'inactive'], name, value)


                class LabelSummary(Entity):
                    """
                    BGP Label Summary
                    
                    .. attribute:: stats
                    
                    	stats
                    	**type**\:  :py:class:`Stats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.LabelSummary, self).__init__()

                        self.yang_name = "label-summary"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("stats", ("stats", Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats))])
                        self._leafs = OrderedDict()

                        self.stats = Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats()
                        self.stats.parent = self
                        self._children_name_map["stats"] = "stats"
                        self._segment_path = lambda: "label-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelSummary, [], name, value)


                    class Stats(Entity):
                        """
                        stats
                        
                        .. attribute:: nbgp_label_alloc_type_gbl_ipv4
                        
                        	nBGP LABEL ALLOC TYPE GBL IPv4
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_gbl_ipv6
                        
                        	nBGP LABEL ALLOC TYPE GBL IPv6
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vrf_ipv4
                        
                        	nBGP LABEL ALLOC TYPE VRF IPv4
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vrf_ipv6
                        
                        	nBGP LABEL ALLOC TYPE VRF IPv6
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_ce_ipv4
                        
                        	nBGP LABEL ALLOC TYPE CE IPv4
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_ce_ipv6
                        
                        	nBGP LABEL ALLOC TYPE CE IPv6
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_tbl_ipv4
                        
                        	nBGP LABEL ALLOC TYPE TBL IPv4
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_tbl_ipv6
                        
                        	nBGP LABEL ALLOC TYPE TBL IPv6
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vpn_ipv4
                        
                        	nBGP LABEL ALLOC TYPE VPN IPv4
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_vpn_ipv6
                        
                        	nBGP LABEL ALLOC TYPE VPN IPv6
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_label_alloc_type_asbr_nh
                        
                        	nBGP LABEL ALLOC TYPE ASBR NH
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nbgp_labels
                        
                        	nBGP LABELS
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bgp_label_rpf_lists
                        
                        	bgp label rpf lists
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bgp_label_rpf_nodes
                        
                        	bgp label rpf nodes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats, self).__init__()

                            self.yang_name = "stats"
                            self.yang_parent_name = "label-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('nbgp_label_alloc_type_gbl_ipv4', (YLeaf(YType.uint32, 'nbgp-label-alloc-type-gbl-ipv4'), ['int'])),
                                ('nbgp_label_alloc_type_gbl_ipv6', (YLeaf(YType.uint32, 'nbgp-label-alloc-type-gbl-ipv6'), ['int'])),
                                ('nbgp_label_alloc_type_vrf_ipv4', (YLeaf(YType.uint32, 'nbgp-label-alloc-type-vrf-ipv4'), ['int'])),
                                ('nbgp_label_alloc_type_vrf_ipv6', (YLeaf(YType.uint32, 'nbgp-label-alloc-type-vrf-ipv6'), ['int'])),
                                ('nbgp_label_alloc_type_ce_ipv4', (YLeaf(YType.uint32, 'nbgp-label-alloc-type-ce-ipv4'), ['int'])),
                                ('nbgp_label_alloc_type_ce_ipv6', (YLeaf(YType.uint32, 'nbgp-label-alloc-type-ce-ipv6'), ['int'])),
                                ('nbgp_label_alloc_type_tbl_ipv4', (YLeaf(YType.uint32, 'nbgp-label-alloc-type-tbl-ipv4'), ['int'])),
                                ('nbgp_label_alloc_type_tbl_ipv6', (YLeaf(YType.uint32, 'nbgp-label-alloc-type-tbl-ipv6'), ['int'])),
                                ('nbgp_label_alloc_type_vpn_ipv4', (YLeaf(YType.uint32, 'nbgp-label-alloc-type-vpn-ipv4'), ['int'])),
                                ('nbgp_label_alloc_type_vpn_ipv6', (YLeaf(YType.uint32, 'nbgp-label-alloc-type-vpn-ipv6'), ['int'])),
                                ('nbgp_label_alloc_type_asbr_nh', (YLeaf(YType.uint32, 'nbgp-label-alloc-type-asbr-nh'), ['int'])),
                                ('nbgp_labels', (YLeaf(YType.uint32, 'nbgp-labels'), ['int'])),
                                ('bgp_label_rpf_lists', (YLeaf(YType.uint32, 'bgp-label-rpf-lists'), ['int'])),
                                ('bgp_label_rpf_nodes', (YLeaf(YType.uint32, 'bgp-label-rpf-nodes'), ['int'])),
                            ])
                            self.nbgp_label_alloc_type_gbl_ipv4 = None
                            self.nbgp_label_alloc_type_gbl_ipv6 = None
                            self.nbgp_label_alloc_type_vrf_ipv4 = None
                            self.nbgp_label_alloc_type_vrf_ipv6 = None
                            self.nbgp_label_alloc_type_ce_ipv4 = None
                            self.nbgp_label_alloc_type_ce_ipv6 = None
                            self.nbgp_label_alloc_type_tbl_ipv4 = None
                            self.nbgp_label_alloc_type_tbl_ipv6 = None
                            self.nbgp_label_alloc_type_vpn_ipv4 = None
                            self.nbgp_label_alloc_type_vpn_ipv6 = None
                            self.nbgp_label_alloc_type_asbr_nh = None
                            self.nbgp_labels = None
                            self.bgp_label_rpf_lists = None
                            self.bgp_label_rpf_nodes = None
                            self._segment_path = lambda: "stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelSummary.Stats, [u'nbgp_label_alloc_type_gbl_ipv4', u'nbgp_label_alloc_type_gbl_ipv6', u'nbgp_label_alloc_type_vrf_ipv4', u'nbgp_label_alloc_type_vrf_ipv6', u'nbgp_label_alloc_type_ce_ipv4', u'nbgp_label_alloc_type_ce_ipv6', u'nbgp_label_alloc_type_tbl_ipv4', u'nbgp_label_alloc_type_tbl_ipv6', u'nbgp_label_alloc_type_vpn_ipv4', u'nbgp_label_alloc_type_vpn_ipv6', u'nbgp_label_alloc_type_asbr_nh', u'nbgp_labels', u'bgp_label_rpf_lists', u'bgp_label_rpf_nodes'], name, value)


                class LabelRpfEntries(Entity):
                    """
                    BGP Label RPF Table
                    
                    .. attribute:: label_rpf_entry
                    
                    	BGP Label RPF Entry
                    	**type**\: list of  		 :py:class:`LabelRpfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries, self).__init__()

                        self.yang_name = "label-rpf-entries"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("label-rpf-entry", ("label_rpf_entry", Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry))])
                        self._leafs = OrderedDict()

                        self.label_rpf_entry = YList(self)
                        self._segment_path = lambda: "label-rpf-entries"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries, [], name, value)


                    class LabelRpfEntry(Entity):
                        """
                        BGP Label RPF Entry
                        
                        .. attribute:: label  (key)
                        
                        	Label index
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpf
                        
                        	rpf
                        	**type**\:  :py:class:`Rpf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry, self).__init__()

                            self.yang_name = "label-rpf-entry"
                            self.yang_parent_name = "label-rpf-entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['label']
                            self._child_classes = OrderedDict([("rpf", ("rpf", Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf))])
                            self._leafs = OrderedDict([
                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                            ])
                            self.label = None

                            self.rpf = Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf()
                            self.rpf.parent = self
                            self._children_name_map["rpf"] = "rpf"
                            self._segment_path = lambda: "label-rpf-entry" + "[label='" + str(self.label) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry, ['label'], name, value)


                        class Rpf(Entity):
                            """
                            rpf
                            
                            .. attribute:: label
                            
                            	label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flags
                            
                            	flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: install
                            
                            	install
                            	**type**\:  :py:class:`BgpLabelRpfInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpLabelRpfInstall>`
                            
                            .. attribute:: rpf
                            
                            	rpf
                            	**type**\: list of  		 :py:class:`Rpf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf.Rpf_>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf, self).__init__()

                                self.yang_name = "rpf"
                                self.yang_parent_name = "label-rpf-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rpf", ("rpf", Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf.Rpf_))])
                                self._leafs = OrderedDict([
                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                    ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                    ('install', (YLeaf(YType.enumeration, 'install'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpLabelRpfInstall', '')])),
                                ])
                                self.label = None
                                self.flags = None
                                self.install = None

                                self.rpf = YList(self)
                                self._segment_path = lambda: "rpf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf, [u'label', u'flags', u'install'], name, value)


                            class Rpf_(Entity):
                                """
                                rpf
                                
                                .. attribute:: ip
                                
                                	ip
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ip6
                                
                                	ip6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: count
                                
                                	count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flags
                                
                                	flags
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf.Rpf_, self).__init__()

                                    self.yang_name = "rpf"
                                    self.yang_parent_name = "rpf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ip', (YLeaf(YType.str, 'ip'), ['str'])),
                                        ('ip6', (YLeaf(YType.str, 'ip6'), ['str'])),
                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                        ('flags', (YLeaf(YType.uint32, 'flags'), ['int'])),
                                    ])
                                    self.ip = None
                                    self.ip6 = None
                                    self.count = None
                                    self.flags = None
                                    self._segment_path = lambda: "rpf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.LabelRpfEntries.LabelRpfEntry.Rpf.Rpf_, [u'ip', u'ip6', u'count', u'flags'], name, value)


                class UpdateGenerationProcess(Entity):
                    """
                    Update generation for the process
                    
                    .. attribute:: update_statistics
                    
                    	Update statistics
                    	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics>`
                    
                    .. attribute:: update_out_logging
                    
                    	Enable syslog messages for update generation events
                    	**type**\: bool
                    
                    .. attribute:: current_update_limit_process
                    
                    	Current Process update limit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_update_limit_process
                    
                    	Configured Process update limit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_out_queue_messages
                    
                    	OutQueue messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_out_queue_size
                    
                    	OutQueue size
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_throttled
                    
                    	Is update throttled
                    	**type**\: bool
                    
                    .. attribute:: update_address_family
                    
                    	List of address\-families
                    	**type**\: list of  		 :py:class:`UpdateAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateAddressFamily>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess, self).__init__()

                        self.yang_name = "update-generation-process"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics)), ("update-address-family", ("update_address_family", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateAddressFamily))])
                        self._leafs = OrderedDict([
                            ('update_out_logging', (YLeaf(YType.boolean, 'update-out-logging'), ['bool'])),
                            ('current_update_limit_process', (YLeaf(YType.uint32, 'current-update-limit-process'), ['int'])),
                            ('configured_update_limit_process', (YLeaf(YType.uint32, 'configured-update-limit-process'), ['int'])),
                            ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                            ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                            ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                        ])
                        self.update_out_logging = None
                        self.current_update_limit_process = None
                        self.configured_update_limit_process = None
                        self.update_out_queue_messages = None
                        self.update_out_queue_size = None
                        self.update_throttled = None

                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics()
                        self.update_statistics.parent = self
                        self._children_name_map["update_statistics"] = "update-statistics"

                        self.update_address_family = YList(self)
                        self._segment_path = lambda: "update-generation-process"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess, [u'update_out_logging', u'current_update_limit_process', u'configured_update_limit_process', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled'], name, value)


                    class UpdateStatistics(Entity):
                        """
                        Update statistics
                        
                        .. attribute:: last_update_discard_timestamp
                        
                        	Last Discarded time
                        	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp>`
                        
                        .. attribute:: last_update_cleared_timestamp
                        
                        	Last Cleared time
                        	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp>`
                        
                        .. attribute:: last_update_throttle_timestamp
                        
                        	Last Throttled time
                        	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp>`
                        
                        .. attribute:: last_update_recovery_timestamp
                        
                        	Last Recovery time
                        	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                        
                        .. attribute:: last_update_memory_allocation_fail_timestamp
                        
                        	Memory allocation failure time
                        	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                        
                        .. attribute:: update_out_queue_messages_high
                        
                        	OutQueue High Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cumulative
                        
                        	OutQueue Cumulative Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_discarded
                        
                        	OutQueue Discarded Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cleared
                        
                        	OutQueue Cleared Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size_high
                        
                        	OutQueue Hi Size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size_cumulative
                        
                        	OutQueue Cumulative Size
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_discarded
                        
                        	OutQueue Discarded Size
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_cleared
                        
                        	OutQueue Cleared Size
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: last_update_discard_age
                        
                        	Time since last Discard event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_cleard_age
                        
                        	Time since last Clear event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: update_throttle_count
                        
                        	Throttle Count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_update_throttle_age
                        
                        	Time since last Throttle event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: update_recovery_count
                        
                        	Recovery Count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_update_recovery_age
                        
                        	Time since last Recovery event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: update_memory_allocation_fail_count
                        
                        	Memory allocation failure count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_update_memory_allocation_fail_age
                        
                        	Time since last memory allocation failure event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics, self).__init__()

                            self.yang_name = "update-statistics"
                            self.yang_parent_name = "update-generation-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                            self._leafs = OrderedDict([
                                ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                            ])
                            self.update_out_queue_messages_high = None
                            self.update_out_queue_messages_cumulative = None
                            self.update_out_queue_messages_discarded = None
                            self.update_out_queue_messages_cleared = None
                            self.update_out_queue_size_high = None
                            self.update_out_queue_size_cumulative = None
                            self.update_out_queue_size_discarded = None
                            self.update_out_queue_size_cleared = None
                            self.last_update_discard_age = None
                            self.last_update_cleard_age = None
                            self.update_throttle_count = None
                            self.last_update_throttle_age = None
                            self.update_recovery_count = None
                            self.last_update_recovery_age = None
                            self.update_memory_allocation_fail_count = None
                            self.last_update_memory_allocation_fail_age = None

                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp()
                            self.last_update_discard_timestamp.parent = self
                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp()
                            self.last_update_cleared_timestamp.parent = self
                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp()
                            self.last_update_throttle_timestamp.parent = self
                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp()
                            self.last_update_recovery_timestamp.parent = self
                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                            self.last_update_memory_allocation_fail_timestamp.parent = self
                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                            self._segment_path = lambda: "update-statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                        class LastUpdateDiscardTimestamp(Entity):
                            """
                            Last Discarded time
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                self.yang_name = "last-update-discard-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-discard-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class LastUpdateClearedTimestamp(Entity):
                            """
                            Last Cleared time
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                self.yang_name = "last-update-cleared-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-cleared-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class LastUpdateThrottleTimestamp(Entity):
                            """
                            Last Throttled time
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                self.yang_name = "last-update-throttle-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-throttle-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class LastUpdateRecoveryTimestamp(Entity):
                            """
                            Last Recovery time
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                self.yang_name = "last-update-recovery-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-recovery-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                            """
                            Memory allocation failure time
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                    class UpdateAddressFamily(Entity):
                        """
                        List of address\-families
                        
                        .. attribute:: update_group_af_name
                        
                        	Address family identifier
                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                        
                        .. attribute:: current_update_limit_af
                        
                        	Current AF update limit
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages
                        
                        	OutQueue messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size
                        
                        	OutQueue size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_throttled
                        
                        	Is update throttled
                        	**type**\: bool
                        
                        .. attribute:: update_update_group_count
                        
                        	Update\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_sub_group_count
                        
                        	Sub\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sub_group_throttled_count
                        
                        	Throttled sub\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_count
                        
                        	Refresh sub\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_throttled_count
                        
                        	Throttled refresh sub\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: filter_group_count
                        
                        	Filter\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_count
                        
                        	Neighbor count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateAddressFamily, self).__init__()

                            self.yang_name = "update-address-family"
                            self.yang_parent_name = "update-generation-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                ('current_update_limit_af', (YLeaf(YType.uint32, 'current-update-limit-af'), ['int'])),
                                ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                                ('update_update_group_count', (YLeaf(YType.uint32, 'update-update-group-count'), ['int'])),
                                ('update_sub_group_count', (YLeaf(YType.uint32, 'update-sub-group-count'), ['int'])),
                                ('sub_group_throttled_count', (YLeaf(YType.uint32, 'sub-group-throttled-count'), ['int'])),
                                ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                ('refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'refresh-sub-group-throttled-count'), ['int'])),
                                ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                            ])
                            self.update_group_af_name = None
                            self.current_update_limit_af = None
                            self.update_out_queue_messages = None
                            self.update_out_queue_size = None
                            self.update_throttled = None
                            self.update_update_group_count = None
                            self.update_sub_group_count = None
                            self.sub_group_throttled_count = None
                            self.refresh_sub_group_count = None
                            self.refresh_sub_group_throttled_count = None
                            self.filter_group_count = None
                            self.neighbor_count = None
                            self._segment_path = lambda: "update-address-family"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateGenerationProcess.UpdateAddressFamily, [u'update_group_af_name', u'current_update_limit_af', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled', u'update_update_group_count', u'update_sub_group_count', u'sub_group_throttled_count', u'refresh_sub_group_count', u'refresh_sub_group_throttled_count', u'filter_group_count', u'neighbor_count'], name, value)


                class Vrfs(Entity):
                    """
                    VRF related operational data
                    
                    .. attribute:: vrf
                    
                    	Operational data for a particular VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.Vrfs, self).__init__()

                        self.yang_name = "vrfs"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = YList(self)
                        self._segment_path = lambda: "vrfs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs, [], name, value)


                    class Vrf(Entity):
                        """
                        Operational data for a particular VRF
                        
                        .. attribute:: vrf_name  (key)
                        
                        	Name of the VRF
                        	**type**\: str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: update_inbound_error_vrf
                        
                        	Update inbound error information for the VRF
                        	**type**\:  :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf>`
                        
                        .. attribute:: afs
                        
                        	BGP address family table
                        	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs>`
                        
                        .. attribute:: information
                        
                        	Meta data for VRF
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information>`
                        
                        .. attribute:: update_inbound_filter_vrf
                        
                        	Update inbound filtering information for the VRF
                        	**type**\:  :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf>`
                        
                        .. attribute:: postits
                        
                        	The BGP Neighbor table
                        	**type**\:  :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits>`
                        
                        .. attribute:: global_process_info
                        
                        	The Global Process information table
                        	**type**\:  :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo>`
                        
                        .. attribute:: update_inbound_error_neighbors
                        
                        	Update inbound error information for all neighbors
                        	**type**\:  :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors>`
                        
                        .. attribute:: update_inbound_filter_neighbors
                        
                        	Update inbound filtering information for all neighbors
                        	**type**\:  :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors>`
                        
                        .. attribute:: bmp
                        
                        	BMP related Operational Data
                        	**type**\:  :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp>`
                        
                        .. attribute:: process_info
                        
                        	A Process instance table entry
                        	**type**\:  :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo>`
                        
                        .. attribute:: sessions
                        
                        	The BGP session table
                        	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions>`
                        
                        .. attribute:: neighbors
                        
                        	The BGP Neighbor table
                        	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors>`
                        
                        .. attribute:: next_hop_vrf
                        
                        	A BGP Next\-hop VRF table entry
                        	**type**\:  :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf>`
                        
                        .. attribute:: neighbor_ranges
                        
                        	The BGP Dynamic Neighbor Range table
                        	**type**\:  :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges>`
                        
                        .. attribute:: message_logs
                        
                        	The BGP Neighbor Message table
                        	**type**\:  :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "vrfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['vrf_name']
                            self._child_classes = OrderedDict([("update-inbound-error-vrf", ("update_inbound_error_vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf)), ("afs", ("afs", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs)), ("information", ("information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information)), ("update-inbound-filter-vrf", ("update_inbound_filter_vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf)), ("postits", ("postits", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits)), ("global-process-info", ("global_process_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo)), ("update-inbound-error-neighbors", ("update_inbound_error_neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors)), ("update-inbound-filter-neighbors", ("update_inbound_filter_neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors)), ("bmp", ("bmp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp)), ("process-info", ("process_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo)), ("sessions", ("sessions", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions)), ("neighbors", ("neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors)), ("next-hop-vrf", ("next_hop_vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf)), ("neighbor-ranges", ("neighbor_ranges", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges)), ("message-logs", ("message_logs", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs))])
                            self._leafs = OrderedDict([
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.vrf_name = None

                            self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf()
                            self.update_inbound_error_vrf.parent = self
                            self._children_name_map["update_inbound_error_vrf"] = "update-inbound-error-vrf"

                            self.afs = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs()
                            self.afs.parent = self
                            self._children_name_map["afs"] = "afs"

                            self.information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"

                            self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf()
                            self.update_inbound_filter_vrf.parent = self
                            self._children_name_map["update_inbound_filter_vrf"] = "update-inbound-filter-vrf"

                            self.postits = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits()
                            self.postits.parent = self
                            self._children_name_map["postits"] = "postits"

                            self.global_process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo()
                            self.global_process_info.parent = self
                            self._children_name_map["global_process_info"] = "global-process-info"

                            self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors()
                            self.update_inbound_error_neighbors.parent = self
                            self._children_name_map["update_inbound_error_neighbors"] = "update-inbound-error-neighbors"

                            self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors()
                            self.update_inbound_filter_neighbors.parent = self
                            self._children_name_map["update_inbound_filter_neighbors"] = "update-inbound-filter-neighbors"

                            self.bmp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp()
                            self.bmp.parent = self
                            self._children_name_map["bmp"] = "bmp"

                            self.process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo()
                            self.process_info.parent = self
                            self._children_name_map["process_info"] = "process-info"

                            self.sessions = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"

                            self.neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"

                            self.next_hop_vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf()
                            self.next_hop_vrf.parent = self
                            self._children_name_map["next_hop_vrf"] = "next-hop-vrf"

                            self.neighbor_ranges = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges()
                            self.neighbor_ranges.parent = self
                            self._children_name_map["neighbor_ranges"] = "neighbor-ranges"

                            self.message_logs = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs()
                            self.message_logs.parent = self
                            self._children_name_map["message_logs"] = "message-logs"
                            self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf, ['vrf_name'], name, value)


                        class UpdateInboundErrorVrf(Entity):
                            """
                            Update inbound error information for the VRF
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_neighbor_count
                            
                            	Count of neighbors that received malformed messages
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed messages received event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf, self).__init__()

                                self.yang_name = "update-inbound-error-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("last-update-malformed-timestamp", ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp))])
                                self._leafs = OrderedDict([
                                    ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                    ('update_malformed_message_count', (YLeaf(YType.uint32, 'update-malformed-message-count'), ['int'])),
                                    ('update_malformed_neighbor_count', (YLeaf(YType.uint32, 'update-malformed-neighbor-count'), ['int'])),
                                    ('last_update_malformed_age', (YLeaf(YType.uint32, 'last-update-malformed-age'), ['int'])),
                                ])
                                self.update_vrf_name = None
                                self.update_malformed_message_count = None
                                self.update_malformed_neighbor_count = None
                                self.last_update_malformed_age = None

                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                                self._segment_path = lambda: "update-inbound-error-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf, [u'update_vrf_name', u'update_malformed_message_count', u'update_malformed_neighbor_count', u'last_update_malformed_age'], name, value)


                            class LastUpdateMalformedTimestamp(Entity):
                                """
                                Last malformed messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "last-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-update-malformed-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class Afs(Entity):
                            """
                            BGP address family table
                            
                            .. attribute:: af
                            
                            	A particular address family
                            	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs, self).__init__()

                                self.yang_name = "afs"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("af", ("af", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af))])
                                self._leafs = OrderedDict()

                                self.af = YList(self)
                                self._segment_path = lambda: "afs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs, [], name, value)


                            class Af(Entity):
                                """
                                A particular address family
                                
                                .. attribute:: af_name  (key)
                                
                                	Address family
                                	**type**\:  :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                
                                .. attribute:: rpki_refresh_af_table
                                
                                	RPKI Refresh Table (per AF)
                                	**type**\:  :py:class:`RpkiRefreshAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable>`
                                
                                .. attribute:: policies
                                
                                	The BGP Policy Table
                                	**type**\:  :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies>`
                                
                                .. attribute:: convergence
                                
                                	A BGP Convergence table entry
                                	**type**\:  :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence>`
                                
                                .. attribute:: af_process_info
                                
                                	A BGP Process address family table entry
                                	**type**\:  :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo>`
                                
                                .. attribute:: path_used_table
                                
                                	The BGP Path Used Table
                                	**type**\:  :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable>`
                                
                                .. attribute:: bmp_path_table_generic
                                
                                	Summary Info about BMP Table
                                	**type**\:  :py:class:`BmpPathTableGeneric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric>`
                                
                                .. attribute:: rpc_sets
                                
                                	BGP next\-hop set table
                                	**type**\:  :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets>`
                                
                                .. attribute:: global_af_process_info
                                
                                	The Global Address Family Process information table
                                	**type**\:  :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo>`
                                
                                .. attribute:: advertised_path_xr
                                
                                	The BGP Advertised path table (bestpath)
                                	**type**\:  :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr>`
                                
                                .. attribute:: sourced_networks
                                
                                	The BGP Convergence table
                                	**type**\:  :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks>`
                                
                                .. attribute:: update_groups
                                
                                	The BGP Update group table
                                	**type**\:  :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups>`
                                
                                .. attribute:: update_generation_sub_groups
                                
                                	Update generation for all sub\-groups
                                	**type**\:  :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups>`
                                
                                .. attribute:: next_hop_address_families
                                
                                	Address family of nexthop table
                                	**type**\:  :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies>`
                                
                                .. attribute:: rt_set_counters
                                
                                	The RT\-set counter table
                                	**type**\:  :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters>`
                                
                                .. attribute:: bmp_paths
                                
                                	The paths in BMP Table
                                	**type**\:  :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths>`
                                
                                .. attribute:: update_generation_update_groups
                                
                                	Update generation for all update\-groups
                                	**type**\:  :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups>`
                                
                                .. attribute:: update_generation_filter_groups
                                
                                	Update generation for all filter\-groups under a sub\-group
                                	**type**\:  :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups>`
                                
                                .. attribute:: networks
                                
                                	The BGP Network Table
                                	**type**\:  :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks>`
                                
                                .. attribute:: path_table
                                
                                	The BGP Path Table
                                	**type**\:  :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable>`
                                
                                .. attribute:: epes
                                
                                	The BGP Egress Engineering table
                                	**type**\:  :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes>`
                                
                                .. attribute:: advertised_path_counts
                                
                                	The BGP Advertised paths table (bestpath)
                                	**type**\:  :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts>`
                                
                                .. attribute:: path_labeled_table
                                
                                	The BGP Path Labeled Table
                                	**type**\:  :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable>`
                                
                                .. attribute:: advertised_paths
                                
                                	The BGP Advertised paths table (add\-paths)
                                	**type**\:  :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths>`
                                
                                .. attribute:: neighbor_af_table
                                
                                	The BGP Neighbor AF table
                                	**type**\:  :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable>`
                                
                                .. attribute:: update_generation_neighbors
                                
                                	Update generation for all neighbors
                                	**type**\:  :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors>`
                                
                                .. attribute:: update_generation_address_family
                                
                                	Update generation for address\-family
                                	**type**\:  :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily>`
                                
                                .. attribute:: dampenings
                                
                                	The BGP Dampening table
                                	**type**\:  :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings>`
                                
                                .. attribute:: prefix_filters
                                
                                	The BGP Prefix Filter table
                                	**type**\:  :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters>`
                                
                                .. attribute:: attributes
                                
                                	The BGP Attribute table
                                	**type**\:  :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af, self).__init__()

                                    self.yang_name = "af"
                                    self.yang_parent_name = "afs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("rpki-refresh-af-table", ("rpki_refresh_af_table", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable)), ("policies", ("policies", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies)), ("convergence", ("convergence", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence)), ("af-process-info", ("af_process_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo)), ("path-used-table", ("path_used_table", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable)), ("bmp-path-table-generic", ("bmp_path_table_generic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric)), ("rpc-sets", ("rpc_sets", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets)), ("global-af-process-info", ("global_af_process_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo)), ("advertised-path-xr", ("advertised_path_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr)), ("sourced-networks", ("sourced_networks", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks)), ("update-groups", ("update_groups", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups)), ("update-generation-sub-groups", ("update_generation_sub_groups", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups)), ("next-hop-address-families", ("next_hop_address_families", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies)), ("rt-set-counters", ("rt_set_counters", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters)), ("bmp-paths", ("bmp_paths", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths)), ("update-generation-update-groups", ("update_generation_update_groups", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups)), ("update-generation-filter-groups", ("update_generation_filter_groups", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups)), ("networks", ("networks", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks)), ("path-table", ("path_table", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable)), ("epes", ("epes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes)), ("advertised-path-counts", ("advertised_path_counts", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts)), ("path-labeled-table", ("path_labeled_table", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable)), ("advertised-paths", ("advertised_paths", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths)), ("neighbor-af-table", ("neighbor_af_table", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable)), ("update-generation-neighbors", ("update_generation_neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors)), ("update-generation-address-family", ("update_generation_address_family", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily)), ("dampenings", ("dampenings", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings)), ("prefix-filters", ("prefix_filters", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters)), ("attributes", ("attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes', 'BgpAddressFamily', '')])),
                                    ])
                                    self.af_name = None

                                    self.rpki_refresh_af_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable()
                                    self.rpki_refresh_af_table.parent = self
                                    self._children_name_map["rpki_refresh_af_table"] = "rpki-refresh-af-table"

                                    self.policies = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies()
                                    self.policies.parent = self
                                    self._children_name_map["policies"] = "policies"

                                    self.convergence = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence()
                                    self.convergence.parent = self
                                    self._children_name_map["convergence"] = "convergence"

                                    self.af_process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo()
                                    self.af_process_info.parent = self
                                    self._children_name_map["af_process_info"] = "af-process-info"

                                    self.path_used_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable()
                                    self.path_used_table.parent = self
                                    self._children_name_map["path_used_table"] = "path-used-table"

                                    self.bmp_path_table_generic = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric()
                                    self.bmp_path_table_generic.parent = self
                                    self._children_name_map["bmp_path_table_generic"] = "bmp-path-table-generic"

                                    self.rpc_sets = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets()
                                    self.rpc_sets.parent = self
                                    self._children_name_map["rpc_sets"] = "rpc-sets"

                                    self.global_af_process_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo()
                                    self.global_af_process_info.parent = self
                                    self._children_name_map["global_af_process_info"] = "global-af-process-info"

                                    self.advertised_path_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr()
                                    self.advertised_path_xr.parent = self
                                    self._children_name_map["advertised_path_xr"] = "advertised-path-xr"

                                    self.sourced_networks = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks()
                                    self.sourced_networks.parent = self
                                    self._children_name_map["sourced_networks"] = "sourced-networks"

                                    self.update_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups()
                                    self.update_groups.parent = self
                                    self._children_name_map["update_groups"] = "update-groups"

                                    self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups()
                                    self.update_generation_sub_groups.parent = self
                                    self._children_name_map["update_generation_sub_groups"] = "update-generation-sub-groups"

                                    self.next_hop_address_families = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies()
                                    self.next_hop_address_families.parent = self
                                    self._children_name_map["next_hop_address_families"] = "next-hop-address-families"

                                    self.rt_set_counters = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters()
                                    self.rt_set_counters.parent = self
                                    self._children_name_map["rt_set_counters"] = "rt-set-counters"

                                    self.bmp_paths = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths()
                                    self.bmp_paths.parent = self
                                    self._children_name_map["bmp_paths"] = "bmp-paths"

                                    self.update_generation_update_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups()
                                    self.update_generation_update_groups.parent = self
                                    self._children_name_map["update_generation_update_groups"] = "update-generation-update-groups"

                                    self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups()
                                    self.update_generation_filter_groups.parent = self
                                    self._children_name_map["update_generation_filter_groups"] = "update-generation-filter-groups"

                                    self.networks = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks()
                                    self.networks.parent = self
                                    self._children_name_map["networks"] = "networks"

                                    self.path_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable()
                                    self.path_table.parent = self
                                    self._children_name_map["path_table"] = "path-table"

                                    self.epes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes()
                                    self.epes.parent = self
                                    self._children_name_map["epes"] = "epes"

                                    self.advertised_path_counts = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts()
                                    self.advertised_path_counts.parent = self
                                    self._children_name_map["advertised_path_counts"] = "advertised-path-counts"

                                    self.path_labeled_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable()
                                    self.path_labeled_table.parent = self
                                    self._children_name_map["path_labeled_table"] = "path-labeled-table"

                                    self.advertised_paths = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths()
                                    self.advertised_paths.parent = self
                                    self._children_name_map["advertised_paths"] = "advertised-paths"

                                    self.neighbor_af_table = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable()
                                    self.neighbor_af_table.parent = self
                                    self._children_name_map["neighbor_af_table"] = "neighbor-af-table"

                                    self.update_generation_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors()
                                    self.update_generation_neighbors.parent = self
                                    self._children_name_map["update_generation_neighbors"] = "update-generation-neighbors"

                                    self.update_generation_address_family = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily()
                                    self.update_generation_address_family.parent = self
                                    self._children_name_map["update_generation_address_family"] = "update-generation-address-family"

                                    self.dampenings = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings()
                                    self.dampenings.parent = self
                                    self._children_name_map["dampenings"] = "dampenings"

                                    self.prefix_filters = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters()
                                    self.prefix_filters.parent = self
                                    self._children_name_map["prefix_filters"] = "prefix-filters"

                                    self.attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes()
                                    self.attributes.parent = self
                                    self._children_name_map["attributes"] = "attributes"
                                    self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                                class RpkiRefreshAfTable(Entity):
                                    """
                                    RPKI Refresh Table (per AF)
                                    
                                    .. attribute:: rpki_refresh_af
                                    
                                    	RPKI Refresh List
                                    	**type**\:  :py:class:`RpkiRefreshAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable, self).__init__()

                                        self.yang_name = "rpki-refresh-af-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rpki-refresh-af", ("rpki_refresh_af", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf))])
                                        self._leafs = OrderedDict()

                                        self.rpki_refresh_af = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf()
                                        self.rpki_refresh_af.parent = self
                                        self._children_name_map["rpki_refresh_af"] = "rpki-refresh-af"
                                        self._segment_path = lambda: "rpki-refresh-af-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable, [], name, value)


                                    class RpkiRefreshAf(Entity):
                                        """
                                        RPKI Refresh List
                                        
                                        .. attribute:: refresh_entry
                                        
                                        	Array of refresh entries
                                        	**type**\: list of  		 :py:class:`RefreshEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf, self).__init__()

                                            self.yang_name = "rpki-refresh-af"
                                            self.yang_parent_name = "rpki-refresh-af-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("refresh-entry", ("refresh_entry", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry))])
                                            self._leafs = OrderedDict()

                                            self.refresh_entry = YList(self)
                                            self._segment_path = lambda: "rpki-refresh-af"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf, [], name, value)


                                        class RefreshEntry(Entity):
                                            """
                                            Array of refresh entries
                                            
                                            .. attribute:: af_name
                                            
                                            	Address Family
                                            	**type**\:  :py:class:`BgpRpkiAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAf>`
                                            
                                            .. attribute:: neighbor
                                            
                                            	BGP neighbor
                                            	**type**\: str
                                            
                                            .. attribute:: policy
                                            
                                            	Route Policy
                                            	**type**\: str
                                            
                                            .. attribute:: paths
                                            
                                            	Number of BGP paths modified or dropped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: drop
                                            
                                            	BGP paths were dropped
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry, self).__init__()

                                                self.yang_name = "refresh-entry"
                                                self.yang_parent_name = "rpki-refresh-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiAf', '')])),
                                                    ('neighbor', (YLeaf(YType.str, 'neighbor'), ['str'])),
                                                    ('policy', (YLeaf(YType.str, 'policy'), ['str'])),
                                                    ('paths', (YLeaf(YType.uint32, 'paths'), ['int'])),
                                                    ('drop', (YLeaf(YType.boolean, 'drop'), ['bool'])),
                                                ])
                                                self.af_name = None
                                                self.neighbor = None
                                                self.policy = None
                                                self.paths = None
                                                self.drop = None
                                                self._segment_path = lambda: "refresh-entry"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry, [u'af_name', u'neighbor', u'policy', u'paths', u'drop'], name, value)


                                class Policies(Entity):
                                    """
                                    The BGP Policy Table
                                    
                                    .. attribute:: policy
                                    
                                    	A BGP Policy table entry
                                    	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies, self).__init__()

                                        self.yang_name = "policies"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("policy", ("policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy))])
                                        self._leafs = OrderedDict()

                                        self.policy = YList(self)
                                        self._segment_path = lambda: "policies"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies, [], name, value)


                                    class Policy(Entity):
                                        """
                                        A BGP Policy table entry
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:  :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:  :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy, self).__init__()

                                            self.yang_name = "policy"
                                            self.yang_parent_name = "policies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr)), ("path-info-after-policy-in", ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn)), ("path-info-after-policy-out", ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn)), ("attributes-after-policy-out", ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.vrf_name = None

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"

                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"

                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                            self._segment_path = lambda: "policy"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy, ['rd', 'network', 'prefix_length', 'neighbor_address', u'no_path', u'af_name', u'route_distinguisher', u'source_route_distinguisher', u'vrf_name'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address-xr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInfoAfterPolicyIn(Entity):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, self).__init__()

                                                self.yang_name = "path-info-after-policy-in"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInfoAfterPolicyOut(Entity):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, self).__init__()

                                                self.yang_name = "path-info-after-policy-out"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-out"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyOut(Entity):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, self).__init__()

                                                self.yang_name = "attributes-after-policy-out"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-out"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class Convergence(Entity):
                                    """
                                    A BGP Convergence table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: has_converged
                                    
                                    	Convergence has been reached
                                    	**type**\: bool
                                    
                                    .. attribute:: are_write_queues_empty
                                    
                                    	All neighbor write queues are empty
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence, self).__init__()

                                        self.yang_name = "convergence"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('has_converged', (YLeaf(YType.boolean, 'has-converged'), ['bool'])),
                                            ('are_write_queues_empty', (YLeaf(YType.boolean, 'are-write-queues-empty'), ['bool'])),
                                        ])
                                        self.af_name = None
                                        self.has_converged = None
                                        self.are_write_queues_empty = None
                                        self._segment_path = lambda: "convergence"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Convergence, [u'af_name', u'has_converged', u'are_write_queues_empty'], name, value)


                                class AfProcessInfo(Entity):
                                    """
                                    A BGP Process address family table entry
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance
                                    
                                    	ID for the BGP process instance
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: vrf_totals
                                    
                                    	per VRF information aggregated across all VRFs
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo, self).__init__()

                                        self.yang_name = "af-process-info"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics))])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance', (YLeaf(YType.uint8, 'process-instance'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('vrf_totals', (YLeaf(YType.boolean, 'vrf-totals'), ['bool'])),
                                        ])
                                        self.af_name = None
                                        self.process_instance = None
                                        self.vrf_name = None
                                        self.vrf_totals = None

                                        self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"

                                        self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"
                                        self._segment_path = lambda: "af-process-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo, [u'af_name', u'process_instance', u'vrf_name', u'vrf_totals'], name, value)


                                    class Global(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: version_wrap_time_spec
                                        
                                        	Version Wrap timestamp
                                        	**type**\:  :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec>`
                                        
                                        .. attribute:: version_wrap_start_time_spec
                                        
                                        	Version Wrap handle start timestamp
                                        	**type**\:  :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec>`
                                        
                                        .. attribute:: version_wrap_done_time_spec
                                        
                                        	Version Wrap handle Done timestamp
                                        	**type**\:  :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec>`
                                        
                                        .. attribute:: trigger_rib
                                        
                                        	Trigger RIB
                                        	**type**\:  :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib>`
                                        
                                        .. attribute:: trigger_import
                                        
                                        	Trigger import
                                        	**type**\:  :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport>`
                                        
                                        .. attribute:: trigger_update
                                        
                                        	Trigger update
                                        	**type**\:  :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate>`
                                        
                                        .. attribute:: trigger_label
                                        
                                        	Trigger label
                                        	**type**\:  :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel>`
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:  :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall>`
                                        
                                        .. attribute:: router_state
                                        
                                        	Router state
                                        	**type**\:  :py:class:`BgpRtrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrState>`
                                        
                                        .. attribute:: table_version
                                        
                                        	BGP table version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrapped
                                        
                                        	Number of times Version Wrap happened
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrapped_tid
                                        
                                        	Version Wrapped trigger tid
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_active_pelem_version
                                        
                                        	Maximum Active Pelem Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: merged_table_version
                                        
                                        	Merged Table Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_download_go_active_done_pending
                                        
                                        	Route Download Go Active Done Pending
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_brib_received_version
                                        
                                        	Version received from 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Version sent to RIB/bRIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_version
                                        
                                        	Version updated by label thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_version
                                        
                                        	Version updated by import thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: standby_version
                                        
                                        	Version updated by sync thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: send_version
                                        
                                        	Version for sending updates to peers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_init_sync_pfx
                                        
                                        	Num of prefix synced during Initsync
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_label_stack_depth_v4_next_hop
                                        
                                        	Max supported label stack depth for IPv4 Nexthop
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_label_stack_depth_v6_next_hop
                                        
                                        	Max supported label stack depth for IPv6 Nexthop
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_num
                                        
                                        	Total local networks
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_memory
                                        
                                        	Total local networks memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_malloced_num
                                        
                                        	Total local networks malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_freed_num
                                        
                                        	Total local networks freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_num
                                        
                                        	Total local paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_memory
                                        
                                        	Total local paths memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_malloced_num
                                        
                                        	Total local paths malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_freed_num
                                        
                                        	Total local paths freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_num
                                        
                                        	Total impoorted paths 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_memory
                                        
                                        	Total imported paths memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_num
                                        
                                        	Total Num of networks
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_memory
                                        
                                        	Total networks memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_malloced_num
                                        
                                        	Total networks malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_freed_num
                                        
                                        	Total networks freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_num
                                        
                                        	Total Num of paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_memory
                                        
                                        	Total paths memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_malloced_num
                                        
                                        	Total paths malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_freed_num
                                        
                                        	Total paths freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_num
                                        
                                        	Total Num of path\-elems
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_memory
                                        
                                        	Total path\-elems memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_malloced_num
                                        
                                        	Total path\-elems malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_freed_num
                                        
                                        	Total path\-elems freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_last_trigger
                                        
                                        	Timestamp when Label thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_label_version
                                        
                                        	Label thread version when last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_bgp_version
                                        
                                        	BGP version when label thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_triggers
                                        
                                        	Label thread triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_last_trigger
                                        
                                        	Timestamp when RIB thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_rib_version
                                        
                                        	RIB thread version when last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_bgp_version
                                        
                                        	BGP version when RIB thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_triggers
                                        
                                        	RIB thread triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_last_trigger
                                        
                                        	Timestamp when Import thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_import_version
                                        
                                        	Import thread version when last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_bgp_version
                                        
                                        	BGP version when Import thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_triggers
                                        
                                        	Import thread triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_gen_last_trigger
                                        
                                        	Timestamp when Update generation thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_gen_bgp_version
                                        
                                        	BGP version when Update generation thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_triggers
                                        
                                        	Update thread triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_r_ds_num
                                        
                                        	Total Num of RDs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_remote_r_ds_num
                                        
                                        	Total Num of remote RDs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_same_r_ds_num
                                        
                                        	Total Num of same RDs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_rd_count
                                        
                                        	Activity\: Number of RDs malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_rd_count
                                        
                                        	Activity\: Number of RDs freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rd_memory
                                        
                                        	Memory (in bytes) used by RD data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: multipath_network_entry_count
                                        
                                        	Number of multipath network entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_network_entry_memory
                                        
                                        	Memory (in bytes) used bymultipath network entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: multipath_paths_count
                                        
                                        	Number of multipath paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_paths_memory
                                        
                                        	Memory (in bytes) used bymultimpath paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("version-wrap-time-spec", ("version_wrap_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec)), ("version-wrap-start-time-spec", ("version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec)), ("version-wrap-done-time-spec", ("version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec)), ("trigger-rib", ("trigger_rib", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib)), ("trigger-import", ("trigger_import", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport)), ("trigger-update", ("trigger_update", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate)), ("trigger-label", ("trigger_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel)), ("rib-install", ("rib_install", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall))])
                                            self._leafs = OrderedDict([
                                                ('router_state', (YLeaf(YType.enumeration, 'router-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRtrState', '')])),
                                                ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                                ('version_wrapped', (YLeaf(YType.uint32, 'version-wrapped'), ['int'])),
                                                ('version_wrapped_tid', (YLeaf(YType.uint32, 'version-wrapped-tid'), ['int'])),
                                                ('max_active_pelem_version', (YLeaf(YType.uint32, 'max-active-pelem-version'), ['int'])),
                                                ('merged_table_version', (YLeaf(YType.uint32, 'merged-table-version'), ['int'])),
                                                ('route_download_go_active_done_pending', (YLeaf(YType.uint32, 'route-download-go-active-done-pending'), ['int'])),
                                                ('rib_brib_received_version', (YLeaf(YType.uint32, 'rib-brib-received-version'), ['int'])),
                                                ('table_brib_version', (YLeaf(YType.uint32, 'table-brib-version'), ['int'])),
                                                ('label_version', (YLeaf(YType.uint32, 'label-version'), ['int'])),
                                                ('import_version', (YLeaf(YType.uint32, 'import-version'), ['int'])),
                                                ('standby_version', (YLeaf(YType.uint32, 'standby-version'), ['int'])),
                                                ('send_version', (YLeaf(YType.uint32, 'send-version'), ['int'])),
                                                ('num_init_sync_pfx', (YLeaf(YType.uint32, 'num-init-sync-pfx'), ['int'])),
                                                ('max_label_stack_depth_v4_next_hop', (YLeaf(YType.uint32, 'max-label-stack-depth-v4-next-hop'), ['int'])),
                                                ('max_label_stack_depth_v6_next_hop', (YLeaf(YType.uint32, 'max-label-stack-depth-v6-next-hop'), ['int'])),
                                                ('local_networks_num', (YLeaf(YType.uint32, 'local-networks-num'), ['int'])),
                                                ('local_networks_memory', (YLeaf(YType.uint32, 'local-networks-memory'), ['int'])),
                                                ('local_networks_malloced_num', (YLeaf(YType.uint32, 'local-networks-malloced-num'), ['int'])),
                                                ('local_networks_freed_num', (YLeaf(YType.uint32, 'local-networks-freed-num'), ['int'])),
                                                ('local_paths_num', (YLeaf(YType.uint32, 'local-paths-num'), ['int'])),
                                                ('local_paths_memory', (YLeaf(YType.uint32, 'local-paths-memory'), ['int'])),
                                                ('local_paths_malloced_num', (YLeaf(YType.uint32, 'local-paths-malloced-num'), ['int'])),
                                                ('local_paths_freed_num', (YLeaf(YType.uint32, 'local-paths-freed-num'), ['int'])),
                                                ('imported_paths_num', (YLeaf(YType.uint32, 'imported-paths-num'), ['int'])),
                                                ('imported_paths_memory', (YLeaf(YType.uint32, 'imported-paths-memory'), ['int'])),
                                                ('networks_num', (YLeaf(YType.uint32, 'networks-num'), ['int'])),
                                                ('networks_memory', (YLeaf(YType.uint32, 'networks-memory'), ['int'])),
                                                ('networks_malloced_num', (YLeaf(YType.uint32, 'networks-malloced-num'), ['int'])),
                                                ('networks_freed_num', (YLeaf(YType.uint32, 'networks-freed-num'), ['int'])),
                                                ('paths_num', (YLeaf(YType.uint32, 'paths-num'), ['int'])),
                                                ('paths_memory', (YLeaf(YType.uint32, 'paths-memory'), ['int'])),
                                                ('paths_malloced_num', (YLeaf(YType.uint32, 'paths-malloced-num'), ['int'])),
                                                ('paths_freed_num', (YLeaf(YType.uint32, 'paths-freed-num'), ['int'])),
                                                ('path_elems_num', (YLeaf(YType.uint32, 'path-elems-num'), ['int'])),
                                                ('path_elems_memory', (YLeaf(YType.uint32, 'path-elems-memory'), ['int'])),
                                                ('path_elems_malloced_num', (YLeaf(YType.uint32, 'path-elems-malloced-num'), ['int'])),
                                                ('path_elems_freed_num', (YLeaf(YType.uint32, 'path-elems-freed-num'), ['int'])),
                                                ('label_last_trigger', (YLeaf(YType.uint64, 'label-last-trigger'), ['int'])),
                                                ('last_label_version', (YLeaf(YType.uint32, 'last-label-version'), ['int'])),
                                                ('label_bgp_version', (YLeaf(YType.uint32, 'label-bgp-version'), ['int'])),
                                                ('label_triggers', (YLeaf(YType.uint32, 'label-triggers'), ['int'])),
                                                ('rib_last_trigger', (YLeaf(YType.uint64, 'rib-last-trigger'), ['int'])),
                                                ('last_rib_version', (YLeaf(YType.uint32, 'last-rib-version'), ['int'])),
                                                ('rib_bgp_version', (YLeaf(YType.uint32, 'rib-bgp-version'), ['int'])),
                                                ('rib_triggers', (YLeaf(YType.uint32, 'rib-triggers'), ['int'])),
                                                ('import_last_trigger', (YLeaf(YType.uint64, 'import-last-trigger'), ['int'])),
                                                ('last_import_version', (YLeaf(YType.uint32, 'last-import-version'), ['int'])),
                                                ('import_bgp_version', (YLeaf(YType.uint32, 'import-bgp-version'), ['int'])),
                                                ('import_triggers', (YLeaf(YType.uint32, 'import-triggers'), ['int'])),
                                                ('update_gen_last_trigger', (YLeaf(YType.uint64, 'update-gen-last-trigger'), ['int'])),
                                                ('update_gen_bgp_version', (YLeaf(YType.uint32, 'update-gen-bgp-version'), ['int'])),
                                                ('update_triggers', (YLeaf(YType.uint32, 'update-triggers'), ['int'])),
                                                ('total_r_ds_num', (YLeaf(YType.uint32, 'total-r-ds-num'), ['int'])),
                                                ('total_remote_r_ds_num', (YLeaf(YType.uint32, 'total-remote-r-ds-num'), ['int'])),
                                                ('total_same_r_ds_num', (YLeaf(YType.uint32, 'total-same-r-ds-num'), ['int'])),
                                                ('malloced_rd_count', (YLeaf(YType.uint32, 'malloced-rd-count'), ['int'])),
                                                ('freed_rd_count', (YLeaf(YType.uint32, 'freed-rd-count'), ['int'])),
                                                ('rd_memory', (YLeaf(YType.uint32, 'rd-memory'), ['int'])),
                                                ('multipath_network_entry_count', (YLeaf(YType.uint32, 'multipath-network-entry-count'), ['int'])),
                                                ('multipath_network_entry_memory', (YLeaf(YType.uint32, 'multipath-network-entry-memory'), ['int'])),
                                                ('multipath_paths_count', (YLeaf(YType.uint32, 'multipath-paths-count'), ['int'])),
                                                ('multipath_paths_memory', (YLeaf(YType.uint32, 'multipath-paths-memory'), ['int'])),
                                                ('update_wait_install_enabled', (YLeaf(YType.uint32, 'update-wait-install-enabled'), ['int'])),
                                                ('rib_acked_table_version', (YLeaf(YType.uint32, 'rib-acked-table-version'), ['int'])),
                                                ('rib_ack_requests', (YLeaf(YType.uint32, 'rib-ack-requests'), ['int'])),
                                                ('rib_acks_received', (YLeaf(YType.uint32, 'rib-acks-received'), ['int'])),
                                                ('rib_slow_acks', (YLeaf(YType.uint32, 'rib-slow-acks'), ['int'])),
                                            ])
                                            self.router_state = None
                                            self.table_version = None
                                            self.version_wrapped = None
                                            self.version_wrapped_tid = None
                                            self.max_active_pelem_version = None
                                            self.merged_table_version = None
                                            self.route_download_go_active_done_pending = None
                                            self.rib_brib_received_version = None
                                            self.table_brib_version = None
                                            self.label_version = None
                                            self.import_version = None
                                            self.standby_version = None
                                            self.send_version = None
                                            self.num_init_sync_pfx = None
                                            self.max_label_stack_depth_v4_next_hop = None
                                            self.max_label_stack_depth_v6_next_hop = None
                                            self.local_networks_num = None
                                            self.local_networks_memory = None
                                            self.local_networks_malloced_num = None
                                            self.local_networks_freed_num = None
                                            self.local_paths_num = None
                                            self.local_paths_memory = None
                                            self.local_paths_malloced_num = None
                                            self.local_paths_freed_num = None
                                            self.imported_paths_num = None
                                            self.imported_paths_memory = None
                                            self.networks_num = None
                                            self.networks_memory = None
                                            self.networks_malloced_num = None
                                            self.networks_freed_num = None
                                            self.paths_num = None
                                            self.paths_memory = None
                                            self.paths_malloced_num = None
                                            self.paths_freed_num = None
                                            self.path_elems_num = None
                                            self.path_elems_memory = None
                                            self.path_elems_malloced_num = None
                                            self.path_elems_freed_num = None
                                            self.label_last_trigger = None
                                            self.last_label_version = None
                                            self.label_bgp_version = None
                                            self.label_triggers = None
                                            self.rib_last_trigger = None
                                            self.last_rib_version = None
                                            self.rib_bgp_version = None
                                            self.rib_triggers = None
                                            self.import_last_trigger = None
                                            self.last_import_version = None
                                            self.import_bgp_version = None
                                            self.import_triggers = None
                                            self.update_gen_last_trigger = None
                                            self.update_gen_bgp_version = None
                                            self.update_triggers = None
                                            self.total_r_ds_num = None
                                            self.total_remote_r_ds_num = None
                                            self.total_same_r_ds_num = None
                                            self.malloced_rd_count = None
                                            self.freed_rd_count = None
                                            self.rd_memory = None
                                            self.multipath_network_entry_count = None
                                            self.multipath_network_entry_memory = None
                                            self.multipath_paths_count = None
                                            self.multipath_paths_memory = None
                                            self.update_wait_install_enabled = None
                                            self.rib_acked_table_version = None
                                            self.rib_ack_requests = None
                                            self.rib_acks_received = None
                                            self.rib_slow_acks = None

                                            self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec()
                                            self.version_wrap_time_spec.parent = self
                                            self._children_name_map["version_wrap_time_spec"] = "version-wrap-time-spec"

                                            self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec()
                                            self.version_wrap_start_time_spec.parent = self
                                            self._children_name_map["version_wrap_start_time_spec"] = "version-wrap-start-time-spec"

                                            self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec()
                                            self.version_wrap_done_time_spec.parent = self
                                            self._children_name_map["version_wrap_done_time_spec"] = "version-wrap-done-time-spec"

                                            self.trigger_rib = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib()
                                            self.trigger_rib.parent = self
                                            self._children_name_map["trigger_rib"] = "trigger-rib"

                                            self.trigger_import = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport()
                                            self.trigger_import.parent = self
                                            self._children_name_map["trigger_import"] = "trigger-import"

                                            self.trigger_update = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate()
                                            self.trigger_update.parent = self
                                            self._children_name_map["trigger_update"] = "trigger-update"

                                            self.trigger_label = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel()
                                            self.trigger_label.parent = self
                                            self._children_name_map["trigger_label"] = "trigger-label"

                                            self.rib_install = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall()
                                            self.rib_install.parent = self
                                            self._children_name_map["rib_install"] = "rib-install"
                                            self._segment_path = lambda: "global"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global, [u'router_state', u'table_version', u'version_wrapped', u'version_wrapped_tid', u'max_active_pelem_version', u'merged_table_version', u'route_download_go_active_done_pending', u'rib_brib_received_version', u'table_brib_version', u'label_version', u'import_version', u'standby_version', u'send_version', u'num_init_sync_pfx', u'max_label_stack_depth_v4_next_hop', u'max_label_stack_depth_v6_next_hop', u'local_networks_num', u'local_networks_memory', u'local_networks_malloced_num', u'local_networks_freed_num', u'local_paths_num', u'local_paths_memory', u'local_paths_malloced_num', u'local_paths_freed_num', u'imported_paths_num', u'imported_paths_memory', u'networks_num', u'networks_memory', u'networks_malloced_num', u'networks_freed_num', u'paths_num', u'paths_memory', u'paths_malloced_num', u'paths_freed_num', u'path_elems_num', u'path_elems_memory', u'path_elems_malloced_num', u'path_elems_freed_num', u'label_last_trigger', u'last_label_version', u'label_bgp_version', u'label_triggers', u'rib_last_trigger', u'last_rib_version', u'rib_bgp_version', u'rib_triggers', u'import_last_trigger', u'last_import_version', u'import_bgp_version', u'import_triggers', u'update_gen_last_trigger', u'update_gen_bgp_version', u'update_triggers', u'total_r_ds_num', u'total_remote_r_ds_num', u'total_same_r_ds_num', u'malloced_rd_count', u'freed_rd_count', u'rd_memory', u'multipath_network_entry_count', u'multipath_network_entry_memory', u'multipath_paths_count', u'multipath_paths_memory', u'update_wait_install_enabled', u'rib_acked_table_version', u'rib_ack_requests', u'rib_acks_received', u'rib_slow_acks'], name, value)


                                        class VersionWrapTimeSpec(Entity):
                                            """
                                            Version Wrap timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-wrap-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class VersionWrapStartTimeSpec(Entity):
                                            """
                                            Version Wrap handle start timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-start-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-wrap-start-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class VersionWrapDoneTimeSpec(Entity):
                                            """
                                            Version Wrap handle Done timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-done-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-wrap-done-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TriggerRib(Entity):
                                            """
                                            Trigger RIB
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib, self).__init__()

                                                self.yang_name = "trigger-rib"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic))])
                                                self._leafs = OrderedDict([
                                                    ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                                ])
                                                self.triggers = None

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-rib"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib, [u'triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-rib"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                        ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                    ])
                                                    self.trigger_version = None
                                                    self.trigger_table_version = None

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._segment_path = lambda: "statistic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "trigger-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TriggerImport(Entity):
                                            """
                                            Trigger import
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport, self).__init__()

                                                self.yang_name = "trigger-import"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic))])
                                                self._leafs = OrderedDict([
                                                    ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                                ])
                                                self.triggers = None

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport, [u'triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                        ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                    ])
                                                    self.trigger_version = None
                                                    self.trigger_table_version = None

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._segment_path = lambda: "statistic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "trigger-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TriggerUpdate(Entity):
                                            """
                                            Trigger update
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate, self).__init__()

                                                self.yang_name = "trigger-update"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic))])
                                                self._leafs = OrderedDict([
                                                    ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                                ])
                                                self.triggers = None

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-update"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate, [u'triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                        ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                    ])
                                                    self.trigger_version = None
                                                    self.trigger_table_version = None

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._segment_path = lambda: "statistic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "trigger-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TriggerLabel(Entity):
                                            """
                                            Trigger label
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel, self).__init__()

                                                self.yang_name = "trigger-label"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic))])
                                                self._leafs = OrderedDict([
                                                    ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                                ])
                                                self.triggers = None

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel, [u'triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-label"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                        ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                    ])
                                                    self.trigger_version = None
                                                    self.trigger_table_version = None

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._segment_path = lambda: "statistic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "trigger-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class RibInstall(Entity):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:  :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:  :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: skipped_count
                                            
                                            	Skipped routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall, self).__init__()

                                                self.yang_name = "rib-install"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("update-time", ("update_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime)), ("install-time", ("install_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime))])
                                                self._leafs = OrderedDict([
                                                    ('installed_count', (YLeaf(YType.uint32, 'installed-count'), ['int'])),
                                                    ('modified_count', (YLeaf(YType.uint32, 'modified-count'), ['int'])),
                                                    ('skipped_count', (YLeaf(YType.uint32, 'skipped-count'), ['int'])),
                                                    ('withdrawn_count', (YLeaf(YType.uint32, 'withdrawn-count'), ['int'])),
                                                    ('start_version', (YLeaf(YType.uint32, 'start-version'), ['int'])),
                                                    ('target_version', (YLeaf(YType.uint32, 'target-version'), ['int'])),
                                                ])
                                                self.installed_count = None
                                                self.modified_count = None
                                                self.skipped_count = None
                                                self.withdrawn_count = None
                                                self.start_version = None
                                                self.target_version = None

                                                self.update_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self._children_name_map["update_time"] = "update-time"

                                                self.install_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self._children_name_map["install_time"] = "install-time"
                                                self._segment_path = lambda: "rib-install"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall, [u'installed_count', u'modified_count', u'skipped_count', u'withdrawn_count', u'start_version', u'target_version'], name, value)


                                            class UpdateTime(Entity):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime, self).__init__()

                                                    self.yang_name = "update-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "update-time"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime, [u'seconds', u'nanoseconds'], name, value)


                                            class InstallTime(Entity):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime, self).__init__()

                                                    self.yang_name = "install-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "install-time"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime, [u'seconds', u'nanoseconds'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: network_entry_count
                                        
                                        	Number of network entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_count
                                        
                                        	Number of paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths
                                        
                                        	Number of imported paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths
                                        
                                        	Number of local paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_count
                                        
                                        	Number of path elems
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: imported_path_memory
                                        
                                        	Memory (in bytes) used by imported paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: local_path_memory
                                        
                                        	Memory (in bytes) used by local paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: path_elem_memory
                                        
                                        	Memory (in bytes) used by pathelem data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_path_count
                                        
                                        	Number of (unused) received paths for inbound soft reconfiguration
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: history_path_count
                                        
                                        	Number of history paths (for dampening)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: damped_path_count
                                        
                                        	Number of dampened paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_prefix_count
                                        
                                        	Activity\: Number of prefixes malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_prefix_count
                                        
                                        	Activity\: Number of prefixes freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_count
                                        
                                        	Activity\: Number of paths malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_count
                                        
                                        	Activity\: Number of paths freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_elem_count
                                        
                                        	Activity\: Number of path elems malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_elem_count
                                        
                                        	Activity\: Number of pathelems freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: any_ebgp_neighbor_missing_policy
                                        
                                        	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_download
                                        
                                        	Attribute download is 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_target_download
                                        
                                        	Route Target download is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: srms_prefix_sid
                                        
                                        	SRMS Prefix SID is 
                                        	**type**\: bool
                                        
                                        .. attribute:: add_path_install_enable
                                        
                                        	Additional paths installation is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: add_path_install_disable
                                        
                                        	Additional paths installation is disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: best_external
                                        
                                        	Best External is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: best_external_disable
                                        
                                        	Best External is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: label_retain
                                        
                                        	Label retention is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: label_retainvalue
                                        
                                        	Label retention value enabled
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tbl_bitf_size
                                        
                                        	Bitfield size on table
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tbl_chunk_bitf_size
                                        
                                        	Chunk Bitfield size on table
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_route_reflector
                                        
                                        	Router is an RR for this AF
                                        	**type**\: bool
                                        
                                        .. attribute:: asbr
                                        
                                        	Router is an ASBR for this AF
                                        	**type**\: bool
                                        
                                        .. attribute:: retain_rt_all
                                        
                                        	Retain\-RT\-All enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_nexthop_self_count
                                        
                                        	Number of iBGP sessions configured with nh\-self
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: use_igpsr_label
                                        
                                        	Use IGP SR label for resolution
                                        	**type**\: bool
                                        
                                        .. attribute:: bmp_network_entry_count
                                        
                                        	Number of BMP net entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_paths_count
                                        
                                        	Total Number of BMP paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bmp_path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('network_entry_count', (YLeaf(YType.uint32, 'network-entry-count'), ['int'])),
                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                ('imported_paths', (YLeaf(YType.uint32, 'imported-paths'), ['int'])),
                                                ('local_paths', (YLeaf(YType.uint32, 'local-paths'), ['int'])),
                                                ('path_elems_count', (YLeaf(YType.uint32, 'path-elems-count'), ['int'])),
                                                ('path_memory', (YLeaf(YType.uint32, 'path-memory'), ['int'])),
                                                ('imported_path_memory', (YLeaf(YType.uint32, 'imported-path-memory'), ['int'])),
                                                ('local_path_memory', (YLeaf(YType.uint32, 'local-path-memory'), ['int'])),
                                                ('prefix_memory', (YLeaf(YType.uint32, 'prefix-memory'), ['int'])),
                                                ('path_elem_memory', (YLeaf(YType.uint32, 'path-elem-memory'), ['int'])),
                                                ('received_path_count', (YLeaf(YType.uint32, 'received-path-count'), ['int'])),
                                                ('history_path_count', (YLeaf(YType.uint32, 'history-path-count'), ['int'])),
                                                ('damped_path_count', (YLeaf(YType.uint32, 'damped-path-count'), ['int'])),
                                                ('malloced_prefix_count', (YLeaf(YType.uint32, 'malloced-prefix-count'), ['int'])),
                                                ('freed_prefix_count', (YLeaf(YType.uint32, 'freed-prefix-count'), ['int'])),
                                                ('malloced_path_count', (YLeaf(YType.uint32, 'malloced-path-count'), ['int'])),
                                                ('freed_path_count', (YLeaf(YType.uint32, 'freed-path-count'), ['int'])),
                                                ('malloced_path_elem_count', (YLeaf(YType.uint32, 'malloced-path-elem-count'), ['int'])),
                                                ('freed_path_elem_count', (YLeaf(YType.uint32, 'freed-path-elem-count'), ['int'])),
                                                ('any_ebgp_neighbor_missing_policy', (YLeaf(YType.boolean, 'any-ebgp-neighbor-missing-policy'), ['bool'])),
                                                ('attribute_download', (YLeaf(YType.boolean, 'attribute-download'), ['bool'])),
                                                ('route_target_download', (YLeaf(YType.boolean, 'route-target-download'), ['bool'])),
                                                ('srms_prefix_sid', (YLeaf(YType.boolean, 'srms-prefix-sid'), ['bool'])),
                                                ('add_path_install_enable', (YLeaf(YType.boolean, 'add-path-install-enable'), ['bool'])),
                                                ('add_path_install_disable', (YLeaf(YType.boolean, 'add-path-install-disable'), ['bool'])),
                                                ('best_external', (YLeaf(YType.boolean, 'best-external'), ['bool'])),
                                                ('best_external_disable', (YLeaf(YType.boolean, 'best-external-disable'), ['bool'])),
                                                ('label_retain', (YLeaf(YType.boolean, 'label-retain'), ['bool'])),
                                                ('label_retainvalue', (YLeaf(YType.uint32, 'label-retainvalue'), ['int'])),
                                                ('tbl_bitf_size', (YLeaf(YType.uint16, 'tbl-bitf-size'), ['int'])),
                                                ('tbl_chunk_bitf_size', (YLeaf(YType.uint16, 'tbl-chunk-bitf-size'), ['int'])),
                                                ('is_route_reflector', (YLeaf(YType.boolean, 'is-route-reflector'), ['bool'])),
                                                ('asbr', (YLeaf(YType.boolean, 'asbr'), ['bool'])),
                                                ('retain_rt_all', (YLeaf(YType.boolean, 'retain-rt-all'), ['bool'])),
                                                ('ibgp_nexthop_self_count', (YLeaf(YType.uint32, 'ibgp-nexthop-self-count'), ['int'])),
                                                ('use_igpsr_label', (YLeaf(YType.boolean, 'use-igpsr-label'), ['bool'])),
                                                ('bmp_network_entry_count', (YLeaf(YType.uint32, 'bmp-network-entry-count'), ['int'])),
                                                ('bmp_paths_count', (YLeaf(YType.uint32, 'bmp-paths-count'), ['int'])),
                                                ('bmp_prefix_memory', (YLeaf(YType.uint32, 'bmp-prefix-memory'), ['int'])),
                                                ('bmp_path_memory', (YLeaf(YType.uint32, 'bmp-path-memory'), ['int'])),
                                            ])
                                            self.network_entry_count = None
                                            self.paths_count = None
                                            self.imported_paths = None
                                            self.local_paths = None
                                            self.path_elems_count = None
                                            self.path_memory = None
                                            self.imported_path_memory = None
                                            self.local_path_memory = None
                                            self.prefix_memory = None
                                            self.path_elem_memory = None
                                            self.received_path_count = None
                                            self.history_path_count = None
                                            self.damped_path_count = None
                                            self.malloced_prefix_count = None
                                            self.freed_prefix_count = None
                                            self.malloced_path_count = None
                                            self.freed_path_count = None
                                            self.malloced_path_elem_count = None
                                            self.freed_path_elem_count = None
                                            self.any_ebgp_neighbor_missing_policy = None
                                            self.attribute_download = None
                                            self.route_target_download = None
                                            self.srms_prefix_sid = None
                                            self.add_path_install_enable = None
                                            self.add_path_install_disable = None
                                            self.best_external = None
                                            self.best_external_disable = None
                                            self.label_retain = None
                                            self.label_retainvalue = None
                                            self.tbl_bitf_size = None
                                            self.tbl_chunk_bitf_size = None
                                            self.is_route_reflector = None
                                            self.asbr = None
                                            self.retain_rt_all = None
                                            self.ibgp_nexthop_self_count = None
                                            self.use_igpsr_label = None
                                            self.bmp_network_entry_count = None
                                            self.bmp_paths_count = None
                                            self.bmp_prefix_memory = None
                                            self.bmp_path_memory = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_, [u'network_entry_count', u'paths_count', u'imported_paths', u'local_paths', u'path_elems_count', u'path_memory', u'imported_path_memory', u'local_path_memory', u'prefix_memory', u'path_elem_memory', u'received_path_count', u'history_path_count', u'damped_path_count', u'malloced_prefix_count', u'freed_prefix_count', u'malloced_path_count', u'freed_path_count', u'malloced_path_elem_count', u'freed_path_elem_count', u'any_ebgp_neighbor_missing_policy', u'attribute_download', u'route_target_download', u'srms_prefix_sid', u'add_path_install_enable', u'add_path_install_disable', u'best_external', u'best_external_disable', u'label_retain', u'label_retainvalue', u'tbl_bitf_size', u'tbl_chunk_bitf_size', u'is_route_reflector', u'asbr', u'retain_rt_all', u'ibgp_nexthop_self_count', u'use_igpsr_label', u'bmp_network_entry_count', u'bmp_paths_count', u'bmp_prefix_memory', u'bmp_path_memory'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: global_
                                        
                                        	Global information
                                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global>`
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_))])
                                            self._leafs = OrderedDict()

                                            self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global()
                                            self.global_.parent = self
                                            self._children_name_map["global_"] = "global"

                                            self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._segment_path = lambda: "performance-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics, [], name, value)


                                        class Global(Entity):
                                            """
                                            Global information
                                            
                                            .. attribute:: has_converged
                                            
                                            	TRUE if process has converged
                                            	**type**\: bool
                                            
                                            .. attribute:: first_nbr_up_time
                                            
                                            	Time when first peer came up (seconds since Jan 1 1970)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: total_pim_install
                                            
                                            	Total number of install to PIM
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_callbacks
                                            
                                            	Total number of PIM callbacks
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_callback_batch
                                            
                                            	Total number of Pim callback batches
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mode_enter_time
                                            
                                            	Time that each mode was entered (seconds since  Jan 1 1970)
                                            	**type**\: list of  		 :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime>`
                                            
                                            .. attribute:: total_pim_install_add
                                            
                                            	Total number of install to PIM for add
                                            	**type**\: list of  		 :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd>`
                                            
                                            .. attribute:: total_pim_install_del
                                            
                                            	Total number of install to PIM for del
                                            	**type**\: list of  		 :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel>`
                                            
                                            .. attribute:: total_pim_callback_add
                                            
                                            	Total number of Pim callbacks for add
                                            	**type**\: list of  		 :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd>`
                                            
                                            .. attribute:: total_pim_callback_del
                                            
                                            	Total number of Pim callbacks for del
                                            	**type**\: list of  		 :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel>`
                                            
                                            .. attribute:: total_pim_callback_add_local
                                            
                                            	Total number of Pim callbacks for local add
                                            	**type**\: list of  		 :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal>`
                                            
                                            .. attribute:: total_pim_callback_del_local
                                            
                                            	Total number of Pim callbacks for Local del
                                            	**type**\: list of  		 :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global, self).__init__()

                                                self.yang_name = "global"
                                                self.yang_parent_name = "performance-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("mode-enter-time", ("mode_enter_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime)), ("total-pim-install-add", ("total_pim_install_add", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd)), ("total-pim-install-del", ("total_pim_install_del", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel)), ("total-pim-callback-add", ("total_pim_callback_add", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd)), ("total-pim-callback-del", ("total_pim_callback_del", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel)), ("total-pim-callback-add-local", ("total_pim_callback_add_local", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal)), ("total-pim-callback-del-local", ("total_pim_callback_del_local", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal))])
                                                self._leafs = OrderedDict([
                                                    ('has_converged', (YLeaf(YType.boolean, 'has-converged'), ['bool'])),
                                                    ('first_nbr_up_time', (YLeaf(YType.uint32, 'first-nbr-up-time'), ['int'])),
                                                    ('total_pim_install', (YLeaf(YType.uint32, 'total-pim-install'), ['int'])),
                                                    ('total_pim_callbacks', (YLeaf(YType.uint32, 'total-pim-callbacks'), ['int'])),
                                                    ('total_pim_callback_batch', (YLeaf(YType.uint32, 'total-pim-callback-batch'), ['int'])),
                                                ])
                                                self.has_converged = None
                                                self.first_nbr_up_time = None
                                                self.total_pim_install = None
                                                self.total_pim_callbacks = None
                                                self.total_pim_callback_batch = None

                                                self.mode_enter_time = YList(self)
                                                self.total_pim_install_add = YList(self)
                                                self.total_pim_install_del = YList(self)
                                                self.total_pim_callback_add = YList(self)
                                                self.total_pim_callback_del = YList(self)
                                                self.total_pim_callback_add_local = YList(self)
                                                self.total_pim_callback_del_local = YList(self)
                                                self._segment_path = lambda: "global"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global, [u'has_converged', u'first_nbr_up_time', u'total_pim_install', u'total_pim_callbacks', u'total_pim_callback_batch'], name, value)


                                            class ModeEnterTime(Entity):
                                                """
                                                Time that each mode was entered (seconds since
                                                
                                                Jan 1 1970)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime, self).__init__()

                                                    self.yang_name = "mode-enter-time"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mode-enter-time"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime, [u'entry'], name, value)


                                            class TotalPimInstallAdd(Entity):
                                                """
                                                Total number of install to PIM for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd, self).__init__()

                                                    self.yang_name = "total-pim-install-add"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-install-add"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd, [u'entry'], name, value)


                                            class TotalPimInstallDel(Entity):
                                                """
                                                Total number of install to PIM for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel, self).__init__()

                                                    self.yang_name = "total-pim-install-del"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-install-del"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel, [u'entry'], name, value)


                                            class TotalPimCallbackAdd(Entity):
                                                """
                                                Total number of Pim callbacks for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd, self).__init__()

                                                    self.yang_name = "total-pim-callback-add"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-callback-add"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd, [u'entry'], name, value)


                                            class TotalPimCallbackDel(Entity):
                                                """
                                                Total number of Pim callbacks for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel, self).__init__()

                                                    self.yang_name = "total-pim-callback-del"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-callback-del"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel, [u'entry'], name, value)


                                            class TotalPimCallbackAddLocal(Entity):
                                                """
                                                Total number of Pim callbacks for local add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal, self).__init__()

                                                    self.yang_name = "total-pim-callback-add-local"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-callback-add-local"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal, [u'entry'], name, value)


                                            class TotalPimCallbackDelLocal(Entity):
                                                """
                                                Total number of Pim callbacks for Local del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal, self).__init__()

                                                    self.yang_name = "total-pim-callback-del-local"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-callback-del-local"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal, [u'entry'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: time_rib_coverged
                                            
                                            	Time last RIB ack was sent 
                                            	**type**\:  :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged>`
                                            
                                            .. attribute:: time_rib_down
                                            
                                            	Time last RIB down wassent. This field is deprecated
                                            	**type**\:  :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown>`
                                            
                                            .. attribute:: first_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the first time
                                            	**type**\:  :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp>`
                                            
                                            .. attribute:: last_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the last time
                                            	**type**\:  :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp>`
                                            
                                            .. attribute:: first_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the first time
                                            	**type**\:  :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: last_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the last time
                                            	**type**\:  :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: time_label_retain
                                            
                                            	Time last label retentiontriggered 
                                            	**type**\:  :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain>`
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: rib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: prefixes_sent_to_rib
                                            
                                            	No. of prefixes sent to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_resent_to_rib
                                            
                                            	No. of prefixes re\-sent to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_not_sent_to_rib
                                            
                                            	No. of prefixes not sent to RIB due to unsupported label stack size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_removed_from_rib
                                            
                                            	No. of prefixes withdrawn from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_sent_to_rib
                                            
                                            	No. of attributes sent to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_removed_from_rib
                                            
                                            	No. of attributes withdrawn from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_recover_from_rib
                                            
                                            	No. of attributes recovered from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: scanner_runs
                                            
                                            	# of times scanner has run
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: scanner_time
                                            
                                            	Time spent running scanner (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: rib_tbl_del_calls
                                            
                                            	No. of rib update skipped on account of table delete
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_invalid_calls
                                            
                                            	No. of  rib update skipped due to table invalid
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_skip_calls
                                            
                                            	No. of rib update skipped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_local_label
                                            
                                            	No. of rib update skipped. due to no local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_retry
                                            
                                            	No. of table rib retires
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_last_update_sent
                                            
                                            	Time last update was sent (seconds since Jan 1 1970)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: is_rib_table_full
                                            
                                            	Indicates if RIB table is in prefix\-limit state
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_table_full_version
                                            
                                            	Version when RIB table became full (from non\-full)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: first_rib_table_full_version
                                            
                                            	Version when RIB table was full for the first time
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_full_version
                                            
                                            	Version when RIB table was full for the last time
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_full_age
                                            
                                            	Time since RIB table was full for the last time (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: first_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the first time
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the last time
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_has_space_age
                                            
                                            	Times since RIB table had space for the last time (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: rib_trigger
                                            
                                            	Rib trigger enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: vrf_flags
                                            
                                            	VRF flags for debug display
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_calls
                                            
                                            	No. of calls to label allocation processing function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_time
                                            
                                            	Time spent running label processing (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: label_rewrite_count
                                            
                                            	Number of label rewrites created
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_release_count
                                            
                                            	Number of labels released
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_added_count
                                            
                                            	Number of labels requested
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_calls
                                            
                                            	Number of calls to import processing function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_time
                                            
                                            	Time spent in import processing (milliseconds) Note time accounted against source nets
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: import_src_net_processed_count
                                            
                                            	Number of source nets processed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_dest_net_processed_count
                                            
                                            	Number of destination nets processed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_added_path_count
                                            
                                            	Number of imported paths added
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_removed_path_count
                                            
                                            	Number of imported paths removed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_replaced_path_count
                                            
                                            	Number of imported paths 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_group_count
                                            
                                            	No. of update group
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subgroup_count
                                            
                                            	No. of update subgroup
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "performance-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("time-rib-coverged", ("time_rib_coverged", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged)), ("time-rib-down", ("time_rib_down", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown)), ("first-rib-table-full-timestamp", ("first_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp)), ("last-rib-table-full-timestamp", ("last_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp)), ("first-rib-table-has-space-timestamp", ("first_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp)), ("last-rib-table-has-space-timestamp", ("last_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp)), ("time-label-retain", ("time_label_retain", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain))])
                                                self._leafs = OrderedDict([
                                                    ('update_generation_calls', (YLeaf(YType.uint32, 'update-generation-calls'), ['int'])),
                                                    ('update_generation_prefixes_count', (YLeaf(YType.uint32, 'update-generation-prefixes-count'), ['int'])),
                                                    ('update_generation_be_prefixes_count', (YLeaf(YType.uint32, 'update-generation-be-prefixes-count'), ['int'])),
                                                    ('update_generation_messages_count', (YLeaf(YType.uint32, 'update-generation-messages-count'), ['int'])),
                                                    ('update_generation_time', (YLeaf(YType.uint32, 'update-generation-time'), ['int'])),
                                                    ('rib_update_calls', (YLeaf(YType.uint32, 'rib-update-calls'), ['int'])),
                                                    ('rib_update_time', (YLeaf(YType.uint32, 'rib-update-time'), ['int'])),
                                                    ('prefixes_sent_to_rib', (YLeaf(YType.uint32, 'prefixes-sent-to-rib'), ['int'])),
                                                    ('prefixes_resent_to_rib', (YLeaf(YType.uint32, 'prefixes-resent-to-rib'), ['int'])),
                                                    ('prefixes_not_sent_to_rib', (YLeaf(YType.uint32, 'prefixes-not-sent-to-rib'), ['int'])),
                                                    ('prefixes_removed_from_rib', (YLeaf(YType.uint32, 'prefixes-removed-from-rib'), ['int'])),
                                                    ('attributes_sent_to_rib', (YLeaf(YType.uint32, 'attributes-sent-to-rib'), ['int'])),
                                                    ('attributes_removed_from_rib', (YLeaf(YType.uint32, 'attributes-removed-from-rib'), ['int'])),
                                                    ('attributes_recover_from_rib', (YLeaf(YType.uint32, 'attributes-recover-from-rib'), ['int'])),
                                                    ('scanner_runs', (YLeaf(YType.uint32, 'scanner-runs'), ['int'])),
                                                    ('scanner_time', (YLeaf(YType.uint32, 'scanner-time'), ['int'])),
                                                    ('rib_tbl_del_calls', (YLeaf(YType.uint32, 'rib-tbl-del-calls'), ['int'])),
                                                    ('rib_tbl_invalid_calls', (YLeaf(YType.uint32, 'rib-tbl-invalid-calls'), ['int'])),
                                                    ('rib_tbl_skip_calls', (YLeaf(YType.uint32, 'rib-tbl-skip-calls'), ['int'])),
                                                    ('rib_tbl_local_label', (YLeaf(YType.uint32, 'rib-tbl-local-label'), ['int'])),
                                                    ('rib_tbl_retry', (YLeaf(YType.uint32, 'rib-tbl-retry'), ['int'])),
                                                    ('time_last_update_sent', (YLeaf(YType.uint32, 'time-last-update-sent'), ['int'])),
                                                    ('is_rib_table_full', (YLeaf(YType.boolean, 'is-rib-table-full'), ['bool'])),
                                                    ('rib_table_full_version', (YLeaf(YType.uint32, 'rib-table-full-version'), ['int'])),
                                                    ('first_rib_table_full_version', (YLeaf(YType.uint32, 'first-rib-table-full-version'), ['int'])),
                                                    ('last_rib_table_full_version', (YLeaf(YType.uint32, 'last-rib-table-full-version'), ['int'])),
                                                    ('last_rib_table_full_age', (YLeaf(YType.uint32, 'last-rib-table-full-age'), ['int'])),
                                                    ('first_rib_table_has_space_version', (YLeaf(YType.uint32, 'first-rib-table-has-space-version'), ['int'])),
                                                    ('last_rib_table_has_space_version', (YLeaf(YType.uint32, 'last-rib-table-has-space-version'), ['int'])),
                                                    ('last_rib_table_has_space_age', (YLeaf(YType.uint32, 'last-rib-table-has-space-age'), ['int'])),
                                                    ('rib_trigger', (YLeaf(YType.boolean, 'rib-trigger'), ['bool'])),
                                                    ('vrf_flags', (YLeaf(YType.uint32, 'vrf-flags'), ['int'])),
                                                    ('label_calls', (YLeaf(YType.uint32, 'label-calls'), ['int'])),
                                                    ('label_time', (YLeaf(YType.uint32, 'label-time'), ['int'])),
                                                    ('label_rewrite_count', (YLeaf(YType.uint32, 'label-rewrite-count'), ['int'])),
                                                    ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                                    ('label_added_count', (YLeaf(YType.uint32, 'label-added-count'), ['int'])),
                                                    ('import_calls', (YLeaf(YType.uint32, 'import-calls'), ['int'])),
                                                    ('import_time', (YLeaf(YType.uint32, 'import-time'), ['int'])),
                                                    ('import_src_net_processed_count', (YLeaf(YType.uint32, 'import-src-net-processed-count'), ['int'])),
                                                    ('import_dest_net_processed_count', (YLeaf(YType.uint32, 'import-dest-net-processed-count'), ['int'])),
                                                    ('import_added_path_count', (YLeaf(YType.uint32, 'import-added-path-count'), ['int'])),
                                                    ('import_removed_path_count', (YLeaf(YType.uint32, 'import-removed-path-count'), ['int'])),
                                                    ('import_replaced_path_count', (YLeaf(YType.uint32, 'import-replaced-path-count'), ['int'])),
                                                    ('update_group_count', (YLeaf(YType.uint32, 'update-group-count'), ['int'])),
                                                    ('subgroup_count', (YLeaf(YType.uint32, 'subgroup-count'), ['int'])),
                                                ])
                                                self.update_generation_calls = None
                                                self.update_generation_prefixes_count = None
                                                self.update_generation_be_prefixes_count = None
                                                self.update_generation_messages_count = None
                                                self.update_generation_time = None
                                                self.rib_update_calls = None
                                                self.rib_update_time = None
                                                self.prefixes_sent_to_rib = None
                                                self.prefixes_resent_to_rib = None
                                                self.prefixes_not_sent_to_rib = None
                                                self.prefixes_removed_from_rib = None
                                                self.attributes_sent_to_rib = None
                                                self.attributes_removed_from_rib = None
                                                self.attributes_recover_from_rib = None
                                                self.scanner_runs = None
                                                self.scanner_time = None
                                                self.rib_tbl_del_calls = None
                                                self.rib_tbl_invalid_calls = None
                                                self.rib_tbl_skip_calls = None
                                                self.rib_tbl_local_label = None
                                                self.rib_tbl_retry = None
                                                self.time_last_update_sent = None
                                                self.is_rib_table_full = None
                                                self.rib_table_full_version = None
                                                self.first_rib_table_full_version = None
                                                self.last_rib_table_full_version = None
                                                self.last_rib_table_full_age = None
                                                self.first_rib_table_has_space_version = None
                                                self.last_rib_table_has_space_version = None
                                                self.last_rib_table_has_space_age = None
                                                self.rib_trigger = None
                                                self.vrf_flags = None
                                                self.label_calls = None
                                                self.label_time = None
                                                self.label_rewrite_count = None
                                                self.label_release_count = None
                                                self.label_added_count = None
                                                self.import_calls = None
                                                self.import_time = None
                                                self.import_src_net_processed_count = None
                                                self.import_dest_net_processed_count = None
                                                self.import_added_path_count = None
                                                self.import_removed_path_count = None
                                                self.import_replaced_path_count = None
                                                self.update_group_count = None
                                                self.subgroup_count = None

                                                self.time_rib_coverged = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged()
                                                self.time_rib_coverged.parent = self
                                                self._children_name_map["time_rib_coverged"] = "time-rib-coverged"

                                                self.time_rib_down = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown()
                                                self.time_rib_down.parent = self
                                                self._children_name_map["time_rib_down"] = "time-rib-down"

                                                self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp()
                                                self.first_rib_table_full_timestamp.parent = self
                                                self._children_name_map["first_rib_table_full_timestamp"] = "first-rib-table-full-timestamp"

                                                self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp()
                                                self.last_rib_table_full_timestamp.parent = self
                                                self._children_name_map["last_rib_table_full_timestamp"] = "last-rib-table-full-timestamp"

                                                self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp()
                                                self.first_rib_table_has_space_timestamp.parent = self
                                                self._children_name_map["first_rib_table_has_space_timestamp"] = "first-rib-table-has-space-timestamp"

                                                self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp()
                                                self.last_rib_table_has_space_timestamp.parent = self
                                                self._children_name_map["last_rib_table_has_space_timestamp"] = "last-rib-table-has-space-timestamp"

                                                self.time_label_retain = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain()
                                                self.time_label_retain.parent = self
                                                self._children_name_map["time_label_retain"] = "time-label-retain"
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_, [u'update_generation_calls', u'update_generation_prefixes_count', u'update_generation_be_prefixes_count', u'update_generation_messages_count', u'update_generation_time', u'rib_update_calls', u'rib_update_time', u'prefixes_sent_to_rib', u'prefixes_resent_to_rib', u'prefixes_not_sent_to_rib', u'prefixes_removed_from_rib', u'attributes_sent_to_rib', u'attributes_removed_from_rib', u'attributes_recover_from_rib', u'scanner_runs', u'scanner_time', u'rib_tbl_del_calls', u'rib_tbl_invalid_calls', u'rib_tbl_skip_calls', u'rib_tbl_local_label', u'rib_tbl_retry', u'time_last_update_sent', u'is_rib_table_full', u'rib_table_full_version', u'first_rib_table_full_version', u'last_rib_table_full_version', u'last_rib_table_full_age', u'first_rib_table_has_space_version', u'last_rib_table_has_space_version', u'last_rib_table_has_space_age', u'rib_trigger', u'vrf_flags', u'label_calls', u'label_time', u'label_rewrite_count', u'label_release_count', u'label_added_count', u'import_calls', u'import_time', u'import_src_net_processed_count', u'import_dest_net_processed_count', u'import_added_path_count', u'import_removed_path_count', u'import_replaced_path_count', u'update_group_count', u'subgroup_count'], name, value)


                                            class TimeRibCoverged(Entity):
                                                """
                                                Time last RIB ack was sent 
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged, self).__init__()

                                                    self.yang_name = "time-rib-coverged"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "time-rib-coverged"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged, [u'seconds', u'nanoseconds'], name, value)


                                            class TimeRibDown(Entity):
                                                """
                                                Time last RIB down wassent. This field is
                                                deprecated
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown, self).__init__()

                                                    self.yang_name = "time-rib-down"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "time-rib-down"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown, [u'seconds', u'nanoseconds'], name, value)


                                            class FirstRibTableFullTimestamp(Entity):
                                                """
                                                Timestamp when RIB table was full for the first
                                                time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp, self).__init__()

                                                    self.yang_name = "first-rib-table-full-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "first-rib-table-full-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastRibTableFullTimestamp(Entity):
                                                """
                                                Timestamp when RIB table was full for the last
                                                time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp, self).__init__()

                                                    self.yang_name = "last-rib-table-full-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-rib-table-full-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class FirstRibTableHasSpaceTimestamp(Entity):
                                                """
                                                Timestamp when RIB table had space for the first
                                                time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp, self).__init__()

                                                    self.yang_name = "first-rib-table-has-space-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "first-rib-table-has-space-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastRibTableHasSpaceTimestamp(Entity):
                                                """
                                                Timestamp when RIB table had space for the last
                                                time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp, self).__init__()

                                                    self.yang_name = "last-rib-table-has-space-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-rib-table-has-space-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class TimeLabelRetain(Entity):
                                                """
                                                Time last label retentiontriggered 
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain, self).__init__()

                                                    self.yang_name = "time-label-retain"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "time-label-retain"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain, [u'seconds', u'nanoseconds'], name, value)


                                class PathUsedTable(Entity):
                                    """
                                    The BGP Path Used Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable, self).__init__()

                                        self.yang_name = "path-used-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path))])
                                        self._leafs = OrderedDict()

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-used-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: orig_source_rd
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-used-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                                ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                                ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                                ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.orig_source_rd = None
                                            self.path_id = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class BmpPathTableGeneric(Entity):
                                    """
                                    Summary Info about BMP Table
                                    
                                    .. attribute:: bmp_version_wrap_time_spec
                                    
                                    	Version Wrap timestamp
                                    	**type**\:  :py:class:`BmpVersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec>`
                                    
                                    .. attribute:: bmp_version_wrap_start_time_spec
                                    
                                    	Version Wrap handle start timestamp
                                    	**type**\:  :py:class:`BmpVersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec>`
                                    
                                    .. attribute:: bmp_version_wrap_done_time_spec
                                    
                                    	Version Wrap handle Done timestamp
                                    	**type**\:  :py:class:`BmpVersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec>`
                                    
                                    .. attribute:: bmp_route_monitoringe_enabled
                                    
                                    	Is Route Monitoring mode enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_table_version
                                    
                                    	Table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_count
                                    
                                    	Number of nets in the table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_count
                                    
                                    	Number of paths in the table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_version_wrapped
                                    
                                    	Number of times Table Version Wrapped
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_version_wrapped_tid
                                    
                                    	Version Wrapped trigger thread id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_version_inprogress
                                    
                                    	Is Version wrap in progress
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_version_incremented
                                    
                                    	Is Version being incremented
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric, self).__init__()

                                        self.yang_name = "bmp-path-table-generic"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bmp-version-wrap-time-spec", ("bmp_version_wrap_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec)), ("bmp-version-wrap-start-time-spec", ("bmp_version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec)), ("bmp-version-wrap-done-time-spec", ("bmp_version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec))])
                                        self._leafs = OrderedDict([
                                            ('bmp_route_monitoringe_enabled', (YLeaf(YType.boolean, 'bmp-route-monitoringe-enabled'), ['bool'])),
                                            ('bmp_table_version', (YLeaf(YType.uint32, 'bmp-table-version'), ['int'])),
                                            ('network_count', (YLeaf(YType.uint32, 'network-count'), ['int'])),
                                            ('path_count', (YLeaf(YType.uint32, 'path-count'), ['int'])),
                                            ('bmp_version_wrapped', (YLeaf(YType.uint32, 'bmp-version-wrapped'), ['int'])),
                                            ('bmp_version_wrapped_tid', (YLeaf(YType.uint32, 'bmp-version-wrapped-tid'), ['int'])),
                                            ('bmp_version_inprogress', (YLeaf(YType.boolean, 'bmp-version-inprogress'), ['bool'])),
                                            ('bmp_version_incremented', (YLeaf(YType.boolean, 'bmp-version-incremented'), ['bool'])),
                                        ])
                                        self.bmp_route_monitoringe_enabled = None
                                        self.bmp_table_version = None
                                        self.network_count = None
                                        self.path_count = None
                                        self.bmp_version_wrapped = None
                                        self.bmp_version_wrapped_tid = None
                                        self.bmp_version_inprogress = None
                                        self.bmp_version_incremented = None

                                        self.bmp_version_wrap_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec()
                                        self.bmp_version_wrap_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_time_spec"] = "bmp-version-wrap-time-spec"

                                        self.bmp_version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec()
                                        self.bmp_version_wrap_start_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_start_time_spec"] = "bmp-version-wrap-start-time-spec"

                                        self.bmp_version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec()
                                        self.bmp_version_wrap_done_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_done_time_spec"] = "bmp-version-wrap-done-time-spec"
                                        self._segment_path = lambda: "bmp-path-table-generic"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric, [u'bmp_route_monitoringe_enabled', u'bmp_table_version', u'network_count', u'path_count', u'bmp_version_wrapped', u'bmp_version_wrapped_tid', u'bmp_version_inprogress', u'bmp_version_incremented'], name, value)


                                    class BmpVersionWrapTimeSpec(Entity):
                                        """
                                        Version Wrap timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-version-wrap-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class BmpVersionWrapStartTimeSpec(Entity):
                                        """
                                        Version Wrap handle start timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-start-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-version-wrap-start-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class BmpVersionWrapDoneTimeSpec(Entity):
                                        """
                                        Version Wrap handle Done timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-done-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-version-wrap-done-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class RpcSets(Entity):
                                    """
                                    BGP next\-hop set table
                                    
                                    .. attribute:: rpc_set
                                    
                                    	A BGP next\-hop set
                                    	**type**\: list of  		 :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets, self).__init__()

                                        self.yang_name = "rpc-sets"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rpc-set", ("rpc_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet))])
                                        self._leafs = OrderedDict()

                                        self.rpc_set = YList(self)
                                        self._segment_path = lambda: "rpc-sets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets, [], name, value)


                                    class RpcSet(Entity):
                                        """
                                        A BGP next\-hop set
                                        
                                        .. attribute:: rpc_set_index  (key)
                                        
                                        	Nexthop set index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop_xr
                                        
                                        	Number of multipath next\-hops
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: srv6sid_address
                                        
                                        	SRv6 SID address value
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: srv6sid_address_len
                                        
                                        	SRv6 SID address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop
                                        
                                        	List of multipath next\-hops
                                        	**type**\: list of  		 :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet, self).__init__()

                                            self.yang_name = "rpc-set"
                                            self.yang_parent_name = "rpc-sets"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['rpc_set_index']
                                            self._child_classes = OrderedDict([("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop))])
                                            self._leafs = OrderedDict([
                                                ('rpc_set_index', (YLeaf(YType.uint32, 'rpc-set-index'), ['int'])),
                                                ('next_hop_xr', (YLeaf(YType.uint32, 'next-hop-xr'), ['int'])),
                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                ('ref_count', (YLeaf(YType.uint32, 'ref-count'), ['int'])),
                                                ('srv6sid_address', (YLeaf(YType.str, 'srv6sid-address'), ['str'])),
                                                ('srv6sid_address_len', (YLeaf(YType.uint32, 'srv6sid-address-len'), ['int'])),
                                            ])
                                            self.rpc_set_index = None
                                            self.next_hop_xr = None
                                            self.label = None
                                            self.ref_count = None
                                            self.srv6sid_address = None
                                            self.srv6sid_address_len = None

                                            self.next_hop = YList(self)
                                            self._segment_path = lambda: "rpc-set" + "[rpc-set-index='" + str(self.rpc_set_index) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet, ['rpc_set_index', u'next_hop_xr', u'label', u'ref_count', u'srv6sid_address', u'srv6sid_address_len'], name, value)


                                        class NextHop(Entity):
                                            """
                                            List of multipath next\-hops
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "rpc-set"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class GlobalAfProcessInfo(Entity):
                                    """
                                    The Global Address Family Process information
                                    table
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: is_nsr_enabled
                                    
                                    	Non\-stop routing enabled
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo, self).__init__()

                                        self.yang_name = "global-af-process-info"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_))])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('is_nsr_enabled', (YLeaf(YType.boolean, 'is-nsr-enabled'), ['bool'])),
                                        ])
                                        self.vrf_name = None
                                        self.af_name = None
                                        self.is_nsr_enabled = None

                                        self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"

                                        self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._segment_path = lambda: "global-af-process-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo, [u'vrf_name', u'af_name', u'is_nsr_enabled'], name, value)


                                    class Global(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:  :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall>`
                                        
                                        .. attribute:: scanner_period
                                        
                                        	Period (in seconds) of address\-family scanner runs
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nh_tunnel_version
                                        
                                        	NH Tunnel Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_prefixes
                                        
                                        	Total prefixes of address\-family scanned
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segment_prefixes
                                        
                                        	Number of prefixes scanned in a segment of address\-family
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segments
                                        
                                        	Number of segments to scan all prefixes of address\-family
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: inter_as_install_enabled
                                        
                                        	Is inter\-AS install to pim on ASBR enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: global_mcast_enabled
                                        
                                        	Is global table mcast enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: segmented_mcast_enabled
                                        
                                        	Is segmented mcast enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: gblafrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: gblafrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\: bool
                                        
                                        .. attribute:: gblafrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: gblafrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\: bool
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_perm_net_cfg
                                        
                                        	Permanent Network Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: perm_net_del_count
                                        
                                        	Count of removed perm paths
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_del_count
                                        
                                        	Count of stale perm paths
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_mark_count
                                        
                                        	Count of stale marked perm paths
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_insert_count
                                        
                                        	Count of inserted perm paths
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_existing_count
                                        
                                        	Count of existing perm paths
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_query_count
                                        
                                        	Count of perm nets given by RPL
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_process_count
                                        
                                        	Count of perm nets processed in RPL
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_nbr_count
                                        
                                        	Count of neighbors configured with perm net
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_not_found_count
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_path_not_found_count
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_found_count
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_reg_path_found_count
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_path_found_count
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_free_count
                                        
                                        	Count of freed perm pelems
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_path_refresh_count
                                        
                                        	Count of perm paths refreshed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_all_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: syncgrp_version
                                        
                                        	Sync\-group Version
                                        	**type**\: list of  		 :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "global-af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rib-install", ("rib_install", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall)), ("syncgrp-version", ("syncgrp_version", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion))])
                                            self._leafs = OrderedDict([
                                                ('scanner_period', (YLeaf(YType.uint16, 'scanner-period'), ['int'])),
                                                ('nh_tunnel_version', (YLeaf(YType.uint32, 'nh-tunnel-version'), ['int'])),
                                                ('scan_prefixes', (YLeaf(YType.uint32, 'scan-prefixes'), ['int'])),
                                                ('scan_segment_prefixes', (YLeaf(YType.uint32, 'scan-segment-prefixes'), ['int'])),
                                                ('scan_segments', (YLeaf(YType.uint8, 'scan-segments'), ['int'])),
                                                ('inter_as_install_enabled', (YLeaf(YType.boolean, 'inter-as-install-enabled'), ['bool'])),
                                                ('global_mcast_enabled', (YLeaf(YType.boolean, 'global-mcast-enabled'), ['bool'])),
                                                ('segmented_mcast_enabled', (YLeaf(YType.boolean, 'segmented-mcast-enabled'), ['bool'])),
                                                ('gblafrpki_disable', (YLeaf(YType.boolean, 'gblafrpki-disable'), ['bool'])),
                                                ('gblafrpki_use_validity', (YLeaf(YType.boolean, 'gblafrpki-use-validity'), ['bool'])),
                                                ('gblafrpki_allow_invalid', (YLeaf(YType.boolean, 'gblafrpki-allow-invalid'), ['bool'])),
                                                ('gblafrpki_signal_ibgp', (YLeaf(YType.boolean, 'gblafrpki-signal-ibgp'), ['bool'])),
                                                ('update_wait_install_enabled', (YLeaf(YType.boolean, 'update-wait-install-enabled'), ['bool'])),
                                                ('rib_ack_requests', (YLeaf(YType.uint32, 'rib-ack-requests'), ['int'])),
                                                ('rib_acks_received', (YLeaf(YType.uint32, 'rib-acks-received'), ['int'])),
                                                ('rib_slow_acks', (YLeaf(YType.uint32, 'rib-slow-acks'), ['int'])),
                                                ('is_perm_net_cfg', (YLeaf(YType.boolean, 'is-perm-net-cfg'), ['bool'])),
                                                ('perm_net_del_count', (YLeaf(YType.uint16, 'perm-net-del-count'), ['int'])),
                                                ('perm_net_stale_del_count', (YLeaf(YType.uint16, 'perm-net-stale-del-count'), ['int'])),
                                                ('perm_net_stale_mark_count', (YLeaf(YType.uint16, 'perm-net-stale-mark-count'), ['int'])),
                                                ('perm_net_insert_count', (YLeaf(YType.uint16, 'perm-net-insert-count'), ['int'])),
                                                ('perm_net_existing_count', (YLeaf(YType.uint16, 'perm-net-existing-count'), ['int'])),
                                                ('perm_net_rpl_query_count', (YLeaf(YType.uint16, 'perm-net-rpl-query-count'), ['int'])),
                                                ('perm_net_rpl_process_count', (YLeaf(YType.uint16, 'perm-net-rpl-process-count'), ['int'])),
                                                ('perm_nbr_count', (YLeaf(YType.uint16, 'perm-nbr-count'), ['int'])),
                                                ('rib_perm_pelem_not_found_count', (YLeaf(YType.uint16, 'rib-perm-pelem-not-found-count'), ['int'])),
                                                ('rib_perm_path_not_found_count', (YLeaf(YType.uint16, 'rib-perm-path-not-found-count'), ['int'])),
                                                ('rib_perm_pelem_found_count', (YLeaf(YType.uint16, 'rib-perm-pelem-found-count'), ['int'])),
                                                ('rib_reg_path_found_count', (YLeaf(YType.uint16, 'rib-reg-path-found-count'), ['int'])),
                                                ('rib_perm_path_found_count', (YLeaf(YType.uint16, 'rib-perm-path-found-count'), ['int'])),
                                                ('perm_pelem_free_count', (YLeaf(YType.uint16, 'perm-pelem-free-count'), ['int'])),
                                                ('perm_path_refresh_count', (YLeaf(YType.uint16, 'perm-path-refresh-count'), ['int'])),
                                                ('perm_pelem_bump_count', (YLeaf(YType.uint16, 'perm-pelem-bump-count'), ['int'])),
                                                ('perm_pelem_all_bump_count', (YLeaf(YType.uint16, 'perm-pelem-all-bump-count'), ['int'])),
                                            ])
                                            self.scanner_period = None
                                            self.nh_tunnel_version = None
                                            self.scan_prefixes = None
                                            self.scan_segment_prefixes = None
                                            self.scan_segments = None
                                            self.inter_as_install_enabled = None
                                            self.global_mcast_enabled = None
                                            self.segmented_mcast_enabled = None
                                            self.gblafrpki_disable = None
                                            self.gblafrpki_use_validity = None
                                            self.gblafrpki_allow_invalid = None
                                            self.gblafrpki_signal_ibgp = None
                                            self.update_wait_install_enabled = None
                                            self.rib_ack_requests = None
                                            self.rib_acks_received = None
                                            self.rib_slow_acks = None
                                            self.is_perm_net_cfg = None
                                            self.perm_net_del_count = None
                                            self.perm_net_stale_del_count = None
                                            self.perm_net_stale_mark_count = None
                                            self.perm_net_insert_count = None
                                            self.perm_net_existing_count = None
                                            self.perm_net_rpl_query_count = None
                                            self.perm_net_rpl_process_count = None
                                            self.perm_nbr_count = None
                                            self.rib_perm_pelem_not_found_count = None
                                            self.rib_perm_path_not_found_count = None
                                            self.rib_perm_pelem_found_count = None
                                            self.rib_reg_path_found_count = None
                                            self.rib_perm_path_found_count = None
                                            self.perm_pelem_free_count = None
                                            self.perm_path_refresh_count = None
                                            self.perm_pelem_bump_count = None
                                            self.perm_pelem_all_bump_count = None

                                            self.rib_install = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall()
                                            self.rib_install.parent = self
                                            self._children_name_map["rib_install"] = "rib-install"

                                            self.syncgrp_version = YList(self)
                                            self._segment_path = lambda: "global"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global, [u'scanner_period', u'nh_tunnel_version', u'scan_prefixes', u'scan_segment_prefixes', u'scan_segments', u'inter_as_install_enabled', u'global_mcast_enabled', u'segmented_mcast_enabled', u'gblafrpki_disable', u'gblafrpki_use_validity', u'gblafrpki_allow_invalid', u'gblafrpki_signal_ibgp', u'update_wait_install_enabled', u'rib_ack_requests', u'rib_acks_received', u'rib_slow_acks', u'is_perm_net_cfg', u'perm_net_del_count', u'perm_net_stale_del_count', u'perm_net_stale_mark_count', u'perm_net_insert_count', u'perm_net_existing_count', u'perm_net_rpl_query_count', u'perm_net_rpl_process_count', u'perm_nbr_count', u'rib_perm_pelem_not_found_count', u'rib_perm_path_not_found_count', u'rib_perm_pelem_found_count', u'rib_reg_path_found_count', u'rib_perm_path_found_count', u'perm_pelem_free_count', u'perm_path_refresh_count', u'perm_pelem_bump_count', u'perm_pelem_all_bump_count'], name, value)


                                        class RibInstall(Entity):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:  :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:  :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: skipped_count
                                            
                                            	Skipped routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall, self).__init__()

                                                self.yang_name = "rib-install"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("update-time", ("update_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime)), ("install-time", ("install_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime))])
                                                self._leafs = OrderedDict([
                                                    ('installed_count', (YLeaf(YType.uint32, 'installed-count'), ['int'])),
                                                    ('modified_count', (YLeaf(YType.uint32, 'modified-count'), ['int'])),
                                                    ('skipped_count', (YLeaf(YType.uint32, 'skipped-count'), ['int'])),
                                                    ('withdrawn_count', (YLeaf(YType.uint32, 'withdrawn-count'), ['int'])),
                                                    ('start_version', (YLeaf(YType.uint32, 'start-version'), ['int'])),
                                                    ('target_version', (YLeaf(YType.uint32, 'target-version'), ['int'])),
                                                ])
                                                self.installed_count = None
                                                self.modified_count = None
                                                self.skipped_count = None
                                                self.withdrawn_count = None
                                                self.start_version = None
                                                self.target_version = None

                                                self.update_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self._children_name_map["update_time"] = "update-time"

                                                self.install_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self._children_name_map["install_time"] = "install-time"
                                                self._segment_path = lambda: "rib-install"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall, [u'installed_count', u'modified_count', u'skipped_count', u'withdrawn_count', u'start_version', u'target_version'], name, value)


                                            class UpdateTime(Entity):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime, self).__init__()

                                                    self.yang_name = "update-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "update-time"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime, [u'seconds', u'nanoseconds'], name, value)


                                            class InstallTime(Entity):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime, self).__init__()

                                                    self.yang_name = "install-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "install-time"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime, [u'seconds', u'nanoseconds'], name, value)


                                        class SyncgrpVersion(Entity):
                                            """
                                            Sync\-group Version
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion, self).__init__()

                                                self.yang_name = "syncgrp-version"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "syncgrp-version"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion, [u'entry'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: table_is_active
                                        
                                        	Table state is active
                                        	**type**\: bool
                                        
                                        .. attribute:: table_id
                                        
                                        	Table ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rd_version
                                        
                                        	RD version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_version
                                        
                                        	Table version synced to RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_conv_version
                                        
                                        	NSR conv version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_is_conv
                                        
                                        	NSR is converged
                                        	**type**\: bool
                                        
                                        .. attribute:: client_reflection_enabled
                                        
                                        	Client reflection enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: dampening_enabled
                                        
                                        	Dampening enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: ebgp_distance
                                        
                                        	Distance for eBGP routes (external)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ibgp_distance
                                        
                                        	Distance for iBGP routes (internal)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: aggregates_distance
                                        
                                        	Dist for aggregate routes (local)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: dynamic_med_enabled
                                        
                                        	Update generation enabled for MED change
                                        	**type**\: bool
                                        
                                        .. attribute:: dynamic_med_interval
                                        
                                        	Delay in update generation after a MED change (in minutes)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: dynamic_med_timer_running
                                        
                                        	Dynamic MED timer running
                                        	**type**\: bool
                                        
                                        .. attribute:: dynamic_med_timer_value
                                        
                                        	Dynamic MED timer value (in seconds) left on the timer
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dynamic_med_periodic_timer_running
                                        
                                        	Dynamic MED periodic timer running
                                        	**type**\: bool
                                        
                                        .. attribute:: dynamic_med_periodic_timer_value
                                        
                                        	Dynamic MED periodic timer value (in seconds) left on the timer
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_has_converged
                                        
                                        	Received convergence notification from RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_convergence_version
                                        
                                        	Last convergence version received from RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                        
                                        	Is nexthop resoultion minimum prefix\-length configured ?
                                        	**type**\: bool
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length
                                        
                                        	Nexthop resoultion minimum prefix\-length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: selective_ebgp_multipath_enabled
                                        
                                        	Selective eBGP multipath isenabled
                                        	**type**\: bool
                                        
                                        .. attribute:: selective_ibgp_multipath_enabled
                                        
                                        	Selective iBGP multipath isenabled
                                        	**type**\: bool
                                        
                                        .. attribute:: selective_eibgp_multipath_enabled
                                        
                                        	Selective eiBGP multipath isenabled
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "global-af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('table_is_active', (YLeaf(YType.boolean, 'table-is-active'), ['bool'])),
                                                ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                                ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                                ('rd_version', (YLeaf(YType.uint32, 'rd-version'), ['int'])),
                                                ('rib_version', (YLeaf(YType.uint32, 'rib-version'), ['int'])),
                                                ('nsr_conv_version', (YLeaf(YType.uint32, 'nsr-conv-version'), ['int'])),
                                                ('nsr_is_conv', (YLeaf(YType.boolean, 'nsr-is-conv'), ['bool'])),
                                                ('client_reflection_enabled', (YLeaf(YType.boolean, 'client-reflection-enabled'), ['bool'])),
                                                ('dampening_enabled', (YLeaf(YType.boolean, 'dampening-enabled'), ['bool'])),
                                                ('ebgp_distance', (YLeaf(YType.uint16, 'ebgp-distance'), ['int'])),
                                                ('ibgp_distance', (YLeaf(YType.uint16, 'ibgp-distance'), ['int'])),
                                                ('aggregates_distance', (YLeaf(YType.uint16, 'aggregates-distance'), ['int'])),
                                                ('dynamic_med_enabled', (YLeaf(YType.boolean, 'dynamic-med-enabled'), ['bool'])),
                                                ('dynamic_med_interval', (YLeaf(YType.uint16, 'dynamic-med-interval'), ['int'])),
                                                ('dynamic_med_timer_running', (YLeaf(YType.boolean, 'dynamic-med-timer-running'), ['bool'])),
                                                ('dynamic_med_timer_value', (YLeaf(YType.uint16, 'dynamic-med-timer-value'), ['int'])),
                                                ('dynamic_med_periodic_timer_running', (YLeaf(YType.boolean, 'dynamic-med-periodic-timer-running'), ['bool'])),
                                                ('dynamic_med_periodic_timer_value', (YLeaf(YType.uint16, 'dynamic-med-periodic-timer-value'), ['int'])),
                                                ('rib_has_converged', (YLeaf(YType.boolean, 'rib-has-converged'), ['bool'])),
                                                ('rib_convergence_version', (YLeaf(YType.uint32, 'rib-convergence-version'), ['int'])),
                                                ('is_rib_table_full', (YLeaf(YType.boolean, 'is-rib-table-full'), ['bool'])),
                                                ('rib_table_full_version', (YLeaf(YType.uint32, 'rib-table-full-version'), ['int'])),
                                                ('nexthop_resolution_minimum_prefix_length_configured', (YLeaf(YType.boolean, 'nexthop-resolution-minimum-prefix-length-configured'), ['bool'])),
                                                ('nexthop_resolution_minimum_prefix_length', (YLeaf(YType.uint32, 'nexthop-resolution-minimum-prefix-length'), ['int'])),
                                                ('selective_ebgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-ebgp-multipath-enabled'), ['bool'])),
                                                ('selective_ibgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-ibgp-multipath-enabled'), ['bool'])),
                                                ('selective_eibgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-eibgp-multipath-enabled'), ['bool'])),
                                                ('rib_acked_table_version', (YLeaf(YType.uint32, 'rib-acked-table-version'), ['int'])),
                                            ])
                                            self.table_is_active = None
                                            self.table_id = None
                                            self.table_version = None
                                            self.rd_version = None
                                            self.rib_version = None
                                            self.nsr_conv_version = None
                                            self.nsr_is_conv = None
                                            self.client_reflection_enabled = None
                                            self.dampening_enabled = None
                                            self.ebgp_distance = None
                                            self.ibgp_distance = None
                                            self.aggregates_distance = None
                                            self.dynamic_med_enabled = None
                                            self.dynamic_med_interval = None
                                            self.dynamic_med_timer_running = None
                                            self.dynamic_med_timer_value = None
                                            self.dynamic_med_periodic_timer_running = None
                                            self.dynamic_med_periodic_timer_value = None
                                            self.rib_has_converged = None
                                            self.rib_convergence_version = None
                                            self.is_rib_table_full = None
                                            self.rib_table_full_version = None
                                            self.nexthop_resolution_minimum_prefix_length_configured = None
                                            self.nexthop_resolution_minimum_prefix_length = None
                                            self.selective_ebgp_multipath_enabled = None
                                            self.selective_ibgp_multipath_enabled = None
                                            self.selective_eibgp_multipath_enabled = None
                                            self.rib_acked_table_version = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_, [u'table_is_active', u'table_id', u'table_version', u'rd_version', u'rib_version', u'nsr_conv_version', u'nsr_is_conv', u'client_reflection_enabled', u'dampening_enabled', u'ebgp_distance', u'ibgp_distance', u'aggregates_distance', u'dynamic_med_enabled', u'dynamic_med_interval', u'dynamic_med_timer_running', u'dynamic_med_timer_value', u'dynamic_med_periodic_timer_running', u'dynamic_med_periodic_timer_value', u'rib_has_converged', u'rib_convergence_version', u'is_rib_table_full', u'rib_table_full_version', u'nexthop_resolution_minimum_prefix_length_configured', u'nexthop_resolution_minimum_prefix_length', u'selective_ebgp_multipath_enabled', u'selective_ibgp_multipath_enabled', u'selective_eibgp_multipath_enabled', u'rib_acked_table_version'], name, value)


                                class AdvertisedPathXr(Entity):
                                    """
                                    The BGP Advertised path table (bestpath)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised path table entry (bestpath)
                                    	**type**\: list of  		 :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr, self).__init__()

                                        self.yang_name = "advertised-path-xr"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-path", ("advertised_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath))])
                                        self._leafs = OrderedDict()

                                        self.advertised_path = YList(self)
                                        self._segment_path = lambda: "advertised-path-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr, [], name, value)


                                    class AdvertisedPath(Entity):
                                        """
                                        A BGP Advertised path table entry (bestpath)
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, self).__init__()

                                            self.yang_name = "advertised-path"
                                            self.yang_parent_name = "advertised-path-xr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "advertised-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, ['rd', 'network', 'prefix_length', 'neighbor_address', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SourcedNetworks(Entity):
                                    """
                                    The BGP Convergence table
                                    
                                    .. attribute:: sourced_network
                                    
                                    	A BGP network command table entry
                                    	**type**\: list of  		 :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks, self).__init__()

                                        self.yang_name = "sourced-networks"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sourced-network", ("sourced_network", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork))])
                                        self._leafs = OrderedDict()

                                        self.sourced_network = YList(self)
                                        self._segment_path = lambda: "sourced-networks"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks, [], name, value)


                                    class SourcedNetwork(Entity):
                                        """
                                        A BGP network command table entry
                                        
                                        .. attribute:: network  (key)
                                        
                                        	Network in prefix/length format
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: sourced_prefix
                                        
                                        	Prefix length
                                        	**type**\:  :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: is_backdoor
                                        
                                        	TRUE if net is a backdoor route
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork, self).__init__()

                                            self.yang_name = "sourced-network"
                                            self.yang_parent_name = "sourced-networks"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['network']
                                            self._child_classes = OrderedDict([("sourced-prefix", ("sourced_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix))])
                                            self._leafs = OrderedDict([
                                                ('network', (YLeaf(YType.str, 'network'), ['str','str'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('is_backdoor', (YLeaf(YType.boolean, 'is-backdoor'), ['bool'])),
                                            ])
                                            self.network = None
                                            self.af_name = None
                                            self.is_backdoor = None

                                            self.sourced_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                            self.sourced_prefix.parent = self
                                            self._children_name_map["sourced_prefix"] = "sourced-prefix"
                                            self._segment_path = lambda: "sourced-network" + "[network='" + str(self.network) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork, ['network', u'af_name', u'is_backdoor'], name, value)


                                        class SourcedPrefix(Entity):
                                            """
                                            Prefix length
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, self).__init__()

                                                self.yang_name = "sourced-prefix"
                                                self.yang_parent_name = "sourced-network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "sourced-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "sourced-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class UpdateGroups(Entity):
                                    """
                                    The BGP Update group table
                                    
                                    .. attribute:: update_group
                                    
                                    	A BGP Update group table entry
                                    	**type**\: list of  		 :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups, self).__init__()

                                        self.yang_name = "update-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-group", ("update_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.update_group = YList(self)
                                        self._segment_path = lambda: "update-groups"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups, [], name, value)


                                    class UpdateGroup(Entity):
                                        """
                                        A BGP Update group table entry
                                        
                                        .. attribute:: update_group_id
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_id
                                        
                                        	Filter group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_af_name
                                        
                                        	Neighbor session Address family
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family for update group
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: should_send_communities
                                        
                                        	Send communities
                                        	**type**\: bool
                                        
                                        .. attribute:: should_send_ext_communities
                                        
                                        	Send Extended communities
                                        	**type**\: bool
                                        
                                        .. attribute:: should_send_stitching_rt
                                        
                                        	Send Stitching RT
                                        	**type**\: bool
                                        
                                        .. attribute:: has_orf_receive_capability
                                        
                                        	ORF receive capability
                                        	**type**\: bool
                                        
                                        .. attribute:: is_route_reflector_client
                                        
                                        	Route\-reflector client
                                        	**type**\: bool
                                        
                                        .. attribute:: is_client_reflection_disabled
                                        
                                        	True if client\-to\-client reflection is disabled 
                                        	**type**\: bool
                                        
                                        .. attribute:: accepts_legacy_pe_rt_route
                                        
                                        	accept\-legacy\-pe\-RT route
                                        	**type**\: bool
                                        
                                        .. attribute:: updgrp_cluster_id
                                        
                                        	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updgrp_cluster_type
                                        
                                        	Cluster ID type\:undefined/number/Ip address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\: str
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\: bool
                                        
                                        .. attribute:: should_remove_private_a_ss
                                        
                                        	Remove private AS numbers
                                        	**type**\: bool
                                        
                                        .. attribute:: should_remove_private_as_ent_path
                                        
                                        	Remove private AS numbersif the entire path consistsof private ASes
                                        	**type**\: bool
                                        
                                        .. attribute:: use_next_hop_self
                                        
                                        	Next hop self
                                        	**type**\: bool
                                        
                                        .. attribute:: use_next_hop_unchanged_mpath
                                        
                                        	Next\-hop\-unchanged multipath
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_peers
                                        
                                        	Internal peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is_common_admin_peers
                                        
                                        	Common admin peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is4_byte_as_peer
                                        
                                        	4\-byte AS capable peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is_addpath_capable
                                        
                                        	Add\-path capable peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is_send_mcast_attr_enabled
                                        
                                        	Send mcast attribute enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aigp_capable
                                        
                                        	AIGP capable peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aigp_cost_community_capable
                                        
                                        	Send AIGP cost community to peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aigp_med_capable
                                        
                                        	Send AIGP cost in MED
                                        	**type**\: bool
                                        
                                        .. attribute:: is_llgr_capable
                                        
                                        	Send Long\-lived Stale paths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_adv_capable
                                        
                                        	Send tranlsated paths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_adv_reorg_capable
                                        
                                        	Send Re\-orig paths
                                        	**type**\: bool
                                        
                                        .. attribute:: disable_native_advertisement
                                        
                                        	Disable advertising native routes
                                        	**type**\: bool
                                        
                                        .. attribute:: disable_def_vrf_imp_advertisement
                                        
                                        	Disable advertising default VRF  imported routes
                                        	**type**\: bool
                                        
                                        .. attribute:: disable_vrf_re_imp_advertisement
                                        
                                        	Disable advertising VRF re\-imported routes
                                        	**type**\: bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: is_directly_connected_ebgp_v6_peers
                                        
                                        	Directly connected EBGP v6 peers
                                        	**type**\: bool
                                        
                                        .. attribute:: minimum_advertisement_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: minimum_advertisement_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outbound route policy name
                                        	**type**\: str
                                        
                                        .. attribute:: desync_count
                                        
                                        	Number of times the update has been desynchronized
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: subgrp_merge_count
                                        
                                        	Number of times sub\-groups have been merged
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_subgrp_count
                                        
                                        	Current count of refresh subgroups
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updates_formatted
                                        
                                        	Number of updates formatted
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updates_replicated
                                        
                                        	No. of updates replicated
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\: bool
                                        
                                        .. attribute:: as_override
                                        
                                        	AS Override option
                                        	**type**\: bool
                                        
                                        .. attribute:: soo_value
                                        
                                        	Site\-of\-origin value
                                        	**type**\: str
                                        
                                        .. attribute:: split_horizon
                                        
                                        	Split horizon check
                                        	**type**\: bool
                                        
                                        .. attribute:: is_labeled_afi_enabled
                                        
                                        	Update group has labeled AFI enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_unlabeled_afi_enabled
                                        
                                        	Update group has unlabeled AFI enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: ext_nh_encoding
                                        
                                        	Extended nexthop encoding cap received
                                        	**type**\: bool
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_adv_perm_net_capable
                                        
                                        	Advertise Permanent\-Net capable peers
                                        	**type**\: bool
                                        
                                        .. attribute:: should_send_gshut_community
                                        
                                        	Send GSHUT community
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_active
                                        
                                        	GSHUT active
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	GSHUT local preference set
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	GSHUT local preference
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	GSHUT AS prepends
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with local\-label via Unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: enable_label_stack
                                        
                                        	Enable label stack
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this update group which are not in any sub\-group
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                        
                                        .. attribute:: update_sub_group
                                        
                                        	Update sub\-group list
                                        	**type**\: list of  		 :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup, self).__init__()

                                            self.yang_name = "update-group"
                                            self.yang_parent_name = "update-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor)), ("update-sub-group", ("update_sub_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup))])
                                            self._leafs = OrderedDict([
                                                ('update_group_id', (YLeaf(YType.uint32, 'update-group-id'), ['int'])),
                                                ('filter_group_id', (YLeaf(YType.uint32, 'filter-group-id'), ['int'])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('session_af_name', (YLeaf(YType.uint8, 'session-af-name'), ['int'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('should_send_communities', (YLeaf(YType.boolean, 'should-send-communities'), ['bool'])),
                                                ('should_send_ext_communities', (YLeaf(YType.boolean, 'should-send-ext-communities'), ['bool'])),
                                                ('should_send_stitching_rt', (YLeaf(YType.boolean, 'should-send-stitching-rt'), ['bool'])),
                                                ('has_orf_receive_capability', (YLeaf(YType.boolean, 'has-orf-receive-capability'), ['bool'])),
                                                ('is_route_reflector_client', (YLeaf(YType.boolean, 'is-route-reflector-client'), ['bool'])),
                                                ('is_client_reflection_disabled', (YLeaf(YType.boolean, 'is-client-reflection-disabled'), ['bool'])),
                                                ('accepts_legacy_pe_rt_route', (YLeaf(YType.boolean, 'accepts-legacy-pe-rt-route'), ['bool'])),
                                                ('updgrp_cluster_id', (YLeaf(YType.uint32, 'updgrp-cluster-id'), ['int'])),
                                                ('updgrp_cluster_type', (YLeaf(YType.uint8, 'updgrp-cluster-type'), ['int'])),
                                                ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                                ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                                ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                                ('should_remove_private_a_ss', (YLeaf(YType.boolean, 'should-remove-private-a-ss'), ['bool'])),
                                                ('should_remove_private_as_ent_path', (YLeaf(YType.boolean, 'should-remove-private-as-ent-path'), ['bool'])),
                                                ('use_next_hop_self', (YLeaf(YType.boolean, 'use-next-hop-self'), ['bool'])),
                                                ('use_next_hop_unchanged_mpath', (YLeaf(YType.boolean, 'use-next-hop-unchanged-mpath'), ['bool'])),
                                                ('is_internal_peers', (YLeaf(YType.boolean, 'is-internal-peers'), ['bool'])),
                                                ('is_common_admin_peers', (YLeaf(YType.boolean, 'is-common-admin-peers'), ['bool'])),
                                                ('is4_byte_as_peer', (YLeaf(YType.boolean, 'is4-byte-as-peer'), ['bool'])),
                                                ('is_addpath_capable', (YLeaf(YType.boolean, 'is-addpath-capable'), ['bool'])),
                                                ('is_send_mcast_attr_enabled', (YLeaf(YType.boolean, 'is-send-mcast-attr-enabled'), ['bool'])),
                                                ('is_aigp_capable', (YLeaf(YType.boolean, 'is-aigp-capable'), ['bool'])),
                                                ('is_aigp_cost_community_capable', (YLeaf(YType.boolean, 'is-aigp-cost-community-capable'), ['bool'])),
                                                ('is_aigp_med_capable', (YLeaf(YType.boolean, 'is-aigp-med-capable'), ['bool'])),
                                                ('is_llgr_capable', (YLeaf(YType.boolean, 'is-llgr-capable'), ['bool'])),
                                                ('is_adv_capable', (YLeaf(YType.boolean, 'is-adv-capable'), ['bool'])),
                                                ('is_adv_reorg_capable', (YLeaf(YType.boolean, 'is-adv-reorg-capable'), ['bool'])),
                                                ('disable_native_advertisement', (YLeaf(YType.boolean, 'disable-native-advertisement'), ['bool'])),
                                                ('disable_def_vrf_imp_advertisement', (YLeaf(YType.boolean, 'disable-def-vrf-imp-advertisement'), ['bool'])),
                                                ('disable_vrf_re_imp_advertisement', (YLeaf(YType.boolean, 'disable-vrf-re-imp-advertisement'), ['bool'])),
                                                ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                                ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                                ('is_directly_connected_ebgp_v6_peers', (YLeaf(YType.boolean, 'is-directly-connected-ebgp-v6-peers'), ['bool'])),
                                                ('minimum_advertisement_interval', (YLeaf(YType.uint32, 'minimum-advertisement-interval'), ['int'])),
                                                ('minimum_advertisement_interval_msecs', (YLeaf(YType.uint32, 'minimum-advertisement-interval-msecs'), ['int'])),
                                                ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                                ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                                ('desync_count', (YLeaf(YType.uint32, 'desync-count'), ['int'])),
                                                ('subgrp_merge_count', (YLeaf(YType.uint32, 'subgrp-merge-count'), ['int'])),
                                                ('refresh_subgrp_count', (YLeaf(YType.uint32, 'refresh-subgrp-count'), ['int'])),
                                                ('updates_formatted', (YLeaf(YType.uint32, 'updates-formatted'), ['int'])),
                                                ('updates_replicated', (YLeaf(YType.uint32, 'updates-replicated'), ['int'])),
                                                ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                                ('as_override', (YLeaf(YType.boolean, 'as-override'), ['bool'])),
                                                ('soo_value', (YLeaf(YType.str, 'soo-value'), ['str'])),
                                                ('split_horizon', (YLeaf(YType.boolean, 'split-horizon'), ['bool'])),
                                                ('is_labeled_afi_enabled', (YLeaf(YType.boolean, 'is-labeled-afi-enabled'), ['bool'])),
                                                ('is_unlabeled_afi_enabled', (YLeaf(YType.boolean, 'is-unlabeled-afi-enabled'), ['bool'])),
                                                ('ext_nh_encoding', (YLeaf(YType.boolean, 'ext-nh-encoding'), ['bool'])),
                                                ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                                ('is_adv_perm_net_capable', (YLeaf(YType.boolean, 'is-adv-perm-net-capable'), ['bool'])),
                                                ('should_send_gshut_community', (YLeaf(YType.boolean, 'should-send-gshut-community'), ['bool'])),
                                                ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                                ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                                ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                                ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                                ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                                ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                            ])
                                            self.update_group_id = None
                                            self.filter_group_id = None
                                            self.process_instance_id = None
                                            self.session_af_name = None
                                            self.update_group_number = None
                                            self.update_group_af_name = None
                                            self.should_send_communities = None
                                            self.should_send_ext_communities = None
                                            self.should_send_stitching_rt = None
                                            self.has_orf_receive_capability = None
                                            self.is_route_reflector_client = None
                                            self.is_client_reflection_disabled = None
                                            self.accepts_legacy_pe_rt_route = None
                                            self.updgrp_cluster_id = None
                                            self.updgrp_cluster_type = None
                                            self.orr_group_name = None
                                            self.orr_group_index = None
                                            self.is_orr_root_address_configured = None
                                            self.should_remove_private_a_ss = None
                                            self.should_remove_private_as_ent_path = None
                                            self.use_next_hop_self = None
                                            self.use_next_hop_unchanged_mpath = None
                                            self.is_internal_peers = None
                                            self.is_common_admin_peers = None
                                            self.is4_byte_as_peer = None
                                            self.is_addpath_capable = None
                                            self.is_send_mcast_attr_enabled = None
                                            self.is_aigp_capable = None
                                            self.is_aigp_cost_community_capable = None
                                            self.is_aigp_med_capable = None
                                            self.is_llgr_capable = None
                                            self.is_adv_capable = None
                                            self.is_adv_reorg_capable = None
                                            self.disable_native_advertisement = None
                                            self.disable_def_vrf_imp_advertisement = None
                                            self.disable_vrf_re_imp_advertisement = None
                                            self.encapsulation_type = None
                                            self.advertise_rt_type = None
                                            self.is_directly_connected_ebgp_v6_peers = None
                                            self.minimum_advertisement_interval = None
                                            self.minimum_advertisement_interval_msecs = None
                                            self.local_as = None
                                            self.route_policy_out = None
                                            self.desync_count = None
                                            self.subgrp_merge_count = None
                                            self.refresh_subgrp_count = None
                                            self.updates_formatted = None
                                            self.updates_replicated = None
                                            self.local_as_replace_as = None
                                            self.as_override = None
                                            self.soo_value = None
                                            self.split_horizon = None
                                            self.is_labeled_afi_enabled = None
                                            self.is_unlabeled_afi_enabled = None
                                            self.ext_nh_encoding = None
                                            self.remote_as = None
                                            self.is_adv_perm_net_capable = None
                                            self.should_send_gshut_community = None
                                            self.gshut_active = None
                                            self.gshut_locpref_set = None
                                            self.gshut_locpref = None
                                            self.gshut_prepends = None
                                            self.advertise_local_labeled_route_unicast = None
                                            self.enable_label_stack = None

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"

                                            self.neighbor = YList(self)
                                            self.update_sub_group = YList(self)
                                            self._segment_path = lambda: "update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup, ['update_group_id', 'filter_group_id', u'process_instance_id', u'session_af_name', u'update_group_number', u'update_group_af_name', u'should_send_communities', u'should_send_ext_communities', u'should_send_stitching_rt', u'has_orf_receive_capability', u'is_route_reflector_client', u'is_client_reflection_disabled', u'accepts_legacy_pe_rt_route', u'updgrp_cluster_id', u'updgrp_cluster_type', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'should_remove_private_a_ss', u'should_remove_private_as_ent_path', u'use_next_hop_self', u'use_next_hop_unchanged_mpath', u'is_internal_peers', u'is_common_admin_peers', u'is4_byte_as_peer', u'is_addpath_capable', u'is_send_mcast_attr_enabled', u'is_aigp_capable', u'is_aigp_cost_community_capable', u'is_aigp_med_capable', u'is_llgr_capable', u'is_adv_capable', u'is_adv_reorg_capable', u'disable_native_advertisement', u'disable_def_vrf_imp_advertisement', u'disable_vrf_re_imp_advertisement', u'encapsulation_type', u'advertise_rt_type', u'is_directly_connected_ebgp_v6_peers', u'minimum_advertisement_interval', u'minimum_advertisement_interval_msecs', u'local_as', u'route_policy_out', u'desync_count', u'subgrp_merge_count', u'refresh_subgrp_count', u'updates_formatted', u'updates_replicated', u'local_as_replace_as', u'as_override', u'soo_value', u'split_horizon', u'is_labeled_afi_enabled', u'is_unlabeled_afi_enabled', u'ext_nh_encoding', u'remote_as', u'is_adv_perm_net_capable', u'should_send_gshut_community', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends', u'advertise_local_labeled_route_unicast', u'enable_label_stack'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: updgen_timer_start_time
                                            
                                            	Timestamp when update timer started for updgrp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_stop_time
                                            
                                            	Timestamp when update timer stopped for updgrp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_process_time
                                            
                                            	Timestamp when update timer processed for updgrp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('update_generation_calls', (YLeaf(YType.uint32, 'update-generation-calls'), ['int'])),
                                                    ('update_generation_prefixes_count', (YLeaf(YType.uint32, 'update-generation-prefixes-count'), ['int'])),
                                                    ('update_generation_be_prefixes_count', (YLeaf(YType.uint32, 'update-generation-be-prefixes-count'), ['int'])),
                                                    ('update_generation_messages_count', (YLeaf(YType.uint32, 'update-generation-messages-count'), ['int'])),
                                                    ('update_generation_time', (YLeaf(YType.uint32, 'update-generation-time'), ['int'])),
                                                    ('updgen_timer_start_time', (YLeaf(YType.uint64, 'updgen-timer-start-time'), ['int'])),
                                                    ('updgen_timer_stop_time', (YLeaf(YType.uint64, 'updgen-timer-stop-time'), ['int'])),
                                                    ('updgen_timer_process_time', (YLeaf(YType.uint64, 'updgen-timer-process-time'), ['int'])),
                                                ])
                                                self.update_generation_calls = None
                                                self.update_generation_prefixes_count = None
                                                self.update_generation_be_prefixes_count = None
                                                self.update_generation_messages_count = None
                                                self.update_generation_time = None
                                                self.updgen_timer_start_time = None
                                                self.updgen_timer_stop_time = None
                                                self.updgen_timer_process_time = None
                                                self._segment_path = lambda: "performance-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, [u'update_generation_calls', u'update_generation_prefixes_count', u'update_generation_be_prefixes_count', u'update_generation_messages_count', u'update_generation_time', u'updgen_timer_start_time', u'updgen_timer_stop_time', u'updgen_timer_process_time'], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Neighbors in this update group which are not in
                                            any sub\-group
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class UpdateSubGroup(Entity):
                                            """
                                            Update sub\-group list
                                            
                                            .. attribute:: update_sub_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: filter_group
                                            
                                            	Update sub\-group fgrp\-num
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: wait_for_eo_rs
                                            
                                            	Wait for  RT Nbr EoRs
                                            	**type**\: bool
                                            
                                            .. attribute:: update_filter_group
                                            
                                            	Update f\-group list
                                            	**type**\: list of  		 :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this subgrp not in any filtergrp
                                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, self).__init__()

                                                self.yang_name = "update-sub-group"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("update-filter-group", ("update_filter_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor))])
                                                self._leafs = OrderedDict([
                                                    ('update_sub_group_number', (YLeaf(YType.uint32, 'update-sub-group-number'), ['int'])),
                                                    ('filter_group', (YLeaf(YType.uint16, 'filter-group'), ['int'])),
                                                    ('wait_for_eo_rs', (YLeaf(YType.boolean, 'wait-for-eo-rs'), ['bool'])),
                                                ])
                                                self.update_sub_group_number = None
                                                self.filter_group = None
                                                self.wait_for_eo_rs = None

                                                self.update_filter_group = YList(self)
                                                self.neighbor = YList(self)
                                                self._segment_path = lambda: "update-sub-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, [u'update_sub_group_number', u'filter_group', u'wait_for_eo_rs'], name, value)


                                            class UpdateFilterGroup(Entity):
                                                """
                                                Update f\-group list
                                                
                                                .. attribute:: update_filter_group_number
                                                
                                                	Update sub\-group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rts
                                                
                                                	RT count per filter group
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_flags
                                                
                                                	Flags per filter group
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fgroup_neighbors
                                                
                                                	Nbrs per filter group
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: fgroup_created_message_elements
                                                
                                                	Number of message elems created for filtergroup
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_deleted_message_elements
                                                
                                                	Number of message elems deleted
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_queued_message_elements
                                                
                                                	Number of message elems queued
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in last update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in all update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_non_optimised_prefixes
                                                
                                                	Number of prefixes  non\-optm from filtergroupin all update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_skipped_prefixes
                                                
                                                	Number of prefixes skipped for filtergroup in last update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_suppressed_prefixes
                                                
                                                	Number of prefixes suppressed for filtergroup in last update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_rt_present
                                                
                                                	RT attribute list present
                                                	**type**\: bool
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                                
                                                .. attribute:: neighbor
                                                
                                                	Neighbors in this update sub\-group
                                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, self).__init__()

                                                    self.yang_name = "update-filter-group"
                                                    self.yang_parent_name = "update-sub-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor))])
                                                    self._leafs = OrderedDict([
                                                        ('update_filter_group_number', (YLeaf(YType.uint32, 'update-filter-group-number'), ['int'])),
                                                        ('rts', (YLeaf(YType.uint32, 'rts'), ['int'])),
                                                        ('fgroup_flags', (YLeaf(YType.uint8, 'fgroup-flags'), ['int'])),
                                                        ('fgroup_neighbors', (YLeaf(YType.uint16, 'fgroup-neighbors'), ['int'])),
                                                        ('fgroup_created_message_elements', (YLeaf(YType.uint32, 'fgroup-created-message-elements'), ['int'])),
                                                        ('fgroup_deleted_message_elements', (YLeaf(YType.uint32, 'fgroup-deleted-message-elements'), ['int'])),
                                                        ('fgroup_queued_message_elements', (YLeaf(YType.uint32, 'fgroup-queued-message-elements'), ['int'])),
                                                        ('fgroup_advertised_prefixes', (YLeaf(YType.uint32, 'fgroup-advertised-prefixes'), ['int'])),
                                                        ('fgroup_total_advertised_prefixes', (YLeaf(YType.uint32, 'fgroup-total-advertised-prefixes'), ['int'])),
                                                        ('fgroup_withdrawn_prefixes', (YLeaf(YType.uint32, 'fgroup-withdrawn-prefixes'), ['int'])),
                                                        ('fgroup_total_withdrawn_prefixes', (YLeaf(YType.uint32, 'fgroup-total-withdrawn-prefixes'), ['int'])),
                                                        ('fgroup_total_non_optimised_prefixes', (YLeaf(YType.uint32, 'fgroup-total-non-optimised-prefixes'), ['int'])),
                                                        ('fgroup_skipped_prefixes', (YLeaf(YType.uint32, 'fgroup-skipped-prefixes'), ['int'])),
                                                        ('fgroup_suppressed_prefixes', (YLeaf(YType.uint32, 'fgroup-suppressed-prefixes'), ['int'])),
                                                        ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                                    ])
                                                    self.update_filter_group_number = None
                                                    self.rts = None
                                                    self.fgroup_flags = None
                                                    self.fgroup_neighbors = None
                                                    self.fgroup_created_message_elements = None
                                                    self.fgroup_deleted_message_elements = None
                                                    self.fgroup_queued_message_elements = None
                                                    self.fgroup_advertised_prefixes = None
                                                    self.fgroup_total_advertised_prefixes = None
                                                    self.fgroup_withdrawn_prefixes = None
                                                    self.fgroup_total_withdrawn_prefixes = None
                                                    self.fgroup_total_non_optimised_prefixes = None
                                                    self.fgroup_skipped_prefixes = None
                                                    self.fgroup_suppressed_prefixes = None
                                                    self.is_rt_present = None

                                                    self.extended_community = YList(self)
                                                    self.neighbor = YList(self)
                                                    self._segment_path = lambda: "update-filter-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, [u'update_filter_group_number', u'rts', u'fgroup_flags', u'fgroup_neighbors', u'fgroup_created_message_elements', u'fgroup_deleted_message_elements', u'fgroup_queued_message_elements', u'fgroup_advertised_prefixes', u'fgroup_total_advertised_prefixes', u'fgroup_withdrawn_prefixes', u'fgroup_total_withdrawn_prefixes', u'fgroup_total_non_optimised_prefixes', u'fgroup_skipped_prefixes', u'fgroup_suppressed_prefixes', u'is_rt_present'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "update-filter-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, [u'entry'], name, value)


                                                class Neighbor(Entity):
                                                    """
                                                    Neighbors in this update sub\-group
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, self).__init__()

                                                        self.yang_name = "neighbor"
                                                        self.yang_parent_name = "update-filter-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class Neighbor(Entity):
                                                """
                                                Neighbors in this subgrp not in any filtergrp
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, self).__init__()

                                                    self.yang_name = "neighbor"
                                                    self.yang_parent_name = "update-sub-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class UpdateGenerationSubGroups(Entity):
                                    """
                                    Update generation for all sub\-groups
                                    
                                    .. attribute:: update_generation_sub_group
                                    
                                    	Update generation for sub\-group
                                    	**type**\: list of  		 :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups, self).__init__()

                                        self.yang_name = "update-generation-sub-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-generation-sub-group", ("update_generation_sub_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup))])
                                        self._leafs = OrderedDict()

                                        self.update_generation_sub_group = YList(self)
                                        self._segment_path = lambda: "update-generation-sub-groups"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups, [], name, value)


                                    class UpdateGenerationSubGroup(Entity):
                                        """
                                        Update generation for sub\-group
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: creation_timestamp
                                        
                                        	Creation time
                                        	**type**\:  :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                        
                                        .. attribute:: last_merge_timestamp
                                        
                                        	Last merge time
                                        	**type**\:  :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                        
                                        .. attribute:: first_update_walk_start_timestamp
                                        
                                        	First update walk start time
                                        	**type**\:  :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: first_update_walk_end_timestamp
                                        
                                        	First update walk end time
                                        	**type**\:  :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: last_update_walk_start_timestamp
                                        
                                        	Last update walk start time
                                        	**type**\:  :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: last_update_walk_end_timestamp
                                        
                                        	Last update walk end time
                                        	**type**\:  :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:  :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: current_update_limit_sub_group
                                        
                                        	Current update limit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: configured_update_limit_sub_group
                                        
                                        	Configured update limit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttled
                                        
                                        	Is update throttled
                                        	**type**\: bool
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_version
                                        
                                        	NSR version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_resume_version
                                        
                                        	Next resume version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: io_write_event_pending
                                        
                                        	Is IO write event pending
                                        	**type**\: bool
                                        
                                        .. attribute:: update_default_route_sent
                                        
                                        	Is default route sent
                                        	**type**\: bool
                                        
                                        .. attribute:: merge_count
                                        
                                        	Merge count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_merged_sub_group_index
                                        
                                        	Last merged sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_attempted
                                        
                                        	Sending EoR has been attempted
                                        	**type**\: bool
                                        
                                        .. attribute:: last_update_walk_end_age
                                        
                                        	Time since last update walk end event
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, self).__init__()

                                            self.yang_name = "update-generation-sub-group"
                                            self.yang_parent_name = "update-generation-sub-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("creation-timestamp", ("creation_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp)), ("last-merge-timestamp", ("last_merge_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp)), ("first-update-walk-start-timestamp", ("first_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp)), ("first-update-walk-end-timestamp", ("first_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp)), ("last-update-walk-start-timestamp", ("last_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp)), ("last-update-walk-end-timestamp", ("last_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp)), ("last-update-queued-timestamp", ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics))])
                                            self._leafs = OrderedDict([
                                                ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                                ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                                ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                                ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                                ('sub_group_id_xr', (YLeaf(YType.uint32, 'sub-group-id-xr'), ['int'])),
                                                ('parent_sub_group_index', (YLeaf(YType.uint32, 'parent-sub-group-index'), ['int'])),
                                                ('parent_sub_group_id', (YLeaf(YType.uint32, 'parent-sub-group-id'), ['int'])),
                                                ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                                ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                                ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                                ('current_update_limit_sub_group', (YLeaf(YType.uint32, 'current-update-limit-sub-group'), ['int'])),
                                                ('configured_update_limit_sub_group', (YLeaf(YType.uint32, 'configured-update-limit-sub-group'), ['int'])),
                                                ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                                ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                                ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                                                ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                                ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                                ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                ('nsr_version', (YLeaf(YType.uint32, 'nsr-version'), ['int'])),
                                                ('pending_target_version', (YLeaf(YType.uint32, 'pending-target-version'), ['int'])),
                                                ('next_resume_version', (YLeaf(YType.uint32, 'next-resume-version'), ['int'])),
                                                ('update_refresh_target_version', (YLeaf(YType.uint32, 'update-refresh-target-version'), ['int'])),
                                                ('io_write_event_pending', (YLeaf(YType.boolean, 'io-write-event-pending'), ['bool'])),
                                                ('update_default_route_sent', (YLeaf(YType.boolean, 'update-default-route-sent'), ['bool'])),
                                                ('merge_count', (YLeaf(YType.uint32, 'merge-count'), ['int'])),
                                                ('last_merged_sub_group_index', (YLeaf(YType.uint32, 'last-merged-sub-group-index'), ['int'])),
                                                ('eo_r_attempted', (YLeaf(YType.boolean, 'eo-r-attempted'), ['bool'])),
                                                ('last_update_walk_end_age', (YLeaf(YType.uint32, 'last-update-walk-end-age'), ['int'])),
                                                ('last_update_queued_age', (YLeaf(YType.uint32, 'last-update-queued-age'), ['int'])),
                                            ])
                                            self.update_group_index = None
                                            self.sub_group_index = None
                                            self.sub_group_id = None
                                            self.process_id = None
                                            self.update_vrf_name = None
                                            self.update_group_af_name = None
                                            self.sub_group_index_xr = None
                                            self.sub_group_id_xr = None
                                            self.parent_sub_group_index = None
                                            self.parent_sub_group_id = None
                                            self.update_group_index_xr = None
                                            self.update_main_table_version = None
                                            self.update_vrf_table_rib_version = None
                                            self.current_update_limit_sub_group = None
                                            self.configured_update_limit_sub_group = None
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.update_throttled = None
                                            self.refresh_sub_group_count = None
                                            self.filter_group_count = None
                                            self.neighbor_count = None
                                            self.version = None
                                            self.nsr_version = None
                                            self.pending_target_version = None
                                            self.next_resume_version = None
                                            self.update_refresh_target_version = None
                                            self.io_write_event_pending = None
                                            self.update_default_route_sent = None
                                            self.merge_count = None
                                            self.last_merged_sub_group_index = None
                                            self.eo_r_attempted = None
                                            self.last_update_walk_end_age = None
                                            self.last_update_queued_age = None

                                            self.creation_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                            self.creation_timestamp.parent = self
                                            self._children_name_map["creation_timestamp"] = "creation-timestamp"

                                            self.last_merge_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                            self.last_merge_timestamp.parent = self
                                            self._children_name_map["last_merge_timestamp"] = "last-merge-timestamp"

                                            self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                            self.first_update_walk_start_timestamp.parent = self
                                            self._children_name_map["first_update_walk_start_timestamp"] = "first-update-walk-start-timestamp"

                                            self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                            self.first_update_walk_end_timestamp.parent = self
                                            self._children_name_map["first_update_walk_end_timestamp"] = "first-update-walk-end-timestamp"

                                            self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                            self.last_update_walk_start_timestamp.parent = self
                                            self._children_name_map["last_update_walk_start_timestamp"] = "last-update-walk-start-timestamp"

                                            self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                            self.last_update_walk_end_timestamp.parent = self
                                            self._children_name_map["last_update_walk_end_timestamp"] = "last-update-walk-end-timestamp"

                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"

                                            self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._segment_path = lambda: "update-generation-sub-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, ['update_group_index', 'sub_group_index', 'sub_group_id', u'process_id', u'update_vrf_name', u'update_group_af_name', u'sub_group_index_xr', u'sub_group_id_xr', u'parent_sub_group_index', u'parent_sub_group_id', u'update_group_index_xr', u'update_main_table_version', u'update_vrf_table_rib_version', u'current_update_limit_sub_group', u'configured_update_limit_sub_group', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled', u'refresh_sub_group_count', u'filter_group_count', u'neighbor_count', u'version', u'nsr_version', u'pending_target_version', u'next_resume_version', u'update_refresh_target_version', u'io_write_event_pending', u'update_default_route_sent', u'merge_count', u'last_merged_sub_group_index', u'eo_r_attempted', u'last_update_walk_end_age', u'last_update_queued_age'], name, value)


                                        class CreationTimestamp(Entity):
                                            """
                                            Creation time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, self).__init__()

                                                self.yang_name = "creation-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "creation-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastMergeTimestamp(Entity):
                                            """
                                            Last merge time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, self).__init__()

                                                self.yang_name = "last-merge-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-merge-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstUpdateWalkStartTimestamp(Entity):
                                            """
                                            First update walk start time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, self).__init__()

                                                self.yang_name = "first-update-walk-start-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-update-walk-start-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstUpdateWalkEndTimestamp(Entity):
                                            """
                                            First update walk end time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, self).__init__()

                                                self.yang_name = "first-update-walk-end-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-update-walk-end-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateWalkStartTimestamp(Entity):
                                            """
                                            Last update walk start time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-walk-start-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-walk-start-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateWalkEndTimestamp(Entity):
                                            """
                                            Last update walk end time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, self).__init__()

                                                self.yang_name = "last-update-walk-end-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-walk-end-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateQueuedTimestamp(Entity):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-queued-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                                self._leafs = OrderedDict([
                                                    ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                    ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                    ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                    ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                    ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                    ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                    ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                    ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                    ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                    ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                    ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                    ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                    ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                    ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                    ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                    ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                                ])
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_size_high = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_cleared = None
                                                self.last_update_discard_age = None
                                                self.last_update_cleard_age = None
                                                self.update_throttle_count = None
                                                self.last_update_throttle_age = None
                                                self.update_recovery_count = None
                                                self.last_update_recovery_age = None
                                                self.update_memory_allocation_fail_count = None
                                                self.last_update_memory_allocation_fail_age = None

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._segment_path = lambda: "update-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-discard-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class NextHopAddressFamilies(Entity):
                                    """
                                    Address family of nexthop table
                                    
                                    .. attribute:: next_hop_address_family
                                    
                                    	Nexthop Address family
                                    	**type**\: list of  		 :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies, self).__init__()

                                        self.yang_name = "next-hop-address-families"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("next-hop-address-family", ("next_hop_address_family", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily))])
                                        self._leafs = OrderedDict()

                                        self.next_hop_address_family = YList(self)
                                        self._segment_path = lambda: "next-hop-address-families"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies, [], name, value)


                                    class NextHopAddressFamily(Entity):
                                        """
                                        Nexthop Address family
                                        
                                        .. attribute:: next_hop_af_name  (key)
                                        
                                        	Address family
                                        	**type**\:  :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: next_hop_af_vrf_af
                                        
                                        	A BGP Next\-hop VRF AF table entry
                                        	**type**\:  :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                        
                                        .. attribute:: next_hop_afs
                                        
                                        	The BGP Next\-hop table
                                        	**type**\:  :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, self).__init__()

                                            self.yang_name = "next-hop-address-family"
                                            self.yang_parent_name = "next-hop-address-families"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_af_name']
                                            self._child_classes = OrderedDict([("next-hop-af-vrf-af", ("next_hop_af_vrf_af", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf)), ("next-hop-afs", ("next_hop_afs", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs))])
                                            self._leafs = OrderedDict([
                                                ('next_hop_af_name', (YLeaf(YType.enumeration, 'next-hop-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes', 'BgpAddressFamily', '')])),
                                            ])
                                            self.next_hop_af_name = None

                                            self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                            self.next_hop_af_vrf_af.parent = self
                                            self._children_name_map["next_hop_af_vrf_af"] = "next-hop-af-vrf-af"

                                            self.next_hop_afs = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                            self.next_hop_afs.parent = self
                                            self._children_name_map["next_hop_afs"] = "next-hop-afs"
                                            self._segment_path = lambda: "next-hop-address-family" + "[next-hop-af-name='" + str(self.next_hop_af_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, ['next_hop_af_name'], name, value)


                                        class NextHopAfVrfAf(Entity):
                                            """
                                            A BGP Next\-hop VRF AF table entry
                                            
                                            .. attribute:: performance_statistics
                                            
                                            	Performance statistics
                                            	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: gwaf_name
                                            
                                            	GW Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: total_nexthops
                                            
                                            	Total number of nexthops
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: critical_trigger_delay
                                            
                                            	Trigger delay for critical event processing
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: non_critical_trigger_delay
                                            
                                            	Trigger delay for non\-critical event processing
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: table_active
                                            
                                            	Whether the VRF is active
                                            	**type**\: bool
                                            
                                            .. attribute:: nh_rib_up
                                            
                                            	Whether the VRF is active
                                            	**type**\: bool
                                            
                                            .. attribute:: nh_rib_version
                                            
                                            	RIB version for gw\_ctx
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_nexthop_version
                                            
                                            	NH version for gw\_ctx
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_table_id
                                            
                                            	Gateway context table id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_table_version
                                            
                                            	Version of the EPE table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_label_version
                                            
                                            	Version of the EPE label walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_downloaded_version
                                            
                                            	Version of the EPE table downloaded
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_standby_version
                                            
                                            	Version of the EPE table processed by sync thread
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, self).__init__()

                                                self.yang_name = "next-hop-af-vrf-af"
                                                self.yang_parent_name = "next-hop-address-family"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics))])
                                                self._leafs = OrderedDict([
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('gwaf_name', (YLeaf(YType.enumeration, 'gwaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('total_nexthops', (YLeaf(YType.uint32, 'total-nexthops'), ['int'])),
                                                    ('critical_trigger_delay', (YLeaf(YType.uint32, 'critical-trigger-delay'), ['int'])),
                                                    ('non_critical_trigger_delay', (YLeaf(YType.uint32, 'non-critical-trigger-delay'), ['int'])),
                                                    ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                                                    ('nh_rib_up', (YLeaf(YType.boolean, 'nh-rib-up'), ['bool'])),
                                                    ('nh_rib_version', (YLeaf(YType.uint32, 'nh-rib-version'), ['int'])),
                                                    ('nh_nexthop_version', (YLeaf(YType.uint32, 'nh-nexthop-version'), ['int'])),
                                                    ('nh_table_id', (YLeaf(YType.uint32, 'nh-table-id'), ['int'])),
                                                    ('epe_table_version', (YLeaf(YType.uint32, 'epe-table-version'), ['int'])),
                                                    ('epe_label_version', (YLeaf(YType.uint32, 'epe-label-version'), ['int'])),
                                                    ('epe_downloaded_version', (YLeaf(YType.uint32, 'epe-downloaded-version'), ['int'])),
                                                    ('epe_standby_version', (YLeaf(YType.uint32, 'epe-standby-version'), ['int'])),
                                                ])
                                                self.af_name = None
                                                self.gwaf_name = None
                                                self.total_nexthops = None
                                                self.critical_trigger_delay = None
                                                self.non_critical_trigger_delay = None
                                                self.table_active = None
                                                self.nh_rib_up = None
                                                self.nh_rib_version = None
                                                self.nh_nexthop_version = None
                                                self.nh_table_id = None
                                                self.epe_table_version = None
                                                self.epe_label_version = None
                                                self.epe_downloaded_version = None
                                                self.epe_standby_version = None

                                                self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                                self.performance_statistics.parent = self
                                                self._children_name_map["performance_statistics"] = "performance-statistics"
                                                self._segment_path = lambda: "next-hop-af-vrf-af"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, [u'af_name', u'gwaf_name', u'total_nexthops', u'critical_trigger_delay', u'non_critical_trigger_delay', u'table_active', u'nh_rib_up', u'nh_rib_version', u'nh_nexthop_version', u'nh_table_id', u'epe_table_version', u'epe_label_version', u'epe_downloaded_version', u'epe_standby_version'], name, value)


                                            class PerformanceStatistics(Entity):
                                                """
                                                Performance statistics
                                                
                                                .. attribute:: critical_notf_count
                                                
                                                	Number of critical event notifications from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: noncritical_notf_count
                                                
                                                	Number of non\-critical event notifications from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_deletes
                                                
                                                	Number of bestpath deletes due to last notification
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_changes
                                                
                                                	Number of bestpath changes due to last notification
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_sync_reg_calls
                                                
                                                	NH sync register calls
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_reg_calls
                                                
                                                	NH async register calls
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_un_reg_calls
                                                
                                                	NH async unregister calls
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_pending_registrations
                                                
                                                	NH Registration List Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_peak_registrations
                                                
                                                	NH Registration List Count Peak
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_batch_finish_calls
                                                
                                                	NH batch finish calls
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_flush_timer_calls
                                                
                                                	NH flush timer calls
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_sync_reg_ts
                                                
                                                	NH Last sync Register TS
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_reg_ts
                                                
                                                	NH Last async Register TS
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_un_reg_ts
                                                
                                                	NH Last async UnRegister TS
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_batch_finish_ts
                                                
                                                	NH Last batch finish TS
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_flush_timer_ts
                                                
                                                	NH Last flush timer TS
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_calls
                                                
                                                	No. of calls to RIB update function
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_time
                                                
                                                	Time spent sending RIB updates (milliseconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: millisecond
                                                
                                                .. attribute:: nexthops_sent_to_rib
                                                
                                                	No. of nexthops sent to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_resent_to_rib
                                                
                                                	No. of nexthops re\-sent to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_removed_from_rib
                                                
                                                	No. of nexthops withdrawn from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_sync_registers_failed
                                                
                                                	No. of sync registers with RIB that failed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: riba_sync_registers_failed
                                                
                                                	No. of async registers with RIB that failed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                                
                                                	No. of nh registers failed because of no tbl\-id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                                
                                                	No. of nh registers failed because of no rib conn
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_nh_not_found
                                                
                                                	No. of times nexthop was not found during tunnel walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_gw_not_found
                                                
                                                	No. of times gw was not found during tunnel walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_backup_creates
                                                
                                                	No. of times backup tid created during tunnel walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, self).__init__()

                                                    self.yang_name = "performance-statistics"
                                                    self.yang_parent_name = "next-hop-af-vrf-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical_notf_count', (YLeaf(YType.uint32, 'critical-notf-count'), ['int'])),
                                                        ('noncritical_notf_count', (YLeaf(YType.uint32, 'noncritical-notf-count'), ['int'])),
                                                        ('last_notf_bestpath_deletes', (YLeaf(YType.uint32, 'last-notf-bestpath-deletes'), ['int'])),
                                                        ('last_notf_bestpath_changes', (YLeaf(YType.uint32, 'last-notf-bestpath-changes'), ['int'])),
                                                        ('nh_sync_reg_calls', (YLeaf(YType.uint32, 'nh-sync-reg-calls'), ['int'])),
                                                        ('nha_sync_reg_calls', (YLeaf(YType.uint32, 'nha-sync-reg-calls'), ['int'])),
                                                        ('nha_sync_un_reg_calls', (YLeaf(YType.uint32, 'nha-sync-un-reg-calls'), ['int'])),
                                                        ('nh_pending_registrations', (YLeaf(YType.uint32, 'nh-pending-registrations'), ['int'])),
                                                        ('nh_peak_registrations', (YLeaf(YType.uint32, 'nh-peak-registrations'), ['int'])),
                                                        ('nh_batch_finish_calls', (YLeaf(YType.uint32, 'nh-batch-finish-calls'), ['int'])),
                                                        ('nh_flush_timer_calls', (YLeaf(YType.uint32, 'nh-flush-timer-calls'), ['int'])),
                                                        ('nh_last_sync_reg_ts', (YLeaf(YType.uint32, 'nh-last-sync-reg-ts'), ['int'])),
                                                        ('nh_last_a_sync_reg_ts', (YLeaf(YType.uint32, 'nh-last-a-sync-reg-ts'), ['int'])),
                                                        ('nh_last_a_sync_un_reg_ts', (YLeaf(YType.uint32, 'nh-last-a-sync-un-reg-ts'), ['int'])),
                                                        ('nh_last_batch_finish_ts', (YLeaf(YType.uint32, 'nh-last-batch-finish-ts'), ['int'])),
                                                        ('nh_last_flush_timer_ts', (YLeaf(YType.uint32, 'nh-last-flush-timer-ts'), ['int'])),
                                                        ('nhrib_update_calls', (YLeaf(YType.uint32, 'nhrib-update-calls'), ['int'])),
                                                        ('nhrib_update_time', (YLeaf(YType.uint32, 'nhrib-update-time'), ['int'])),
                                                        ('nexthops_sent_to_rib', (YLeaf(YType.uint32, 'nexthops-sent-to-rib'), ['int'])),
                                                        ('nexthops_resent_to_rib', (YLeaf(YType.uint32, 'nexthops-resent-to-rib'), ['int'])),
                                                        ('nexthops_removed_from_rib', (YLeaf(YType.uint32, 'nexthops-removed-from-rib'), ['int'])),
                                                        ('rib_sync_registers_failed', (YLeaf(YType.uint32, 'rib-sync-registers-failed'), ['int'])),
                                                        ('riba_sync_registers_failed', (YLeaf(YType.uint32, 'riba-sync-registers-failed'), ['int'])),
                                                        ('ribnh_reg_failed_for_no_tbl_id', (YLeaf(YType.uint32, 'ribnh-reg-failed-for-no-tbl-id'), ['int'])),
                                                        ('ribnh_reg_failed_for_no_rib_conn', (YLeaf(YType.uint32, 'ribnh-reg-failed-for-no-rib-conn'), ['int'])),
                                                        ('tunnel_walk_nh_not_found', (YLeaf(YType.uint32, 'tunnel-walk-nh-not-found'), ['int'])),
                                                        ('tunnel_walk_gw_not_found', (YLeaf(YType.uint32, 'tunnel-walk-gw-not-found'), ['int'])),
                                                        ('tunnel_walk_backup_creates', (YLeaf(YType.uint32, 'tunnel-walk-backup-creates'), ['int'])),
                                                    ])
                                                    self.critical_notf_count = None
                                                    self.noncritical_notf_count = None
                                                    self.last_notf_bestpath_deletes = None
                                                    self.last_notf_bestpath_changes = None
                                                    self.nh_sync_reg_calls = None
                                                    self.nha_sync_reg_calls = None
                                                    self.nha_sync_un_reg_calls = None
                                                    self.nh_pending_registrations = None
                                                    self.nh_peak_registrations = None
                                                    self.nh_batch_finish_calls = None
                                                    self.nh_flush_timer_calls = None
                                                    self.nh_last_sync_reg_ts = None
                                                    self.nh_last_a_sync_reg_ts = None
                                                    self.nh_last_a_sync_un_reg_ts = None
                                                    self.nh_last_batch_finish_ts = None
                                                    self.nh_last_flush_timer_ts = None
                                                    self.nhrib_update_calls = None
                                                    self.nhrib_update_time = None
                                                    self.nexthops_sent_to_rib = None
                                                    self.nexthops_resent_to_rib = None
                                                    self.nexthops_removed_from_rib = None
                                                    self.rib_sync_registers_failed = None
                                                    self.riba_sync_registers_failed = None
                                                    self.ribnh_reg_failed_for_no_tbl_id = None
                                                    self.ribnh_reg_failed_for_no_rib_conn = None
                                                    self.tunnel_walk_nh_not_found = None
                                                    self.tunnel_walk_gw_not_found = None
                                                    self.tunnel_walk_backup_creates = None
                                                    self._segment_path = lambda: "performance-statistics"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, [u'critical_notf_count', u'noncritical_notf_count', u'last_notf_bestpath_deletes', u'last_notf_bestpath_changes', u'nh_sync_reg_calls', u'nha_sync_reg_calls', u'nha_sync_un_reg_calls', u'nh_pending_registrations', u'nh_peak_registrations', u'nh_batch_finish_calls', u'nh_flush_timer_calls', u'nh_last_sync_reg_ts', u'nh_last_a_sync_reg_ts', u'nh_last_a_sync_un_reg_ts', u'nh_last_batch_finish_ts', u'nh_last_flush_timer_ts', u'nhrib_update_calls', u'nhrib_update_time', u'nexthops_sent_to_rib', u'nexthops_resent_to_rib', u'nexthops_removed_from_rib', u'rib_sync_registers_failed', u'riba_sync_registers_failed', u'ribnh_reg_failed_for_no_tbl_id', u'ribnh_reg_failed_for_no_rib_conn', u'tunnel_walk_nh_not_found', u'tunnel_walk_gw_not_found', u'tunnel_walk_backup_creates'], name, value)


                                        class NextHopAfs(Entity):
                                            """
                                            The BGP Next\-hop table
                                            
                                            .. attribute:: next_hop_af
                                            
                                            	A BGP Next hop entry
                                            	**type**\: list of  		 :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, self).__init__()

                                                self.yang_name = "next-hop-afs"
                                                self.yang_parent_name = "next-hop-address-family"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop-af", ("next_hop_af", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf))])
                                                self._leafs = OrderedDict()

                                                self.next_hop_af = YList(self)
                                                self._segment_path = lambda: "next-hop-afs"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, [], name, value)


                                            class NextHopAf(Entity):
                                                """
                                                A BGP Next hop entry
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_set
                                                
                                                	Attribute Set Name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:  :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel>`
                                                
                                                .. attribute:: nexthop_internal_info
                                                
                                                	Internal nexthop info
                                                	**type**\:  :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: rib_nexthop_id
                                                
                                                	RIB Nexthop Id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_pending_registration
                                                
                                                	Nexthop registration is pending
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_reference_count
                                                
                                                	Number of neighbors/prefixes referencing this nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_reference_count_total
                                                
                                                	Number of neighbors/prefixes referencing this nexthop (AFs)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_first_hop_if_handle
                                                
                                                	First\-hop interface handle
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: nexthop_aigp_metric
                                                
                                                	AIGP metrice of nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_reachable
                                                
                                                	Is Gateway reachable ?
                                                	**type**\: bool
                                                
                                                .. attribute:: nexthop_gateway_prefix_connected
                                                
                                                	Is Gateway resolved through Connected route ?
                                                	**type**\: bool
                                                
                                                .. attribute:: nexthop_gateway_prefix_length
                                                
                                                	Gateway prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_info
                                                
                                                	Gateway related info, includingOptimal Route Reflector Gateways
                                                	**type**\: list of  		 :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address List
                                                	**type**\: list of  		 :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, self).__init__()

                                                    self.yang_name = "next-hop-af"
                                                    self.yang_parent_name = "next-hop-afs"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nexthop-address", ("nexthop_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel)), ("nexthop-internal-info", ("nexthop_internal_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo)), ("nexthop-gateway-info", ("nexthop_gateway_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('attribute_set', (YLeaf(YType.str, 'attribute-set'), ['str'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('rib_nexthop_id', (YLeaf(YType.uint32, 'rib-nexthop-id'), ['int'])),
                                                        ('nexthop_pending_registration', (YLeaf(YType.uint8, 'nexthop-pending-registration'), ['int'])),
                                                        ('nexthop_reference_count', (YLeaf(YType.uint32, 'nexthop-reference-count'), ['int'])),
                                                        ('nh_reference_count_total', (YLeaf(YType.uint32, 'nh-reference-count-total'), ['int'])),
                                                        ('nh_first_hop_if_handle', (YLeaf(YType.str, 'nh-first-hop-if-handle'), ['str'])),
                                                        ('nexthop_aigp_metric', (YLeaf(YType.uint32, 'nexthop-aigp-metric'), ['int'])),
                                                        ('nexthop_gateway_reachable', (YLeaf(YType.boolean, 'nexthop-gateway-reachable'), ['bool'])),
                                                        ('nexthop_gateway_prefix_connected', (YLeaf(YType.boolean, 'nexthop-gateway-prefix-connected'), ['bool'])),
                                                        ('nexthop_gateway_prefix_length', (YLeaf(YType.uint32, 'nexthop-gateway-prefix-length'), ['int'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.attribute_set = None
                                                    self.af_name = None
                                                    self.rib_nexthop_id = None
                                                    self.nexthop_pending_registration = None
                                                    self.nexthop_reference_count = None
                                                    self.nh_reference_count_total = None
                                                    self.nh_first_hop_if_handle = None
                                                    self.nexthop_aigp_metric = None
                                                    self.nexthop_gateway_reachable = None
                                                    self.nexthop_gateway_prefix_connected = None
                                                    self.nexthop_gateway_prefix_length = None

                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self._children_name_map["nexthop_address"] = "nexthop-address"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.nexthop_internal_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                    self.nexthop_internal_info.parent = self
                                                    self._children_name_map["nexthop_internal_info"] = "nexthop-internal-info"

                                                    self.nexthop_gateway_info = YList(self)
                                                    self.neighbor_address = YList(self)
                                                    self._segment_path = lambda: "next-hop-af"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, ['next_hop_address', 'attribute_set', u'af_name', u'rib_nexthop_id', u'nexthop_pending_registration', u'nexthop_reference_count', u'nh_reference_count_total', u'nh_first_hop_if_handle', u'nexthop_aigp_metric', u'nexthop_gateway_reachable', u'nexthop_gateway_prefix_connected', u'nexthop_gateway_prefix_length'], name, value)


                                                class NexthopAddress(Entity):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, self).__init__()

                                                        self.yang_name = "nexthop-address"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "nexthop-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class NexthopInternalInfo(Entity):
                                                    """
                                                    Internal nexthop info
                                                    
                                                    .. attribute:: nexthop_address
                                                    
                                                    	Nexthop address
                                                    	**type**\:  :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                    
                                                    .. attribute:: nexthop_id
                                                    
                                                    	Comm librray ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_version
                                                    
                                                    	Table version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_flags
                                                    
                                                    	Nexthop flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_if_handle
                                                    
                                                    	Nexthop ifhandle
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_af_user_bits
                                                    
                                                    	Bitmask indicating the AFs which share the nexthop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_label
                                                    
                                                    	Nexthop label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_metrice
                                                    
                                                    	Nexthop metrices
                                                    	**type**\: list of  		 :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                    
                                                    .. attribute:: nexthop_refcount
                                                    
                                                    	Nexthop refcounts
                                                    	**type**\: list of  		 :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                    
                                                    .. attribute:: nexthop_gateway_internal_info
                                                    
                                                    	Internal nexthop Gateway info
                                                    	**type**\: list of  		 :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, self).__init__()

                                                        self.yang_name = "nexthop-internal-info"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("nexthop-address", ("nexthop_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress)), ("nexthop-metrice", ("nexthop_metrice", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice)), ("nexthop-refcount", ("nexthop_refcount", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount)), ("nexthop-gateway-internal-info", ("nexthop_gateway_internal_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo))])
                                                        self._leafs = OrderedDict([
                                                            ('nexthop_id', (YLeaf(YType.uint32, 'nexthop-id'), ['int'])),
                                                            ('nexthop_version', (YLeaf(YType.uint32, 'nexthop-version'), ['int'])),
                                                            ('nexthop_flags', (YLeaf(YType.uint32, 'nexthop-flags'), ['int'])),
                                                            ('nexthop_if_handle', (YLeaf(YType.uint32, 'nexthop-if-handle'), ['int'])),
                                                            ('nexthop_af_user_bits', (YLeaf(YType.uint32, 'nexthop-af-user-bits'), ['int'])),
                                                            ('nexthop_label', (YLeaf(YType.uint32, 'nexthop-label'), ['int'])),
                                                            ('gateway_flags', (YLeaf(YType.uint32, 'gateway-flags'), ['int'])),
                                                        ])
                                                        self.nexthop_id = None
                                                        self.nexthop_version = None
                                                        self.nexthop_flags = None
                                                        self.nexthop_if_handle = None
                                                        self.nexthop_af_user_bits = None
                                                        self.nexthop_label = None
                                                        self.gateway_flags = None

                                                        self.nexthop_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                        self.nexthop_address.parent = self
                                                        self._children_name_map["nexthop_address"] = "nexthop-address"

                                                        self.nexthop_metrice = YList(self)
                                                        self.nexthop_refcount = YList(self)
                                                        self.nexthop_gateway_internal_info = YList(self)
                                                        self._segment_path = lambda: "nexthop-internal-info"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, [u'nexthop_id', u'nexthop_version', u'nexthop_flags', u'nexthop_if_handle', u'nexthop_af_user_bits', u'nexthop_label', u'gateway_flags'], name, value)


                                                    class NexthopAddress(Entity):
                                                        """
                                                        Nexthop address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, self).__init__()

                                                            self.yang_name = "nexthop-address"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "nexthop-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                    class NexthopMetrice(Entity):
                                                        """
                                                        Nexthop metrices
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, self).__init__()

                                                            self.yang_name = "nexthop-metrice"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "nexthop-metrice"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, [u'entry'], name, value)


                                                    class NexthopRefcount(Entity):
                                                        """
                                                        Nexthop refcounts
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, self).__init__()

                                                            self.yang_name = "nexthop-refcount"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "nexthop-refcount"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, [u'entry'], name, value)


                                                    class NexthopGatewayInternalInfo(Entity):
                                                        """
                                                        Internal nexthop Gateway info
                                                        
                                                        .. attribute:: gateway_flags
                                                        
                                                        	Gateway flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: registration_type
                                                        
                                                        	Nexthop registration type
                                                        	**type**\:  :py:class:`BgpNhValidate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidate>`
                                                        
                                                        .. attribute:: registration_since
                                                        
                                                        	Time since registration
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, self).__init__()

                                                            self.yang_name = "nexthop-gateway-internal-info"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('gateway_flags', (YLeaf(YType.uint32, 'gateway-flags'), ['int'])),
                                                                ('registration_type', (YLeaf(YType.enumeration, 'registration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhValidate', '')])),
                                                                ('registration_since', (YLeaf(YType.uint32, 'registration-since'), ['int'])),
                                                            ])
                                                            self.gateway_flags = None
                                                            self.registration_type = None
                                                            self.registration_since = None
                                                            self._segment_path = lambda: "nexthop-gateway-internal-info"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, [u'gateway_flags', u'registration_type', u'registration_since'], name, value)


                                                class NexthopGatewayInfo(Entity):
                                                    """
                                                    Gateway related info, includingOptimal Route
                                                    Reflector Gateways
                                                    
                                                    .. attribute:: nexthop_route
                                                    
                                                    	Route resolving the nethop
                                                    	**type**\:  :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                    
                                                    .. attribute:: nexthop_route_prefix_length
                                                    
                                                    	Prefix length of the route resolving the nexthop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_route_protocol
                                                    
                                                    	Protocol that resolves the route to the nexthop
                                                    	**type**\: str
                                                    
                                                    .. attribute:: nexthop_route_path_count
                                                    
                                                    	Number of paths in the resolving route
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_af_invalid_bits
                                                    
                                                    	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: nexthop_status
                                                    
                                                    	Nexthop status
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_tableid
                                                    
                                                    	Nexthop Table id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: nexthop_metric
                                                    
                                                    	IGP metric for nexthop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_type
                                                    
                                                    	Last nexthop event type
                                                    	**type**\:  :py:class:`BgpNhEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEvent>`
                                                    
                                                    .. attribute:: last_update_type
                                                    
                                                    	Last nexthop update type
                                                    	**type**\:  :py:class:`BgpNhUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdate>`
                                                    
                                                    .. attribute:: critical_events
                                                    
                                                    	Number of critical events received from RIB
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: non_critical_events
                                                    
                                                    	Number of non\-critical events received from RIB
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_since
                                                    
                                                    	Time since the last event sent to or received from RIB
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_rib_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_enabled
                                                    
                                                    	TRUE if MPLS is configured for IAS/CsC application
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nexthop_mpls_interfaces
                                                    
                                                    	Number of interfaces on which MPLS is enabled
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_label
                                                    
                                                    	Local label allocated for IAS/CsC application
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_route_path
                                                    
                                                    	Nexthops of the resolving route
                                                    	**type**\: list of  		 :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, self).__init__()

                                                        self.yang_name = "nexthop-gateway-info"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("nexthop-route", ("nexthop_route", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute)), ("nexthop-route-path", ("nexthop_route_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath))])
                                                        self._leafs = OrderedDict([
                                                            ('nexthop_route_prefix_length', (YLeaf(YType.uint8, 'nexthop-route-prefix-length'), ['int'])),
                                                            ('nexthop_route_protocol', (YLeaf(YType.str, 'nexthop-route-protocol'), ['str'])),
                                                            ('nexthop_route_path_count', (YLeaf(YType.uint32, 'nexthop-route-path-count'), ['int'])),
                                                            ('nexthop_af_invalid_bits', (YLeaf(YType.uint16, 'nexthop-af-invalid-bits'), ['int'])),
                                                            ('nexthop_status', (YLeaf(YType.uint8, 'nexthop-status'), ['int'])),
                                                            ('nexthop_tableid', (YLeaf(YType.uint64, 'nexthop-tableid'), ['int'])),
                                                            ('nexthop_metric', (YLeaf(YType.uint32, 'nexthop-metric'), ['int'])),
                                                            ('last_event_type', (YLeaf(YType.enumeration, 'last-event-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhEvent', '')])),
                                                            ('last_update_type', (YLeaf(YType.enumeration, 'last-update-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhUpdate', '')])),
                                                            ('critical_events', (YLeaf(YType.uint32, 'critical-events'), ['int'])),
                                                            ('non_critical_events', (YLeaf(YType.uint32, 'non-critical-events'), ['int'])),
                                                            ('last_event_since', (YLeaf(YType.uint32, 'last-event-since'), ['int'])),
                                                            ('last_rib_update', (YLeaf(YType.uint32, 'last-rib-update'), ['int'])),
                                                            ('nexthop_mpls_enabled', (YLeaf(YType.boolean, 'nexthop-mpls-enabled'), ['bool'])),
                                                            ('nexthop_mpls_interfaces', (YLeaf(YType.uint32, 'nexthop-mpls-interfaces'), ['int'])),
                                                            ('nexthop_mpls_label', (YLeaf(YType.uint32, 'nexthop-mpls-label'), ['int'])),
                                                        ])
                                                        self.nexthop_route_prefix_length = None
                                                        self.nexthop_route_protocol = None
                                                        self.nexthop_route_path_count = None
                                                        self.nexthop_af_invalid_bits = None
                                                        self.nexthop_status = None
                                                        self.nexthop_tableid = None
                                                        self.nexthop_metric = None
                                                        self.last_event_type = None
                                                        self.last_update_type = None
                                                        self.critical_events = None
                                                        self.non_critical_events = None
                                                        self.last_event_since = None
                                                        self.last_rib_update = None
                                                        self.nexthop_mpls_enabled = None
                                                        self.nexthop_mpls_interfaces = None
                                                        self.nexthop_mpls_label = None

                                                        self.nexthop_route = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                        self.nexthop_route.parent = self
                                                        self._children_name_map["nexthop_route"] = "nexthop-route"

                                                        self.nexthop_route_path = YList(self)
                                                        self._segment_path = lambda: "nexthop-gateway-info"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, [u'nexthop_route_prefix_length', u'nexthop_route_protocol', u'nexthop_route_path_count', u'nexthop_af_invalid_bits', u'nexthop_status', u'nexthop_tableid', u'nexthop_metric', u'last_event_type', u'last_update_type', u'critical_events', u'non_critical_events', u'last_event_since', u'last_rib_update', u'nexthop_mpls_enabled', u'nexthop_mpls_interfaces', u'nexthop_mpls_label'], name, value)


                                                    class NexthopRoute(Entity):
                                                        """
                                                        Route resolving the nethop
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, self).__init__()

                                                            self.yang_name = "nexthop-route"
                                                            self.yang_parent_name = "nexthop-gateway-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "nexthop-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                    class NexthopRoutePath(Entity):
                                                        """
                                                        Nexthops of the resolving route
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, self).__init__()

                                                            self.yang_name = "nexthop-route-path"
                                                            self.yang_parent_name = "nexthop-gateway-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "nexthop-route-path"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address List
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class RtSetCounters(Entity):
                                    """
                                    The RT\-set counter table
                                    
                                    .. attribute:: rt_set_counter
                                    
                                    	One RT\-set counter table entry
                                    	**type**\: list of  		 :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters, self).__init__()

                                        self.yang_name = "rt-set-counters"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rt-set-counter", ("rt_set_counter", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter))])
                                        self._leafs = OrderedDict()

                                        self.rt_set_counter = YList(self)
                                        self._segment_path = lambda: "rt-set-counters"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters, [], name, value)


                                    class RtSetCounter(Entity):
                                        """
                                        One RT\-set counter table entry
                                        
                                        .. attribute:: rt_set_id  (key)
                                        
                                        	RTSet ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_target_set
                                        
                                        	Route Target set
                                        	**type**\:  :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter, self).__init__()

                                            self.yang_name = "rt-set-counter"
                                            self.yang_parent_name = "rt-set-counters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['rt_set_id']
                                            self._child_classes = OrderedDict([("route-target-set", ("route_target_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet))])
                                            self._leafs = OrderedDict([
                                                ('rt_set_id', (YLeaf(YType.uint32, 'rt-set-id'), ['int'])),
                                            ])
                                            self.rt_set_id = None

                                            self.route_target_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                            self.route_target_set.parent = self
                                            self._children_name_map["route_target_set"] = "route-target-set"
                                            self._segment_path = lambda: "rt-set-counter" + "[rt-set-id='" + str(self.rt_set_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter, ['rt_set_id'], name, value)


                                        class RouteTargetSet(Entity):
                                            """
                                            Route Target set
                                            
                                            .. attribute:: rt_set_len
                                            
                                            	Length in bytes of set of route targets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rt_set_id
                                            
                                            	Identifier of the rtset
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rt_set_net_count
                                            
                                            	Count of nets with paths with the rtset
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rt_set
                                            
                                            	Set of route targets
                                            	**type**\: list of  		 :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, self).__init__()

                                                self.yang_name = "route-target-set"
                                                self.yang_parent_name = "rt-set-counter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rt-set", ("rt_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet))])
                                                self._leafs = OrderedDict([
                                                    ('rt_set_len', (YLeaf(YType.uint8, 'rt-set-len'), ['int'])),
                                                    ('rt_set_id', (YLeaf(YType.uint32, 'rt-set-id'), ['int'])),
                                                    ('rt_set_net_count', (YLeaf(YType.uint32, 'rt-set-net-count'), ['int'])),
                                                ])
                                                self.rt_set_len = None
                                                self.rt_set_id = None
                                                self.rt_set_net_count = None

                                                self.rt_set = YList(self)
                                                self._segment_path = lambda: "route-target-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, [u'rt_set_len', u'rt_set_id', u'rt_set_net_count'], name, value)


                                            class RtSet(Entity):
                                                """
                                                Set of route targets
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, self).__init__()

                                                    self.yang_name = "rt-set"
                                                    self.yang_parent_name = "route-target-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rt-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, [u'entry'], name, value)


                                class BmpPaths(Entity):
                                    """
                                    The paths in BMP Table
                                    
                                    .. attribute:: bmp_path
                                    
                                    	A BMP path table entry
                                    	**type**\: list of  		 :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths, self).__init__()

                                        self.yang_name = "bmp-paths"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bmp-path", ("bmp_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath))])
                                        self._leafs = OrderedDict()

                                        self.bmp_path = YList(self)
                                        self._segment_path = lambda: "bmp-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths, [], name, value)


                                    class BmpPath(Entity):
                                        """
                                        A BMP path table entry
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Net Version bump timestamp
                                        	**type**\:  :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                        
                                        .. attribute:: version_age
                                        
                                        	Net Version bump age
                                        	**type**\:  :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: bmp_net_flags
                                        
                                        	Flags associated with net
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_net_version
                                        
                                        	Net's version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for the net
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path
                                        
                                        	List of paths under the BMP net
                                        	**type**\: list of  		 :py:class:`BmpPath_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath, self).__init__()

                                            self.yang_name = "bmp-path"
                                            self.yang_parent_name = "bmp-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix)), ("version-timestamp", ("version_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp)), ("version-age", ("version_age", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge)), ("bmp-path", ("bmp_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_))])
                                            self._leafs = OrderedDict([
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('bmp_net_flags', (YLeaf(YType.uint32, 'bmp-net-flags'), ['int'])),
                                                ('bmp_net_version', (YLeaf(YType.uint32, 'bmp-net-version'), ['int'])),
                                                ('num_of_path', (YLeaf(YType.uint32, 'num-of-path'), ['int'])),
                                                ('has_local_label', (YLeaf(YType.boolean, 'has-local-label'), ['bool'])),
                                                ('net_local_label', (YLeaf(YType.uint32, 'net-local-label'), ['int'])),
                                            ])
                                            self.network = None
                                            self.prefix_length = None
                                            self.af_name = None
                                            self.bmp_net_flags = None
                                            self.bmp_net_version = None
                                            self.num_of_path = None
                                            self.has_local_label = None
                                            self.net_local_label = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self._children_name_map["version_timestamp"] = "version-timestamp"

                                            self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                            self.version_age.parent = self
                                            self._children_name_map["version_age"] = "version-age"

                                            self.bmp_path = YList(self)
                                            self._segment_path = lambda: "bmp-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath, ['network', 'prefix_length', u'af_name', u'bmp_net_flags', u'bmp_net_version', u'num_of_path', u'has_local_label', u'net_local_label'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VersionTimestamp(Entity):
                                            """
                                            Net Version bump timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, self).__init__()

                                                self.yang_name = "version-timestamp"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class VersionAge(Entity):
                                            """
                                            Net Version bump age
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge, self).__init__()

                                                self.yang_name = "version-age"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-age"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge, [u'seconds', u'nanoseconds'], name, value)


                                        class BmpPath_(Entity):
                                            """
                                            List of paths under the BMP net
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress>`
                                            
                                            .. attribute:: bmp_path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_path_adv_bit_map
                                            
                                            	Path's Adv bit map
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bmp_path_snd_bit_map
                                            
                                            	Path's pending snd bit map
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bmp_nbr_bit_map
                                            
                                            	Paths Nbr bmp bit map
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path
                                            
                                            	Is path originated locally?
                                            	**type**\: bool
                                            
                                            .. attribute:: bpath_pointer
                                            
                                            	BGP Path pointer
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: received_label
                                            
                                            	Set of received label stack
                                            	**type**\: list of  		 :py:class:`ReceivedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_, self).__init__()

                                                self.yang_name = "bmp-path"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress)), ("received-label", ("received_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel))])
                                                self._leafs = OrderedDict([
                                                    ('bmp_path_flags', (YLeaf(YType.uint32, 'bmp-path-flags'), ['int'])),
                                                    ('bmp_path_adv_bit_map', (YLeaf(YType.uint16, 'bmp-path-adv-bit-map'), ['int'])),
                                                    ('bmp_path_snd_bit_map', (YLeaf(YType.uint16, 'bmp-path-snd-bit-map'), ['int'])),
                                                    ('bmp_nbr_bit_map', (YLeaf(YType.uint32, 'bmp-nbr-bit-map'), ['int'])),
                                                    ('local_path', (YLeaf(YType.boolean, 'local-path'), ['bool'])),
                                                    ('bpath_pointer', (YLeaf(YType.uint64, 'bpath-pointer'), ['int'])),
                                                ])
                                                self.bmp_path_flags = None
                                                self.bmp_path_adv_bit_map = None
                                                self.bmp_path_snd_bit_map = None
                                                self.bmp_nbr_bit_map = None
                                                self.local_path = None
                                                self.bpath_pointer = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.received_label = YList(self)
                                                self._segment_path = lambda: "bmp-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_, [u'bmp_path_flags', u'bmp_path_adv_bit_map', u'bmp_path_snd_bit_map', u'bmp_nbr_bit_map', u'local_path', u'bpath_pointer'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bmp-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class ReceivedLabel(Entity):
                                                """
                                                Set of received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel, self).__init__()

                                                    self.yang_name = "received-label"
                                                    self.yang_parent_name = "bmp-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "received-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel, [u'entry'], name, value)


                                class UpdateGenerationUpdateGroups(Entity):
                                    """
                                    Update generation for all update\-groups
                                    
                                    .. attribute:: update_generation_update_group
                                    
                                    	Update generation for update\-group
                                    	**type**\: list of  		 :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups, self).__init__()

                                        self.yang_name = "update-generation-update-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-generation-update-group", ("update_generation_update_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.update_generation_update_group = YList(self)
                                        self._segment_path = lambda: "update-generation-update-groups"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups, [], name, value)


                                    class UpdateGenerationUpdateGroup(Entity):
                                        """
                                        Update generation for update\-group
                                        
                                        .. attribute:: update_group_index  (key)
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_timer_start_timestamp
                                        
                                        	Last update timer start time
                                        	**type**\:  :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                        
                                        .. attribute:: last_update_timer_stop_timestamp
                                        
                                        	Last update timer stop time
                                        	**type**\:  :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                        
                                        .. attribute:: last_update_timer_expiry_timestamp
                                        
                                        	Last update timer expiry time
                                        	**type**\:  :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                        
                                        .. attribute:: last_update_timer_remaining_value
                                        
                                        	Update timer remaining time
                                        	**type**\:  :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                        
                                        .. attribute:: last_update_timer_delay_value
                                        
                                        	Last update timer delay value
                                        	**type**\:  :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: neighbor_session_af_name
                                        
                                        	Neighbor session address family
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_flags2
                                        
                                        	Update\-group internal flags2
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue Size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_sub_group_count
                                        
                                        	Sub\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_throttled_count
                                        
                                        	Throttled sub\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_throttled_count
                                        
                                        	Throttled refresh sub\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_leaving_count
                                        
                                        	Count of neighbors leaving the update\-group
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_recovery_pending
                                        
                                        	Is update generation recovery pending
                                        	**type**\: bool
                                        
                                        .. attribute:: last_update_timer_expiry_age
                                        
                                        	Time since last update timer expiry event
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_update_timer_running
                                        
                                        	Is update timer running
                                        	**type**\: bool
                                        
                                        .. attribute:: perm_pelem_encountered
                                        
                                        	Count of Perm Pelems seen by updgen
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_allowed
                                        
                                        	Count of Perm Pelems allowed by updgen
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_not_allowed
                                        
                                        	Count of Perm Pelems not allowed by updgen
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_exp_wdr
                                        
                                        	Count of Perm Pelems explicitly wdrn by updgen
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_spur_wdr
                                        
                                        	Count of Perm Pelems Spurious withdraws by updgen
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_permanent
                                        
                                        	Permanent UG check
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, self).__init__()

                                            self.yang_name = "update-generation-update-group"
                                            self.yang_parent_name = "update-generation-update-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['update_group_index']
                                            self._child_classes = OrderedDict([("last-update-timer-start-timestamp", ("last_update_timer_start_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp)), ("last-update-timer-stop-timestamp", ("last_update_timer_stop_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp)), ("last-update-timer-expiry-timestamp", ("last_update_timer_expiry_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp)), ("last-update-timer-remaining-value", ("last_update_timer_remaining_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue)), ("last-update-timer-delay-value", ("last_update_timer_delay_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics))])
                                            self._leafs = OrderedDict([
                                                ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                                ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('neighbor_session_af_name', (YLeaf(YType.uint8, 'neighbor-session-af-name'), ['int'])),
                                                ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                                ('update_group_flags2', (YLeaf(YType.uint32, 'update-group-flags2'), ['int'])),
                                                ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                                ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                                ('update_sub_group_count', (YLeaf(YType.uint32, 'update-sub-group-count'), ['int'])),
                                                ('sub_group_throttled_count', (YLeaf(YType.uint32, 'sub-group-throttled-count'), ['int'])),
                                                ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                                ('refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'refresh-sub-group-throttled-count'), ['int'])),
                                                ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                                ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                                ('neighbor_leaving_count', (YLeaf(YType.uint32, 'neighbor-leaving-count'), ['int'])),
                                                ('update_generation_recovery_pending', (YLeaf(YType.boolean, 'update-generation-recovery-pending'), ['bool'])),
                                                ('last_update_timer_expiry_age', (YLeaf(YType.uint32, 'last-update-timer-expiry-age'), ['int'])),
                                                ('is_update_timer_running', (YLeaf(YType.boolean, 'is-update-timer-running'), ['bool'])),
                                                ('perm_pelem_encountered', (YLeaf(YType.uint32, 'perm-pelem-encountered'), ['int'])),
                                                ('perm_pelem_allowed', (YLeaf(YType.uint32, 'perm-pelem-allowed'), ['int'])),
                                                ('perm_pelem_not_allowed', (YLeaf(YType.uint32, 'perm-pelem-not-allowed'), ['int'])),
                                                ('perm_pelem_exp_wdr', (YLeaf(YType.uint32, 'perm-pelem-exp-wdr'), ['int'])),
                                                ('perm_pelem_spur_wdr', (YLeaf(YType.uint32, 'perm-pelem-spur-wdr'), ['int'])),
                                                ('is_permanent', (YLeaf(YType.boolean, 'is-permanent'), ['bool'])),
                                            ])
                                            self.update_group_index = None
                                            self.process_id = None
                                            self.update_vrf_name = None
                                            self.update_group_af_name = None
                                            self.neighbor_session_af_name = None
                                            self.update_group_index_xr = None
                                            self.update_group_flags2 = None
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.update_sub_group_count = None
                                            self.sub_group_throttled_count = None
                                            self.refresh_sub_group_count = None
                                            self.refresh_sub_group_throttled_count = None
                                            self.filter_group_count = None
                                            self.neighbor_count = None
                                            self.neighbor_leaving_count = None
                                            self.update_generation_recovery_pending = None
                                            self.last_update_timer_expiry_age = None
                                            self.is_update_timer_running = None
                                            self.perm_pelem_encountered = None
                                            self.perm_pelem_allowed = None
                                            self.perm_pelem_not_allowed = None
                                            self.perm_pelem_exp_wdr = None
                                            self.perm_pelem_spur_wdr = None
                                            self.is_permanent = None

                                            self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                            self.last_update_timer_start_timestamp.parent = self
                                            self._children_name_map["last_update_timer_start_timestamp"] = "last-update-timer-start-timestamp"

                                            self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                            self.last_update_timer_stop_timestamp.parent = self
                                            self._children_name_map["last_update_timer_stop_timestamp"] = "last-update-timer-stop-timestamp"

                                            self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                            self.last_update_timer_expiry_timestamp.parent = self
                                            self._children_name_map["last_update_timer_expiry_timestamp"] = "last-update-timer-expiry-timestamp"

                                            self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                            self.last_update_timer_remaining_value.parent = self
                                            self._children_name_map["last_update_timer_remaining_value"] = "last-update-timer-remaining-value"

                                            self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                            self.last_update_timer_delay_value.parent = self
                                            self._children_name_map["last_update_timer_delay_value"] = "last-update-timer-delay-value"

                                            self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._segment_path = lambda: "update-generation-update-group" + "[update-group-index='" + str(self.update_group_index) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, ['update_group_index', u'process_id', u'update_vrf_name', u'update_group_af_name', u'neighbor_session_af_name', u'update_group_index_xr', u'update_group_flags2', u'update_out_queue_messages', u'update_out_queue_size', u'update_sub_group_count', u'sub_group_throttled_count', u'refresh_sub_group_count', u'refresh_sub_group_throttled_count', u'filter_group_count', u'neighbor_count', u'neighbor_leaving_count', u'update_generation_recovery_pending', u'last_update_timer_expiry_age', u'is_update_timer_running', u'perm_pelem_encountered', u'perm_pelem_allowed', u'perm_pelem_not_allowed', u'perm_pelem_exp_wdr', u'perm_pelem_spur_wdr', u'is_permanent'], name, value)


                                        class LastUpdateTimerStartTimestamp(Entity):
                                            """
                                            Last update timer start time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-start-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-timer-start-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateTimerStopTimestamp(Entity):
                                            """
                                            Last update timer stop time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-stop-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-timer-stop-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateTimerExpiryTimestamp(Entity):
                                            """
                                            Last update timer expiry time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-expiry-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-timer-expiry-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateTimerRemainingValue(Entity):
                                            """
                                            Update timer remaining time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, self).__init__()

                                                self.yang_name = "last-update-timer-remaining-value"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-timer-remaining-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateTimerDelayValue(Entity):
                                            """
                                            Last update timer delay value
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, self).__init__()

                                                self.yang_name = "last-update-timer-delay-value"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-timer-delay-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, [u'seconds', u'nanoseconds'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                                self._leafs = OrderedDict([
                                                    ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                    ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                    ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                    ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                    ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                    ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                    ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                    ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                    ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                    ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                    ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                    ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                    ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                    ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                    ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                    ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                                ])
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_size_high = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_cleared = None
                                                self.last_update_discard_age = None
                                                self.last_update_cleard_age = None
                                                self.update_throttle_count = None
                                                self.last_update_throttle_age = None
                                                self.update_recovery_count = None
                                                self.last_update_recovery_age = None
                                                self.update_memory_allocation_fail_count = None
                                                self.last_update_memory_allocation_fail_age = None

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._segment_path = lambda: "update-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-discard-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateGenerationFilterGroups(Entity):
                                    """
                                    Update generation for all filter\-groups under
                                    a sub\-group
                                    
                                    .. attribute:: update_generation_filter_group
                                    
                                    	Update generation for filter\-group
                                    	**type**\: list of  		 :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups, self).__init__()

                                        self.yang_name = "update-generation-filter-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-generation-filter-group", ("update_generation_filter_group", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup))])
                                        self._leafs = OrderedDict()

                                        self.update_generation_filter_group = YList(self)
                                        self._segment_path = lambda: "update-generation-filter-groups"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups, [], name, value)


                                    class UpdateGenerationFilterGroup(Entity):
                                        """
                                        Update generation for filter\-group
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_filter_group_index
                                        
                                        	Parent Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, self).__init__()

                                            self.yang_name = "update-generation-filter-group"
                                            self.yang_parent_name = "update-generation-filter-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                                ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                                ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                                ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                                ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('update_filter_group_index', (YLeaf(YType.uint32, 'update-filter-group-index'), ['int'])),
                                                ('parent_filter_group_index', (YLeaf(YType.uint32, 'parent-filter-group-index'), ['int'])),
                                                ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                                ('sub_group_id_xr', (YLeaf(YType.uint32, 'sub-group-id-xr'), ['int'])),
                                                ('parent_sub_group_index', (YLeaf(YType.uint32, 'parent-sub-group-index'), ['int'])),
                                                ('parent_sub_group_id', (YLeaf(YType.uint32, 'parent-sub-group-id'), ['int'])),
                                                ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                                ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                            ])
                                            self.update_group_index = None
                                            self.sub_group_index = None
                                            self.sub_group_id = None
                                            self.filter_group_index = None
                                            self.process_id = None
                                            self.update_vrf_name = None
                                            self.update_group_af_name = None
                                            self.update_filter_group_index = None
                                            self.parent_filter_group_index = None
                                            self.sub_group_index_xr = None
                                            self.sub_group_id_xr = None
                                            self.parent_sub_group_index = None
                                            self.parent_sub_group_id = None
                                            self.update_group_index_xr = None
                                            self.neighbor_count = None
                                            self._segment_path = lambda: "update-generation-filter-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, ['update_group_index', 'sub_group_index', 'sub_group_id', 'filter_group_index', u'process_id', u'update_vrf_name', u'update_group_af_name', u'update_filter_group_index', u'parent_filter_group_index', u'sub_group_index_xr', u'sub_group_id_xr', u'parent_sub_group_index', u'parent_sub_group_id', u'update_group_index_xr', u'neighbor_count'], name, value)


                                class Networks(Entity):
                                    """
                                    The BGP Network Table
                                    
                                    .. attribute:: network
                                    
                                    	A BGP Network table entry
                                    	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks, self).__init__()

                                        self.yang_name = "networks"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("network", ("network", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network))])
                                        self._leafs = OrderedDict()

                                        self.network = YList(self)
                                        self._segment_path = lambda: "networks"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks, [], name, value)


                                    class Network(Entity):
                                        """
                                        A BGP Network table entry
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Version timestamp
                                        	**type**\:  :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                        
                                        .. attribute:: version_age
                                        
                                        	Version age
                                        	**type**\:  :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: has_inconsistent_paths
                                        
                                        	Net has inconsistent paths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_net_aggregation_suppressed
                                        
                                        	Net suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_net_ldp_signaled
                                        
                                        	L2VPN Net LDP signaled  aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version # for net
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Table version # for updates
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label_rewrite
                                        
                                        	Net label has rewrite
                                        	**type**\: bool
                                        
                                        .. attribute:: net_local_label_srgb
                                        
                                        	Net label allocated fromSegment routing global block
                                        	**type**\: bool
                                        
                                        .. attribute:: has_lbl_retained
                                        
                                        	Net has label retained
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: net_flags
                                        
                                        	Flags associated with                            net
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_extended_flags
                                        
                                        	Net extended flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_multipath
                                        
                                        	Net has multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: net_eibgp_multipath
                                        
                                        	Net has EIBGP multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: net_backup_available
                                        
                                        	Net has backup path
                                        	**type**\: bool
                                        
                                        .. attribute:: net_backup_label_rewrite_available
                                        
                                        	Net has label rewrite for backup path
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	RIB install failed
                                        	**type**\: bool
                                        
                                        .. attribute:: gateway_array
                                        
                                        	Gateway array ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: resilient_nexthop_set
                                        
                                        	Resilient nexthop set ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_permanent_network
                                        
                                        	Permanent Network
                                        	**type**\: bool
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for this net
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bit
                                        
                                        	Bit
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Flags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: has_s_rv6sid_allocated
                                        
                                        	Net has SRv6 SID allocated
                                        	**type**\: bool
                                        
                                        .. attribute:: srv6sid_address
                                        
                                        	SRv6 SID address value
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: srv6sid_address_len
                                        
                                        	SRv6 SID address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                        
                                        .. attribute:: local_process_instance_path
                                        
                                        	Local (to process instance) paths for this net 
                                        	**type**\: list of  		 :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                        
                                        .. attribute:: active_process_instance_path
                                        
                                        	Active's paths for this net 
                                        	**type**\: list of  		 :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                        
                                        .. attribute:: local_path_element
                                        
                                        	Local path element list
                                        	**type**\: list of  		 :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement>`
                                        
                                        .. attribute:: active_path_element
                                        
                                        	Path element list received from Active inst
                                        	**type**\: list of  		 :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "networks"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix)), ("version-timestamp", ("version_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp)), ("version-age", ("version_age", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield)), ("local-process-instance-path", ("local_process_instance_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath)), ("active-process-instance-path", ("active_process_instance_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath)), ("local-path-element", ("local_path_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement)), ("active-path-element", ("active_path_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('has_inconsistent_paths', (YLeaf(YType.boolean, 'has-inconsistent-paths'), ['bool'])),
                                                ('is_net_aggregation_suppressed', (YLeaf(YType.boolean, 'is-net-aggregation-suppressed'), ['bool'])),
                                                ('is_net_ldp_signaled', (YLeaf(YType.boolean, 'is-net-ldp-signaled'), ['bool'])),
                                                ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                                ('table_brib_version', (YLeaf(YType.uint32, 'table-brib-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('has_local_label', (YLeaf(YType.boolean, 'has-local-label'), ['bool'])),
                                                ('net_local_label', (YLeaf(YType.uint32, 'net-local-label'), ['int'])),
                                                ('net_local_label_rewrite', (YLeaf(YType.boolean, 'net-local-label-rewrite'), ['bool'])),
                                                ('net_local_label_srgb', (YLeaf(YType.boolean, 'net-local-label-srgb'), ['bool'])),
                                                ('has_lbl_retained', (YLeaf(YType.boolean, 'has-lbl-retained'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('net_flags', (YLeaf(YType.uint32, 'net-flags'), ['int'])),
                                                ('net_extended_flags', (YLeaf(YType.uint32, 'net-extended-flags'), ['int'])),
                                                ('net_multipath', (YLeaf(YType.boolean, 'net-multipath'), ['bool'])),
                                                ('net_eibgp_multipath', (YLeaf(YType.boolean, 'net-eibgp-multipath'), ['bool'])),
                                                ('net_backup_available', (YLeaf(YType.boolean, 'net-backup-available'), ['bool'])),
                                                ('net_backup_label_rewrite_available', (YLeaf(YType.boolean, 'net-backup-label-rewrite-available'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('gateway_array', (YLeaf(YType.uint32, 'gateway-array'), ['int'])),
                                                ('resilient_nexthop_set', (YLeaf(YType.uint32, 'resilient-nexthop-set'), ['int'])),
                                                ('is_permanent_network', (YLeaf(YType.boolean, 'is-permanent-network'), ['bool'])),
                                                ('num_of_path', (YLeaf(YType.uint32, 'num-of-path'), ['int'])),
                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                ('bit', (YLeaf(YType.uint16, 'bit'), ['int'])),
                                                ('flags', (YLeaf(YType.uint8, 'flags'), ['int'])),
                                                ('has_s_rv6sid_allocated', (YLeaf(YType.boolean, 'has-s-rv6sid-allocated'), ['bool'])),
                                                ('srv6sid_address', (YLeaf(YType.str, 'srv6sid-address'), ['str'])),
                                                ('srv6sid_address_len', (YLeaf(YType.uint32, 'srv6sid-address-len'), ['int'])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.has_inconsistent_paths = None
                                            self.is_net_aggregation_suppressed = None
                                            self.is_net_ldp_signaled = None
                                            self.table_version = None
                                            self.table_brib_version = None
                                            self.advertisedto_pe = None
                                            self.has_local_label = None
                                            self.net_local_label = None
                                            self.net_local_label_rewrite = None
                                            self.net_local_label_srgb = None
                                            self.has_lbl_retained = None
                                            self.route_distinguisher = None
                                            self.vrf_name = None
                                            self.net_flags = None
                                            self.net_extended_flags = None
                                            self.net_multipath = None
                                            self.net_eibgp_multipath = None
                                            self.net_backup_available = None
                                            self.net_backup_label_rewrite_available = None
                                            self.rib_failed = None
                                            self.gateway_array = None
                                            self.resilient_nexthop_set = None
                                            self.is_permanent_network = None
                                            self.num_of_path = None
                                            self.version = None
                                            self.bit = None
                                            self.flags = None
                                            self.has_s_rv6sid_allocated = None
                                            self.srv6sid_address = None
                                            self.srv6sid_address_len = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.version_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self._children_name_map["version_timestamp"] = "version-timestamp"

                                            self.version_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge()
                                            self.version_age.parent = self
                                            self._children_name_map["version_age"] = "version-age"

                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self.local_process_instance_path = YList(self)
                                            self.active_process_instance_path = YList(self)
                                            self.local_path_element = YList(self)
                                            self.active_path_element = YList(self)
                                            self._segment_path = lambda: "network"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network, ['rd', 'network', 'prefix_length', u'af_name', u'process_instance_id', u'has_inconsistent_paths', u'is_net_aggregation_suppressed', u'is_net_ldp_signaled', u'table_version', u'table_brib_version', u'advertisedto_pe', u'has_local_label', u'net_local_label', u'net_local_label_rewrite', u'net_local_label_srgb', u'has_lbl_retained', u'route_distinguisher', u'vrf_name', u'net_flags', u'net_extended_flags', u'net_multipath', u'net_eibgp_multipath', u'net_backup_available', u'net_backup_label_rewrite_available', u'rib_failed', u'gateway_array', u'resilient_nexthop_set', u'is_permanent_network', u'num_of_path', u'version', u'bit', u'flags', u'has_s_rv6sid_allocated', u'srv6sid_address', u'srv6sid_address_len'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VersionTimestamp(Entity):
                                            """
                                            Version timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp, self).__init__()

                                                self.yang_name = "version-timestamp"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class VersionAge(Entity):
                                            """
                                            Version age
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge, self).__init__()

                                                self.yang_name = "version-age"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-age"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge, [u'seconds', u'nanoseconds'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class LocalProcessInstancePath(Entity):
                                            """
                                            Local (to process instance) paths for this net 
                                            
                                            .. attribute:: advertised_neighbor
                                            
                                            	Advertised Neighbor Address. Valid in the case of Advertised table
                                            	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor>`
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                            	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\: bool
                                            
                                            .. attribute:: label_oor_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\: bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: original_source_route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\: str
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\: str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath, self).__init__()

                                                self.yang_name = "local-process-instance-path"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn))])
                                                self._leafs = OrderedDict([
                                                    ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                    ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                    ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                    ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                    ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                    ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                    ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.no_path = None
                                                self.af_name = None
                                                self.process_instance_id = None
                                                self.label_oor = None
                                                self.label_oor_version = None
                                                self.label_fail = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.original_source_route_distinguisher = None
                                                self.prefix_version = None
                                                self.vrf_name = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None

                                                self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor()
                                                self.advertised_neighbor.parent = self
                                                self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._segment_path = lambda: "local-process-instance-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                            class AdvertisedNeighbor(Entity):
                                                """
                                                Advertised Neighbor Address. Valid in the case
                                                of Advertised table
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor, self).__init__()

                                                    self.yang_name = "advertised-neighbor"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "advertised-neighbor"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\: bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\: bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgp
                                                
                                                	Not advertised to EBGPs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\: bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\: bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\: bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\: bool
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\: str
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\: bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\: bool
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\: bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\: bool
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_self_originated_path
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\: bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\: bool
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\: bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\: bool
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\: bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\: bool
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\: bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\: bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: mac_ip_present
                                                
                                                	Mac IP Present  present
                                                	**type**\: bool
                                                
                                                .. attribute:: mac_ip
                                                
                                                	Mac associated with IP
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue>`
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield))])
                                                    self._leafs = OrderedDict([
                                                        ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                        ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                        ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                        ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                        ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                        ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                        ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                        ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                        ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                        ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                        ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                        ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                        ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                        ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                        ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                        ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                        ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                        ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                        ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                        ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                        ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                        ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                        ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                        ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                        ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                        ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                        ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                        ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                        ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                        ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                        ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                        ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                        ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                        ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                        ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                        ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                        ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                        ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                        ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                        ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                        ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                        ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                        ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                        ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                        ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                        ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                        ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                        ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                        ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                        ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                        ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                        ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                        ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                        ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                        ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                        ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                        ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                        ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                        ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                        ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                        ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                        ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                        ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                        ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                        ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                        ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                        ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                        ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                        ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                        ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                        ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                        ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                        ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                        ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                        ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                        ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                        ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                        ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                        ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                        ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                        ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                        ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                        ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                        ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                        ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                        ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                        ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                        ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                        ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                        ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                        ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                        ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                        ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                        ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                        ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                    ])
                                                    self.route_type = None
                                                    self.is_path_valid = None
                                                    self.is_path_damped = None
                                                    self.is_path_history_held = None
                                                    self.is_internal_path = None
                                                    self.is_best_path = None
                                                    self.is_as_best = None
                                                    self.is_spkr_as_best = None
                                                    self.is_partial_best = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebgp = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_received_only = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_imported = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_vpn_only = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_multipath = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_stale = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.has_local_net_label = None
                                                    self.local_label = None
                                                    self.igp_metric = None
                                                    self.path_weight = None
                                                    self.neighbor_router_id = None
                                                    self.has_mdt_group_addr = None
                                                    self.l2vpn_size = None
                                                    self.l2vpn_evpn_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_nh_addr = None
                                                    self.has_second_label = None
                                                    self.second_label = None
                                                    self.path_flap_count = None
                                                    self.seconds_since_first_flap = None
                                                    self.time_to_unsuppress = None
                                                    self.dampen_penalty = None
                                                    self.halflife_time = None
                                                    self.suppress_penalty = None
                                                    self.reuse_value = None
                                                    self.maximum_suppress_time = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_id_comp_winner = None
                                                    self.path_flags = None
                                                    self.path_import_flags = None
                                                    self.best_path_id = None
                                                    self.local_path_id = None
                                                    self.rcvd_path_id = None
                                                    self.path_table_version = None
                                                    self.advertisedto_pe = None
                                                    self.rib_failed = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.ibgp_signaled_validity = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_path = None
                                                    self.aigp_metric = None
                                                    self.mvpn_sfs_path = None
                                                    self.fspec_invalid_path = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.has_mvpn_extcomm = None
                                                    self.mvpn_path_flags = None
                                                    self.local_nh = None
                                                    self.rt_set_limit_enabled = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_permanent_path = None
                                                    self.graceful_shutdown = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.has_vpn_nexthop_addr = None
                                                    self.is_orig_src_rd_present = None
                                                    self.af_name = None
                                                    self.route_distinguisher = None
                                                    self.mac_ip_present = None
                                                    self.mac_ip = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                    self.rcvd_label = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self._segment_path = lambda: "path-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mdt-group-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "gw-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "nh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "best-path-comp-winner"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nbr-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "vpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rcvd-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                                class L2vpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "mvpn-pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "local-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "pe-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "best-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "add-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied. In the
                                                case of path type received\-only this will be
                                                attributes before inbound policy
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\: bool
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\: bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp))])
                                                    self._leafs = OrderedDict([
                                                        ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                        ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                        ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                        ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                        ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                        ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                        ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                        ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                        ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                        ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                        ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                        ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                        ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                        ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                        ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                        ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                        ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                        ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                        ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                        ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                        ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                        ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                        ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                    ])
                                                    self.is_as_path2_byte = None
                                                    self.is_application_gateway_present = None
                                                    self.is_attr_set_present = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.is_rnh_present = None
                                                    self.is_ribrnh_present = None
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.vpn_distinguisher = None
                                                    self.rnh_type = None
                                                    self.rnh_len = None
                                                    self.rnh_addr_len = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_mac = None
                                                    self.ribrnhip_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnh_encap = None

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._segment_path = lambda: "attributes-after-policy-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "common-attributes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "attr-set"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.mac_address = None
                                                        self._segment_path = lambda: "rnh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "ribrnh-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class ActiveProcessInstancePath(Entity):
                                            """
                                            Active's paths for this net 
                                            
                                            .. attribute:: advertised_neighbor
                                            
                                            	Advertised Neighbor Address. Valid in the case of Advertised table
                                            	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor>`
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                            	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\: bool
                                            
                                            .. attribute:: label_oor_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\: bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: original_source_route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\: str
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\: str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, self).__init__()

                                                self.yang_name = "active-process-instance-path"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn))])
                                                self._leafs = OrderedDict([
                                                    ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                    ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                    ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                    ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                    ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                    ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                    ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.no_path = None
                                                self.af_name = None
                                                self.process_instance_id = None
                                                self.label_oor = None
                                                self.label_oor_version = None
                                                self.label_fail = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.original_source_route_distinguisher = None
                                                self.prefix_version = None
                                                self.vrf_name = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None

                                                self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor()
                                                self.advertised_neighbor.parent = self
                                                self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._segment_path = lambda: "active-process-instance-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                            class AdvertisedNeighbor(Entity):
                                                """
                                                Advertised Neighbor Address. Valid in the case
                                                of Advertised table
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor, self).__init__()

                                                    self.yang_name = "advertised-neighbor"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "advertised-neighbor"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\: bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\: bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgp
                                                
                                                	Not advertised to EBGPs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\: bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\: bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\: bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\: bool
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\: str
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\: bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\: bool
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\: bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\: bool
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_self_originated_path
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\: bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\: bool
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\: bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\: bool
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\: bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\: bool
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\: bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\: bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: mac_ip_present
                                                
                                                	Mac IP Present  present
                                                	**type**\: bool
                                                
                                                .. attribute:: mac_ip
                                                
                                                	Mac associated with IP
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue>`
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield))])
                                                    self._leafs = OrderedDict([
                                                        ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                        ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                        ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                        ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                        ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                        ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                        ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                        ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                        ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                        ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                        ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                        ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                        ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                        ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                        ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                        ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                        ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                        ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                        ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                        ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                        ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                        ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                        ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                        ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                        ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                        ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                        ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                        ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                        ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                        ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                        ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                        ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                        ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                        ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                        ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                        ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                        ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                        ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                        ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                        ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                        ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                        ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                        ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                        ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                        ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                        ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                        ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                        ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                        ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                        ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                        ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                        ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                        ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                        ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                        ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                        ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                        ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                        ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                        ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                        ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                        ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                        ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                        ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                        ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                        ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                        ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                        ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                        ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                        ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                        ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                        ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                        ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                        ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                        ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                        ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                        ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                        ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                        ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                        ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                        ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                        ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                        ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                        ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                        ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                        ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                        ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                        ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                        ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                        ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                        ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                        ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                        ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                        ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                        ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                        ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                    ])
                                                    self.route_type = None
                                                    self.is_path_valid = None
                                                    self.is_path_damped = None
                                                    self.is_path_history_held = None
                                                    self.is_internal_path = None
                                                    self.is_best_path = None
                                                    self.is_as_best = None
                                                    self.is_spkr_as_best = None
                                                    self.is_partial_best = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebgp = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_received_only = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_imported = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_vpn_only = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_multipath = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_stale = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.has_local_net_label = None
                                                    self.local_label = None
                                                    self.igp_metric = None
                                                    self.path_weight = None
                                                    self.neighbor_router_id = None
                                                    self.has_mdt_group_addr = None
                                                    self.l2vpn_size = None
                                                    self.l2vpn_evpn_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_nh_addr = None
                                                    self.has_second_label = None
                                                    self.second_label = None
                                                    self.path_flap_count = None
                                                    self.seconds_since_first_flap = None
                                                    self.time_to_unsuppress = None
                                                    self.dampen_penalty = None
                                                    self.halflife_time = None
                                                    self.suppress_penalty = None
                                                    self.reuse_value = None
                                                    self.maximum_suppress_time = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_id_comp_winner = None
                                                    self.path_flags = None
                                                    self.path_import_flags = None
                                                    self.best_path_id = None
                                                    self.local_path_id = None
                                                    self.rcvd_path_id = None
                                                    self.path_table_version = None
                                                    self.advertisedto_pe = None
                                                    self.rib_failed = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.ibgp_signaled_validity = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_path = None
                                                    self.aigp_metric = None
                                                    self.mvpn_sfs_path = None
                                                    self.fspec_invalid_path = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.has_mvpn_extcomm = None
                                                    self.mvpn_path_flags = None
                                                    self.local_nh = None
                                                    self.rt_set_limit_enabled = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_permanent_path = None
                                                    self.graceful_shutdown = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.has_vpn_nexthop_addr = None
                                                    self.is_orig_src_rd_present = None
                                                    self.af_name = None
                                                    self.route_distinguisher = None
                                                    self.mac_ip_present = None
                                                    self.mac_ip = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                    self.rcvd_label = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self._segment_path = lambda: "path-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mdt-group-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "gw-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "nh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "best-path-comp-winner"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nbr-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "vpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rcvd-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                                class L2vpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "mvpn-pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "local-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "pe-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "best-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "add-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied. In the
                                                case of path type received\-only this will be
                                                attributes before inbound policy
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\: bool
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\: bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp))])
                                                    self._leafs = OrderedDict([
                                                        ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                        ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                        ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                        ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                        ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                        ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                        ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                        ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                        ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                        ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                        ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                        ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                        ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                        ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                        ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                        ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                        ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                        ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                        ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                        ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                        ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                        ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                        ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                    ])
                                                    self.is_as_path2_byte = None
                                                    self.is_application_gateway_present = None
                                                    self.is_attr_set_present = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.is_rnh_present = None
                                                    self.is_ribrnh_present = None
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.vpn_distinguisher = None
                                                    self.rnh_type = None
                                                    self.rnh_len = None
                                                    self.rnh_addr_len = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_mac = None
                                                    self.ribrnhip_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnh_encap = None

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._segment_path = lambda: "attributes-after-policy-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "common-attributes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "attr-set"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.mac_address = None
                                                        self._segment_path = lambda: "rnh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "ribrnh-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class LocalPathElement(Entity):
                                            """
                                            Local path element list
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:  :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:  :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement, self).__init__()

                                                self.yang_name = "local-path-element"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("pelem-path-nexthop", ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel)), ("pelem-path-neighbor-addr", ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr))])
                                                self._leafs = OrderedDict([
                                                    ('pelem_path_id', (YLeaf(YType.uint32, 'pelem-path-id'), ['int'])),
                                                    ('pelem_version', (YLeaf(YType.uint32, 'pelem-version'), ['int'])),
                                                    ('pelem_flags', (YLeaf(YType.uint32, 'pelem-flags'), ['int'])),
                                                    ('pelem_gw_metric', (YLeaf(YType.uint32, 'pelem-gw-metric'), ['int'])),
                                                    ('pelem_path_flags', (YLeaf(YType.uint64, 'pelem-path-flags'), ['int'])),
                                                    ('pelem_path_peer_path_id', (YLeaf(YType.uint32, 'pelem-path-peer-path-id'), ['int'])),
                                                    ('pelem_table_attr_version', (YLeaf(YType.uint32, 'pelem-table-attr-version'), ['int'])),
                                                    ('pelem_path_table_attr_version', (YLeaf(YType.uint32, 'pelem-path-table-attr-version'), ['int'])),
                                                    ('pelem_no_bestpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-bestpath-table-attr-version'), ['int'])),
                                                    ('pelem_no_addpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-addpath-table-attr-version'), ['int'])),
                                                    ('is_perm_path_pelem', (YLeaf(YType.boolean, 'is-perm-path-pelem'), ['bool'])),
                                                ])
                                                self.pelem_path_id = None
                                                self.pelem_version = None
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.is_perm_path_pelem = None

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._segment_path = lambda: "local-path-element"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement, [u'pelem_path_id', u'pelem_version', u'pelem_flags', u'pelem_gw_metric', u'pelem_path_flags', u'pelem_path_peer_path_id', u'pelem_table_attr_version', u'pelem_path_table_attr_version', u'pelem_no_bestpath_table_attr_version', u'pelem_no_addpath_table_attr_version', u'is_perm_path_pelem'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "pelem-path-nexthop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class ActivePathElement(Entity):
                                            """
                                            Path element list received from Active inst
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:  :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:  :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement, self).__init__()

                                                self.yang_name = "active-path-element"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("pelem-path-nexthop", ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel)), ("pelem-path-neighbor-addr", ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr))])
                                                self._leafs = OrderedDict([
                                                    ('pelem_path_id', (YLeaf(YType.uint32, 'pelem-path-id'), ['int'])),
                                                    ('pelem_version', (YLeaf(YType.uint32, 'pelem-version'), ['int'])),
                                                    ('pelem_flags', (YLeaf(YType.uint32, 'pelem-flags'), ['int'])),
                                                    ('pelem_gw_metric', (YLeaf(YType.uint32, 'pelem-gw-metric'), ['int'])),
                                                    ('pelem_path_flags', (YLeaf(YType.uint64, 'pelem-path-flags'), ['int'])),
                                                    ('pelem_path_peer_path_id', (YLeaf(YType.uint32, 'pelem-path-peer-path-id'), ['int'])),
                                                    ('pelem_table_attr_version', (YLeaf(YType.uint32, 'pelem-table-attr-version'), ['int'])),
                                                    ('pelem_path_table_attr_version', (YLeaf(YType.uint32, 'pelem-path-table-attr-version'), ['int'])),
                                                    ('pelem_no_bestpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-bestpath-table-attr-version'), ['int'])),
                                                    ('pelem_no_addpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-addpath-table-attr-version'), ['int'])),
                                                    ('is_perm_path_pelem', (YLeaf(YType.boolean, 'is-perm-path-pelem'), ['bool'])),
                                                ])
                                                self.pelem_path_id = None
                                                self.pelem_version = None
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.is_perm_path_pelem = None

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._segment_path = lambda: "active-path-element"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement, [u'pelem_path_id', u'pelem_version', u'pelem_flags', u'pelem_gw_metric', u'pelem_path_flags', u'pelem_path_peer_path_id', u'pelem_table_attr_version', u'pelem_path_table_attr_version', u'pelem_no_bestpath_table_attr_version', u'pelem_no_addpath_table_attr_version', u'is_perm_path_pelem'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "pelem-path-nexthop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class PathTable(Entity):
                                    """
                                    The BGP Path Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable, self).__init__()

                                        self.yang_name = "path-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path))])
                                        self._leafs = OrderedDict()

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: orig_source_rd
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                                ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                                ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                                ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.orig_source_rd = None
                                            self.path_id = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class Epes(Entity):
                                    """
                                    The BGP Egress Engineering table
                                    
                                    .. attribute:: epe
                                    
                                    	A BGP Egress Engineering table entry
                                    	**type**\: list of  		 :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes, self).__init__()

                                        self.yang_name = "epes"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("epe", ("epe", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe))])
                                        self._leafs = OrderedDict()

                                        self.epe = YList(self)
                                        self._segment_path = lambda: "epes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes, [], name, value)


                                    class Epe(Entity):
                                        """
                                        A BGP Egress Engineering table entry
                                        
                                        .. attribute:: epe_key_length
                                        
                                        	Epe Key Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_set_key
                                        
                                        	Epe Set Key
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: epe_local_address
                                        
                                        	Local address
                                        	**type**\:  :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                        
                                        .. attribute:: epe_next_hop
                                        
                                        	Nexthop address
                                        	**type**\:  :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                        
                                        .. attribute:: epe_key_length_xr
                                        
                                        	EPE key length in bits
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_version
                                        
                                        	EPE object's version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_flags
                                        
                                        	EPE object's flags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_local_asn
                                        
                                        	Local AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_remote_asn
                                        
                                        	Remote AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_remote_router_id
                                        
                                        	Remote router id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_local_router_id
                                        
                                        	Local router id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rpc_set_object_id
                                        
                                        	RPC set object ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_key
                                        
                                        	Key of EPE object
                                        	**type**\: list of  		 :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey>`
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	List of nexthop ID of EPE
                                        	**type**\: list of  		 :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId>`
                                        
                                        .. attribute:: ifhandle
                                        
                                        	List of ifhandle of EPE
                                        	**type**\: list of  		 :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle>`
                                        
                                        .. attribute:: first_hop
                                        
                                        	List of firsthops of EPE
                                        	**type**\: list of  		 :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe, self).__init__()

                                            self.yang_name = "epe"
                                            self.yang_parent_name = "epes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("epe-local-address", ("epe_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress)), ("epe-next-hop", ("epe_next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop)), ("epe-key", ("epe_key", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey)), ("nexthop-id", ("nexthop_id", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId)), ("ifhandle", ("ifhandle", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle)), ("first-hop", ("first_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop))])
                                            self._leafs = OrderedDict([
                                                ('epe_key_length', (YLeaf(YType.uint32, 'epe-key-length'), ['int'])),
                                                ('epe_set_key', (YLeaf(YType.str, 'epe-set-key'), ['str'])),
                                                ('epe_key_length_xr', (YLeaf(YType.uint8, 'epe-key-length-xr'), ['int'])),
                                                ('epe_version', (YLeaf(YType.uint32, 'epe-version'), ['int'])),
                                                ('epe_flags', (YLeaf(YType.uint8, 'epe-flags'), ['int'])),
                                                ('epe_local_asn', (YLeaf(YType.uint32, 'epe-local-asn'), ['int'])),
                                                ('epe_remote_asn', (YLeaf(YType.uint32, 'epe-remote-asn'), ['int'])),
                                                ('epe_remote_router_id', (YLeaf(YType.uint32, 'epe-remote-router-id'), ['int'])),
                                                ('epe_local_router_id', (YLeaf(YType.uint32, 'epe-local-router-id'), ['int'])),
                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                ('ref_count', (YLeaf(YType.uint32, 'ref-count'), ['int'])),
                                                ('rpc_set_object_id', (YLeaf(YType.uint32, 'rpc-set-object-id'), ['int'])),
                                            ])
                                            self.epe_key_length = None
                                            self.epe_set_key = None
                                            self.epe_key_length_xr = None
                                            self.epe_version = None
                                            self.epe_flags = None
                                            self.epe_local_asn = None
                                            self.epe_remote_asn = None
                                            self.epe_remote_router_id = None
                                            self.epe_local_router_id = None
                                            self.label = None
                                            self.ref_count = None
                                            self.rpc_set_object_id = None

                                            self.epe_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                            self.epe_local_address.parent = self
                                            self._children_name_map["epe_local_address"] = "epe-local-address"

                                            self.epe_next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop()
                                            self.epe_next_hop.parent = self
                                            self._children_name_map["epe_next_hop"] = "epe-next-hop"

                                            self.epe_key = YList(self)
                                            self.nexthop_id = YList(self)
                                            self.ifhandle = YList(self)
                                            self.first_hop = YList(self)
                                            self._segment_path = lambda: "epe"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe, ['epe_key_length', 'epe_set_key', u'epe_key_length_xr', u'epe_version', u'epe_flags', u'epe_local_asn', u'epe_remote_asn', u'epe_remote_router_id', u'epe_local_router_id', u'label', u'ref_count', u'rpc_set_object_id'], name, value)


                                        class EpeLocalAddress(Entity):
                                            """
                                            Local address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress, self).__init__()

                                                self.yang_name = "epe-local-address"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "epe-local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class EpeNextHop(Entity):
                                            """
                                            Nexthop address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop, self).__init__()

                                                self.yang_name = "epe-next-hop"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "epe-next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class EpeKey(Entity):
                                            """
                                            Key of EPE object
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey, self).__init__()

                                                self.yang_name = "epe-key"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "epe-key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey, [u'entry'], name, value)


                                        class NexthopId(Entity):
                                            """
                                            List of nexthop ID of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId, self).__init__()

                                                self.yang_name = "nexthop-id"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "nexthop-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId, [u'entry'], name, value)


                                        class Ifhandle(Entity):
                                            """
                                            List of ifhandle of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle, self).__init__()

                                                self.yang_name = "ifhandle"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "ifhandle"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle, [u'entry'], name, value)


                                        class FirstHop(Entity):
                                            """
                                            List of firsthops of EPE
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop, self).__init__()

                                                self.yang_name = "first-hop"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "first-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertisedPathCounts(Entity):
                                    """
                                    The BGP Advertised paths table (bestpath)
                                    
                                    .. attribute:: advertised_path_count
                                    
                                    	The BGP Advertised path table Count (bestpath)
                                    	**type**\: list of  		 :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts, self).__init__()

                                        self.yang_name = "advertised-path-counts"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-path-count", ("advertised_path_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount))])
                                        self._leafs = OrderedDict()

                                        self.advertised_path_count = YList(self)
                                        self._segment_path = lambda: "advertised-path-counts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts, [], name, value)


                                    class AdvertisedPathCount(Entity):
                                        """
                                        The BGP Advertised path table Count
                                        (bestpath)
                                        
                                        .. attribute:: neighbor_address  (key)
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: max_prefix_advertisedcount
                                        
                                        	Number of prefixes advertsied to neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, self).__init__()

                                            self.yang_name = "advertised-path-count"
                                            self.yang_parent_name = "advertised-path-counts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['neighbor_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('max_prefix_advertisedcount', (YLeaf(YType.uint32, 'max-prefix-advertisedcount'), ['int'])),
                                            ])
                                            self.neighbor_address = None
                                            self.max_prefix_advertisedcount = None
                                            self._segment_path = lambda: "advertised-path-count" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, ['neighbor_address', u'max_prefix_advertisedcount'], name, value)


                                class PathLabeledTable(Entity):
                                    """
                                    The BGP Path Labeled Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable, self).__init__()

                                        self.yang_name = "path-labeled-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path))])
                                        self._leafs = OrderedDict()

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-labeled-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: orig_source_rd
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-labeled-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                                ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                                ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                                ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.orig_source_rd = None
                                            self.path_id = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertisedPaths(Entity):
                                    """
                                    The BGP Advertised paths table (add\-paths)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised paths table entry (add\-paths)
                                    	**type**\: list of  		 :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths, self).__init__()

                                        self.yang_name = "advertised-paths"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-path", ("advertised_path", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath))])
                                        self._leafs = OrderedDict()

                                        self.advertised_path = YList(self)
                                        self._segment_path = lambda: "advertised-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths, [], name, value)


                                    class AdvertisedPath(Entity):
                                        """
                                        A BGP Advertised paths table entry
                                        (add\-paths)
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor 
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: paths
                                        
                                        	paths
                                        	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                        
                                        .. attribute:: adv_path_info
                                        
                                        	Net Advertized Paths
                                        	**type**\: list of  		 :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath, self).__init__()

                                            self.yang_name = "advertised-path"
                                            self.yang_parent_name = "advertised-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("paths", ("paths", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths)), ("adv-path-info", ("adv_path_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None

                                            self.paths = YList(self)
                                            self.adv_path_info = YList(self)
                                            self._segment_path = lambda: "advertised-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath, ['rd', 'network', 'prefix_length', 'neighbor_address'], name, value)


                                        class Paths(Entity):
                                            """
                                            paths
                                            
                                            .. attribute:: advertised_neighbor
                                            
                                            	Advertised Neighbor Address. Valid in the case of Advertised table
                                            	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor>`
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                            	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\: bool
                                            
                                            .. attribute:: label_oor_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\: bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: original_source_route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\: str
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\: str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn))])
                                                self._leafs = OrderedDict([
                                                    ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                    ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                    ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                    ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                    ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                    ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                    ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.no_path = None
                                                self.af_name = None
                                                self.process_instance_id = None
                                                self.label_oor = None
                                                self.label_oor_version = None
                                                self.label_fail = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.original_source_route_distinguisher = None
                                                self.prefix_version = None
                                                self.vrf_name = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None

                                                self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor()
                                                self.advertised_neighbor.parent = self
                                                self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                                self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._segment_path = lambda: "paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                            class AdvertisedNeighbor(Entity):
                                                """
                                                Advertised Neighbor Address. Valid in the case
                                                of Advertised table
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor, self).__init__()

                                                    self.yang_name = "advertised-neighbor"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "advertised-neighbor"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\: bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\: bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgp
                                                
                                                	Not advertised to EBGPs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\: bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\: bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\: bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\: bool
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\: str
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\: bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\: bool
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\: bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\: bool
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_self_originated_path
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\: bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\: bool
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\: bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\: bool
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\: bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\: bool
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\: bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\: bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: mac_ip_present
                                                
                                                	Mac IP Present  present
                                                	**type**\: bool
                                                
                                                .. attribute:: mac_ip
                                                
                                                	Mac associated with IP
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue>`
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield))])
                                                    self._leafs = OrderedDict([
                                                        ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                        ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                        ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                        ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                        ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                        ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                        ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                        ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                        ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                        ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                        ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                        ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                        ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                        ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                        ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                        ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                        ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                        ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                        ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                        ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                        ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                        ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                        ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                        ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                        ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                        ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                        ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                        ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                        ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                        ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                        ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                        ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                        ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                        ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                        ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                        ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                        ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                        ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                        ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                        ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                        ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                        ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                        ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                        ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                        ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                        ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                        ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                        ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                        ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                        ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                        ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                        ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                        ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                        ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                        ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                        ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                        ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                        ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                        ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                        ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                        ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                        ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                        ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                        ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                        ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                        ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                        ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                        ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                        ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                        ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                        ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                        ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                        ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                        ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                        ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                        ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                        ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                        ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                        ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                        ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                        ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                        ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                        ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                        ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                        ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                        ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                        ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                        ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                        ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                        ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                        ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                        ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                        ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                        ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                        ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                    ])
                                                    self.route_type = None
                                                    self.is_path_valid = None
                                                    self.is_path_damped = None
                                                    self.is_path_history_held = None
                                                    self.is_internal_path = None
                                                    self.is_best_path = None
                                                    self.is_as_best = None
                                                    self.is_spkr_as_best = None
                                                    self.is_partial_best = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebgp = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_received_only = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_imported = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_vpn_only = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_multipath = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_stale = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.has_local_net_label = None
                                                    self.local_label = None
                                                    self.igp_metric = None
                                                    self.path_weight = None
                                                    self.neighbor_router_id = None
                                                    self.has_mdt_group_addr = None
                                                    self.l2vpn_size = None
                                                    self.l2vpn_evpn_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_nh_addr = None
                                                    self.has_second_label = None
                                                    self.second_label = None
                                                    self.path_flap_count = None
                                                    self.seconds_since_first_flap = None
                                                    self.time_to_unsuppress = None
                                                    self.dampen_penalty = None
                                                    self.halflife_time = None
                                                    self.suppress_penalty = None
                                                    self.reuse_value = None
                                                    self.maximum_suppress_time = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_id_comp_winner = None
                                                    self.path_flags = None
                                                    self.path_import_flags = None
                                                    self.best_path_id = None
                                                    self.local_path_id = None
                                                    self.rcvd_path_id = None
                                                    self.path_table_version = None
                                                    self.advertisedto_pe = None
                                                    self.rib_failed = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.ibgp_signaled_validity = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_path = None
                                                    self.aigp_metric = None
                                                    self.mvpn_sfs_path = None
                                                    self.fspec_invalid_path = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.has_mvpn_extcomm = None
                                                    self.mvpn_path_flags = None
                                                    self.local_nh = None
                                                    self.rt_set_limit_enabled = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_permanent_path = None
                                                    self.graceful_shutdown = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.has_vpn_nexthop_addr = None
                                                    self.is_orig_src_rd_present = None
                                                    self.af_name = None
                                                    self.route_distinguisher = None
                                                    self.mac_ip_present = None
                                                    self.mac_ip = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                    self.rcvd_label = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self._segment_path = lambda: "path-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mdt-group-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "gw-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "nh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "best-path-comp-winner"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nbr-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "vpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rcvd-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, [u'entry'], name, value)


                                                class L2vpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "mvpn-pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "local-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "pe-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "best-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "add-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied. In the
                                                case of path type received\-only this will be
                                                attributes before inbound policy
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\: bool
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\: bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp))])
                                                    self._leafs = OrderedDict([
                                                        ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                        ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                        ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                        ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                        ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                        ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                        ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                        ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                        ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                        ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                        ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                        ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                        ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                        ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                        ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                        ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                        ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                        ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                        ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                        ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                        ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                        ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                        ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                    ])
                                                    self.is_as_path2_byte = None
                                                    self.is_application_gateway_present = None
                                                    self.is_attr_set_present = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.is_rnh_present = None
                                                    self.is_ribrnh_present = None
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.vpn_distinguisher = None
                                                    self.rnh_type = None
                                                    self.rnh_len = None
                                                    self.rnh_addr_len = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_mac = None
                                                    self.ribrnhip_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnh_encap = None

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._segment_path = lambda: "attributes-after-policy-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "common-attributes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "attr-set"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.mac_address = None
                                                        self._segment_path = lambda: "rnh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "ribrnh-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AdvPathInfo(Entity):
                                            """
                                            Net Advertized Paths
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                            
                                            .. attribute:: path_info_after_policy_in
                                            
                                            	Path information after inbound policy
                                            	**type**\:  :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                            
                                            .. attribute:: path_info_after_policy_out
                                            
                                            	Path information after outbound policy
                                            	**type**\:  :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy
                                            	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: attributes_after_policy_out
                                            
                                            	Attributes after outbound policy
                                            	**type**\:  :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, self).__init__()

                                                self.yang_name = "adv-path-info"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr)), ("path-info-after-policy-in", ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn)), ("path-info-after-policy-out", ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn)), ("attributes-after-policy-out", ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut))])
                                                self._leafs = OrderedDict([
                                                    ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ])
                                                self.no_path = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.vrf_name = None

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                                self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                                self.path_info_after_policy_in.parent = self
                                                self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"

                                                self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                                self.path_info_after_policy_out.parent = self
                                                self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"

                                                self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                                self.attributes_after_policy_out.parent = self
                                                self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                                self._segment_path = lambda: "adv-path-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, [u'no_path', u'af_name', u'route_distinguisher', u'source_route_distinguisher', u'vrf_name'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address-xr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PathInfoAfterPolicyIn(Entity):
                                                """
                                                Path information after inbound policy
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel>`
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\: bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\: bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgp
                                                
                                                	Not advertised to EBGPs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\: bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\: bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\: bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\: bool
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\: str
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\: bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\: bool
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\: bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\: bool
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_self_originated_path
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\: bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\: bool
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\: bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\: bool
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\: bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\: bool
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\: bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\: bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: mac_ip_present
                                                
                                                	Mac IP Present  present
                                                	**type**\: bool
                                                
                                                .. attribute:: mac_ip
                                                
                                                	Mac associated with IP
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel>`
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue>`
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, self).__init__()

                                                    self.yang_name = "path-info-after-policy-in"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield))])
                                                    self._leafs = OrderedDict([
                                                        ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                        ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                        ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                        ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                        ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                        ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                        ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                        ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                        ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                        ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                        ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                        ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                        ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                        ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                        ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                        ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                        ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                        ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                        ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                        ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                        ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                        ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                        ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                        ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                        ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                        ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                        ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                        ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                        ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                        ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                        ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                        ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                        ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                        ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                        ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                        ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                        ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                        ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                        ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                        ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                        ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                        ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                        ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                        ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                        ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                        ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                        ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                        ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                        ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                        ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                        ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                        ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                        ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                        ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                        ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                        ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                        ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                        ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                        ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                        ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                        ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                        ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                        ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                        ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                        ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                        ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                        ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                        ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                        ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                        ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                        ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                        ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                        ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                        ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                        ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                        ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                        ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                        ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                        ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                        ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                        ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                        ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                        ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                        ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                        ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                        ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                        ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                        ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                        ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                        ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                        ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                        ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                        ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                        ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                        ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                    ])
                                                    self.route_type = None
                                                    self.is_path_valid = None
                                                    self.is_path_damped = None
                                                    self.is_path_history_held = None
                                                    self.is_internal_path = None
                                                    self.is_best_path = None
                                                    self.is_as_best = None
                                                    self.is_spkr_as_best = None
                                                    self.is_partial_best = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebgp = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_received_only = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_imported = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_vpn_only = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_multipath = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_stale = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.has_local_net_label = None
                                                    self.local_label = None
                                                    self.igp_metric = None
                                                    self.path_weight = None
                                                    self.neighbor_router_id = None
                                                    self.has_mdt_group_addr = None
                                                    self.l2vpn_size = None
                                                    self.l2vpn_evpn_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_nh_addr = None
                                                    self.has_second_label = None
                                                    self.second_label = None
                                                    self.path_flap_count = None
                                                    self.seconds_since_first_flap = None
                                                    self.time_to_unsuppress = None
                                                    self.dampen_penalty = None
                                                    self.halflife_time = None
                                                    self.suppress_penalty = None
                                                    self.reuse_value = None
                                                    self.maximum_suppress_time = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_id_comp_winner = None
                                                    self.path_flags = None
                                                    self.path_import_flags = None
                                                    self.best_path_id = None
                                                    self.local_path_id = None
                                                    self.rcvd_path_id = None
                                                    self.path_table_version = None
                                                    self.advertisedto_pe = None
                                                    self.rib_failed = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.ibgp_signaled_validity = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_path = None
                                                    self.aigp_metric = None
                                                    self.mvpn_sfs_path = None
                                                    self.fspec_invalid_path = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.has_mvpn_extcomm = None
                                                    self.mvpn_path_flags = None
                                                    self.local_nh = None
                                                    self.rt_set_limit_enabled = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_permanent_path = None
                                                    self.graceful_shutdown = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.has_vpn_nexthop_addr = None
                                                    self.is_orig_src_rd_present = None
                                                    self.af_name = None
                                                    self.route_distinguisher = None
                                                    self.mac_ip_present = None
                                                    self.mac_ip = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                    self.rcvd_label = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self._segment_path = lambda: "path-info-after-policy-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mdt-group-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "gw-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "nh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "best-path-comp-winner"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nbr-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "vpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rcvd-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, [u'entry'], name, value)


                                                class L2vpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "mvpn-pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, [u'entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "local-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "pe-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "best-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "add-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PathInfoAfterPolicyOut(Entity):
                                                """
                                                Path information after outbound policy
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel>`
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\: bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\: bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgp
                                                
                                                	Not advertised to EBGPs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\: bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\: bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\: bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\: bool
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\: str
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\: bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\: bool
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\: bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\: bool
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_self_originated_path
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\: bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\: bool
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\: bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\: bool
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\: bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\: bool
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\: bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\: bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: mac_ip_present
                                                
                                                	Mac IP Present  present
                                                	**type**\: bool
                                                
                                                .. attribute:: mac_ip
                                                
                                                	Mac associated with IP
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel>`
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue>`
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, self).__init__()

                                                    self.yang_name = "path-info-after-policy-out"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield))])
                                                    self._leafs = OrderedDict([
                                                        ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                        ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                        ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                        ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                        ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                        ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                        ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                        ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                        ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                        ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                        ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                        ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                        ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                        ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                        ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                        ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                        ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                        ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                        ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                        ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                        ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                        ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                        ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                        ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                        ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                        ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                        ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                        ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                        ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                        ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                        ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                        ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                        ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                        ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                        ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                        ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                        ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                        ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                        ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                        ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                        ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                        ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                        ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                        ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                        ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                        ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                        ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                        ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                        ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                        ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                        ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                        ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                        ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                        ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                        ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                        ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                        ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                        ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                        ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                        ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                        ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                        ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                        ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                        ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                        ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                        ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                        ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                        ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                        ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                        ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                        ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                        ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                        ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                        ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                        ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                        ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                        ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                        ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                        ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                        ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                        ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                        ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                        ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                        ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                        ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                        ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                        ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                        ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                        ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                        ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                        ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                        ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                        ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                        ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                        ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                    ])
                                                    self.route_type = None
                                                    self.is_path_valid = None
                                                    self.is_path_damped = None
                                                    self.is_path_history_held = None
                                                    self.is_internal_path = None
                                                    self.is_best_path = None
                                                    self.is_as_best = None
                                                    self.is_spkr_as_best = None
                                                    self.is_partial_best = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebgp = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_received_only = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_imported = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_vpn_only = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_multipath = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_stale = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.has_local_net_label = None
                                                    self.local_label = None
                                                    self.igp_metric = None
                                                    self.path_weight = None
                                                    self.neighbor_router_id = None
                                                    self.has_mdt_group_addr = None
                                                    self.l2vpn_size = None
                                                    self.l2vpn_evpn_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_nh_addr = None
                                                    self.has_second_label = None
                                                    self.second_label = None
                                                    self.path_flap_count = None
                                                    self.seconds_since_first_flap = None
                                                    self.time_to_unsuppress = None
                                                    self.dampen_penalty = None
                                                    self.halflife_time = None
                                                    self.suppress_penalty = None
                                                    self.reuse_value = None
                                                    self.maximum_suppress_time = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_id_comp_winner = None
                                                    self.path_flags = None
                                                    self.path_import_flags = None
                                                    self.best_path_id = None
                                                    self.local_path_id = None
                                                    self.rcvd_path_id = None
                                                    self.path_table_version = None
                                                    self.advertisedto_pe = None
                                                    self.rib_failed = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.ibgp_signaled_validity = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_path = None
                                                    self.aigp_metric = None
                                                    self.mvpn_sfs_path = None
                                                    self.fspec_invalid_path = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.has_mvpn_extcomm = None
                                                    self.mvpn_path_flags = None
                                                    self.local_nh = None
                                                    self.rt_set_limit_enabled = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_permanent_path = None
                                                    self.graceful_shutdown = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.has_vpn_nexthop_addr = None
                                                    self.is_orig_src_rd_present = None
                                                    self.af_name = None
                                                    self.route_distinguisher = None
                                                    self.mac_ip_present = None
                                                    self.mac_ip = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                                    self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                    self.rcvd_label = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self._segment_path = lambda: "path-info-after-policy-out"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mdt-group-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "gw-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "nh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "best-path-comp-winner"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nbr-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "vpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rcvd-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, [u'entry'], name, value)


                                                class L2vpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "mvpn-pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, [u'entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "local-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "pe-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "best-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "add-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\: bool
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\: bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp))])
                                                    self._leafs = OrderedDict([
                                                        ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                        ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                        ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                        ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                        ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                        ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                        ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                        ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                        ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                        ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                        ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                        ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                        ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                        ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                        ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                        ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                        ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                        ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                        ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                        ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                        ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                        ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                        ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                    ])
                                                    self.is_as_path2_byte = None
                                                    self.is_application_gateway_present = None
                                                    self.is_attr_set_present = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.is_rnh_present = None
                                                    self.is_ribrnh_present = None
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.vpn_distinguisher = None
                                                    self.rnh_type = None
                                                    self.rnh_len = None
                                                    self.rnh_addr_len = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_mac = None
                                                    self.ribrnhip_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnh_encap = None

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._segment_path = lambda: "attributes-after-policy-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "common-attributes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "attr-set"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.mac_address = None
                                                        self._segment_path = lambda: "rnh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "ribrnh-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AttributesAfterPolicyOut(Entity):
                                                """
                                                Attributes after outbound policy
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\: bool
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\: bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, self).__init__()

                                                    self.yang_name = "attributes-after-policy-out"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp))])
                                                    self._leafs = OrderedDict([
                                                        ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                        ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                        ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                        ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                        ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                        ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                        ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                        ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                        ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                        ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                        ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                        ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                        ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                        ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                        ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                        ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                        ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                        ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                        ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                        ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                        ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                        ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                        ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                    ])
                                                    self.is_as_path2_byte = None
                                                    self.is_application_gateway_present = None
                                                    self.is_attr_set_present = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.is_rnh_present = None
                                                    self.is_ribrnh_present = None
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.vpn_distinguisher = None
                                                    self.rnh_type = None
                                                    self.rnh_len = None
                                                    self.rnh_addr_len = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_mac = None
                                                    self.ribrnhip_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnh_encap = None

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"

                                                    self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._segment_path = lambda: "attributes-after-policy-out"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "common-attributes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "attr-set"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.mac_address = None
                                                        self._segment_path = lambda: "rnh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "ribrnh-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NeighborAfTable(Entity):
                                    """
                                    The BGP Neighbor AF table
                                    
                                    .. attribute:: neighbor
                                    
                                    	A BGP Neighbor table entry
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable, self).__init__()

                                        self.yang_name = "neighbor-af-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor))])
                                        self._leafs = OrderedDict()

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "neighbor-af-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        A BGP Neighbor table entry
                                        
                                        .. attribute:: neighbor_address  (key)
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: connection_local_address
                                        
                                        	Local address for the connection
                                        	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                        
                                        .. attribute:: connection_remote_address
                                        
                                        	Remote address for the connection
                                        	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                        
                                        .. attribute:: send_notification_info
                                        
                                        	Information on the last notification sent
                                        	**type**\:  :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                        
                                        .. attribute:: received_notification_info
                                        
                                        	Information on the last notification received
                                        	**type**\:  :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                        
                                        .. attribute:: message_statistics
                                        
                                        	Message statistics
                                        	**type**\:  :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                        
                                        .. attribute:: tcp_init_sync_time_spec
                                        
                                        	Time When neighbor entered TCP Init Sync
                                        	**type**\:  :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_phase_two_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Phase Two
                                        	**type**\:  :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_done_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Done
                                        	**type**\:  :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                        
                                        .. attribute:: graceful_maintenance
                                        
                                        	Graceful Maintenance
                                        	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                        
                                        .. attribute:: speaker_id
                                        
                                        	Speaker this neighbor is allocated to
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: description
                                        
                                        	Description
                                        	**type**\: str
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_internal_link
                                        
                                        	Internal link to neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: is_external_neighbor_not_directly_connected
                                        
                                        	External neighbor not directly connected
                                        	**type**\: bool
                                        
                                        .. attribute:: messages_received
                                        
                                        	Number of messages received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_sent
                                        
                                        	Number of messages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_messages_in
                                        
                                        	No. of update msgs received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_messages_out
                                        
                                        	No. of update messages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_queued_in
                                        
                                        	No. of msgs on receive queue
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_queued_out
                                        
                                        	No. of messages on send queue
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_established_time
                                        
                                        	Time (in secs) that the connection has been established
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_state
                                        
                                        	State of connection
                                        	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                        
                                        .. attribute:: previous_connection_state
                                        
                                        	Previous state of connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_admin_status
                                        
                                        	Administrative status of connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: open_check_error_code
                                        
                                        	Open check error code
                                        	**type**\:  :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                        
                                        .. attribute:: is_local_address_configured
                                        
                                        	Local address configured for the neighbor connection
                                        	**type**\: bool
                                        
                                        .. attribute:: connection_local_port
                                        
                                        	Local port for the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_remote_port
                                        
                                        	Remote port for the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_interface_handle
                                        
                                        	Interface Handle of Neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_notification_sent
                                        
                                        	Notification was sent during last reset
                                        	**type**\: bool
                                        
                                        .. attribute:: is_administratively_shut_down
                                        
                                        	Neighbor is administratively shut down
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_max_prefix_shutdown
                                        
                                        	Neighbor shut down because it exceeded max prfx count
                                        	**type**\: bool
                                        
                                        .. attribute:: is_out_of_memory_shutdown
                                        
                                        	Neighbor shut down during a SEVERE low memory condition
                                        	**type**\: bool
                                        
                                        .. attribute:: is_out_of_memory_forced_up
                                        
                                        	Neighbor forced up during a low memory condition
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ebgp_peer_as_league
                                        
                                        	EBGP peer belongs to AS League
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ebgp_peer_common_admin
                                        
                                        	EBGP peer with common administation
                                        	**type**\: bool
                                        
                                        .. attribute:: ttl_security_enabled
                                        
                                        	TTL Security enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: suppress4_byte_as
                                        
                                        	Suppress 4byteas capability
                                        	**type**\: bool
                                        
                                        .. attribute:: bfd_session_state
                                        
                                        	BFD state for this peer
                                        	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                        
                                        .. attribute:: bfd_session_created_state
                                        
                                        	BFD state for this peer
                                        	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                        
                                        .. attribute:: bfd_session_enable_mode
                                        
                                        	BFD enable mode for this peer
                                        	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                        
                                        .. attribute:: bfd_minintervalval
                                        
                                        	BFD Mininterval for this peer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_multiplierval
                                        
                                        	BFD Multiplier for this peer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_state_ts
                                        
                                        	Timestamp since when nbr is in this bfd state
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: router_id
                                        
                                        	Router ID for the neighbor
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: negotiated_protocol_version
                                        
                                        	Negotiated protocol version
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ebgp_time_to_live
                                        
                                        	Maximum number of hops for external BGP neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                        
                                        	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: tcpmss
                                        
                                        	Neighbor TCP Maximum Segment                     size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_log_in
                                        
                                        	Message in log count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_log_out
                                        
                                        	Message out log count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_local_as
                                        
                                        	Local AS configured on the neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_no_prepend
                                        
                                        	Option to not prepend the Local AS to announcements
                                        	**type**\: bool
                                        
                                        .. attribute:: is_capability_negotiation_suppressed
                                        
                                        	Capability negotiation suppressed
                                        	**type**\: bool
                                        
                                        .. attribute:: is_capability_negotiation_performed
                                        
                                        	Capability negotiation performed
                                        	**type**\: bool
                                        
                                        .. attribute:: is_route_refresh_capability_received
                                        
                                        	Route refresh capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_route_refresh_old_capability_received
                                        
                                        	Route refresh old capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_gr_aware
                                        
                                        	GR awareness received
                                        	**type**\: bool
                                        
                                        .. attribute:: is4_byte_as_capability_received
                                        
                                        	4\-byte AScapability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is4_byte_as_capability_sent
                                        
                                        	4\-byte AScapability Snt
                                        	**type**\: bool
                                        
                                        .. attribute:: multi_protocol_capability_received
                                        
                                        	Multi\-protocol capability has been received
                                        	**type**\: bool
                                        
                                        .. attribute:: hold_time
                                        
                                        	Hold time (in secs) negotiated for this connection
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: keep_alive_time
                                        
                                        	Keepalive time (in secs) negotiated for this connection
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_hold_time
                                        
                                        	Hold time (in secs) configured for this connection
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_keepalive
                                        
                                        	Keepalive time (in secs) configured for this connection
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_min_acc_hold_time
                                        
                                        	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: min_advertise_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: min_advertise_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: min_origination_interval
                                        
                                        	Minimum origination interval (in secs)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connect_retry_interval
                                        
                                        	Time (in secs) for connect retry timer
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_update
                                        
                                        	Time (in secs) since last update message was received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read
                                        
                                        	Time (in secs) since last read
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read_reset
                                        
                                        	Time (in secs) since last read before last reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_last_cb
                                        
                                        	CB
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: time_last_cb_reset
                                        
                                        	Last CB before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_fb
                                        
                                        	FB
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: count_last_write
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_last_write
                                        
                                        	Time (in secs) since last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: attempted_last_write_bytes
                                        
                                        	Attempted size of last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_last_write_bytes
                                        
                                        	Actual size of last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_second_last_write
                                        
                                        	Time (in secs) since second  last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: attempted_second_last_write_bytes
                                        
                                        	Attempted size of second last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_bytes
                                        
                                        	Actual size of second last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: attempted_last_write_reset_bytes
                                        
                                        	Attempted size of last write before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_last_write_reset_bytes
                                        
                                        	Actual size of last write before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_second_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: attempted_second_last_write_reset_bytes
                                        
                                        	Attempted size of second last write before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_reset_bytes
                                        
                                        	Actual size of second last write before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_write_event
                                        
                                        	Time (in secs) since last write thread event
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_write_event
                                        
                                        	Time (in secs) since second last write thread event
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_aexpiry_reset
                                        
                                        	Time (in secs) since last KA timer expiry before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_k_aexpiry_reset
                                        
                                        	Time (in secs) since second last KA timer expiry before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_anotsent_reset
                                        
                                        	Duration (in secs) since last time that KA was not sent before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_aerror_reset
                                        
                                        	Duration (in secs) since last time that an error was encountered after KA expiry
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_astart_reset
                                        
                                        	Time (in secs) since the last KA timer start before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_k_astart_reset
                                        
                                        	Time (in secs) since the second last KA timer start before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of times the connection was established
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of times connection was dropped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_connection_last_dropped
                                        
                                        	Time since the connection last went down (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: reset_reason
                                        
                                        	Reason for last connection reset
                                        	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                        
                                        .. attribute:: peer_reset_reason
                                        
                                        	Reason for last peer close event
                                        	**type**\:  :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                        
                                        .. attribute:: peer_error_code
                                        
                                        	If peer closed, error received from transport
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_notify_error_code
                                        
                                        	Code for the last error notification seen on the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notify_error_subcode
                                        
                                        	Error subcode of the last error notification seen on the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: error_notifies_received
                                        
                                        	Number of error notifications received on the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: error_notifies_sent
                                        
                                        	Number of error notifications sent on the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as_number
                                        
                                        	Remote AS number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dmz_link_bandwidth
                                        
                                        	Bandwidth of link to single\-hop eBGP peer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ebgp_recv_dmz
                                        
                                        	Receive Bandwidth of link to single\-hop eBGP peer
                                        	**type**\: bool
                                        
                                        .. attribute:: ebgp_send_dmz_mode
                                        
                                        	Ebgp send dmz link bw mode
                                        	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                        
                                        .. attribute:: tos_type
                                        
                                        	Precedence or DSCP type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_value
                                        
                                        	Precedence or DSCP value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tcp_session_open_mode
                                        
                                        	The TCP mode to be used to set up BGP session with the neighbor
                                        	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: standby_rp
                                        
                                        	Standby RP socket inited for Active Open
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_enabled
                                        
                                        	Neighbor supports NSR
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_restart_enabled_nbr
                                        
                                        	Neighbor supports graceful\-restart
                                        	**type**\: bool
                                        
                                        .. attribute:: gr_restart_time
                                        
                                        	Neighbor restart time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: gr_stale_path_time
                                        
                                        	Neighbor stale\-path time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: fssn_offset
                                        
                                        	First standby SeqNo offset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fpbsn_offset
                                        
                                        	First standby PDU boundary SeqNo offset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_ackd_seq_no
                                        
                                        	SeqNo of the last Ackd byte
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bytes_written
                                        
                                        	Total bytes written by write thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bytes_read
                                        
                                        	Total bytes read
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: socket_read_bytes
                                        
                                        	Total read bytes value insocket\-lib
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: is_read_disabled
                                        
                                        	If true, socket read isdisabled
                                        	**type**\: bool
                                        
                                        .. attribute:: update_bytes_read
                                        
                                        	Total update bytes read
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: nsr_state
                                        
                                        	NSR state
                                        	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                        
                                        .. attribute:: is_passive_close
                                        
                                        	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: nbr_enforce_first_as
                                        
                                        	Neighbor enforce first AS
                                        	**type**\: bool
                                        
                                        .. attribute:: active_bmp_servers
                                        
                                        	BMP Servers to which the neighbor sends logs
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nbr_cluster_id
                                        
                                        	Cluster id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nbr_in_cluster
                                        
                                        	Type of cluster\_id\:undefined/number/Ip address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ignore_connected
                                        
                                        	If true, the VPN client isan IBGP CE peer
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_vpn_client
                                        
                                        	If true, don't do NHconnected check for nbr
                                        	**type**\: bool
                                        
                                        .. attribute:: io_armed
                                        
                                        	If true, socket has beenauto\-armed for io control
                                        	**type**\: bool
                                        
                                        .. attribute:: read_armed
                                        
                                        	If true, socket has beenauto\-armed for read
                                        	**type**\: bool
                                        
                                        .. attribute:: write_armed
                                        
                                        	If true, socket has beenauto\-armed for write
                                        	**type**\: bool
                                        
                                        .. attribute:: discard_data_bytes
                                        
                                        	Remaining discard data (bytes) on Standby
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\: bool
                                        
                                        .. attribute:: local_as_dual_as
                                        
                                        	Local AS Dual\-AS option
                                        	**type**\: bool
                                        
                                        .. attribute:: local_as_dual_as_mode_native
                                        
                                        	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                        	**type**\: bool
                                        
                                        .. attribute:: egress_peer_engineering_enabled
                                        
                                        	Indicates if Egress Peer Engineering is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: discard_as4_path
                                        
                                        	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\: bool
                                        
                                        .. attribute:: dynamic_neighbor
                                        
                                        	Dynamic neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: af_data
                                        
                                        	Address family specific neighbor data
                                        	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbor-af-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['neighbor_address']
                                            self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress)), ("send-notification-info", ("send_notification_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo)), ("received-notification-info", ("received_notification_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics)), ("message-statistics", ("message_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics)), ("tcp-init-sync-time-spec", ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec)), ("tcp-init-sync-phase-two-time-spec", ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec)), ("tcp-init-sync-done-time-spec", ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData))])
                                            self._leafs = OrderedDict([
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                                ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                                ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                                ('is_external_neighbor_not_directly_connected', (YLeaf(YType.boolean, 'is-external-neighbor-not-directly-connected'), ['bool'])),
                                                ('messages_received', (YLeaf(YType.uint32, 'messages-received'), ['int'])),
                                                ('messages_sent', (YLeaf(YType.uint32, 'messages-sent'), ['int'])),
                                                ('update_messages_in', (YLeaf(YType.uint32, 'update-messages-in'), ['int'])),
                                                ('update_messages_out', (YLeaf(YType.uint32, 'update-messages-out'), ['int'])),
                                                ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                                ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                                ('connection_established_time', (YLeaf(YType.uint32, 'connection-established-time'), ['int'])),
                                                ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                                ('previous_connection_state', (YLeaf(YType.uint32, 'previous-connection-state'), ['int'])),
                                                ('connection_admin_status', (YLeaf(YType.uint32, 'connection-admin-status'), ['int'])),
                                                ('open_check_error_code', (YLeaf(YType.enumeration, 'open-check-error-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpOpenCheckErr', '')])),
                                                ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                                ('connection_local_port', (YLeaf(YType.uint32, 'connection-local-port'), ['int'])),
                                                ('connection_remote_port', (YLeaf(YType.uint32, 'connection-remote-port'), ['int'])),
                                                ('neighbor_interface_handle', (YLeaf(YType.uint32, 'neighbor-interface-handle'), ['int'])),
                                                ('reset_notification_sent', (YLeaf(YType.boolean, 'reset-notification-sent'), ['bool'])),
                                                ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                                ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                                ('is_out_of_memory_shutdown', (YLeaf(YType.boolean, 'is-out-of-memory-shutdown'), ['bool'])),
                                                ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                                ('is_ebgp_peer_as_league', (YLeaf(YType.boolean, 'is-ebgp-peer-as-league'), ['bool'])),
                                                ('is_ebgp_peer_common_admin', (YLeaf(YType.boolean, 'is-ebgp-peer-common-admin'), ['bool'])),
                                                ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                                ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                                ('bfd_session_state', (YLeaf(YType.enumeration, 'bfd-session-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                                ('bfd_session_created_state', (YLeaf(YType.enumeration, 'bfd-session-created-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                                ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                                ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                                ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                                ('bfd_state_ts', (YLeaf(YType.uint64, 'bfd-state-ts'), ['int'])),
                                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                ('negotiated_protocol_version', (YLeaf(YType.uint16, 'negotiated-protocol-version'), ['int'])),
                                                ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                                ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                                ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                                ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                                ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                                ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                                ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                                ('is_capability_negotiation_suppressed', (YLeaf(YType.boolean, 'is-capability-negotiation-suppressed'), ['bool'])),
                                                ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                                ('is_route_refresh_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-capability-received'), ['bool'])),
                                                ('is_route_refresh_old_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-old-capability-received'), ['bool'])),
                                                ('is_gr_aware', (YLeaf(YType.boolean, 'is-gr-aware'), ['bool'])),
                                                ('is4_byte_as_capability_received', (YLeaf(YType.boolean, 'is4-byte-as-capability-received'), ['bool'])),
                                                ('is4_byte_as_capability_sent', (YLeaf(YType.boolean, 'is4-byte-as-capability-sent'), ['bool'])),
                                                ('multi_protocol_capability_received', (YLeaf(YType.boolean, 'multi-protocol-capability-received'), ['bool'])),
                                                ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                                ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                                ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                                ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                                ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                                ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                                ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                                ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                                ('connect_retry_interval', (YLeaf(YType.uint16, 'connect-retry-interval'), ['int'])),
                                                ('time_since_last_update', (YLeaf(YType.uint32, 'time-since-last-update'), ['int'])),
                                                ('time_since_last_read', (YLeaf(YType.uint32, 'time-since-last-read'), ['int'])),
                                                ('time_since_last_read_reset', (YLeaf(YType.uint32, 'time-since-last-read-reset'), ['int'])),
                                                ('time_last_cb', (YLeaf(YType.uint64, 'time-last-cb'), ['int'])),
                                                ('time_last_cb_reset', (YLeaf(YType.uint32, 'time-last-cb-reset'), ['int'])),
                                                ('time_last_fb', (YLeaf(YType.uint64, 'time-last-fb'), ['int'])),
                                                ('count_last_write', (YLeaf(YType.uint32, 'count-last-write'), ['int'])),
                                                ('time_since_last_write', (YLeaf(YType.uint32, 'time-since-last-write'), ['int'])),
                                                ('attempted_last_write_bytes', (YLeaf(YType.uint32, 'attempted-last-write-bytes'), ['int'])),
                                                ('actual_last_write_bytes', (YLeaf(YType.uint32, 'actual-last-write-bytes'), ['int'])),
                                                ('time_since_second_last_write', (YLeaf(YType.uint32, 'time-since-second-last-write'), ['int'])),
                                                ('attempted_second_last_write_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-bytes'), ['int'])),
                                                ('actual_second_last_write_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-bytes'), ['int'])),
                                                ('time_since_last_write_reset', (YLeaf(YType.uint32, 'time-since-last-write-reset'), ['int'])),
                                                ('attempted_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-last-write-reset-bytes'), ['int'])),
                                                ('actual_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-last-write-reset-bytes'), ['int'])),
                                                ('time_since_second_last_write_reset', (YLeaf(YType.uint32, 'time-since-second-last-write-reset'), ['int'])),
                                                ('attempted_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-reset-bytes'), ['int'])),
                                                ('actual_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-reset-bytes'), ['int'])),
                                                ('last_write_event', (YLeaf(YType.uint32, 'last-write-event'), ['int'])),
                                                ('second_last_write_event', (YLeaf(YType.uint32, 'second-last-write-event'), ['int'])),
                                                ('last_k_aexpiry_reset', (YLeaf(YType.uint32, 'last-k-aexpiry-reset'), ['int'])),
                                                ('second_last_k_aexpiry_reset', (YLeaf(YType.uint32, 'second-last-k-aexpiry-reset'), ['int'])),
                                                ('last_k_anotsent_reset', (YLeaf(YType.uint32, 'last-k-anotsent-reset'), ['int'])),
                                                ('last_k_aerror_reset', (YLeaf(YType.uint32, 'last-k-aerror-reset'), ['int'])),
                                                ('last_k_astart_reset', (YLeaf(YType.uint32, 'last-k-astart-reset'), ['int'])),
                                                ('second_last_k_astart_reset', (YLeaf(YType.uint32, 'second-last-k-astart-reset'), ['int'])),
                                                ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                                ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                                ('time_since_connection_last_dropped', (YLeaf(YType.uint32, 'time-since-connection-last-dropped'), ['int'])),
                                                ('reset_reason', (YLeaf(YType.enumeration, 'reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                                ('peer_reset_reason', (YLeaf(YType.enumeration, 'peer-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPeerResetReasonIndex', '')])),
                                                ('peer_error_code', (YLeaf(YType.uint32, 'peer-error-code'), ['int'])),
                                                ('last_notify_error_code', (YLeaf(YType.uint8, 'last-notify-error-code'), ['int'])),
                                                ('last_notify_error_subcode', (YLeaf(YType.uint8, 'last-notify-error-subcode'), ['int'])),
                                                ('error_notifies_received', (YLeaf(YType.uint32, 'error-notifies-received'), ['int'])),
                                                ('error_notifies_sent', (YLeaf(YType.uint32, 'error-notifies-sent'), ['int'])),
                                                ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                                ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                                ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                                ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                                ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                                ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                                ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                                ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                                ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                                ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                                ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                                ('fssn_offset', (YLeaf(YType.uint32, 'fssn-offset'), ['int'])),
                                                ('fpbsn_offset', (YLeaf(YType.uint32, 'fpbsn-offset'), ['int'])),
                                                ('last_ackd_seq_no', (YLeaf(YType.uint32, 'last-ackd-seq-no'), ['int'])),
                                                ('bytes_written', (YLeaf(YType.uint32, 'bytes-written'), ['int'])),
                                                ('bytes_read', (YLeaf(YType.uint32, 'bytes-read'), ['int'])),
                                                ('socket_read_bytes', (YLeaf(YType.uint32, 'socket-read-bytes'), ['int'])),
                                                ('is_read_disabled', (YLeaf(YType.boolean, 'is-read-disabled'), ['bool'])),
                                                ('update_bytes_read', (YLeaf(YType.uint32, 'update-bytes-read'), ['int'])),
                                                ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                                ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                                ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                                ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                                ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                                ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                                ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                                ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                                ('io_armed', (YLeaf(YType.boolean, 'io-armed'), ['bool'])),
                                                ('read_armed', (YLeaf(YType.boolean, 'read-armed'), ['bool'])),
                                                ('write_armed', (YLeaf(YType.boolean, 'write-armed'), ['bool'])),
                                                ('discard_data_bytes', (YLeaf(YType.uint32, 'discard-data-bytes'), ['int'])),
                                                ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                                ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                                ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                                ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                                ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                                ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                                ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                                ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                                ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                                ('dynamic_neighbor', (YLeaf(YType.boolean, 'dynamic-neighbor'), ['bool'])),
                                            ])
                                            self.neighbor_address = None
                                            self.speaker_id = None
                                            self.description = None
                                            self.local_as = None
                                            self.remote_as = None
                                            self.has_internal_link = None
                                            self.is_external_neighbor_not_directly_connected = None
                                            self.messages_received = None
                                            self.messages_sent = None
                                            self.update_messages_in = None
                                            self.update_messages_out = None
                                            self.messages_queued_in = None
                                            self.messages_queued_out = None
                                            self.connection_established_time = None
                                            self.connection_state = None
                                            self.previous_connection_state = None
                                            self.connection_admin_status = None
                                            self.open_check_error_code = None
                                            self.is_local_address_configured = None
                                            self.connection_local_port = None
                                            self.connection_remote_port = None
                                            self.neighbor_interface_handle = None
                                            self.reset_notification_sent = None
                                            self.is_administratively_shut_down = None
                                            self.is_neighbor_max_prefix_shutdown = None
                                            self.is_out_of_memory_shutdown = None
                                            self.is_out_of_memory_forced_up = None
                                            self.is_ebgp_peer_as_league = None
                                            self.is_ebgp_peer_common_admin = None
                                            self.ttl_security_enabled = None
                                            self.suppress4_byte_as = None
                                            self.bfd_session_state = None
                                            self.bfd_session_created_state = None
                                            self.bfd_session_enable_mode = None
                                            self.bfd_minintervalval = None
                                            self.bfd_multiplierval = None
                                            self.bfd_state_ts = None
                                            self.router_id = None
                                            self.negotiated_protocol_version = None
                                            self.ebgp_time_to_live = None
                                            self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                            self.tcpmss = None
                                            self.msg_log_in = None
                                            self.msg_log_out = None
                                            self.neighbor_local_as = None
                                            self.local_as_no_prepend = None
                                            self.is_capability_negotiation_suppressed = None
                                            self.is_capability_negotiation_performed = None
                                            self.is_route_refresh_capability_received = None
                                            self.is_route_refresh_old_capability_received = None
                                            self.is_gr_aware = None
                                            self.is4_byte_as_capability_received = None
                                            self.is4_byte_as_capability_sent = None
                                            self.multi_protocol_capability_received = None
                                            self.hold_time = None
                                            self.keep_alive_time = None
                                            self.configured_hold_time = None
                                            self.configured_keepalive = None
                                            self.configured_min_acc_hold_time = None
                                            self.min_advertise_interval = None
                                            self.min_advertise_interval_msecs = None
                                            self.min_origination_interval = None
                                            self.connect_retry_interval = None
                                            self.time_since_last_update = None
                                            self.time_since_last_read = None
                                            self.time_since_last_read_reset = None
                                            self.time_last_cb = None
                                            self.time_last_cb_reset = None
                                            self.time_last_fb = None
                                            self.count_last_write = None
                                            self.time_since_last_write = None
                                            self.attempted_last_write_bytes = None
                                            self.actual_last_write_bytes = None
                                            self.time_since_second_last_write = None
                                            self.attempted_second_last_write_bytes = None
                                            self.actual_second_last_write_bytes = None
                                            self.time_since_last_write_reset = None
                                            self.attempted_last_write_reset_bytes = None
                                            self.actual_last_write_reset_bytes = None
                                            self.time_since_second_last_write_reset = None
                                            self.attempted_second_last_write_reset_bytes = None
                                            self.actual_second_last_write_reset_bytes = None
                                            self.last_write_event = None
                                            self.second_last_write_event = None
                                            self.last_k_aexpiry_reset = None
                                            self.second_last_k_aexpiry_reset = None
                                            self.last_k_anotsent_reset = None
                                            self.last_k_aerror_reset = None
                                            self.last_k_astart_reset = None
                                            self.second_last_k_astart_reset = None
                                            self.connection_up_count = None
                                            self.connection_down_count = None
                                            self.time_since_connection_last_dropped = None
                                            self.reset_reason = None
                                            self.peer_reset_reason = None
                                            self.peer_error_code = None
                                            self.last_notify_error_code = None
                                            self.last_notify_error_subcode = None
                                            self.error_notifies_received = None
                                            self.error_notifies_sent = None
                                            self.remote_as_number = None
                                            self.dmz_link_bandwidth = None
                                            self.ebgp_recv_dmz = None
                                            self.ebgp_send_dmz_mode = None
                                            self.tos_type = None
                                            self.tos_value = None
                                            self.tcp_session_open_mode = None
                                            self.vrf_name = None
                                            self.standby_rp = None
                                            self.nsr_enabled = None
                                            self.graceful_restart_enabled_nbr = None
                                            self.gr_restart_time = None
                                            self.gr_stale_path_time = None
                                            self.fssn_offset = None
                                            self.fpbsn_offset = None
                                            self.last_ackd_seq_no = None
                                            self.bytes_written = None
                                            self.bytes_read = None
                                            self.socket_read_bytes = None
                                            self.is_read_disabled = None
                                            self.update_bytes_read = None
                                            self.nsr_state = None
                                            self.is_passive_close = None
                                            self.nbr_enforce_first_as = None
                                            self.active_bmp_servers = None
                                            self.nbr_cluster_id = None
                                            self.nbr_in_cluster = None
                                            self.ignore_connected = None
                                            self.internal_vpn_client = None
                                            self.io_armed = None
                                            self.read_armed = None
                                            self.write_armed = None
                                            self.discard_data_bytes = None
                                            self.local_as_replace_as = None
                                            self.local_as_dual_as = None
                                            self.local_as_dual_as_mode_native = None
                                            self.egress_peer_engineering_enabled = None
                                            self.discard_as4_path = None
                                            self.rpki_disable = None
                                            self.rpki_use_validity = None
                                            self.rpki_allow_invalid = None
                                            self.rpki_signal_ibgp = None
                                            self.dynamic_neighbor = None

                                            self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                            self.connection_local_address.parent = self
                                            self._children_name_map["connection_local_address"] = "connection-local-address"

                                            self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                            self.connection_remote_address.parent = self
                                            self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                            self.send_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                            self.send_notification_info.parent = self
                                            self._children_name_map["send_notification_info"] = "send-notification-info"

                                            self.received_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                            self.received_notification_info.parent = self
                                            self._children_name_map["received_notification_info"] = "received-notification-info"

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"

                                            self.message_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                            self.message_statistics.parent = self
                                            self._children_name_map["message_statistics"] = "message-statistics"

                                            self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                            self.tcp_init_sync_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"

                                            self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                            self.tcp_init_sync_phase_two_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"

                                            self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                            self.tcp_init_sync_done_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"

                                            self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                            self.af_data = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_external_neighbor_not_directly_connected', u'messages_received', u'messages_sent', u'update_messages_in', u'update_messages_out', u'messages_queued_in', u'messages_queued_out', u'connection_established_time', u'connection_state', u'previous_connection_state', u'connection_admin_status', u'open_check_error_code', u'is_local_address_configured', u'connection_local_port', u'connection_remote_port', u'neighbor_interface_handle', u'reset_notification_sent', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_shutdown', u'is_out_of_memory_forced_up', u'is_ebgp_peer_as_league', u'is_ebgp_peer_common_admin', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_state', u'bfd_session_created_state', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'bfd_state_ts', u'router_id', u'negotiated_protocol_version', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_suppressed', u'is_capability_negotiation_performed', u'is_route_refresh_capability_received', u'is_route_refresh_old_capability_received', u'is_gr_aware', u'is4_byte_as_capability_received', u'is4_byte_as_capability_sent', u'multi_protocol_capability_received', u'hold_time', u'keep_alive_time', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'connect_retry_interval', u'time_since_last_update', u'time_since_last_read', u'time_since_last_read_reset', u'time_last_cb', u'time_last_cb_reset', u'time_last_fb', u'count_last_write', u'time_since_last_write', u'attempted_last_write_bytes', u'actual_last_write_bytes', u'time_since_second_last_write', u'attempted_second_last_write_bytes', u'actual_second_last_write_bytes', u'time_since_last_write_reset', u'attempted_last_write_reset_bytes', u'actual_last_write_reset_bytes', u'time_since_second_last_write_reset', u'attempted_second_last_write_reset_bytes', u'actual_second_last_write_reset_bytes', u'last_write_event', u'second_last_write_event', u'last_k_aexpiry_reset', u'second_last_k_aexpiry_reset', u'last_k_anotsent_reset', u'last_k_aerror_reset', u'last_k_astart_reset', u'second_last_k_astart_reset', u'connection_up_count', u'connection_down_count', u'time_since_connection_last_dropped', u'reset_reason', u'peer_reset_reason', u'peer_error_code', u'last_notify_error_code', u'last_notify_error_subcode', u'error_notifies_received', u'error_notifies_sent', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'fssn_offset', u'fpbsn_offset', u'last_ackd_seq_no', u'bytes_written', u'bytes_read', u'socket_read_bytes', u'is_read_disabled', u'update_bytes_read', u'nsr_state', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'io_armed', u'read_armed', u'write_armed', u'discard_data_bytes', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'dynamic_neighbor'], name, value)


                                        class ConnectionLocalAddress(Entity):
                                            """
                                            Local address for the connection
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, self).__init__()

                                                self.yang_name = "connection-local-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "connection-local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class ConnectionRemoteAddress(Entity):
                                            """
                                            Remote address for the connection
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, self).__init__()

                                                self.yang_name = "connection-remote-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "connection-remote-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class SendNotificationInfo(Entity):
                                            """
                                            Information on the last notification sent
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, self).__init__()

                                                self.yang_name = "send-notification-info"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData))])
                                                self._leafs = OrderedDict([
                                                    ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                                    ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                                    ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                                ])
                                                self.time_since_last_notification = None
                                                self.notification_error_code = None
                                                self.notification_error_subcode = None

                                                self.last_notification_data = YList(self)
                                                self._segment_path = lambda: "send-notification-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                            class LastNotificationData(Entity):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                                    self.yang_name = "last-notification-data"
                                                    self.yang_parent_name = "send-notification-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "last-notification-data"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                        class ReceivedNotificationInfo(Entity):
                                            """
                                            Information on the last notification received
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, self).__init__()

                                                self.yang_name = "received-notification-info"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData))])
                                                self._leafs = OrderedDict([
                                                    ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                                    ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                                    ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                                ])
                                                self.time_since_last_notification = None
                                                self.notification_error_code = None
                                                self.notification_error_subcode = None

                                                self.last_notification_data = YList(self)
                                                self._segment_path = lambda: "received-notification-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                            class LastNotificationData(Entity):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                                    self.yang_name = "last-notification-data"
                                                    self.yang_parent_name = "received-notification-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "last-notification-data"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: read_throttles
                                            
                                            	Number of partial read throttles
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: low_throttled_read
                                            
                                            	Num socket reads after nbrs crossed low threshold
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: high_throttled_read
                                            
                                            	Num of socket reads after nbr crossed high threshold
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_since_last_throttled_read
                                            
                                            	Time (in secs) since last read after being throttled
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: read_calls_count
                                            
                                            	No. of calls to function to read inbound data
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_messages_count
                                            
                                            	Number of BGP messages read
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: data_bytes_read
                                            
                                            	No. of bytes of data read
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: io_read_time
                                            
                                            	Time spent reading inbound data (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: write_calls_count
                                            
                                            	No. of calls to function to write outbound data
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: data_bytes_written
                                            
                                            	No. of data bytes written
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: io_write_time
                                            
                                            	Time spent writing outbound data (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: last_sent_seq_no
                                            
                                            	Seq No of the last sent byte
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_subgroup_calls_count
                                            
                                            	No. of calls to function to process sub\-group message list
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_subgroup_messages_count
                                            
                                            	Number of sub\-group msgs processed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subgroup_list_time
                                            
                                            	Time spent processing sub\-group message list  (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: write_queue_calls_count
                                            
                                            	No. of calls to function to process write queue
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_messages_count
                                            
                                            	Number of write queue messages processed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_time
                                            
                                            	Time spent processing write queue (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: inbound_update_messages
                                            
                                            	Number of inbound update messages processed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inbound_update_messages_time
                                            
                                            	Time spent processing inbound update messages (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: maximum_read_size
                                            
                                            	Size of largest socket (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: actives
                                            
                                            	Number of retried Active opens for this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: failed_post_actives
                                            
                                            	Number of Active Opens that failed in the Post Active State for this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passives
                                            
                                            	Number of retried Passive opens for this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rejected_passives
                                            
                                            	Number of rejected Passive opens for this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: active_collision
                                            
                                            	Number of Closed Active connections for this neighbor due to collision 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passive_collision
                                            
                                            	Number of Closed Remote opens for this neighborneighbor due to collision 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_read_thread_trigger
                                            
                                            	Number of times io\-control thread trigger read thread
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_write_thread_trigger
                                            
                                            	Number of times io\-control thread trigger write thread
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: network_status
                                            
                                            	Socket status, TRUE if socket closed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reset_flags
                                            
                                            	Reset flags, per thread
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nbr_flags
                                            
                                            	Nbr flags, per thread
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nbr_fd
                                            
                                            	Primary FD, per nbr
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: reset_retries
                                            
                                            	Reset Retries, per nbr
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sync_flags
                                            
                                            	Sync flags, per nbr
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nsr_oper_down_count
                                            
                                            	Number of times NSR scoped sync has been done
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_nsr_scoped_sync
                                            
                                            	Last time NSR scoped syncwas done for the neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('read_throttles', (YLeaf(YType.uint32, 'read-throttles'), ['int'])),
                                                    ('low_throttled_read', (YLeaf(YType.uint32, 'low-throttled-read'), ['int'])),
                                                    ('high_throttled_read', (YLeaf(YType.uint32, 'high-throttled-read'), ['int'])),
                                                    ('time_since_last_throttled_read', (YLeaf(YType.uint32, 'time-since-last-throttled-read'), ['int'])),
                                                    ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                                    ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                                    ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                                    ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                                    ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                                    ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                                    ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                                    ('last_sent_seq_no', (YLeaf(YType.uint32, 'last-sent-seq-no'), ['int'])),
                                                    ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                                    ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                                    ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                                    ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                                    ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                                    ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                                    ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                                    ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                                    ('maximum_read_size', (YLeaf(YType.uint32, 'maximum-read-size'), ['int'])),
                                                    ('actives', (YLeaf(YType.uint32, 'actives'), ['int'])),
                                                    ('failed_post_actives', (YLeaf(YType.uint32, 'failed-post-actives'), ['int'])),
                                                    ('passives', (YLeaf(YType.uint32, 'passives'), ['int'])),
                                                    ('rejected_passives', (YLeaf(YType.uint32, 'rejected-passives'), ['int'])),
                                                    ('active_collision', (YLeaf(YType.uint32, 'active-collision'), ['int'])),
                                                    ('passive_collision', (YLeaf(YType.uint32, 'passive-collision'), ['int'])),
                                                    ('control_to_read_thread_trigger', (YLeaf(YType.uint32, 'control-to-read-thread-trigger'), ['int'])),
                                                    ('control_to_write_thread_trigger', (YLeaf(YType.uint32, 'control-to-write-thread-trigger'), ['int'])),
                                                    ('network_status', (YLeaf(YType.uint32, 'network-status'), ['int'])),
                                                    ('reset_flags', (YLeaf(YType.uint32, 'reset-flags'), ['int'])),
                                                    ('nbr_flags', (YLeaf(YType.uint32, 'nbr-flags'), ['int'])),
                                                    ('nbr_fd', (YLeaf(YType.int32, 'nbr-fd'), ['int'])),
                                                    ('reset_retries', (YLeaf(YType.uint8, 'reset-retries'), ['int'])),
                                                    ('sync_flags', (YLeaf(YType.uint32, 'sync-flags'), ['int'])),
                                                    ('nsr_oper_down_count', (YLeaf(YType.uint32, 'nsr-oper-down-count'), ['int'])),
                                                    ('last_nsr_scoped_sync', (YLeaf(YType.uint32, 'last-nsr-scoped-sync'), ['int'])),
                                                ])
                                                self.read_throttles = None
                                                self.low_throttled_read = None
                                                self.high_throttled_read = None
                                                self.time_since_last_throttled_read = None
                                                self.read_calls_count = None
                                                self.read_messages_count = None
                                                self.data_bytes_read = None
                                                self.io_read_time = None
                                                self.write_calls_count = None
                                                self.data_bytes_written = None
                                                self.io_write_time = None
                                                self.last_sent_seq_no = None
                                                self.write_subgroup_calls_count = None
                                                self.write_subgroup_messages_count = None
                                                self.subgroup_list_time = None
                                                self.write_queue_calls_count = None
                                                self.write_queue_messages_count = None
                                                self.write_queue_time = None
                                                self.inbound_update_messages = None
                                                self.inbound_update_messages_time = None
                                                self.maximum_read_size = None
                                                self.actives = None
                                                self.failed_post_actives = None
                                                self.passives = None
                                                self.rejected_passives = None
                                                self.active_collision = None
                                                self.passive_collision = None
                                                self.control_to_read_thread_trigger = None
                                                self.control_to_write_thread_trigger = None
                                                self.network_status = None
                                                self.reset_flags = None
                                                self.nbr_flags = None
                                                self.nbr_fd = None
                                                self.reset_retries = None
                                                self.sync_flags = None
                                                self.nsr_oper_down_count = None
                                                self.last_nsr_scoped_sync = None
                                                self._segment_path = lambda: "performance-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, [u'read_throttles', u'low_throttled_read', u'high_throttled_read', u'time_since_last_throttled_read', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'last_sent_seq_no', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time', u'maximum_read_size', u'actives', u'failed_post_actives', u'passives', u'rejected_passives', u'active_collision', u'passive_collision', u'control_to_read_thread_trigger', u'control_to_write_thread_trigger', u'network_status', u'reset_flags', u'nbr_flags', u'nbr_fd', u'reset_retries', u'sync_flags', u'nsr_oper_down_count', u'last_nsr_scoped_sync'], name, value)


                                        class MessageStatistics(Entity):
                                            """
                                            Message statistics
                                            
                                            .. attribute:: open
                                            
                                            	Open
                                            	**type**\:  :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                            
                                            .. attribute:: notification
                                            
                                            	Notification
                                            	**type**\:  :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                            
                                            .. attribute:: update
                                            
                                            	Update
                                            	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                            
                                            .. attribute:: keepalive
                                            
                                            	Keepalive
                                            	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                            
                                            .. attribute:: route_refresh
                                            
                                            	Route refresh
                                            	**type**\:  :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                            
                                            .. attribute:: total
                                            
                                            	Total
                                            	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, self).__init__()

                                                self.yang_name = "message-statistics"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("open", ("open", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open)), ("notification", ("notification", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification)), ("update", ("update", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update)), ("keepalive", ("keepalive", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive)), ("route-refresh", ("route_refresh", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh)), ("total", ("total", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total))])
                                                self._leafs = OrderedDict()

                                                self.open = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                                self.open.parent = self
                                                self._children_name_map["open"] = "open"

                                                self.notification = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                                self.notification.parent = self
                                                self._children_name_map["notification"] = "notification"

                                                self.update = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                                self.update.parent = self
                                                self._children_name_map["update"] = "update"

                                                self.keepalive = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                                self.keepalive.parent = self
                                                self._children_name_map["keepalive"] = "keepalive"

                                                self.route_refresh = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                                self.route_refresh.parent = self
                                                self._children_name_map["route_refresh"] = "route-refresh"

                                                self.total = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                                self.total.parent = self
                                                self._children_name_map["total"] = "total"
                                                self._segment_path = lambda: "message-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, [], name, value)


                                            class Open(Entity):
                                                """
                                                Open
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, self).__init__()

                                                    self.yang_name = "open"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "open"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "open"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "open"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Notification(Entity):
                                                """
                                                Notification
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, self).__init__()

                                                    self.yang_name = "notification"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "notification"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "notification"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "notification"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Update(Entity):
                                                """
                                                Update
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, self).__init__()

                                                    self.yang_name = "update"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "update"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Keepalive(Entity):
                                                """
                                                Keepalive
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                                    self.yang_name = "keepalive"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "keepalive"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "keepalive"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "keepalive"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class RouteRefresh(Entity):
                                                """
                                                Route refresh
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                                    self.yang_name = "route-refresh"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "route-refresh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "route-refresh"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "route-refresh"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Total(Entity):
                                                """
                                                Total
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, self).__init__()

                                                    self.yang_name = "total"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "total"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "total"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "total"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TcpInitSyncTimeSpec(Entity):
                                            """
                                            Time When neighbor entered TCP Init Sync
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "tcp-init-sync-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                            """
                                            Time when neighbor entered TCP Init Sync Phase
                                            Two
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TcpInitSyncDoneTimeSpec(Entity):
                                            """
                                            Time when neighbor entered TCP Init Sync Done
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-done-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "tcp-init-sync-done-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class GracefulMaintenance(Entity):
                                            """
                                            Graceful Maintenance
                                            
                                            .. attribute:: gshut_exists
                                            
                                            	Graceful Maintenance enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: gshut_local_active
                                            
                                            	Graceful Maintenance locally activated
                                            	**type**\: bool
                                            
                                            .. attribute:: gshut_active
                                            
                                            	Graceful Maintenance activated
                                            	**type**\: bool
                                            
                                            .. attribute:: gshut_locpref_set
                                            
                                            	Graceful Maintenance Local Preference set
                                            	**type**\: bool
                                            
                                            .. attribute:: gshut_locpref
                                            
                                            	Graceful Maintenance Local Preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: gshut_prepends
                                            
                                            	Graceful Maintenance number of AS prepends
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, self).__init__()

                                                self.yang_name = "graceful-maintenance"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                                    ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                                    ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                                    ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                                    ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                                    ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                                ])
                                                self.gshut_exists = None
                                                self.gshut_local_active = None
                                                self.gshut_active = None
                                                self.gshut_locpref_set = None
                                                self.gshut_locpref = None
                                                self.gshut_prepends = None
                                                self._segment_path = lambda: "graceful-maintenance"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                                        class AfData(Entity):
                                            """
                                            Address family specific neighbor data
                                            
                                            .. attribute:: neighbor_af_performance_statistics
                                            
                                            	Neighbor AF statistics
                                            	**type**\:  :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: is_neighbor_route_reflector_client
                                            
                                            	Nbr is a route reflector client
                                            	**type**\: bool
                                            
                                            .. attribute:: is_legacy_pe_rt
                                            
                                            	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_af_capable
                                            
                                            	Address family capability received from neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: is_soft_reconfiguration_inbound_allowed
                                            
                                            	Inbound soft reconfiguration allowed
                                            	**type**\: bool
                                            
                                            .. attribute:: is_use_soft_reconfiguration_always_on
                                            
                                            	Soft reconf overrides route refresh
                                            	**type**\: bool
                                            
                                            .. attribute:: remove_private_as_from_updates
                                            
                                            	Private AS numbers removed from updates to this nbr
                                            	**type**\: bool
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_updates
                                            
                                            	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                            	**type**\: bool
                                            
                                            .. attribute:: remove_private_as_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr
                                            	**type**\: bool
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                            	**type**\: bool
                                            
                                            .. attribute:: flowspec_validation_d_isable
                                            
                                            	Flowspec Validation Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: flowspec_redirect_validation_d_isable
                                            
                                            	Flowspec Redirect Validation Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: orr_group_name
                                            
                                            	ORR Group Name
                                            	**type**\: str
                                            
                                            .. attribute:: orr_group_index
                                            
                                            	ORR Group Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_orr_root_address_configured
                                            
                                            	ORR Root address configuredfor the neighbor connection
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_afi
                                            
                                            	Encode in Advertise AFI
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_afi_reorg
                                            
                                            	Encode in Advertise AFI
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_afi_disable
                                            
                                            	Encode in Advertise AFI
                                            	**type**\: bool
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_rt_type
                                            
                                            	Advertise RT type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: advertise_afi_def_vrf_imp_disable
                                            
                                            	Advertise of default VRF import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                            
                                            	Advertise of v4 default VRF import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                            
                                            	Advertise of v6 default VRF import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_afi_vrf_re_imp_disable
                                            
                                            	Advertise of VRF re\-import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                            
                                            	Advertise of v4 VRF re\-import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                            
                                            	Advertise of v6 VRF re\-import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_afi_eo_r_ready
                                            
                                            	EoR Can be sent for Advertise AFI
                                            	**type**\: bool
                                            
                                            .. attribute:: always_use_next_hop_local
                                            
                                            	Local router always used for next\-hop
                                            	**type**\: bool
                                            
                                            .. attribute:: sent_community_to_neighbor
                                            
                                            	Community attribute sent to neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: sent_gshut_community_to_neighbor
                                            
                                            	GSHUT Community attribute sent to neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: sent_extended_community_to_neighbor
                                            
                                            	Extended community attribute sent to neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_default_originate
                                            
                                            	Neighbor originates default
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orf_sent
                                            
                                            	Outbound route filter sent to neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: is_update_deferred
                                            
                                            	Update deferred until ORF/route refresh received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orf_send_scheduled
                                            
                                            	Scheduled to send prefix based ORF
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: filter_group_index
                                            
                                            	Filter group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_update_throttled
                                            
                                            	Updates Throttled becausewrite limit is reached
                                            	**type**\: bool
                                            
                                            .. attribute:: is_update_leaving
                                            
                                            	Nbr leaving update\-groupto another
                                            	**type**\: bool
                                            
                                            .. attribute:: vpn_update_gen_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\: bool
                                            
                                            .. attribute:: vpn_update_gen_trigger_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\: bool
                                            
                                            .. attribute:: is_addpath_send_operational
                                            
                                            	Addpath is operational on send\-side
                                            	**type**\: bool
                                            
                                            .. attribute:: is_addpath_receive_operational
                                            
                                            	Addpath is operational on receive\-side
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_version
                                            
                                            	Neighbor version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight for this AF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: max_prefix_limit
                                            
                                            	Max limit for # of prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: use_max_prefix_warning_only
                                            
                                            	Warning only when maximum prefix limit reached
                                            	**type**\: bool
                                            
                                            .. attribute:: max_prefix_discard_extra_paths
                                            
                                            	Discard extra paths when prefix limit reached
                                            	**type**\: bool
                                            
                                            .. attribute:: max_prefix_exceed_discard_paths
                                            
                                            	Did we discard extra paths when prefix limit reached
                                            	**type**\: bool
                                            
                                            .. attribute:: max_prefix_threshold_percent
                                            
                                            	Percentage of maximum no. of prefixes at which to generate warning
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: percentage
                                            
                                            .. attribute:: max_prefix_restart_time
                                            
                                            	Time interval (in minutes) after which peering session will be reestablished
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: minute
                                            
                                            .. attribute:: prefixes_accepted
                                            
                                            	No. of prefixes accepted
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_synced
                                            
                                            	Number of prefixes synced to standby
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn_not_found
                                            
                                            	No. of prefixes withdrawn but not found
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied
                                            
                                            	No. of prefixes denied
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_no_policy
                                            
                                            	No. of prefixes denied because there was no inbound policy
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_rt_permit
                                            
                                            	No. of prefixes denied because RT extended community is not imported
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_orf_policy
                                            
                                            	No. of prefixes denied by prefix based ORF policy
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_policy
                                            
                                            	No. of prefixes denied by inbound policy
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_bestpaths
                                            
                                            	No. of bestpaths from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_best_externalpaths
                                            
                                            	No. of best\-external paths from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_advertised
                                            
                                            	No. of prefixes advertised
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_be_advertised
                                            
                                            	No BE prefixes advertised
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_suppressed
                                            
                                            	No. of prefixes suppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn
                                            
                                            	No. of prefixes withdrawn
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_peer_orf_capable
                                            
                                            	Peer has outbound route filter capability
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertised_orf_send
                                            
                                            	Prefix based ORF send mode capability advertised
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_orf_send_capable
                                            
                                            	Prefix based ORF send mode capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertised_orf_receive
                                            
                                            	Prefix based ORF receive mode capability advertised
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_orf_receive_capable
                                            
                                            	Prefix based ORF receive mode capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertised_graceful_restart
                                            
                                            	Graceful Restart Capability advertised
                                            	**type**\: bool
                                            
                                            .. attribute:: is_graceful_restart_state_flag
                                            
                                            	Restart state flag enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_graceful_restart_capable
                                            
                                            	Graceful Restart Capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_add_path_send_capability_advertised
                                            
                                            	Addpath Send capability advertised
                                            	**type**\: bool
                                            
                                            .. attribute:: is_add_path_send_capability_received
                                            
                                            	Addpath Send capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_add_path_receive_capability_advertised
                                            
                                            	Addpath Receive capability advertised
                                            	**type**\: bool
                                            
                                            .. attribute:: is_add_path_receive_capability_received
                                            
                                            	Addpath Receive capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_received
                                            
                                            	Extended nexthop encoding capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_sent
                                            
                                            	Extended nexhop encoding capability Sent
                                            	**type**\: bool
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart time advertised (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: local_restart_time
                                            
                                            	Local Restart time (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: stale_path_timeout
                                            
                                            	Stale path timeout time (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: rib_purge_timeout_value
                                            
                                            	RIB purge timeout time (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_preserved_forwarding_state
                                            
                                            	Neighbor preserved forwarding state
                                            	**type**\: bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_configured
                                            
                                            	Long\-lived graceful\-restart stale time is configured
                                            	**type**\: bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_sent
                                            
                                            	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_accept
                                            
                                            	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_capability_received
                                            
                                            	Long\-lived graceful\-restart capability received from the neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_received
                                            
                                            	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                            
                                            	Neighbor preserved long\-lived forwarding state
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_capable
                                            
                                            	Treat neighbor as long\-lived graceful\-restart capable
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                            
                                            	Remaining long\-lived graceful\-restart time
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_refreshes_received
                                            
                                            	Number of route refresh requests received
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_refreshes_sent
                                            
                                            	Number of route refresh requests sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_target_version
                                            
                                            	Target version for refresh update generation
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_version
                                            
                                            	Version till which refresh updates have been generated
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_acked_version
                                            
                                            	Version acked by the peer for refresh updates sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_prefix_orf_present
                                            
                                            	Outbound route filter prefix ORF present
                                            	**type**\: bool
                                            
                                            .. attribute:: orf_entries_received
                                            
                                            	Number of outbound route filter entries received
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_default_originate_sent
                                            
                                            	Default origination update sent
                                            	**type**\: bool
                                            
                                            .. attribute:: route_policy_prefix_orf
                                            
                                            	Prefix based ORF for incoming updates
                                            	**type**\: str
                                            
                                            .. attribute:: route_policy_in
                                            
                                            	Incoming route policy name
                                            	**type**\: str
                                            
                                            .. attribute:: route_policy_out
                                            
                                            	Outgoing route policy name
                                            	**type**\: str
                                            
                                            .. attribute:: route_policy_default_originate
                                            
                                            	Default\-originate route policy name
                                            	**type**\: str
                                            
                                            .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                            
                                            	eBGP neighbor with no configured inbound policy
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                            
                                            	eBGP neighbor with no configured outbound policy
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_override_set
                                            
                                            	As override set 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_allow_as_in_set
                                            
                                            	Allowas\-in set 
                                            	**type**\: bool
                                            
                                            .. attribute:: allow_as_in_count
                                            
                                            	Allowas\-in count config
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: address_family_long_lived_time
                                            
                                            	AF specific Long\-lived\-time config
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: eo_r_received_in_read_only
                                            
                                            	An EoR was received while in read\-only mode
                                            	**type**\: bool
                                            
                                            .. attribute:: acked_version
                                            
                                            	Version mapped from acked seqNo
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: synced_acked_version
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: outstanding_version
                                            
                                            	No. of all outstanding version objects waiting for ack from the peer
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: outstanding_refresh_version
                                            
                                            	No. of only refresh version objects waiting for ack from the peer
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: outstanding_version_max
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aigp_set
                                            
                                            	AIGP set 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rt_present_standby
                                            
                                            	RT attribute list present
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_enabled
                                            
                                            	Accept\-Own enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: selective_multipath_eligible
                                            
                                            	Selective multipath eligible
                                            	**type**\: bool
                                            
                                            .. attribute:: afrpki_disable
                                            
                                            	Prefix validation disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: afrpki_use_validity
                                            
                                            	Prefix v. use validity
                                            	**type**\: bool
                                            
                                            .. attribute:: afrpki_allow_invalid
                                            
                                            	Prefix v. allow invalid
                                            	**type**\: bool
                                            
                                            .. attribute:: afrpki_signal_ibgp
                                            
                                            	Prefix v. signal ibgp
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertise_permanent_network
                                            
                                            	Advertise Permanent Network
                                            	**type**\: bool
                                            
                                            .. attribute:: is_send_mcast_attr
                                            
                                            	Send Mcast Attr
                                            	**type**\: bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	Import Stitching enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	Import Reoriginate enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	Import Reoriginate Stitching enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_v4_flags
                                            
                                            	Advertise options for VPNV4
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_v6_flags
                                            
                                            	Advertise options for VPNV6
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_local_labeled_route_unicast
                                            
                                            	Advertise routes with 
                                            	**type**\: bool
                                            
                                            .. attribute:: prefixes_denied_non_cumulative
                                            
                                            	No. of prefixes exactly denied (non cumulative)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: enable_label_stack
                                            
                                            	Enable label stack
                                            	**type**\: bool
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_standby
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData, self).__init__()

                                                self.yang_name = "af-data"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-af-performance-statistics", ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby))])
                                                self._leafs = OrderedDict([
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                                    ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                                    ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                                    ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                                    ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                                    ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                                    ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                                    ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                                    ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                                    ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                                    ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                                    ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                                    ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                                    ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                                    ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                                    ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                                    ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                                    ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                                    ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                                    ('advertise_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-def-vrf-imp-disable'), ['bool'])),
                                                    ('advertise_evpnv4_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-def-vrf-imp-disable'), ['bool'])),
                                                    ('advertise_evpnv6_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-def-vrf-imp-disable'), ['bool'])),
                                                    ('advertise_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-vrf-re-imp-disable'), ['bool'])),
                                                    ('advertise_evpnv4_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-vrf-re-imp-disable'), ['bool'])),
                                                    ('advertise_evpnv6_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-vrf-re-imp-disable'), ['bool'])),
                                                    ('advertise_afi_eo_r_ready', (YLeaf(YType.boolean, 'advertise-afi-eo-r-ready'), ['bool'])),
                                                    ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                                    ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                                    ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                                    ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                                    ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                                    ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                                    ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                                    ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                                    ('is_update_throttled', (YLeaf(YType.boolean, 'is-update-throttled'), ['bool'])),
                                                    ('is_update_leaving', (YLeaf(YType.boolean, 'is-update-leaving'), ['bool'])),
                                                    ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                                    ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                                    ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                                    ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                                    ('neighbor_version', (YLeaf(YType.uint32, 'neighbor-version'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                                    ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                                    ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                                    ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                                    ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                                    ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                                    ('prefixes_accepted', (YLeaf(YType.uint32, 'prefixes-accepted'), ['int'])),
                                                    ('prefixes_synced', (YLeaf(YType.uint32, 'prefixes-synced'), ['int'])),
                                                    ('prefixes_withdrawn_not_found', (YLeaf(YType.uint32, 'prefixes-withdrawn-not-found'), ['int'])),
                                                    ('prefixes_denied', (YLeaf(YType.uint32, 'prefixes-denied'), ['int'])),
                                                    ('prefixes_denied_no_policy', (YLeaf(YType.uint32, 'prefixes-denied-no-policy'), ['int'])),
                                                    ('prefixes_denied_rt_permit', (YLeaf(YType.uint32, 'prefixes-denied-rt-permit'), ['int'])),
                                                    ('prefixes_denied_orf_policy', (YLeaf(YType.uint32, 'prefixes-denied-orf-policy'), ['int'])),
                                                    ('prefixes_denied_policy', (YLeaf(YType.uint32, 'prefixes-denied-policy'), ['int'])),
                                                    ('number_of_bestpaths', (YLeaf(YType.uint32, 'number-of-bestpaths'), ['int'])),
                                                    ('number_of_best_externalpaths', (YLeaf(YType.uint32, 'number-of-best-externalpaths'), ['int'])),
                                                    ('prefixes_advertised', (YLeaf(YType.uint32, 'prefixes-advertised'), ['int'])),
                                                    ('prefixes_be_advertised', (YLeaf(YType.uint32, 'prefixes-be-advertised'), ['int'])),
                                                    ('prefixes_suppressed', (YLeaf(YType.uint32, 'prefixes-suppressed'), ['int'])),
                                                    ('prefixes_withdrawn', (YLeaf(YType.uint32, 'prefixes-withdrawn'), ['int'])),
                                                    ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                                    ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                                    ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                                    ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                                    ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                                    ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                                    ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                                    ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                                    ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                                    ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                                    ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                                    ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                                    ('is_ext_nh_encoding_capability_received', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-received'), ['bool'])),
                                                    ('is_ext_nh_encoding_capability_sent', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-sent'), ['bool'])),
                                                    ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                                    ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                                    ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                                    ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                                    ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                                    ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                                    ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                                    ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                                    ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                                    ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                                    ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                                    ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                                    ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                                    ('route_refreshes_received', (YLeaf(YType.uint32, 'route-refreshes-received'), ['int'])),
                                                    ('route_refreshes_sent', (YLeaf(YType.uint32, 'route-refreshes-sent'), ['int'])),
                                                    ('refresh_target_version', (YLeaf(YType.uint32, 'refresh-target-version'), ['int'])),
                                                    ('refresh_version', (YLeaf(YType.uint32, 'refresh-version'), ['int'])),
                                                    ('refresh_acked_version', (YLeaf(YType.uint32, 'refresh-acked-version'), ['int'])),
                                                    ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                                    ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                                    ('is_default_originate_sent', (YLeaf(YType.boolean, 'is-default-originate-sent'), ['bool'])),
                                                    ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                                    ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                                    ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                                    ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                                    ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                                    ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                                    ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                                    ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                                    ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                                    ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                                    ('eo_r_received_in_read_only', (YLeaf(YType.boolean, 'eo-r-received-in-read-only'), ['bool'])),
                                                    ('acked_version', (YLeaf(YType.uint32, 'acked-version'), ['int'])),
                                                    ('synced_acked_version', (YLeaf(YType.uint32, 'synced-acked-version'), ['int'])),
                                                    ('outstanding_version', (YLeaf(YType.uint32, 'outstanding-version'), ['int'])),
                                                    ('outstanding_refresh_version', (YLeaf(YType.uint32, 'outstanding-refresh-version'), ['int'])),
                                                    ('outstanding_version_max', (YLeaf(YType.uint32, 'outstanding-version-max'), ['int'])),
                                                    ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                                    ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                                    ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                                    ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                                    ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                                    ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                                    ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                                    ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                                    ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                                    ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                                    ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                                    ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                                    ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                                    ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                                    ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                                    ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                                    ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                                    ('prefixes_denied_non_cumulative', (YLeaf(YType.uint32, 'prefixes-denied-non-cumulative'), ['int'])),
                                                    ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                                ])
                                                self.af_name = None
                                                self.is_neighbor_route_reflector_client = None
                                                self.is_legacy_pe_rt = None
                                                self.is_neighbor_af_capable = None
                                                self.is_soft_reconfiguration_inbound_allowed = None
                                                self.is_use_soft_reconfiguration_always_on = None
                                                self.remove_private_as_from_updates = None
                                                self.remove_private_as_entire_aspath_from_updates = None
                                                self.remove_private_as_from_inbound_updates = None
                                                self.remove_private_as_entire_aspath_from_inbound_updates = None
                                                self.flowspec_validation_d_isable = None
                                                self.flowspec_redirect_validation_d_isable = None
                                                self.orr_group_name = None
                                                self.orr_group_index = None
                                                self.is_orr_root_address_configured = None
                                                self.advertise_afi = None
                                                self.advertise_afi_reorg = None
                                                self.advertise_afi_disable = None
                                                self.encapsulation_type = None
                                                self.advertise_rt_type = None
                                                self.advertise_afi_def_vrf_imp_disable = None
                                                self.advertise_evpnv4_afi_def_vrf_imp_disable = None
                                                self.advertise_evpnv6_afi_def_vrf_imp_disable = None
                                                self.advertise_afi_vrf_re_imp_disable = None
                                                self.advertise_evpnv4_afi_vrf_re_imp_disable = None
                                                self.advertise_evpnv6_afi_vrf_re_imp_disable = None
                                                self.advertise_afi_eo_r_ready = None
                                                self.always_use_next_hop_local = None
                                                self.sent_community_to_neighbor = None
                                                self.sent_gshut_community_to_neighbor = None
                                                self.sent_extended_community_to_neighbor = None
                                                self.neighbor_default_originate = None
                                                self.is_orf_sent = None
                                                self.is_update_deferred = None
                                                self.is_orf_send_scheduled = None
                                                self.update_group_number = None
                                                self.filter_group_index = None
                                                self.is_update_throttled = None
                                                self.is_update_leaving = None
                                                self.vpn_update_gen_enabled = None
                                                self.vpn_update_gen_trigger_enabled = None
                                                self.is_addpath_send_operational = None
                                                self.is_addpath_receive_operational = None
                                                self.neighbor_version = None
                                                self.weight = None
                                                self.max_prefix_limit = None
                                                self.use_max_prefix_warning_only = None
                                                self.max_prefix_discard_extra_paths = None
                                                self.max_prefix_exceed_discard_paths = None
                                                self.max_prefix_threshold_percent = None
                                                self.max_prefix_restart_time = None
                                                self.prefixes_accepted = None
                                                self.prefixes_synced = None
                                                self.prefixes_withdrawn_not_found = None
                                                self.prefixes_denied = None
                                                self.prefixes_denied_no_policy = None
                                                self.prefixes_denied_rt_permit = None
                                                self.prefixes_denied_orf_policy = None
                                                self.prefixes_denied_policy = None
                                                self.number_of_bestpaths = None
                                                self.number_of_best_externalpaths = None
                                                self.prefixes_advertised = None
                                                self.prefixes_be_advertised = None
                                                self.prefixes_suppressed = None
                                                self.prefixes_withdrawn = None
                                                self.is_peer_orf_capable = None
                                                self.is_advertised_orf_send = None
                                                self.is_received_orf_send_capable = None
                                                self.is_advertised_orf_receive = None
                                                self.is_received_orf_receive_capable = None
                                                self.is_advertised_graceful_restart = None
                                                self.is_graceful_restart_state_flag = None
                                                self.is_received_graceful_restart_capable = None
                                                self.is_add_path_send_capability_advertised = None
                                                self.is_add_path_send_capability_received = None
                                                self.is_add_path_receive_capability_advertised = None
                                                self.is_add_path_receive_capability_received = None
                                                self.is_ext_nh_encoding_capability_received = None
                                                self.is_ext_nh_encoding_capability_sent = None
                                                self.restart_time = None
                                                self.local_restart_time = None
                                                self.stale_path_timeout = None
                                                self.rib_purge_timeout_value = None
                                                self.neighbor_preserved_forwarding_state = None
                                                self.long_lived_graceful_restart_stale_time_configured = None
                                                self.long_lived_graceful_restart_stale_time_sent = None
                                                self.long_lived_graceful_restart_stale_time_accept = None
                                                self.long_lived_graceful_restart_capability_received = None
                                                self.long_lived_graceful_restart_stale_time_received = None
                                                self.neighbor_preserved_long_lived_forwarding_state = None
                                                self.neighbor_long_lived_graceful_restart_capable = None
                                                self.neighbor_long_lived_graceful_restart_time_remaining = None
                                                self.route_refreshes_received = None
                                                self.route_refreshes_sent = None
                                                self.refresh_target_version = None
                                                self.refresh_version = None
                                                self.refresh_acked_version = None
                                                self.is_prefix_orf_present = None
                                                self.orf_entries_received = None
                                                self.is_default_originate_sent = None
                                                self.route_policy_prefix_orf = None
                                                self.route_policy_in = None
                                                self.route_policy_out = None
                                                self.route_policy_default_originate = None
                                                self.is_neighbor_ebgp_without_inbound_policy = None
                                                self.is_neighbor_ebgp_without_outbound_policy = None
                                                self.is_as_override_set = None
                                                self.is_allow_as_in_set = None
                                                self.allow_as_in_count = None
                                                self.address_family_long_lived_time = None
                                                self.eo_r_received_in_read_only = None
                                                self.acked_version = None
                                                self.synced_acked_version = None
                                                self.outstanding_version = None
                                                self.outstanding_refresh_version = None
                                                self.outstanding_version_max = None
                                                self.is_aigp_set = None
                                                self.is_rt_present = None
                                                self.is_rt_present_standby = None
                                                self.accept_own_enabled = None
                                                self.selective_multipath_eligible = None
                                                self.afrpki_disable = None
                                                self.afrpki_use_validity = None
                                                self.afrpki_allow_invalid = None
                                                self.afrpki_signal_ibgp = None
                                                self.is_advertise_permanent_network = None
                                                self.is_send_mcast_attr = None
                                                self.import_stitching = None
                                                self.import_reoriginate = None
                                                self.import_reoriginate_stitching = None
                                                self.advertise_v4_flags = None
                                                self.advertise_v6_flags = None
                                                self.advertise_local_labeled_route_unicast = None
                                                self.prefixes_denied_non_cumulative = None
                                                self.enable_label_stack = None

                                                self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                                self.neighbor_af_performance_statistics.parent = self
                                                self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"

                                                self.extended_community = YList(self)
                                                self.extended_community_standby = YList(self)
                                                self._segment_path = lambda: "af-data"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_disable', u'encapsulation_type', u'advertise_rt_type', u'advertise_afi_def_vrf_imp_disable', u'advertise_evpnv4_afi_def_vrf_imp_disable', u'advertise_evpnv6_afi_def_vrf_imp_disable', u'advertise_afi_vrf_re_imp_disable', u'advertise_evpnv4_afi_vrf_re_imp_disable', u'advertise_evpnv6_afi_vrf_re_imp_disable', u'advertise_afi_eo_r_ready', u'always_use_next_hop_local', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'update_group_number', u'filter_group_index', u'is_update_throttled', u'is_update_leaving', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'neighbor_version', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'prefixes_accepted', u'prefixes_synced', u'prefixes_withdrawn_not_found', u'prefixes_denied', u'prefixes_denied_no_policy', u'prefixes_denied_rt_permit', u'prefixes_denied_orf_policy', u'prefixes_denied_policy', u'number_of_bestpaths', u'number_of_best_externalpaths', u'prefixes_advertised', u'prefixes_be_advertised', u'prefixes_suppressed', u'prefixes_withdrawn', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'is_ext_nh_encoding_capability_received', u'is_ext_nh_encoding_capability_sent', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'route_refreshes_received', u'route_refreshes_sent', u'refresh_target_version', u'refresh_version', u'refresh_acked_version', u'is_prefix_orf_present', u'orf_entries_received', u'is_default_originate_sent', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'eo_r_received_in_read_only', u'acked_version', u'synced_acked_version', u'outstanding_version', u'outstanding_refresh_version', u'outstanding_version_max', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'advertise_local_labeled_route_unicast', u'prefixes_denied_non_cumulative', u'enable_label_stack'], name, value)


                                            class NeighborAfPerformanceStatistics(Entity):
                                                """
                                                Neighbor AF statistics
                                                
                                                .. attribute:: sub_group_pending_message_count
                                                
                                                	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: processed_messages
                                                
                                                	Number of messages processed from the neighbor's write queue
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent_messages
                                                
                                                	Number of messages sent from the neighbor's write queue
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_transmit
                                                
                                                	No. of update messages with split\-horizon flag that were sent out
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_blocked
                                                
                                                	No. of update messages with split\-horizon flag that were blocked
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_transmit
                                                
                                                	No. of withdraw messages with split\-horizon flag that were sent out
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_blocked
                                                
                                                	No. of withdraw messages with split\-horizon flag that were blocked
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                                    self.yang_name = "neighbor-af-performance-statistics"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sub_group_pending_message_count', (YLeaf(YType.uint32, 'sub-group-pending-message-count'), ['int'])),
                                                        ('processed_messages', (YLeaf(YType.uint32, 'processed-messages'), ['int'])),
                                                        ('sent_messages', (YLeaf(YType.uint32, 'sent-messages'), ['int'])),
                                                        ('split_horizon_update_transmit', (YLeaf(YType.uint32, 'split-horizon-update-transmit'), ['int'])),
                                                        ('split_horizon_update_blocked', (YLeaf(YType.uint32, 'split-horizon-update-blocked'), ['int'])),
                                                        ('split_horizon_withdraw_transmit', (YLeaf(YType.uint32, 'split-horizon-withdraw-transmit'), ['int'])),
                                                        ('split_horizon_withdraw_blocked', (YLeaf(YType.uint32, 'split-horizon-withdraw-blocked'), ['int'])),
                                                    ])
                                                    self.sub_group_pending_message_count = None
                                                    self.processed_messages = None
                                                    self.sent_messages = None
                                                    self.split_horizon_update_transmit = None
                                                    self.split_horizon_update_blocked = None
                                                    self.split_horizon_withdraw_transmit = None
                                                    self.split_horizon_withdraw_blocked = None
                                                    self._segment_path = lambda: "neighbor-af-performance-statistics"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, [u'sub_group_pending_message_count', u'processed_messages', u'sent_messages', u'split_horizon_update_transmit', u'split_horizon_update_blocked', u'split_horizon_withdraw_transmit', u'split_horizon_withdraw_blocked'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, [u'entry'], name, value)


                                            class ExtendedCommunityStandby(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                                    self.yang_name = "extended-community-standby"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community-standby"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                                class UpdateGenerationNeighbors(Entity):
                                    """
                                    Update generation for all neighbors
                                    
                                    .. attribute:: update_generation_neighbor
                                    
                                    	Update generation for neighbor
                                    	**type**\: list of  		 :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors, self).__init__()

                                        self.yang_name = "update-generation-neighbors"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-generation-neighbor", ("update_generation_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor))])
                                        self._leafs = OrderedDict()

                                        self.update_generation_neighbor = YList(self)
                                        self._segment_path = lambda: "update-generation-neighbors"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors, [], name, value)


                                    class UpdateGenerationNeighbor(Entity):
                                        """
                                        Update generation for neighbor
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: update_neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                        
                                        .. attribute:: last_sub_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:  :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                        
                                        .. attribute:: last_sub_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:  :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                        
                                        .. attribute:: last_filter_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:  :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                        
                                        .. attribute:: last_filter_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:  :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                        
                                        .. attribute:: first_default_originate_timestamp
                                        
                                        	First default\-origination time
                                        	**type**\:  :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: last_default_originate_timestamp
                                        
                                        	Last default\-origination time
                                        	**type**\:  :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: last_update_group_start_timestamp
                                        
                                        	Last update\-group timer start
                                        	**type**\:  :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                        
                                        .. attribute:: last_update_group_expiry_timestamp
                                        
                                        	Last update\-group timer expiry
                                        	**type**\:  :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                        
                                        .. attribute:: first_update_queued_timestamp
                                        
                                        	First update queued time
                                        	**type**\:  :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:  :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_queued_timestamp
                                        
                                        	Last refresh update queued time
                                        	**type**\:  :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: first_update_write_timestamp
                                        
                                        	First update write time
                                        	**type**\:  :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                        
                                        .. attribute:: last_update_write_timestamp
                                        
                                        	Last update write time
                                        	**type**\:  :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_write_timestamp
                                        
                                        	Last refresh update write time
                                        	**type**\:  :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_filter_group_index
                                        
                                        	Refresh Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_index
                                        
                                        	Refresh Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_id
                                        
                                        	Refresh sub\-group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_messages
                                        
                                        	Refresh OutQueue messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_size
                                        
                                        	Refresh OutQueue size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_messages
                                        
                                        	Filter\-group messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_resume_version
                                        
                                        	Resume version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ack_version
                                        
                                        	Ack version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: synced_ack_version
                                        
                                        	Synced ack version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_count
                                        
                                        	Outstanding version count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_version
                                        
                                        	Refresh version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_requested_target_version
                                        
                                        	Requested refresh target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_pending_target_version
                                        
                                        	Pending refresh target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_next_resume_version
                                        
                                        	Refresh resume version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_ack_version
                                        
                                        	Refresh Ack version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_default_originate_age
                                        
                                        	Time since last default\-origination event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: default_originate_state
                                        
                                        	Default\-origination state
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: default_originate_internal_context
                                        
                                        	Default\-origination context
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: is_eor_outstanding
                                        
                                        	Number of EORs outstanding
                                        	**type**\: bool
                                        
                                        .. attribute:: outbound_refresh_count
                                        
                                        	Refresh Outbound count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_refresh_count
                                        
                                        	Refresh Inbound count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_update_group_timer_running
                                        
                                        	Is update\-group timer running
                                        	**type**\: bool
                                        
                                        .. attribute:: current_update_group_af_name
                                        
                                        	Current Update\-group address\-family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: last_update_group_af_name
                                        
                                        	Last Update\-group address\-family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_queued_age
                                        
                                        	Time since last refresh update queued event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_write_age
                                        
                                        	Time since last update write event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_write_age
                                        
                                        	Time since last refresh update write event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, self).__init__()

                                            self.yang_name = "update-generation-neighbor"
                                            self.yang_parent_name = "update-generation-neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress)), ("last-sub-group-add-timestamp", ("last_sub_group_add_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp)), ("last-sub-group-remove-timestamp", ("last_sub_group_remove_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp)), ("last-filter-group-add-timestamp", ("last_filter_group_add_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp)), ("last-filter-group-remove-timestamp", ("last_filter_group_remove_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp)), ("first-default-originate-timestamp", ("first_default_originate_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp)), ("last-default-originate-timestamp", ("last_default_originate_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp)), ("last-update-group-start-timestamp", ("last_update_group_start_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp)), ("last-update-group-expiry-timestamp", ("last_update_group_expiry_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp)), ("first-update-queued-timestamp", ("first_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp)), ("last-update-queued-timestamp", ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp)), ("last-refresh-update-queued-timestamp", ("last_refresh_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp)), ("first-update-write-timestamp", ("first_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp)), ("last-update-write-timestamp", ("last_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp)), ("last-refresh-update-write-timestamp", ("last_refresh_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics))])
                                            self._leafs = OrderedDict([
                                                ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                                ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                                ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                                ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('update_filter_group_index', (YLeaf(YType.uint32, 'update-filter-group-index'), ['int'])),
                                                ('refresh_filter_group_index', (YLeaf(YType.uint32, 'refresh-filter-group-index'), ['int'])),
                                                ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                                ('refresh_sub_group_index', (YLeaf(YType.uint32, 'refresh-sub-group-index'), ['int'])),
                                                ('refresh_sub_group_id', (YLeaf(YType.uint32, 'refresh-sub-group-id'), ['int'])),
                                                ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                                ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                                ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                                ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                                ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                                ('refresh_update_out_queue_messages', (YLeaf(YType.uint32, 'refresh-update-out-queue-messages'), ['int'])),
                                                ('refresh_update_out_queue_size', (YLeaf(YType.uint32, 'refresh-update-out-queue-size'), ['int'])),
                                                ('update_filter_group_messages', (YLeaf(YType.uint32, 'update-filter-group-messages'), ['int'])),
                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                ('pending_target_version', (YLeaf(YType.uint32, 'pending-target-version'), ['int'])),
                                                ('next_resume_version', (YLeaf(YType.uint32, 'next-resume-version'), ['int'])),
                                                ('ack_version', (YLeaf(YType.uint32, 'ack-version'), ['int'])),
                                                ('synced_ack_version', (YLeaf(YType.uint32, 'synced-ack-version'), ['int'])),
                                                ('outstanding_version_count', (YLeaf(YType.uint32, 'outstanding-version-count'), ['int'])),
                                                ('update_refresh_version', (YLeaf(YType.uint32, 'update-refresh-version'), ['int'])),
                                                ('refresh_requested_target_version', (YLeaf(YType.uint32, 'refresh-requested-target-version'), ['int'])),
                                                ('update_refresh_target_version', (YLeaf(YType.uint32, 'update-refresh-target-version'), ['int'])),
                                                ('refresh_pending_target_version', (YLeaf(YType.uint32, 'refresh-pending-target-version'), ['int'])),
                                                ('refresh_next_resume_version', (YLeaf(YType.uint32, 'refresh-next-resume-version'), ['int'])),
                                                ('refresh_ack_version', (YLeaf(YType.uint32, 'refresh-ack-version'), ['int'])),
                                                ('last_default_originate_age', (YLeaf(YType.uint32, 'last-default-originate-age'), ['int'])),
                                                ('default_originate_state', (YLeaf(YType.int32, 'default-originate-state'), ['int'])),
                                                ('default_originate_internal_context', (YLeaf(YType.int32, 'default-originate-internal-context'), ['int'])),
                                                ('is_eor_outstanding', (YLeaf(YType.boolean, 'is-eor-outstanding'), ['bool'])),
                                                ('outbound_refresh_count', (YLeaf(YType.uint32, 'outbound-refresh-count'), ['int'])),
                                                ('inbound_refresh_count', (YLeaf(YType.uint32, 'inbound-refresh-count'), ['int'])),
                                                ('is_update_group_timer_running', (YLeaf(YType.boolean, 'is-update-group-timer-running'), ['bool'])),
                                                ('current_update_group_af_name', (YLeaf(YType.enumeration, 'current-update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('last_update_group_af_name', (YLeaf(YType.enumeration, 'last-update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('last_update_queued_age', (YLeaf(YType.uint32, 'last-update-queued-age'), ['int'])),
                                                ('last_refresh_update_queued_age', (YLeaf(YType.uint32, 'last-refresh-update-queued-age'), ['int'])),
                                                ('last_update_write_age', (YLeaf(YType.uint32, 'last-update-write-age'), ['int'])),
                                                ('last_refresh_update_write_age', (YLeaf(YType.uint32, 'last-refresh-update-write-age'), ['int'])),
                                            ])
                                            self.update_group_index = None
                                            self.sub_group_index = None
                                            self.sub_group_id = None
                                            self.filter_group_index = None
                                            self.neighbor_address = None
                                            self.process_id = None
                                            self.update_vrf_name = None
                                            self.update_group_af_name = None
                                            self.update_filter_group_index = None
                                            self.refresh_filter_group_index = None
                                            self.sub_group_index_xr = None
                                            self.refresh_sub_group_index = None
                                            self.refresh_sub_group_id = None
                                            self.update_group_index_xr = None
                                            self.update_main_table_version = None
                                            self.update_vrf_table_rib_version = None
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.refresh_update_out_queue_messages = None
                                            self.refresh_update_out_queue_size = None
                                            self.update_filter_group_messages = None
                                            self.version = None
                                            self.pending_target_version = None
                                            self.next_resume_version = None
                                            self.ack_version = None
                                            self.synced_ack_version = None
                                            self.outstanding_version_count = None
                                            self.update_refresh_version = None
                                            self.refresh_requested_target_version = None
                                            self.update_refresh_target_version = None
                                            self.refresh_pending_target_version = None
                                            self.refresh_next_resume_version = None
                                            self.refresh_ack_version = None
                                            self.last_default_originate_age = None
                                            self.default_originate_state = None
                                            self.default_originate_internal_context = None
                                            self.is_eor_outstanding = None
                                            self.outbound_refresh_count = None
                                            self.inbound_refresh_count = None
                                            self.is_update_group_timer_running = None
                                            self.current_update_group_af_name = None
                                            self.last_update_group_af_name = None
                                            self.last_update_queued_age = None
                                            self.last_refresh_update_queued_age = None
                                            self.last_update_write_age = None
                                            self.last_refresh_update_write_age = None

                                            self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                            self.update_neighbor_address.parent = self
                                            self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                            self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                            self.last_sub_group_add_timestamp.parent = self
                                            self._children_name_map["last_sub_group_add_timestamp"] = "last-sub-group-add-timestamp"

                                            self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                            self.last_sub_group_remove_timestamp.parent = self
                                            self._children_name_map["last_sub_group_remove_timestamp"] = "last-sub-group-remove-timestamp"

                                            self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                            self.last_filter_group_add_timestamp.parent = self
                                            self._children_name_map["last_filter_group_add_timestamp"] = "last-filter-group-add-timestamp"

                                            self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                            self.last_filter_group_remove_timestamp.parent = self
                                            self._children_name_map["last_filter_group_remove_timestamp"] = "last-filter-group-remove-timestamp"

                                            self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                            self.first_default_originate_timestamp.parent = self
                                            self._children_name_map["first_default_originate_timestamp"] = "first-default-originate-timestamp"

                                            self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                            self.last_default_originate_timestamp.parent = self
                                            self._children_name_map["last_default_originate_timestamp"] = "last-default-originate-timestamp"

                                            self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                            self.last_update_group_start_timestamp.parent = self
                                            self._children_name_map["last_update_group_start_timestamp"] = "last-update-group-start-timestamp"

                                            self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                            self.last_update_group_expiry_timestamp.parent = self
                                            self._children_name_map["last_update_group_expiry_timestamp"] = "last-update-group-expiry-timestamp"

                                            self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                            self.first_update_queued_timestamp.parent = self
                                            self._children_name_map["first_update_queued_timestamp"] = "first-update-queued-timestamp"

                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"

                                            self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                            self.last_refresh_update_queued_timestamp.parent = self
                                            self._children_name_map["last_refresh_update_queued_timestamp"] = "last-refresh-update-queued-timestamp"

                                            self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                            self.first_update_write_timestamp.parent = self
                                            self._children_name_map["first_update_write_timestamp"] = "first-update-write-timestamp"

                                            self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                            self.last_update_write_timestamp.parent = self
                                            self._children_name_map["last_update_write_timestamp"] = "last-update-write-timestamp"

                                            self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                            self.last_refresh_update_write_timestamp.parent = self
                                            self._children_name_map["last_refresh_update_write_timestamp"] = "last-refresh-update-write-timestamp"

                                            self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._segment_path = lambda: "update-generation-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, ['update_group_index', 'sub_group_index', 'sub_group_id', 'filter_group_index', 'neighbor_address', u'process_id', u'update_vrf_name', u'update_group_af_name', u'update_filter_group_index', u'refresh_filter_group_index', u'sub_group_index_xr', u'refresh_sub_group_index', u'refresh_sub_group_id', u'update_group_index_xr', u'update_main_table_version', u'update_vrf_table_rib_version', u'update_out_queue_messages', u'update_out_queue_size', u'refresh_update_out_queue_messages', u'refresh_update_out_queue_size', u'update_filter_group_messages', u'version', u'pending_target_version', u'next_resume_version', u'ack_version', u'synced_ack_version', u'outstanding_version_count', u'update_refresh_version', u'refresh_requested_target_version', u'update_refresh_target_version', u'refresh_pending_target_version', u'refresh_next_resume_version', u'refresh_ack_version', u'last_default_originate_age', u'default_originate_state', u'default_originate_internal_context', u'is_eor_outstanding', u'outbound_refresh_count', u'inbound_refresh_count', u'is_update_group_timer_running', u'current_update_group_af_name', u'last_update_group_af_name', u'last_update_queued_age', u'last_refresh_update_queued_age', u'last_update_write_age', u'last_refresh_update_write_age'], name, value)


                                        class UpdateNeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, self).__init__()

                                                self.yang_name = "update-neighbor-address"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "update-neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class LastSubGroupAddTimestamp(Entity):
                                            """
                                            Last added time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, self).__init__()

                                                self.yang_name = "last-sub-group-add-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-sub-group-add-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastSubGroupRemoveTimestamp(Entity):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, self).__init__()

                                                self.yang_name = "last-sub-group-remove-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-sub-group-remove-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastFilterGroupAddTimestamp(Entity):
                                            """
                                            Last added time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, self).__init__()

                                                self.yang_name = "last-filter-group-add-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-filter-group-add-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastFilterGroupRemoveTimestamp(Entity):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, self).__init__()

                                                self.yang_name = "last-filter-group-remove-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-filter-group-remove-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstDefaultOriginateTimestamp(Entity):
                                            """
                                            First default\-origination time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, self).__init__()

                                                self.yang_name = "first-default-originate-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-default-originate-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastDefaultOriginateTimestamp(Entity):
                                            """
                                            Last default\-origination time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, self).__init__()

                                                self.yang_name = "last-default-originate-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-default-originate-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateGroupStartTimestamp(Entity):
                                            """
                                            Last update\-group timer start
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-group-start-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-group-start-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateGroupExpiryTimestamp(Entity):
                                            """
                                            Last update\-group timer expiry
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, self).__init__()

                                                self.yang_name = "last-update-group-expiry-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-group-expiry-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstUpdateQueuedTimestamp(Entity):
                                            """
                                            First update queued time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "first-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-update-queued-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateQueuedTimestamp(Entity):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-queued-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRefreshUpdateQueuedTimestamp(Entity):
                                            """
                                            Last refresh update queued time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-refresh-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-refresh-update-queued-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstUpdateWriteTimestamp(Entity):
                                            """
                                            First update write time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "first-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-update-write-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateWriteTimestamp(Entity):
                                            """
                                            Last update write time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "last-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-write-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRefreshUpdateWriteTimestamp(Entity):
                                            """
                                            Last refresh update write time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "last-refresh-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-refresh-update-write-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                                self._leafs = OrderedDict([
                                                    ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                    ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                    ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                    ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                    ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                    ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                    ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                    ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                    ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                    ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                    ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                    ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                    ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                    ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                    ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                    ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                                ])
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_size_high = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_cleared = None
                                                self.last_update_discard_age = None
                                                self.last_update_cleard_age = None
                                                self.update_throttle_count = None
                                                self.last_update_throttle_age = None
                                                self.update_recovery_count = None
                                                self.last_update_recovery_age = None
                                                self.update_memory_allocation_fail_count = None
                                                self.last_update_memory_allocation_fail_age = None

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._segment_path = lambda: "update-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-discard-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateGenerationAddressFamily(Entity):
                                    """
                                    Update generation for address\-family
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Upate statistics
                                    	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_rib_version
                                    
                                    	RIB version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_min_neighbor_version
                                    
                                    	Minimum Neighbor version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_af
                                    
                                    	Current AF update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_af
                                    
                                    	Configured AF update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_subgrp_ebgp
                                    
                                    	Current EBGP sub\-group update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_subgrp_ebgp
                                    
                                    	Configured EBGP sub\-group update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_sub_group_ibgp
                                    
                                    	Current IBGP sub\-group update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_sub_group_ibgp
                                    
                                    	Configured IBGP sub\-group update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messsages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is Update throttled
                                    	**type**\: bool
                                    
                                    .. attribute:: update_update_group_count
                                    
                                    	Update\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: update_vrfaf_name
                                    
                                    	Address family identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_rd_version
                                    
                                    	RD Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_update_group_count
                                    
                                    	VRF Table update\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_sub_group_count
                                    
                                    	VRF Table sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_sub_group_throttled_count
                                    
                                    	VRF Table throttled sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_count
                                    
                                    	VRF Table refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_throttled_count
                                    
                                    	VRF Table throttled refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_filter_group_count
                                    
                                    	VRF Table filter\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_neighbor_count
                                    
                                    	VRF Table neighbor count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily, self).__init__()

                                        self.yang_name = "update-generation-address-family"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics))])
                                        self._leafs = OrderedDict([
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                            ('update_rib_version', (YLeaf(YType.uint32, 'update-rib-version'), ['int'])),
                                            ('update_min_neighbor_version', (YLeaf(YType.uint32, 'update-min-neighbor-version'), ['int'])),
                                            ('current_update_limit_af', (YLeaf(YType.uint32, 'current-update-limit-af'), ['int'])),
                                            ('configured_update_limit_af', (YLeaf(YType.uint32, 'configured-update-limit-af'), ['int'])),
                                            ('current_update_limit_subgrp_ebgp', (YLeaf(YType.uint32, 'current-update-limit-subgrp-ebgp'), ['int'])),
                                            ('configured_update_limit_subgrp_ebgp', (YLeaf(YType.uint32, 'configured-update-limit-subgrp-ebgp'), ['int'])),
                                            ('current_update_limit_sub_group_ibgp', (YLeaf(YType.uint32, 'current-update-limit-sub-group-ibgp'), ['int'])),
                                            ('configured_update_limit_sub_group_ibgp', (YLeaf(YType.uint32, 'configured-update-limit-sub-group-ibgp'), ['int'])),
                                            ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                            ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                            ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                                            ('update_update_group_count', (YLeaf(YType.uint32, 'update-update-group-count'), ['int'])),
                                            ('update_sub_group_count', (YLeaf(YType.uint32, 'update-sub-group-count'), ['int'])),
                                            ('sub_group_throttled_count', (YLeaf(YType.uint32, 'sub-group-throttled-count'), ['int'])),
                                            ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                            ('refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'refresh-sub-group-throttled-count'), ['int'])),
                                            ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                            ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                            ('update_table_vrf_name', (YLeaf(YType.str, 'update-table-vrf-name'), ['str'])),
                                            ('update_vrfaf_name', (YLeaf(YType.uint32, 'update-vrfaf-name'), ['int'])),
                                            ('update_vrf_rd_version', (YLeaf(YType.uint32, 'update-vrf-rd-version'), ['int'])),
                                            ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                            ('table_update_group_count', (YLeaf(YType.uint32, 'table-update-group-count'), ['int'])),
                                            ('update_table_sub_group_count', (YLeaf(YType.uint32, 'update-table-sub-group-count'), ['int'])),
                                            ('table_sub_group_throttled_count', (YLeaf(YType.uint32, 'table-sub-group-throttled-count'), ['int'])),
                                            ('table_refresh_sub_group_count', (YLeaf(YType.uint32, 'table-refresh-sub-group-count'), ['int'])),
                                            ('table_refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'table-refresh-sub-group-throttled-count'), ['int'])),
                                            ('update_table_filter_group_count', (YLeaf(YType.uint32, 'update-table-filter-group-count'), ['int'])),
                                            ('table_neighbor_count', (YLeaf(YType.uint32, 'table-neighbor-count'), ['int'])),
                                        ])
                                        self.update_group_af_name = None
                                        self.update_main_table_version = None
                                        self.update_rib_version = None
                                        self.update_min_neighbor_version = None
                                        self.current_update_limit_af = None
                                        self.configured_update_limit_af = None
                                        self.current_update_limit_subgrp_ebgp = None
                                        self.configured_update_limit_subgrp_ebgp = None
                                        self.current_update_limit_sub_group_ibgp = None
                                        self.configured_update_limit_sub_group_ibgp = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_throttled = None
                                        self.update_update_group_count = None
                                        self.update_sub_group_count = None
                                        self.sub_group_throttled_count = None
                                        self.refresh_sub_group_count = None
                                        self.refresh_sub_group_throttled_count = None
                                        self.filter_group_count = None
                                        self.neighbor_count = None
                                        self.update_table_vrf_name = None
                                        self.update_vrfaf_name = None
                                        self.update_vrf_rd_version = None
                                        self.update_vrf_table_rib_version = None
                                        self.table_update_group_count = None
                                        self.update_table_sub_group_count = None
                                        self.table_sub_group_throttled_count = None
                                        self.table_refresh_sub_group_count = None
                                        self.table_refresh_sub_group_throttled_count = None
                                        self.update_table_filter_group_count = None
                                        self.table_neighbor_count = None

                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._segment_path = lambda: "update-generation-address-family"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily, [u'update_group_af_name', u'update_main_table_version', u'update_rib_version', u'update_min_neighbor_version', u'current_update_limit_af', u'configured_update_limit_af', u'current_update_limit_subgrp_ebgp', u'configured_update_limit_subgrp_ebgp', u'current_update_limit_sub_group_ibgp', u'configured_update_limit_sub_group_ibgp', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled', u'update_update_group_count', u'update_sub_group_count', u'sub_group_throttled_count', u'refresh_sub_group_count', u'refresh_sub_group_throttled_count', u'filter_group_count', u'neighbor_count', u'update_table_vrf_name', u'update_vrfaf_name', u'update_vrf_rd_version', u'update_vrf_table_rib_version', u'table_update_group_count', u'update_table_sub_group_count', u'table_sub_group_throttled_count', u'table_refresh_sub_group_count', u'table_refresh_sub_group_throttled_count', u'update_table_filter_group_count', u'table_neighbor_count'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Upate statistics
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                            ])
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_size_high = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_cleared = None
                                            self.last_update_discard_age = None
                                            self.last_update_cleard_age = None
                                            self.update_throttle_count = None
                                            self.last_update_throttle_age = None
                                            self.update_recovery_count = None
                                            self.last_update_recovery_age = None
                                            self.update_memory_allocation_fail_count = None
                                            self.last_update_memory_allocation_fail_age = None

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._segment_path = lambda: "update-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-discard-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-cleared-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-throttle-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-recovery-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class Dampenings(Entity):
                                    """
                                    The BGP Dampening table
                                    
                                    .. attribute:: dampening
                                    
                                    	A BGP Dampening table entry
                                    	**type**\: list of  		 :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings, self).__init__()

                                        self.yang_name = "dampenings"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampening", ("dampening", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening))])
                                        self._leafs = OrderedDict()

                                        self.dampening = YList(self)
                                        self._segment_path = lambda: "dampenings"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings, [], name, value)


                                    class Dampening(Entity):
                                        """
                                        A BGP Dampening table entry
                                        
                                        .. attribute:: reuse
                                        
                                        	Reuse array index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: orig_source_rd
                                        
                                        	Original Source Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "dampenings"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('reuse', (YLeaf(YType.uint32, 'reuse'), ['int'])),
                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('length', (YLeaf(YType.uint32, 'length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                                ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                                ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.reuse = None
                                            self.version = None
                                            self.rd = None
                                            self.network = None
                                            self.length = None
                                            self.neighbor_address = None
                                            self.source_rd = None
                                            self.orig_source_rd = None
                                            self.path_id = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "dampening"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening, ['reuse', 'version', 'rd', 'network', 'length', 'neighbor_address', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class PrefixFilters(Entity):
                                    """
                                    The BGP Prefix Filter table
                                    
                                    .. attribute:: prefix_filter
                                    
                                    	A BGP prefix filter table entry
                                    	**type**\: list of  		 :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters, self).__init__()

                                        self.yang_name = "prefix-filters"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-filter", ("prefix_filter", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter))])
                                        self._leafs = OrderedDict()

                                        self.prefix_filter = YList(self)
                                        self._segment_path = lambda: "prefix-filters"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters, [], name, value)


                                    class PrefixFilter(Entity):
                                        """
                                        A BGP prefix filter table entry
                                        
                                        .. attribute:: neighbor_address  (key)
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                        
                                        .. attribute:: prefix_list_info
                                        
                                        	Prefix list
                                        	**type**\:  :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identfier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter, self).__init__()

                                            self.yang_name = "prefix-filter"
                                            self.yang_parent_name = "prefix-filters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['neighbor_address']
                                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr)), ("prefix-list-info", ("prefix_list_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo))])
                                            self._leafs = OrderedDict([
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.neighbor_address = None
                                            self.af_name = None

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                            self.prefix_list_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                            self.prefix_list_info.parent = self
                                            self._children_name_map["prefix_list_info"] = "prefix-list-info"
                                            self._segment_path = lambda: "prefix-filter" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter, ['neighbor_address', u'af_name'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "prefix-filter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address-xr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PrefixListInfo(Entity):
                                            """
                                            Prefix list
                                            
                                            .. attribute:: bgp_pfxlst
                                            
                                            	bgp pfxlst
                                            	**type**\: list of  		 :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, self).__init__()

                                                self.yang_name = "prefix-list-info"
                                                self.yang_parent_name = "prefix-filter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-pfxlst", ("bgp_pfxlst", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst))])
                                                self._leafs = OrderedDict()

                                                self.bgp_pfxlst = YList(self)
                                                self._segment_path = lambda: "prefix-list-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, [], name, value)


                                            class BgpPfxlst(Entity):
                                                """
                                                bgp pfxlst
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_prefix_grant
                                                
                                                	TRUE = permit, FALSE = deny
                                                	**type**\: bool
                                                
                                                .. attribute:: min_prefix_length
                                                
                                                	Minimum prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: max_prefix_length
                                                
                                                	Maximum prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, self).__init__()

                                                    self.yang_name = "bgp-pfxlst"
                                                    self.yang_parent_name = "prefix-list-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix))])
                                                    self._leafs = OrderedDict([
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('is_prefix_grant', (YLeaf(YType.boolean, 'is-prefix-grant'), ['bool'])),
                                                        ('min_prefix_length', (YLeaf(YType.uint8, 'min-prefix-length'), ['int'])),
                                                        ('max_prefix_length', (YLeaf(YType.uint8, 'max-prefix-length'), ['int'])),
                                                    ])
                                                    self.sequence_number = None
                                                    self.is_prefix_grant = None
                                                    self.min_prefix_length = None
                                                    self.max_prefix_length = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._segment_path = lambda: "bgp-pfxlst"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, [u'sequence_number', u'is_prefix_grant', u'min_prefix_length', u'max_prefix_length'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "bgp-pfxlst"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class Attributes(Entity):
                                    """
                                    The BGP Attribute table
                                    
                                    .. attribute:: attribute
                                    
                                    	A BGP Attribute table entry
                                    	**type**\: list of  		 :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes, self).__init__()

                                        self.yang_name = "attributes"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("attribute", ("attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute))])
                                        self._leafs = OrderedDict()

                                        self.attribute = YList(self)
                                        self._segment_path = lambda: "attributes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes, [], name, value)


                                    class Attribute(Entity):
                                        """
                                        A BGP Attribute table entry
                                        
                                        .. attribute:: attribute_iid
                                        
                                        	Attribute IID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_cache_bucket
                                        
                                        	Attribute cache bucket
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_cache_id
                                        
                                        	Attribute cache ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_info
                                        
                                        	Attributes
                                        	**type**\:  :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: attribute_instance_id
                                        
                                        	Attribute Instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: attribute_structure_id
                                        
                                        	ID of attribute structure
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_structure_hash_value
                                        
                                        	Hash value for attribute structure
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_count
                                        
                                        	Number of paths which use this attribute structure
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute, self).__init__()

                                            self.yang_name = "attribute"
                                            self.yang_parent_name = "attributes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("attribute-info", ("attribute_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo))])
                                            self._leafs = OrderedDict([
                                                ('attribute_iid', (YLeaf(YType.uint32, 'attribute-iid'), ['int'])),
                                                ('attribute_cache_bucket', (YLeaf(YType.uint32, 'attribute-cache-bucket'), ['int'])),
                                                ('attribute_cache_id', (YLeaf(YType.uint32, 'attribute-cache-id'), ['int'])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('attribute_instance_id', (YLeaf(YType.uint8, 'attribute-instance-id'), ['int'])),
                                                ('attribute_structure_id', (YLeaf(YType.uint32, 'attribute-structure-id'), ['int'])),
                                                ('attribute_structure_hash_value', (YLeaf(YType.uint32, 'attribute-structure-hash-value'), ['int'])),
                                                ('reference_count', (YLeaf(YType.uint32, 'reference-count'), ['int'])),
                                            ])
                                            self.attribute_iid = None
                                            self.attribute_cache_bucket = None
                                            self.attribute_cache_id = None
                                            self.process_instance_id = None
                                            self.attribute_instance_id = None
                                            self.attribute_structure_id = None
                                            self.attribute_structure_hash_value = None
                                            self.reference_count = None

                                            self.attribute_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                            self.attribute_info.parent = self
                                            self._children_name_map["attribute_info"] = "attribute-info"
                                            self._segment_path = lambda: "attribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute, ['attribute_iid', 'attribute_cache_bucket', 'attribute_cache_id', u'process_instance_id', u'attribute_instance_id', u'attribute_structure_id', u'attribute_structure_hash_value', u'reference_count'], name, value)


                                        class AttributeInfo(Entity):
                                            """
                                            Attributes
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo, self).__init__()

                                                self.yang_name = "attribute-info"
                                                self.yang_parent_name = "attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attribute-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class Information(Entity):
                            """
                            Meta data for VRF
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{16}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                ])
                                self.route_distinguisher = None
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Information, [u'route_distinguisher'], name, value)


                        class UpdateInboundFilterVrf(Entity):
                            """
                            Update inbound filtering information for the VRF
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_neighbor_count
                            
                            	Count of neighbors that received filtered messages
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered messages received event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf, self).__init__()

                                self.yang_name = "update-inbound-filter-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("last-update-filtered-timestamp", ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp))])
                                self._leafs = OrderedDict([
                                    ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                    ('update_filtered_message_count', (YLeaf(YType.uint32, 'update-filtered-message-count'), ['int'])),
                                    ('update_filtered_neighbor_count', (YLeaf(YType.uint32, 'update-filtered-neighbor-count'), ['int'])),
                                    ('last_update_filtered_age', (YLeaf(YType.uint32, 'last-update-filtered-age'), ['int'])),
                                ])
                                self.update_vrf_name = None
                                self.update_filtered_message_count = None
                                self.update_filtered_neighbor_count = None
                                self.last_update_filtered_age = None

                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                                self._segment_path = lambda: "update-inbound-filter-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf, [u'update_vrf_name', u'update_filtered_message_count', u'update_filtered_neighbor_count', u'last_update_filtered_age'], name, value)


                            class LastUpdateFilteredTimestamp(Entity):
                                """
                                Last Filtered messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "last-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-update-filtered-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class Postits(Entity):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: postit
                            
                            	A BGP Postit table entry
                            	**type**\: list of  		 :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits, self).__init__()

                                self.yang_name = "postits"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("postit", ("postit", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit))])
                                self._leafs = OrderedDict()

                                self.postit = YList(self)
                                self._segment_path = lambda: "postits"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits, [], name, value)


                            class Postit(Entity):
                                """
                                A BGP Postit table entry
                                
                                .. attribute:: neighbor_address  (key)
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbors_address
                                
                                	Neighbor Addr
                                	**type**\:  :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress>`
                                
                                .. attribute:: vrf_name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: connect_state
                                
                                	State
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: start_time
                                
                                	StartTime
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: neighbor_af
                                
                                	Neighbor Afi
                                	**type**\: list of  		 :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborAf>`
                                
                                .. attribute:: postit_info
                                
                                	Postit Info
                                	**type**\: list of  		 :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit, self).__init__()

                                    self.yang_name = "postit"
                                    self.yang_parent_name = "postits"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_address']
                                    self._child_classes = OrderedDict([("neighbors-address", ("neighbors_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress)), ("neighbor-af", ("neighbor_af", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborAf)), ("postit-info", ("postit_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('connect_state', (YLeaf(YType.uint32, 'connect-state'), ['int'])),
                                        ('start_time', (YLeaf(YType.uint32, 'start-time'), ['int'])),
                                        ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                    ])
                                    self.neighbor_address = None
                                    self.vrf_name = None
                                    self.connect_state = None
                                    self.start_time = None
                                    self.nsr_state = None

                                    self.neighbors_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress()
                                    self.neighbors_address.parent = self
                                    self._children_name_map["neighbors_address"] = "neighbors-address"

                                    self.neighbor_af = YList(self)
                                    self.postit_info = YList(self)
                                    self._segment_path = lambda: "postit" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit, ['neighbor_address', u'vrf_name', u'connect_state', u'start_time', u'nsr_state'], name, value)


                                class NeighborsAddress(Entity):
                                    """
                                    Neighbor Addr
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress, self).__init__()

                                        self.yang_name = "neighbors-address"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "neighbors-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NeighborAf(Entity):
                                    """
                                    Neighbor Afi
                                    
                                    .. attribute:: entry
                                    
                                    	Array entry
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborAf, self).__init__()

                                        self.yang_name = "neighbor-af"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "neighbor-af"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.NeighborAf, [u'entry'], name, value)


                                class PostitInfo(Entity):
                                    """
                                    Postit Info
                                    
                                    .. attribute:: postit_notification
                                    
                                    	Postit notification
                                    	**type**\:  :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification>`
                                    
                                    .. attribute:: postit_type
                                    
                                    	Postit Type
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_subtype
                                    
                                    	Postit Subtype
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_flags
                                    
                                    	Postit Flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_af_name
                                    
                                    	Postit Afi
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: postit_ts
                                    
                                    	Postit TS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: postit_direction
                                    
                                    	Postit Direction
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_id
                                    
                                    	Postit ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_policy
                                    
                                    	Policy
                                    	**type**\: str
                                    
                                    .. attribute:: postit_reset
                                    
                                    	Reset
                                    	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo, self).__init__()

                                        self.yang_name = "postit-info"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("postit-notification", ("postit_notification", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification))])
                                        self._leafs = OrderedDict([
                                            ('postit_type', (YLeaf(YType.uint32, 'postit-type'), ['int'])),
                                            ('postit_subtype', (YLeaf(YType.uint32, 'postit-subtype'), ['int'])),
                                            ('postit_flags', (YLeaf(YType.uint8, 'postit-flags'), ['int'])),
                                            ('postit_af_name', (YLeaf(YType.enumeration, 'postit-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('postit_ts', (YLeaf(YType.uint64, 'postit-ts'), ['int'])),
                                            ('postit_direction', (YLeaf(YType.uint8, 'postit-direction'), ['int'])),
                                            ('postit_id', (YLeaf(YType.uint32, 'postit-id'), ['int'])),
                                            ('peer_id', (YLeaf(YType.uint32, 'peer-id'), ['int'])),
                                            ('postit_policy', (YLeaf(YType.str, 'postit-policy'), ['str'])),
                                            ('postit_reset', (YLeaf(YType.enumeration, 'postit-reset'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                        ])
                                        self.postit_type = None
                                        self.postit_subtype = None
                                        self.postit_flags = None
                                        self.postit_af_name = None
                                        self.postit_ts = None
                                        self.postit_direction = None
                                        self.postit_id = None
                                        self.peer_id = None
                                        self.postit_policy = None
                                        self.postit_reset = None

                                        self.postit_notification = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification()
                                        self.postit_notification.parent = self
                                        self._children_name_map["postit_notification"] = "postit-notification"
                                        self._segment_path = lambda: "postit-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo, [u'postit_type', u'postit_subtype', u'postit_flags', u'postit_af_name', u'postit_ts', u'postit_direction', u'postit_id', u'peer_id', u'postit_policy', u'postit_reset'], name, value)


                                    class PostitNotification(Entity):
                                        """
                                        Postit notification
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification, self).__init__()

                                            self.yang_name = "postit-notification"
                                            self.yang_parent_name = "postit-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData))])
                                            self._leafs = OrderedDict([
                                                ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                                ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                                ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                            ])
                                            self.time_since_last_notification = None
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "postit-notification"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "postit-notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "last-notification-data"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, [u'entry'], name, value)


                        class GlobalProcessInfo(Entity):
                            """
                            The Global Process information table
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf_>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\: str
                            
                            .. attribute:: vrfid
                            
                            	VRF ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo, self).__init__()

                                self.yang_name = "global-process-info"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf_))])
                                self._leafs = OrderedDict([
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('vrfid', (YLeaf(YType.uint32, 'vrfid'), ['int'])),
                                ])
                                self.vrf_name = None
                                self.vrfid = None

                                self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"

                                self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._segment_path = lambda: "global-process-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo, [u'vrf_name', u'vrfid'], name, value)


                            class Global(Entity):
                                """
                                Global information
                                
                                .. attribute:: in_standalone_mode
                                
                                	Standalone or Distributed mode
                                	**type**\: bool
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_name
                                
                                	Name of BGP instance
                                	**type**\: str
                                
                                .. attribute:: restart_count
                                
                                	No of times BGP has started
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_delay
                                
                                	Update delay timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: generic_scan_period
                                
                                	Period (in seconds) of generic scanner runs
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: confederation_id
                                
                                	Confederation ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: cluster_id
                                
                                	Cluster ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_cluster_id
                                
                                	Configured cluster ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_cluster_id_specified_as_ip
                                
                                	Cluster ID specified as an IP address
                                	**type**\: bool
                                
                                .. attribute:: asn_format
                                
                                	BGP AS Number Format
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start_configured
                                
                                	Configured segment\-routing Global Block start value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end_configured
                                
                                	Configured segment\-routing Global Block end value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start
                                
                                	In use segment\-routing Global Block start value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end
                                
                                	In use Segment\-routing Global Block end value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\: bool
                                
                                .. attribute:: graceful_maint_all_nbrs
                                
                                	Graceful Maintenance also for neighbors without GM configuration
                                	**type**\: bool
                                
                                .. attribute:: graceful_maint_retain_routes
                                
                                	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                                	**type**\: bool
                                
                                .. attribute:: process_rlimit
                                
                                	Platform RLIMIT max for the process
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_maximum_buffer_size
                                
                                	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_default_buffer_size
                                
                                	Default value for BMP buffer limit when a value is not configured
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_current_buffer_size
                                
                                	Current value for BMP buffer 
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_cur_maximum_buffer_size
                                
                                	Maximum limit user has configure using max\-buffer\-size command under bmp\-server
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: cluster_id_entry
                                
                                	All configured Cluster IDs
                                	**type**\: list of  		 :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global.ClusterIdEntry>`
                                
                                .. attribute:: color_id
                                
                                	All configured Color IDs
                                	**type**\: list of  		 :py:class:`ColorId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global.ColorId>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "global-process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cluster-id-entry", ("cluster_id_entry", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global.ClusterIdEntry)), ("color-id", ("color_id", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global.ColorId))])
                                    self._leafs = OrderedDict([
                                        ('in_standalone_mode', (YLeaf(YType.boolean, 'in-standalone-mode'), ['bool'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('instance_name', (YLeaf(YType.str, 'instance-name'), ['str'])),
                                        ('restart_count', (YLeaf(YType.uint32, 'restart-count'), ['int'])),
                                        ('update_delay', (YLeaf(YType.uint32, 'update-delay'), ['int'])),
                                        ('generic_scan_period', (YLeaf(YType.uint16, 'generic-scan-period'), ['int'])),
                                        ('confederation_id', (YLeaf(YType.uint32, 'confederation-id'), ['int'])),
                                        ('cluster_id', (YLeaf(YType.uint32, 'cluster-id'), ['int'])),
                                        ('configured_cluster_id', (YLeaf(YType.uint32, 'configured-cluster-id'), ['int'])),
                                        ('is_cluster_id_specified_as_ip', (YLeaf(YType.boolean, 'is-cluster-id-specified-as-ip'), ['bool'])),
                                        ('asn_format', (YLeaf(YType.uint32, 'asn-format'), ['int'])),
                                        ('srgb_start_configured', (YLeaf(YType.uint32, 'srgb-start-configured'), ['int'])),
                                        ('srgb_end_configured', (YLeaf(YType.uint32, 'srgb-end-configured'), ['int'])),
                                        ('srgb_start', (YLeaf(YType.uint32, 'srgb-start'), ['int'])),
                                        ('srgb_end', (YLeaf(YType.uint32, 'srgb-end'), ['int'])),
                                        ('graceful_maintenance', (YLeaf(YType.boolean, 'graceful-maintenance'), ['bool'])),
                                        ('graceful_maint_all_nbrs', (YLeaf(YType.boolean, 'graceful-maint-all-nbrs'), ['bool'])),
                                        ('graceful_maint_retain_routes', (YLeaf(YType.boolean, 'graceful-maint-retain-routes'), ['bool'])),
                                        ('process_rlimit', (YLeaf(YType.uint64, 'process-rlimit'), ['int'])),
                                        ('bmp_maximum_buffer_size', (YLeaf(YType.uint64, 'bmp-maximum-buffer-size'), ['int'])),
                                        ('bmp_default_buffer_size', (YLeaf(YType.uint64, 'bmp-default-buffer-size'), ['int'])),
                                        ('bmp_current_buffer_size', (YLeaf(YType.uint64, 'bmp-current-buffer-size'), ['int'])),
                                        ('bmp_cur_maximum_buffer_size', (YLeaf(YType.uint64, 'bmp-cur-maximum-buffer-size'), ['int'])),
                                    ])
                                    self.in_standalone_mode = None
                                    self.local_as = None
                                    self.instance_name = None
                                    self.restart_count = None
                                    self.update_delay = None
                                    self.generic_scan_period = None
                                    self.confederation_id = None
                                    self.cluster_id = None
                                    self.configured_cluster_id = None
                                    self.is_cluster_id_specified_as_ip = None
                                    self.asn_format = None
                                    self.srgb_start_configured = None
                                    self.srgb_end_configured = None
                                    self.srgb_start = None
                                    self.srgb_end = None
                                    self.graceful_maintenance = None
                                    self.graceful_maint_all_nbrs = None
                                    self.graceful_maint_retain_routes = None
                                    self.process_rlimit = None
                                    self.bmp_maximum_buffer_size = None
                                    self.bmp_default_buffer_size = None
                                    self.bmp_current_buffer_size = None
                                    self.bmp_cur_maximum_buffer_size = None

                                    self.cluster_id_entry = YList(self)
                                    self.color_id = YList(self)
                                    self._segment_path = lambda: "global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global, [u'in_standalone_mode', u'local_as', u'instance_name', u'restart_count', u'update_delay', u'generic_scan_period', u'confederation_id', u'cluster_id', u'configured_cluster_id', u'is_cluster_id_specified_as_ip', u'asn_format', u'srgb_start_configured', u'srgb_end_configured', u'srgb_start', u'srgb_end', u'graceful_maintenance', u'graceful_maint_all_nbrs', u'graceful_maint_retain_routes', u'process_rlimit', u'bmp_maximum_buffer_size', u'bmp_default_buffer_size', u'bmp_current_buffer_size', u'bmp_cur_maximum_buffer_size'], name, value)


                                class ClusterIdEntry(Entity):
                                    """
                                    All configured Cluster IDs
                                    
                                    .. attribute:: cluster_id_val
                                    
                                    	Cluster ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: cluster_id_type
                                    
                                    	Cluster ID type\: number or IPv4 address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global.ClusterIdEntry, self).__init__()

                                        self.yang_name = "cluster-id-entry"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('cluster_id_val', (YLeaf(YType.uint32, 'cluster-id-val'), ['int'])),
                                            ('cluster_id_type', (YLeaf(YType.uint8, 'cluster-id-type'), ['int'])),
                                        ])
                                        self.cluster_id_val = None
                                        self.cluster_id_type = None
                                        self._segment_path = lambda: "cluster-id-entry"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global.ClusterIdEntry, [u'cluster_id_val', u'cluster_id_type'], name, value)


                                class ColorId(Entity):
                                    """
                                    All configured Color IDs
                                    
                                    .. attribute:: color_id_val
                                    
                                    	Color ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global.ColorId, self).__init__()

                                        self.yang_name = "color-id"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('color_id_val', (YLeaf(YType.uint32, 'color-id-val'), ['int'])),
                                        ])
                                        self.color_id_val = None
                                        self._segment_path = lambda: "color-id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Global.ColorId, [u'color_id_val'], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: vrf_is_active
                                
                                	VRF state
                                	**type**\: bool
                                
                                .. attribute:: route_distinguisher
                                
                                	Route Distinguisher
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: router_id
                                
                                	Router ID for the VRF
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: configured_router_id
                                
                                	Configured router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                                
                                	Redistribute iBGP into IGPs enabled
                                	**type**\: bool
                                
                                .. attribute:: is_fast_external_fallover_enabled
                                
                                	Fast external fallover enabled
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_missing_med_is_worst_enabled
                                
                                	Bestpath\: Treat missing MED as worst
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_always_compare_med_enabled
                                
                                	Bestpath\: Always compare MED
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_ignore_as_path_enabled
                                
                                	Bestpath\: Ignore AS path
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                                
                                	Bestpath\: Relax AS path for mpath
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                                
                                	Bestpath\: Compare MED from confed peer
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                                
                                	Bestpath\: Compare routerID for eBGP peers
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_aigp_ignore_enabled
                                
                                	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_igp_metric_ignore_enabled
                                
                                	Bestpath\: Ignore IGP metric
                                	**type**\: bool
                                
                                .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                                
                                	Multipath\: Ignore everything AS path onwards for mpath
                                	**type**\: bool
                                
                                .. attribute:: is_enforce_first_as_enabled
                                
                                	Enforce first AS
                                	**type**\: bool
                                
                                .. attribute:: default_local_preference
                                
                                	Default local preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_time
                                
                                	Default keepalive timer (seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: hold_time
                                
                                	Default hold timer (seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: min_acceptable_hold_time
                                
                                	Default min acceptable hold time from neighbor(seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: is_neighbor_logging
                                
                                	Neighbor logging enabled
                                	**type**\: bool
                                
                                .. attribute:: is_default_metric_configured
                                
                                	Default metric configured
                                	**type**\: bool
                                
                                .. attribute:: default_metric
                                
                                	Default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_default_originate_configured
                                
                                	Default route originate configured
                                	**type**\: bool
                                
                                .. attribute:: is_graceful_restart
                                
                                	Graceful restart enabled
                                	**type**\: bool
                                
                                .. attribute:: is_nsr
                                
                                	Non\-stop routing enabled
                                	**type**\: bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: stale_path_time
                                
                                	Stale path timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rpki_use_validity
                                
                                	Use RPKI validity for bestpath calculation
                                	**type**\: bool
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Allow invalid paths
                                	**type**\: bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Signal RPKI validity to iBGP peers
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "global-process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vrf_is_active', (YLeaf(YType.boolean, 'vrf-is-active'), ['bool'])),
                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                        ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                        ('configured_router_id', (YLeaf(YType.str, 'configured-router-id'), ['str'])),
                                        ('is_redistribute_ibgp_to_ig_ps_enabled', (YLeaf(YType.boolean, 'is-redistribute-ibgp-to-ig-ps-enabled'), ['bool'])),
                                        ('is_fast_external_fallover_enabled', (YLeaf(YType.boolean, 'is-fast-external-fallover-enabled'), ['bool'])),
                                        ('is_bestpath_missing_med_is_worst_enabled', (YLeaf(YType.boolean, 'is-bestpath-missing-med-is-worst-enabled'), ['bool'])),
                                        ('is_bestpath_always_compare_med_enabled', (YLeaf(YType.boolean, 'is-bestpath-always-compare-med-enabled'), ['bool'])),
                                        ('is_bestpath_ignore_as_path_enabled', (YLeaf(YType.boolean, 'is-bestpath-ignore-as-path-enabled'), ['bool'])),
                                        ('is_bestpath_as_path_mpath_relax_enabled', (YLeaf(YType.boolean, 'is-bestpath-as-path-mpath-relax-enabled'), ['bool'])),
                                        ('is_bestpath_compare_med_from_confed_peer_enabled', (YLeaf(YType.boolean, 'is-bestpath-compare-med-from-confed-peer-enabled'), ['bool'])),
                                        ('is_bestpath_compare_router_id_for_ebgp_peers_enabled', (YLeaf(YType.boolean, 'is-bestpath-compare-router-id-for-ebgp-peers-enabled'), ['bool'])),
                                        ('is_bestpath_aigp_ignore_enabled', (YLeaf(YType.boolean, 'is-bestpath-aigp-ignore-enabled'), ['bool'])),
                                        ('is_bestpath_igp_metric_ignore_enabled', (YLeaf(YType.boolean, 'is-bestpath-igp-metric-ignore-enabled'), ['bool'])),
                                        ('is_multipath_as_path_ignore_onwards_enabled', (YLeaf(YType.boolean, 'is-multipath-as-path-ignore-onwards-enabled'), ['bool'])),
                                        ('is_enforce_first_as_enabled', (YLeaf(YType.boolean, 'is-enforce-first-as-enabled'), ['bool'])),
                                        ('default_local_preference', (YLeaf(YType.uint32, 'default-local-preference'), ['int'])),
                                        ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                        ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                        ('min_acceptable_hold_time', (YLeaf(YType.uint16, 'min-acceptable-hold-time'), ['int'])),
                                        ('is_neighbor_logging', (YLeaf(YType.boolean, 'is-neighbor-logging'), ['bool'])),
                                        ('is_default_metric_configured', (YLeaf(YType.boolean, 'is-default-metric-configured'), ['bool'])),
                                        ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                        ('is_default_originate_configured', (YLeaf(YType.boolean, 'is-default-originate-configured'), ['bool'])),
                                        ('is_graceful_restart', (YLeaf(YType.boolean, 'is-graceful-restart'), ['bool'])),
                                        ('is_nsr', (YLeaf(YType.boolean, 'is-nsr'), ['bool'])),
                                        ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                        ('stale_path_time', (YLeaf(YType.uint32, 'stale-path-time'), ['int'])),
                                        ('rib_purge_timeout', (YLeaf(YType.uint32, 'rib-purge-timeout'), ['int'])),
                                        ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                        ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                        ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                    ])
                                    self.vrf_is_active = None
                                    self.route_distinguisher = None
                                    self.router_id = None
                                    self.configured_router_id = None
                                    self.is_redistribute_ibgp_to_ig_ps_enabled = None
                                    self.is_fast_external_fallover_enabled = None
                                    self.is_bestpath_missing_med_is_worst_enabled = None
                                    self.is_bestpath_always_compare_med_enabled = None
                                    self.is_bestpath_ignore_as_path_enabled = None
                                    self.is_bestpath_as_path_mpath_relax_enabled = None
                                    self.is_bestpath_compare_med_from_confed_peer_enabled = None
                                    self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = None
                                    self.is_bestpath_aigp_ignore_enabled = None
                                    self.is_bestpath_igp_metric_ignore_enabled = None
                                    self.is_multipath_as_path_ignore_onwards_enabled = None
                                    self.is_enforce_first_as_enabled = None
                                    self.default_local_preference = None
                                    self.keep_alive_time = None
                                    self.hold_time = None
                                    self.min_acceptable_hold_time = None
                                    self.is_neighbor_logging = None
                                    self.is_default_metric_configured = None
                                    self.default_metric = None
                                    self.is_default_originate_configured = None
                                    self.is_graceful_restart = None
                                    self.is_nsr = None
                                    self.restart_time = None
                                    self.stale_path_time = None
                                    self.rib_purge_timeout = None
                                    self.rpki_use_validity = None
                                    self.rpki_allow_invalid = None
                                    self.rpki_signal_ibgp = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.GlobalProcessInfo.Vrf_, [u'vrf_is_active', u'route_distinguisher', u'router_id', u'configured_router_id', u'is_redistribute_ibgp_to_ig_ps_enabled', u'is_fast_external_fallover_enabled', u'is_bestpath_missing_med_is_worst_enabled', u'is_bestpath_always_compare_med_enabled', u'is_bestpath_ignore_as_path_enabled', u'is_bestpath_as_path_mpath_relax_enabled', u'is_bestpath_compare_med_from_confed_peer_enabled', u'is_bestpath_compare_router_id_for_ebgp_peers_enabled', u'is_bestpath_aigp_ignore_enabled', u'is_bestpath_igp_metric_ignore_enabled', u'is_multipath_as_path_ignore_onwards_enabled', u'is_enforce_first_as_enabled', u'default_local_preference', u'keep_alive_time', u'hold_time', u'min_acceptable_hold_time', u'is_neighbor_logging', u'is_default_metric_configured', u'default_metric', u'is_default_originate_configured', u'is_graceful_restart', u'is_nsr', u'restart_time', u'stale_path_time', u'rib_purge_timeout', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp'], name, value)


                        class UpdateInboundErrorNeighbors(Entity):
                            """
                            Update inbound error information for all
                            neighbors
                            
                            .. attribute:: update_inbound_error_neighbor
                            
                            	Update inbound error information for neighbor
                            	**type**\: list of  		 :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors, self).__init__()

                                self.yang_name = "update-inbound-error-neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("update-inbound-error-neighbor", ("update_inbound_error_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor))])
                                self._leafs = OrderedDict()

                                self.update_inbound_error_neighbor = YList(self)
                                self._segment_path = lambda: "update-inbound-error-neighbors"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors, [], name, value)


                            class UpdateInboundErrorNeighbor(Entity):
                                """
                                Update inbound error information for neighbor
                                
                                .. attribute:: neighbor_address  (key)
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: first_update_malformed_timestamp
                                
                                	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                                
                                .. attribute:: last_update_malformed_timestamp
                                
                                	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                                
                                .. attribute:: first_update_memory_allocation_fail_timestamp
                                
                                	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: last_update_memory_allocation_fail_timestamp
                                
                                	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: first_update_error_handling_reset_timestamp
                                
                                	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                                
                                .. attribute:: last_error_handling_reset_timestamp
                                
                                	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: update_error_handling_avoid_reset
                                
                                	Configure error\-handling to avoid resets
                                	**type**\: bool
                                
                                .. attribute:: total_update_message_count
                                
                                	Total update messages count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_malformed_message_count
                                
                                	Malformed messages count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_malformed_age
                                
                                	Time since last malformed message received event (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: update_memory_allocation_fail_count
                                
                                	Memory allocation failure count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_memory_allocation_fail_age
                                
                                	Time since last memory allocation failure event (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: update_error_handling_reset_count
                                
                                	Error\-handling reset count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_error_handling_reset_age
                                
                                	Time since last error\-handling reset event (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: update_error_message_list_count
                                
                                	Malformed messages list count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_total_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_action_count
                                
                                	Number of occurence of each action type since  session establishment
                                	**type**\: list of  		 :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                                
                                .. attribute:: update_error_message
                                
                                	List of malformed messages
                                	**type**\: list of  		 :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, self).__init__()

                                    self.yang_name = "update-inbound-error-neighbor"
                                    self.yang_parent_name = "update-inbound-error-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_address']
                                    self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress)), ("first-update-malformed-timestamp", ("first_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp)), ("last-update-malformed-timestamp", ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp)), ("first-update-memory-allocation-fail-timestamp", ("first_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp)), ("first-update-error-handling-reset-timestamp", ("first_update_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp)), ("last-error-handling-reset-timestamp", ("last_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp)), ("establishment-action-count", ("establishment_action_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount)), ("update-error-message", ("update_error_message", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                        ('update_error_handling_avoid_reset', (YLeaf(YType.boolean, 'update-error-handling-avoid-reset'), ['bool'])),
                                        ('total_update_message_count', (YLeaf(YType.uint32, 'total-update-message-count'), ['int'])),
                                        ('update_malformed_message_count', (YLeaf(YType.uint32, 'update-malformed-message-count'), ['int'])),
                                        ('last_update_malformed_age', (YLeaf(YType.uint32, 'last-update-malformed-age'), ['int'])),
                                        ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                        ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                        ('update_error_handling_reset_count', (YLeaf(YType.uint32, 'update-error-handling-reset-count'), ['int'])),
                                        ('last_error_handling_reset_age', (YLeaf(YType.uint32, 'last-error-handling-reset-age'), ['int'])),
                                        ('update_error_message_list_count', (YLeaf(YType.uint32, 'update-error-message-list-count'), ['int'])),
                                        ('update_attribute_discard_count', (YLeaf(YType.uint32, 'update-attribute-discard-count'), ['int'])),
                                        ('establishment_total_update_message_count', (YLeaf(YType.uint32, 'establishment-total-update-message-count'), ['int'])),
                                    ])
                                    self.neighbor_address = None
                                    self.update_vrf_name = None
                                    self.update_error_handling_avoid_reset = None
                                    self.total_update_message_count = None
                                    self.update_malformed_message_count = None
                                    self.last_update_malformed_age = None
                                    self.update_memory_allocation_fail_count = None
                                    self.last_update_memory_allocation_fail_age = None
                                    self.update_error_handling_reset_count = None
                                    self.last_error_handling_reset_age = None
                                    self.update_error_message_list_count = None
                                    self.update_attribute_discard_count = None
                                    self.establishment_total_update_message_count = None

                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                    self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                    self.first_update_malformed_timestamp.parent = self
                                    self._children_name_map["first_update_malformed_timestamp"] = "first-update-malformed-timestamp"

                                    self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                    self.last_update_malformed_timestamp.parent = self
                                    self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"

                                    self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                    self.first_update_memory_allocation_fail_timestamp.parent = self
                                    self._children_name_map["first_update_memory_allocation_fail_timestamp"] = "first-update-memory-allocation-fail-timestamp"

                                    self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                    self.last_update_memory_allocation_fail_timestamp.parent = self
                                    self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"

                                    self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                    self.first_update_error_handling_reset_timestamp.parent = self
                                    self._children_name_map["first_update_error_handling_reset_timestamp"] = "first-update-error-handling-reset-timestamp"

                                    self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                    self.last_error_handling_reset_timestamp.parent = self
                                    self._children_name_map["last_error_handling_reset_timestamp"] = "last-error-handling-reset-timestamp"

                                    self.establishment_action_count = YList(self)
                                    self.update_error_message = YList(self)
                                    self._segment_path = lambda: "update-inbound-error-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, ['neighbor_address', u'update_vrf_name', u'update_error_handling_avoid_reset', u'total_update_message_count', u'update_malformed_message_count', u'last_update_malformed_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age', u'update_error_handling_reset_count', u'last_error_handling_reset_age', u'update_error_message_list_count', u'update_attribute_discard_count', u'establishment_total_update_message_count'], name, value)


                                class UpdateNeighborAddress(Entity):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, self).__init__()

                                        self.yang_name = "update-neighbor-address"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "update-neighbor-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class FirstUpdateMalformedTimestamp(Entity):
                                    """
                                    First malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, self).__init__()

                                        self.yang_name = "first-update-malformed-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "first-update-malformed-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LastUpdateMalformedTimestamp(Entity):
                                    """
                                    Last malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, self).__init__()

                                        self.yang_name = "last-update-malformed-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "last-update-malformed-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class FirstUpdateMemoryAllocationFailTimestamp(Entity):
                                    """
                                    First memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, self).__init__()

                                        self.yang_name = "first-update-memory-allocation-fail-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "first-update-memory-allocation-fail-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                    """
                                    Last memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                        self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class FirstUpdateErrorHandlingResetTimestamp(Entity):
                                    """
                                    First error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, self).__init__()

                                        self.yang_name = "first-update-error-handling-reset-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "first-update-error-handling-reset-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LastErrorHandlingResetTimestamp(Entity):
                                    """
                                    Last error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, self).__init__()

                                        self.yang_name = "last-error-handling-reset-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "last-error-handling-reset-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class EstablishmentActionCount(Entity):
                                    """
                                    Number of occurence of each action type since
                                    
                                    session establishment
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, self).__init__()

                                        self.yang_name = "establishment-action-count"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "establishment-action-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, [u'entry'], name, value)


                                class UpdateErrorMessage(Entity):
                                    """
                                    List of malformed messages
                                    
                                    .. attribute:: update_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:  :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                    
                                    .. attribute:: update_message_reset_data
                                    
                                    	Reset data
                                    	**type**\:  :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                    
                                    .. attribute:: update_error_final_action
                                    
                                    	Error final action
                                    	**type**\:  :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                    
                                    .. attribute:: update_attribute_discard_count
                                    
                                    	Discarded attribute count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_error_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_error_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\: str
                                    
                                    .. attribute:: update_error_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\: bool
                                    
                                    .. attribute:: update_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of  		 :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                    
                                    .. attribute:: update_error_element
                                    
                                    	Error element list
                                    	**type**\: list of  		 :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, self).__init__()

                                        self.yang_name = "update-error-message"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-message-timestamp", ("update_message_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp)), ("update-message-reset-data", ("update_message_reset_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData)), ("update-message-data", ("update_message_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData)), ("update-error-element", ("update_error_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement))])
                                        self._leafs = OrderedDict([
                                            ('update_error_final_action', (YLeaf(YType.enumeration, 'update-error-final-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdErrAction', '')])),
                                            ('update_attribute_discard_count', (YLeaf(YType.uint32, 'update-attribute-discard-count'), ['int'])),
                                            ('update_error_nlri_address_family', (YLeaf(YType.enumeration, 'update-error-nlri-address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('update_error_nlri_string', (YLeaf(YType.str, 'update-error-nlri-string'), ['str'])),
                                            ('update_error_nlri_string_truncated', (YLeaf(YType.boolean, 'update-error-nlri-string-truncated'), ['bool'])),
                                        ])
                                        self.update_error_final_action = None
                                        self.update_attribute_discard_count = None
                                        self.update_error_nlri_address_family = None
                                        self.update_error_nlri_string = None
                                        self.update_error_nlri_string_truncated = None

                                        self.update_message_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                        self.update_message_timestamp.parent = self
                                        self._children_name_map["update_message_timestamp"] = "update-message-timestamp"

                                        self.update_message_reset_data = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                        self.update_message_reset_data.parent = self
                                        self._children_name_map["update_message_reset_data"] = "update-message-reset-data"

                                        self.update_message_data = YList(self)
                                        self.update_error_element = YList(self)
                                        self._segment_path = lambda: "update-error-message"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, [u'update_error_final_action', u'update_attribute_discard_count', u'update_error_nlri_address_family', u'update_error_nlri_string', u'update_error_nlri_string_truncated'], name, value)


                                    class UpdateMessageTimestamp(Entity):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, self).__init__()

                                            self.yang_name = "update-message-timestamp"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "update-message-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateMessageResetData(Entity):
                                        """
                                        Reset data
                                        
                                        .. attribute:: update_error_reset_reason
                                        
                                        	Reset Reason
                                        	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                        
                                        .. attribute:: update_error_reset_notification_code
                                        
                                        	Notification code
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_error_reset_notification_sub_code
                                        
                                        	Notification sub code
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_reset_notification_data
                                        
                                        	Notification data
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_reset_notification_data_length
                                        
                                        	Notification data length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, self).__init__()

                                            self.yang_name = "update-message-reset-data"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update_error_reset_reason', (YLeaf(YType.enumeration, 'update-error-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                                ('update_error_reset_notification_code', (YLeaf(YType.uint8, 'update-error-reset-notification-code'), ['int'])),
                                                ('update_error_reset_notification_sub_code', (YLeaf(YType.uint16, 'update-error-reset-notification-sub-code'), ['int'])),
                                                ('update_error_reset_notification_data', (YLeaf(YType.str, 'update-error-reset-notification-data'), ['str'])),
                                                ('update_error_reset_notification_data_length', (YLeaf(YType.uint16, 'update-error-reset-notification-data-length'), ['int'])),
                                            ])
                                            self.update_error_reset_reason = None
                                            self.update_error_reset_notification_code = None
                                            self.update_error_reset_notification_sub_code = None
                                            self.update_error_reset_notification_data = None
                                            self.update_error_reset_notification_data_length = None
                                            self._segment_path = lambda: "update-message-reset-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, [u'update_error_reset_reason', u'update_error_reset_notification_code', u'update_error_reset_notification_sub_code', u'update_error_reset_notification_data', u'update_error_reset_notification_data_length'], name, value)


                                    class UpdateMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, self).__init__()

                                            self.yang_name = "update-message-data"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "update-message-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, [u'entry'], name, value)


                                    class UpdateErrorElement(Entity):
                                        """
                                        Error element list
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_length
                                        
                                        	Attribute Length [RFC4271\: BGP4]
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_data
                                        
                                        	Error data
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_data_length
                                        
                                        	Error data length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_action
                                        
                                        	Error action
                                        	**type**\:  :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, self).__init__()

                                            self.yang_name = "update-error-element"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update_attribute_flags', (YLeaf(YType.uint8, 'update-attribute-flags'), ['int'])),
                                                ('update_attribute_code', (YLeaf(YType.uint8, 'update-attribute-code'), ['int'])),
                                                ('update_attribute_length', (YLeaf(YType.uint16, 'update-attribute-length'), ['int'])),
                                                ('update_error_data', (YLeaf(YType.str, 'update-error-data'), ['str'])),
                                                ('update_error_data_length', (YLeaf(YType.uint16, 'update-error-data-length'), ['int'])),
                                                ('update_error_action', (YLeaf(YType.enumeration, 'update-error-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdErrAction', '')])),
                                            ])
                                            self.update_attribute_flags = None
                                            self.update_attribute_code = None
                                            self.update_attribute_length = None
                                            self.update_error_data = None
                                            self.update_error_data_length = None
                                            self.update_error_action = None
                                            self._segment_path = lambda: "update-error-element"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, [u'update_attribute_flags', u'update_attribute_code', u'update_attribute_length', u'update_error_data', u'update_error_data_length', u'update_error_action'], name, value)


                        class UpdateInboundFilterNeighbors(Entity):
                            """
                            Update inbound filtering information for all
                            neighbors
                            
                            .. attribute:: update_inbound_filter_neighbor
                            
                            	Update inbound filtering information for neighbor
                            	**type**\: list of  		 :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors, self).__init__()

                                self.yang_name = "update-inbound-filter-neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("update-inbound-filter-neighbor", ("update_inbound_filter_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor))])
                                self._leafs = OrderedDict()

                                self.update_inbound_filter_neighbor = YList(self)
                                self._segment_path = lambda: "update-inbound-filter-neighbors"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors, [], name, value)


                            class UpdateInboundFilterNeighbor(Entity):
                                """
                                Update inbound filtering information for
                                neighbor
                                
                                .. attribute:: neighbor_address  (key)
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: first_update_filtered_timestamp
                                
                                	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                                
                                .. attribute:: last_update_filtered_timestamp
                                
                                	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: update_filter_logging_enabled
                                
                                	Logging is enabled
                                	**type**\: bool
                                
                                .. attribute:: configured_update_filter_message_buffer_count
                                
                                	Configured Filtered message buffer count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: operational_update_filter_message_buffer_count
                                
                                	Operational Filtered messages buffer count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filter_message_buffer_circular
                                
                                	Indicates if the message buffers are circular
                                	**type**\: bool
                                
                                .. attribute:: update_attribute_filter_group_name
                                
                                	Update attribute\-filter group name
                                	**type**\: str
                                
                                .. attribute:: operational_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled
                                	**type**\: bool
                                
                                .. attribute:: message_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled for the current message being parsed
                                	**type**\: bool
                                
                                .. attribute:: total_filter_update_message_count
                                
                                	Total update messages count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_total_filter_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filtered_message_count
                                
                                	Filtered messages count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_update_filtered_message_count
                                
                                	Filtered messages count since session establishment
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_filtered_age
                                
                                	Time since last filtered message received event (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: update_filter_message_list_count
                                
                                	Filtered messages list count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_filter_attributes
                                
                                	List of attributes that can be filtered
                                	**type**\: list of  		 :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                                
                                .. attribute:: update_filter_message
                                
                                	List of filtered messages
                                	**type**\: list of  		 :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, self).__init__()

                                    self.yang_name = "update-inbound-filter-neighbor"
                                    self.yang_parent_name = "update-inbound-filter-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_address']
                                    self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress)), ("first-update-filtered-timestamp", ("first_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp)), ("last-update-filtered-timestamp", ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp)), ("update-attribute-filter-attributes", ("update_attribute_filter_attributes", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes)), ("update-filter-message", ("update_filter_message", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                        ('update_filter_logging_enabled', (YLeaf(YType.boolean, 'update-filter-logging-enabled'), ['bool'])),
                                        ('configured_update_filter_message_buffer_count', (YLeaf(YType.uint32, 'configured-update-filter-message-buffer-count'), ['int'])),
                                        ('operational_update_filter_message_buffer_count', (YLeaf(YType.uint32, 'operational-update-filter-message-buffer-count'), ['int'])),
                                        ('update_filter_message_buffer_circular', (YLeaf(YType.boolean, 'update-filter-message-buffer-circular'), ['bool'])),
                                        ('update_attribute_filter_group_name', (YLeaf(YType.str, 'update-attribute-filter-group-name'), ['str'])),
                                        ('operational_update_attribute_filtering_enabled', (YLeaf(YType.boolean, 'operational-update-attribute-filtering-enabled'), ['bool'])),
                                        ('message_update_attribute_filtering_enabled', (YLeaf(YType.boolean, 'message-update-attribute-filtering-enabled'), ['bool'])),
                                        ('total_filter_update_message_count', (YLeaf(YType.uint32, 'total-filter-update-message-count'), ['int'])),
                                        ('establishment_total_filter_update_message_count', (YLeaf(YType.uint32, 'establishment-total-filter-update-message-count'), ['int'])),
                                        ('update_filtered_message_count', (YLeaf(YType.uint32, 'update-filtered-message-count'), ['int'])),
                                        ('establishment_update_filtered_message_count', (YLeaf(YType.uint32, 'establishment-update-filtered-message-count'), ['int'])),
                                        ('last_update_filtered_age', (YLeaf(YType.uint32, 'last-update-filtered-age'), ['int'])),
                                        ('update_filter_message_list_count', (YLeaf(YType.uint32, 'update-filter-message-list-count'), ['int'])),
                                    ])
                                    self.neighbor_address = None
                                    self.update_vrf_name = None
                                    self.update_filter_logging_enabled = None
                                    self.configured_update_filter_message_buffer_count = None
                                    self.operational_update_filter_message_buffer_count = None
                                    self.update_filter_message_buffer_circular = None
                                    self.update_attribute_filter_group_name = None
                                    self.operational_update_attribute_filtering_enabled = None
                                    self.message_update_attribute_filtering_enabled = None
                                    self.total_filter_update_message_count = None
                                    self.establishment_total_filter_update_message_count = None
                                    self.update_filtered_message_count = None
                                    self.establishment_update_filtered_message_count = None
                                    self.last_update_filtered_age = None
                                    self.update_filter_message_list_count = None

                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                    self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                    self.first_update_filtered_timestamp.parent = self
                                    self._children_name_map["first_update_filtered_timestamp"] = "first-update-filtered-timestamp"

                                    self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                    self.last_update_filtered_timestamp.parent = self
                                    self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"

                                    self.update_attribute_filter_attributes = YList(self)
                                    self.update_filter_message = YList(self)
                                    self._segment_path = lambda: "update-inbound-filter-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, ['neighbor_address', u'update_vrf_name', u'update_filter_logging_enabled', u'configured_update_filter_message_buffer_count', u'operational_update_filter_message_buffer_count', u'update_filter_message_buffer_circular', u'update_attribute_filter_group_name', u'operational_update_attribute_filtering_enabled', u'message_update_attribute_filtering_enabled', u'total_filter_update_message_count', u'establishment_total_filter_update_message_count', u'update_filtered_message_count', u'establishment_update_filtered_message_count', u'last_update_filtered_age', u'update_filter_message_list_count'], name, value)


                                class UpdateNeighborAddress(Entity):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, self).__init__()

                                        self.yang_name = "update-neighbor-address"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "update-neighbor-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class FirstUpdateFilteredTimestamp(Entity):
                                    """
                                    First filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, self).__init__()

                                        self.yang_name = "first-update-filtered-timestamp"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "first-update-filtered-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LastUpdateFilteredTimestamp(Entity):
                                    """
                                    Last filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, self).__init__()

                                        self.yang_name = "last-update-filtered-timestamp"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "last-update-filtered-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateAttributeFilterAttributes(Entity):
                                    """
                                    List of attributes that can be filtered
                                    
                                    .. attribute:: last_update_filter_match_timestamp
                                    
                                    	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:  :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                    
                                    .. attribute:: update_internal_attribute_code
                                    
                                    	Internal attribute code [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    .. attribute:: update_filter_match_count
                                    
                                    	Filter match counter
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: establishment_update_filter_match_count
                                    
                                    	Filter match counter since last session establishment
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_filter_match_age
                                    
                                    	Time since this attribute was last filtered (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, self).__init__()

                                        self.yang_name = "update-attribute-filter-attributes"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("last-update-filter-match-timestamp", ("last_update_filter_match_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('update_internal_attribute_code', (YLeaf(YType.uint32, 'update-internal-attribute-code'), ['int'])),
                                            ('update_filter_action', (YLeaf(YType.enumeration, 'update-filter-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                            ('update_filter_match_count', (YLeaf(YType.uint32, 'update-filter-match-count'), ['int'])),
                                            ('establishment_update_filter_match_count', (YLeaf(YType.uint32, 'establishment-update-filter-match-count'), ['int'])),
                                            ('last_update_filter_match_age', (YLeaf(YType.uint32, 'last-update-filter-match-age'), ['int'])),
                                        ])
                                        self.update_internal_attribute_code = None
                                        self.update_filter_action = None
                                        self.update_filter_match_count = None
                                        self.establishment_update_filter_match_count = None
                                        self.last_update_filter_match_age = None

                                        self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                        self.last_update_filter_match_timestamp.parent = self
                                        self._children_name_map["last_update_filter_match_timestamp"] = "last-update-filter-match-timestamp"
                                        self._segment_path = lambda: "update-attribute-filter-attributes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, [u'update_internal_attribute_code', u'update_filter_action', u'update_filter_match_count', u'establishment_update_filter_match_count', u'last_update_filter_match_age'], name, value)


                                    class LastUpdateFilterMatchTimestamp(Entity):
                                        """
                                        Last attribute filtered time\: time elapsed since
                                        00\:00\:00 UTC, January 1, 1970
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, self).__init__()

                                            self.yang_name = "last-update-filter-match-timestamp"
                                            self.yang_parent_name = "update-attribute-filter-attributes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-filter-match-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateFilterMessage(Entity):
                                    """
                                    List of filtered messages
                                    
                                    .. attribute:: update_filter_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:  :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                    
                                    .. attribute:: update_filtered_attribute_count
                                    
                                    	Filtered attributes count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_final_action
                                    
                                    	Filtering final action
                                    	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    .. attribute:: update_filter_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_filter_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\: str
                                    
                                    .. attribute:: update_filter_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\: bool
                                    
                                    .. attribute:: update_filter_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of  		 :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                    
                                    .. attribute:: update_filter_element
                                    
                                    	Filtering element list
                                    	**type**\: list of  		 :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, self).__init__()

                                        self.yang_name = "update-filter-message"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-filter-message-timestamp", ("update_filter_message_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp)), ("update-filter-message-data", ("update_filter_message_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData)), ("update-filter-element", ("update_filter_element", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement))])
                                        self._leafs = OrderedDict([
                                            ('update_filtered_attribute_count', (YLeaf(YType.uint32, 'update-filtered-attribute-count'), ['int'])),
                                            ('update_filter_final_action', (YLeaf(YType.enumeration, 'update-filter-final-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                            ('update_filter_nlri_address_family', (YLeaf(YType.enumeration, 'update-filter-nlri-address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('update_filter_nlri_string', (YLeaf(YType.str, 'update-filter-nlri-string'), ['str'])),
                                            ('update_filter_nlri_string_truncated', (YLeaf(YType.boolean, 'update-filter-nlri-string-truncated'), ['bool'])),
                                        ])
                                        self.update_filtered_attribute_count = None
                                        self.update_filter_final_action = None
                                        self.update_filter_nlri_address_family = None
                                        self.update_filter_nlri_string = None
                                        self.update_filter_nlri_string_truncated = None

                                        self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                        self.update_filter_message_timestamp.parent = self
                                        self._children_name_map["update_filter_message_timestamp"] = "update-filter-message-timestamp"

                                        self.update_filter_message_data = YList(self)
                                        self.update_filter_element = YList(self)
                                        self._segment_path = lambda: "update-filter-message"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, [u'update_filtered_attribute_count', u'update_filter_final_action', u'update_filter_nlri_address_family', u'update_filter_nlri_string', u'update_filter_nlri_string_truncated'], name, value)


                                    class UpdateFilterMessageTimestamp(Entity):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, self).__init__()

                                            self.yang_name = "update-filter-message-timestamp"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "update-filter-message-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateFilterMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, self).__init__()

                                            self.yang_name = "update-filter-message-data"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "update-filter-message-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, [u'entry'], name, value)


                                    class UpdateFilterElement(Entity):
                                        """
                                        Filtering element list
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_filter_action
                                        
                                        	Filtering action
                                        	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, self).__init__()

                                            self.yang_name = "update-filter-element"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update_attribute_flags', (YLeaf(YType.uint8, 'update-attribute-flags'), ['int'])),
                                                ('update_attribute_code', (YLeaf(YType.uint8, 'update-attribute-code'), ['int'])),
                                                ('update_filter_action', (YLeaf(YType.enumeration, 'update-filter-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                            ])
                                            self.update_attribute_flags = None
                                            self.update_attribute_code = None
                                            self.update_filter_action = None
                                            self._segment_path = lambda: "update-filter-element"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, [u'update_attribute_flags', u'update_attribute_code', u'update_filter_action'], name, value)


                        class Bmp(Entity):
                            """
                            BMP related Operational Data
                            
                            .. attribute:: server_summaries
                            
                            	Table of BMP Servers
                            	**type**\:  :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries>`
                            
                            .. attribute:: server_neighbors
                            
                            	Table of Neighbors for a BMP Server
                            	**type**\:  :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp, self).__init__()

                                self.yang_name = "bmp"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("server-summaries", ("server_summaries", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries)), ("server-neighbors", ("server_neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors))])
                                self._leafs = OrderedDict()

                                self.server_summaries = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries()
                                self.server_summaries.parent = self
                                self._children_name_map["server_summaries"] = "server-summaries"

                                self.server_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors()
                                self.server_neighbors.parent = self
                                self._children_name_map["server_neighbors"] = "server-neighbors"
                                self._segment_path = lambda: "bmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp, [], name, value)


                            class ServerSummaries(Entity):
                                """
                                Table of BMP Servers
                                
                                .. attribute:: server_summary
                                
                                	Summary Information about BMP server
                                	**type**\: list of  		 :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries, self).__init__()

                                    self.yang_name = "server-summaries"
                                    self.yang_parent_name = "bmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("server-summary", ("server_summary", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary))])
                                    self._leafs = OrderedDict()

                                    self.server_summary = YList(self)
                                    self._segment_path = lambda: "server-summaries"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries, [], name, value)


                                class ServerSummary(Entity):
                                    """
                                    Summary Information about BMP server
                                    
                                    .. attribute:: server_id  (key)
                                    
                                    	BMP Server ID
                                    	**type**\: int
                                    
                                    	**range:** 1..8
                                    
                                    .. attribute:: bmp_server_state_age
                                    
                                    	Age of current state of BMP Server
                                    	**type**\:  :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                    
                                    .. attribute:: bmp_server_state_time_spec
                                    
                                    	Timespec of current state of BMP Server
                                    	**type**\:  :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                    
                                    .. attribute:: bmp_server_last_discon_time
                                    
                                    	Timespec of Last Disconnect event received from BMP server
                                    	**type**\:  :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                    
                                    .. attribute:: update_source_address
                                    
                                    	Address of Interface configured as Update Source
                                    	**type**\:  :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                    
                                    .. attribute:: bmp_server_id
                                    
                                    	BMP Server ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: bmp_server_host_name
                                    
                                    	BMP Server Hostname
                                    	**type**\: str
                                    
                                    .. attribute:: bmp_server_port
                                    
                                    	BMP Server Port Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_server_state
                                    
                                    	Connection state of the BMP server
                                    	**type**\:  :py:class:`BgpBmpState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpState>`
                                    
                                    .. attribute:: bmp_server_is_flapping
                                    
                                    	Connection to the BMP server Flapping
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_server_nbr_count
                                    
                                    	Neighbor count for the BMP Server
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_init_msg_count
                                    
                                    	Number of Initiation Msgs sent by this BMP Server
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_termination_msg_count
                                    
                                    	Number of Termination Messages sent by this BMP Server
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_status_report_count
                                    
                                    	Number of Status ReportMessages sent by this BMP Server
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_count
                                    
                                    	Total number of per peer messages sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_drop_count
                                    
                                    	Total number of messages dropped
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count
                                    
                                    	Total number of bmpQ msgs pending
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence (0) or DSCP (1) type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_source_interface_name
                                    
                                    	Interface configured as Update Source
                                    	**type**\: str
                                    
                                    .. attribute:: update_source_vrf_id
                                    
                                    	VRF ID of interface configured as Update Source
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_vrf_name
                                    
                                    	VRF Name configured
                                    	**type**\: str
                                    
                                    .. attribute:: bmp_vrf_id
                                    
                                    	VRF ID for the vrf name configured
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_update_mode
                                    
                                    	Update sending mode configured for this BMP server
                                    	**type**\:  :py:class:`BgpBmpUpdMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdMode>`
                                    
                                    .. attribute:: tcp_keep_alive_interval
                                    
                                    	TCP Keep alive interval configured
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_maximum_segment_size
                                    
                                    	TCP Maximum Segments size configured
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_write_cb_pending
                                    
                                    	Are we waiting for TCP write callback ?
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_result
                                    
                                    	Last TCP Socket write status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_cb_time
                                    
                                    	Last TCP Write CB time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tcp_last_write_time
                                    
                                    	Last TCP Write time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_all_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent for all BMP servers 
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_cb_time
                                    
                                    	Last BMPQ write pulse callback time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: path_update_count
                                    
                                    	Number of path update sent 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_count
                                    
                                    	Number of path wdraw sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_update_drop
                                    
                                    	Number of path update drop 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_drop
                                    
                                    	Number of path wdraw drop 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_max
                                    
                                    	Total bmpQ msgs pending max
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_hwts
                                    
                                    	Total bmpQ msgs pending max time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_bytes_written_tcp
                                    
                                    	Total bytes sent to TCP
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: tcp_write_time
                                    
                                    	Time spent processing sending msg to TCP(milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: bmpr_mon_upd_messages
                                    
                                    	Total bmpQ update msgs 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmpr_mon_wdraw_messages
                                    
                                    	Total bmpQ withdraw msgs 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_messages_wdraw_discarded
                                    
                                    	Total bmpQ wdraw msgs discarded because of peer down
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_pfx_wdraw_discarded
                                    
                                    	Total bmpQ wdraw pfxes discarded because of peer down
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_route_mon_count
                                    
                                    	Total number of per peer route mon messages sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmpr_mon_update_gen_time
                                    
                                    	Time spent in update generation(milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: bmpr_mon_eo_rmessages
                                    
                                    	Total bmpQ EOR update msgs 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_rmon_cur_buffer_size
                                    
                                    	Current Buffer usage per BMP Route Mon
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_maximum_buffer_size_route_mon
                                    
                                    	Buffer limit used for route mon
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_server_up_count
                                    
                                    	Number of BMP server that are UP
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_in_progress
                                    
                                    	Update generation in progress
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_reset_walk_in_progress
                                    
                                    	Reset walk in progress
                                    	**type**\: bool
                                    
                                    .. attribute:: bmpafi_info
                                    
                                    	AFI specific info for BMP server
                                    	**type**\: list of  		 :py:class:`BmpafiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary, self).__init__()

                                        self.yang_name = "server-summary"
                                        self.yang_parent_name = "server-summaries"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['server_id']
                                        self._child_classes = OrderedDict([("bmp-server-state-age", ("bmp_server_state_age", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge)), ("bmp-server-state-time-spec", ("bmp_server_state_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec)), ("bmp-server-last-discon-time", ("bmp_server_last_discon_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime)), ("update-source-address", ("update_source_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress)), ("bmpafi-info", ("bmpafi_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo))])
                                        self._leafs = OrderedDict([
                                            ('server_id', (YLeaf(YType.uint32, 'server-id'), ['int'])),
                                            ('bmp_server_id', (YLeaf(YType.uint8, 'bmp-server-id'), ['int'])),
                                            ('bmp_server_host_name', (YLeaf(YType.str, 'bmp-server-host-name'), ['str'])),
                                            ('bmp_server_port', (YLeaf(YType.uint32, 'bmp-server-port'), ['int'])),
                                            ('bmp_server_state', (YLeaf(YType.enumeration, 'bmp-server-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBmpState', '')])),
                                            ('bmp_server_is_flapping', (YLeaf(YType.boolean, 'bmp-server-is-flapping'), ['bool'])),
                                            ('bmp_server_nbr_count', (YLeaf(YType.uint32, 'bmp-server-nbr-count'), ['int'])),
                                            ('bmp_init_msg_count', (YLeaf(YType.uint32, 'bmp-init-msg-count'), ['int'])),
                                            ('bmp_termination_msg_count', (YLeaf(YType.uint32, 'bmp-termination-msg-count'), ['int'])),
                                            ('bmp_status_report_count', (YLeaf(YType.uint32, 'bmp-status-report-count'), ['int'])),
                                            ('bmp_per_peer_msg_count', (YLeaf(YType.uint32, 'bmp-per-peer-msg-count'), ['int'])),
                                            ('bmp_peer_msg_drop_count', (YLeaf(YType.uint32, 'bmp-peer-msg-drop-count'), ['int'])),
                                            ('bmp_peer_msg_pending_count', (YLeaf(YType.uint32, 'bmp-peer-msg-pending-count'), ['int'])),
                                            ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                            ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                            ('update_source_interface_name', (YLeaf(YType.str, 'update-source-interface-name'), ['str'])),
                                            ('update_source_vrf_id', (YLeaf(YType.uint32, 'update-source-vrf-id'), ['int'])),
                                            ('bmp_vrf_name', (YLeaf(YType.str, 'bmp-vrf-name'), ['str'])),
                                            ('bmp_vrf_id', (YLeaf(YType.uint32, 'bmp-vrf-id'), ['int'])),
                                            ('bmp_update_mode', (YLeaf(YType.enumeration, 'bmp-update-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBmpUpdMode', '')])),
                                            ('tcp_keep_alive_interval', (YLeaf(YType.uint32, 'tcp-keep-alive-interval'), ['int'])),
                                            ('tcp_maximum_segment_size', (YLeaf(YType.uint32, 'tcp-maximum-segment-size'), ['int'])),
                                            ('tcp_write_cb_pending', (YLeaf(YType.uint32, 'tcp-write-cb-pending'), ['int'])),
                                            ('tcp_last_write_result', (YLeaf(YType.uint32, 'tcp-last-write-result'), ['int'])),
                                            ('tcp_last_write_cb_time', (YLeaf(YType.uint64, 'tcp-last-write-cb-time'), ['int'])),
                                            ('tcp_last_write_time', (YLeaf(YType.uint64, 'tcp-last-write-time'), ['int'])),
                                            ('bmpq_last_write_pulse_sent_time', (YLeaf(YType.uint64, 'bmpq-last-write-pulse-sent-time'), ['int'])),
                                            ('bmpq_last_all_write_pulse_sent_time', (YLeaf(YType.uint64, 'bmpq-last-all-write-pulse-sent-time'), ['int'])),
                                            ('bmpq_last_write_pulse_cb_time', (YLeaf(YType.uint64, 'bmpq-last-write-pulse-cb-time'), ['int'])),
                                            ('path_update_count', (YLeaf(YType.uint32, 'path-update-count'), ['int'])),
                                            ('path_withdraw_count', (YLeaf(YType.uint32, 'path-withdraw-count'), ['int'])),
                                            ('path_update_drop', (YLeaf(YType.uint32, 'path-update-drop'), ['int'])),
                                            ('path_withdraw_drop', (YLeaf(YType.uint32, 'path-withdraw-drop'), ['int'])),
                                            ('bmp_peer_msg_pending_count_max', (YLeaf(YType.uint32, 'bmp-peer-msg-pending-count-max'), ['int'])),
                                            ('bmp_peer_msg_pending_count_hwts', (YLeaf(YType.uint64, 'bmp-peer-msg-pending-count-hwts'), ['int'])),
                                            ('bmp_bytes_written_tcp', (YLeaf(YType.uint64, 'bmp-bytes-written-tcp'), ['int'])),
                                            ('tcp_write_time', (YLeaf(YType.uint32, 'tcp-write-time'), ['int'])),
                                            ('bmpr_mon_upd_messages', (YLeaf(YType.uint32, 'bmpr-mon-upd-messages'), ['int'])),
                                            ('bmpr_mon_wdraw_messages', (YLeaf(YType.uint32, 'bmpr-mon-wdraw-messages'), ['int'])),
                                            ('bmp_messages_wdraw_discarded', (YLeaf(YType.uint32, 'bmp-messages-wdraw-discarded'), ['int'])),
                                            ('bmp_pfx_wdraw_discarded', (YLeaf(YType.uint32, 'bmp-pfx-wdraw-discarded'), ['int'])),
                                            ('bmp_per_peer_msg_route_mon_count', (YLeaf(YType.uint32, 'bmp-per-peer-msg-route-mon-count'), ['int'])),
                                            ('bmpr_mon_update_gen_time', (YLeaf(YType.uint32, 'bmpr-mon-update-gen-time'), ['int'])),
                                            ('bmpr_mon_eo_rmessages', (YLeaf(YType.uint32, 'bmpr-mon-eo-rmessages'), ['int'])),
                                            ('bmp_rmon_cur_buffer_size', (YLeaf(YType.uint64, 'bmp-rmon-cur-buffer-size'), ['int'])),
                                            ('bmp_maximum_buffer_size_route_mon', (YLeaf(YType.uint64, 'bmp-maximum-buffer-size-route-mon'), ['int'])),
                                            ('bmp_server_up_count', (YLeaf(YType.uint32, 'bmp-server-up-count'), ['int'])),
                                            ('bmp_upd_gen_in_progress', (YLeaf(YType.boolean, 'bmp-upd-gen-in-progress'), ['bool'])),
                                            ('bmp_reset_walk_in_progress', (YLeaf(YType.boolean, 'bmp-reset-walk-in-progress'), ['bool'])),
                                        ])
                                        self.server_id = None
                                        self.bmp_server_id = None
                                        self.bmp_server_host_name = None
                                        self.bmp_server_port = None
                                        self.bmp_server_state = None
                                        self.bmp_server_is_flapping = None
                                        self.bmp_server_nbr_count = None
                                        self.bmp_init_msg_count = None
                                        self.bmp_termination_msg_count = None
                                        self.bmp_status_report_count = None
                                        self.bmp_per_peer_msg_count = None
                                        self.bmp_peer_msg_drop_count = None
                                        self.bmp_peer_msg_pending_count = None
                                        self.tos_type = None
                                        self.tos_value = None
                                        self.update_source_interface_name = None
                                        self.update_source_vrf_id = None
                                        self.bmp_vrf_name = None
                                        self.bmp_vrf_id = None
                                        self.bmp_update_mode = None
                                        self.tcp_keep_alive_interval = None
                                        self.tcp_maximum_segment_size = None
                                        self.tcp_write_cb_pending = None
                                        self.tcp_last_write_result = None
                                        self.tcp_last_write_cb_time = None
                                        self.tcp_last_write_time = None
                                        self.bmpq_last_write_pulse_sent_time = None
                                        self.bmpq_last_all_write_pulse_sent_time = None
                                        self.bmpq_last_write_pulse_cb_time = None
                                        self.path_update_count = None
                                        self.path_withdraw_count = None
                                        self.path_update_drop = None
                                        self.path_withdraw_drop = None
                                        self.bmp_peer_msg_pending_count_max = None
                                        self.bmp_peer_msg_pending_count_hwts = None
                                        self.bmp_bytes_written_tcp = None
                                        self.tcp_write_time = None
                                        self.bmpr_mon_upd_messages = None
                                        self.bmpr_mon_wdraw_messages = None
                                        self.bmp_messages_wdraw_discarded = None
                                        self.bmp_pfx_wdraw_discarded = None
                                        self.bmp_per_peer_msg_route_mon_count = None
                                        self.bmpr_mon_update_gen_time = None
                                        self.bmpr_mon_eo_rmessages = None
                                        self.bmp_rmon_cur_buffer_size = None
                                        self.bmp_maximum_buffer_size_route_mon = None
                                        self.bmp_server_up_count = None
                                        self.bmp_upd_gen_in_progress = None
                                        self.bmp_reset_walk_in_progress = None

                                        self.bmp_server_state_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                        self.bmp_server_state_age.parent = self
                                        self._children_name_map["bmp_server_state_age"] = "bmp-server-state-age"

                                        self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                        self.bmp_server_state_time_spec.parent = self
                                        self._children_name_map["bmp_server_state_time_spec"] = "bmp-server-state-time-spec"

                                        self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                        self.bmp_server_last_discon_time.parent = self
                                        self._children_name_map["bmp_server_last_discon_time"] = "bmp-server-last-discon-time"

                                        self.update_source_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                        self.update_source_address.parent = self
                                        self._children_name_map["update_source_address"] = "update-source-address"

                                        self.bmpafi_info = YList(self)
                                        self._segment_path = lambda: "server-summary" + "[server-id='" + str(self.server_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary, ['server_id', u'bmp_server_id', u'bmp_server_host_name', u'bmp_server_port', u'bmp_server_state', u'bmp_server_is_flapping', u'bmp_server_nbr_count', u'bmp_init_msg_count', u'bmp_termination_msg_count', u'bmp_status_report_count', u'bmp_per_peer_msg_count', u'bmp_peer_msg_drop_count', u'bmp_peer_msg_pending_count', u'tos_type', u'tos_value', u'update_source_interface_name', u'update_source_vrf_id', u'bmp_vrf_name', u'bmp_vrf_id', u'bmp_update_mode', u'tcp_keep_alive_interval', u'tcp_maximum_segment_size', u'tcp_write_cb_pending', u'tcp_last_write_result', u'tcp_last_write_cb_time', u'tcp_last_write_time', u'bmpq_last_write_pulse_sent_time', u'bmpq_last_all_write_pulse_sent_time', u'bmpq_last_write_pulse_cb_time', u'path_update_count', u'path_withdraw_count', u'path_update_drop', u'path_withdraw_drop', u'bmp_peer_msg_pending_count_max', u'bmp_peer_msg_pending_count_hwts', u'bmp_bytes_written_tcp', u'tcp_write_time', u'bmpr_mon_upd_messages', u'bmpr_mon_wdraw_messages', u'bmp_messages_wdraw_discarded', u'bmp_pfx_wdraw_discarded', u'bmp_per_peer_msg_route_mon_count', u'bmpr_mon_update_gen_time', u'bmpr_mon_eo_rmessages', u'bmp_rmon_cur_buffer_size', u'bmp_maximum_buffer_size_route_mon', u'bmp_server_up_count', u'bmp_upd_gen_in_progress', u'bmp_reset_walk_in_progress'], name, value)


                                    class BmpServerStateAge(Entity):
                                        """
                                        Age of current state of BMP Server
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, self).__init__()

                                            self.yang_name = "bmp-server-state-age"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-server-state-age"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, [u'seconds', u'nanoseconds'], name, value)


                                    class BmpServerStateTimeSpec(Entity):
                                        """
                                        Timespec of current state of BMP Server
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, self).__init__()

                                            self.yang_name = "bmp-server-state-time-spec"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-server-state-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class BmpServerLastDisconTime(Entity):
                                        """
                                        Timespec of Last Disconnect event received from
                                        BMP server
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, self).__init__()

                                            self.yang_name = "bmp-server-last-discon-time"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-server-last-discon-time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateSourceAddress(Entity):
                                        """
                                        Address of Interface configured as Update Source
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, self).__init__()

                                            self.yang_name = "update-source-address"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "update-source-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class BmpafiInfo(Entity):
                                        """
                                        AFI specific info for BMP server
                                        
                                        .. attribute:: bmp_resume_prefix
                                        
                                        	BMP Resume prefix
                                        	**type**\:  :py:class:`BmpResumePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix>`
                                        
                                        .. attribute:: bmp_filter_neighbor_address
                                        
                                        	Filter Neighbor Address
                                        	**type**\:  :py:class:`BmpFilterNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress>`
                                        
                                        .. attribute:: bmpaf_name
                                        
                                        	BMP Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: bmp_resume_prefix_len
                                        
                                        	BMP Resume prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_resume_start_version
                                        
                                        	Update Gen ResumeWalk start version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_resume_end_version
                                        
                                        	Update Gen ResumeWalk end version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_walk_stopped
                                        
                                        	Update Gen WalkStopped
                                        	**type**\: bool
                                        
                                        .. attribute:: bmp_upd_gen_resume_net_version
                                        
                                        	Update Gen ResumeWalk Net version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_walk_run_time_stamp
                                        
                                        	Last Update Gen Run time stamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_run_count
                                        
                                        	Number of times Update Gen ran
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_stop_time_stamp
                                        
                                        	Last Update Gen Stop time stamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_stop_count
                                        
                                        	Number of times Update Gen Stopped
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_init_eor_end_version
                                        
                                        	Version to reach to send EOR
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_init_eor_pending_cnt
                                        
                                        	Count for pending EOR
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_filter_neighbor_address_set
                                        
                                        	Filter Neighbor Address Set ?
                                        	**type**\: bool
                                        
                                        .. attribute:: bmp_filter_nbr_cnt
                                        
                                        	Filter nbr Count for this AFI
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_send_version
                                        
                                        	Table Version that this BMP server has caught upto
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, self).__init__()

                                            self.yang_name = "bmpafi-info"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bmp-resume-prefix", ("bmp_resume_prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix)), ("bmp-filter-neighbor-address", ("bmp_filter_neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('bmpaf_name', (YLeaf(YType.enumeration, 'bmpaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('bmp_resume_prefix_len', (YLeaf(YType.uint32, 'bmp-resume-prefix-len'), ['int'])),
                                                ('bmp_upd_gen_resume_start_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-start-version'), ['int'])),
                                                ('bmp_upd_gen_resume_end_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-end-version'), ['int'])),
                                                ('bmp_upd_gen_walk_stopped', (YLeaf(YType.boolean, 'bmp-upd-gen-walk-stopped'), ['bool'])),
                                                ('bmp_upd_gen_resume_net_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-net-version'), ['int'])),
                                                ('bmp_upd_gen_walk_run_time_stamp', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-run-time-stamp'), ['int'])),
                                                ('bmp_upd_gen_walk_run_count', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-run-count'), ['int'])),
                                                ('bmp_upd_gen_walk_stop_time_stamp', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-stop-time-stamp'), ['int'])),
                                                ('bmp_upd_gen_walk_stop_count', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-stop-count'), ['int'])),
                                                ('bmp_init_eor_end_version', (YLeaf(YType.uint32, 'bmp-init-eor-end-version'), ['int'])),
                                                ('bmp_init_eor_pending_cnt', (YLeaf(YType.uint32, 'bmp-init-eor-pending-cnt'), ['int'])),
                                                ('bmp_filter_neighbor_address_set', (YLeaf(YType.boolean, 'bmp-filter-neighbor-address-set'), ['bool'])),
                                                ('bmp_filter_nbr_cnt', (YLeaf(YType.uint32, 'bmp-filter-nbr-cnt'), ['int'])),
                                                ('bmp_send_version', (YLeaf(YType.uint32, 'bmp-send-version'), ['int'])),
                                            ])
                                            self.bmpaf_name = None
                                            self.bmp_resume_prefix_len = None
                                            self.bmp_upd_gen_resume_start_version = None
                                            self.bmp_upd_gen_resume_end_version = None
                                            self.bmp_upd_gen_walk_stopped = None
                                            self.bmp_upd_gen_resume_net_version = None
                                            self.bmp_upd_gen_walk_run_time_stamp = None
                                            self.bmp_upd_gen_walk_run_count = None
                                            self.bmp_upd_gen_walk_stop_time_stamp = None
                                            self.bmp_upd_gen_walk_stop_count = None
                                            self.bmp_init_eor_end_version = None
                                            self.bmp_init_eor_pending_cnt = None
                                            self.bmp_filter_neighbor_address_set = None
                                            self.bmp_filter_nbr_cnt = None
                                            self.bmp_send_version = None

                                            self.bmp_resume_prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix()
                                            self.bmp_resume_prefix.parent = self
                                            self._children_name_map["bmp_resume_prefix"] = "bmp-resume-prefix"

                                            self.bmp_filter_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress()
                                            self.bmp_filter_neighbor_address.parent = self
                                            self._children_name_map["bmp_filter_neighbor_address"] = "bmp-filter-neighbor-address"
                                            self._segment_path = lambda: "bmpafi-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, [u'bmpaf_name', u'bmp_resume_prefix_len', u'bmp_upd_gen_resume_start_version', u'bmp_upd_gen_resume_end_version', u'bmp_upd_gen_walk_stopped', u'bmp_upd_gen_resume_net_version', u'bmp_upd_gen_walk_run_time_stamp', u'bmp_upd_gen_walk_run_count', u'bmp_upd_gen_walk_stop_time_stamp', u'bmp_upd_gen_walk_stop_count', u'bmp_init_eor_end_version', u'bmp_init_eor_pending_cnt', u'bmp_filter_neighbor_address_set', u'bmp_filter_nbr_cnt', u'bmp_send_version'], name, value)


                                        class BmpResumePrefix(Entity):
                                            """
                                            BMP Resume prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, self).__init__()

                                                self.yang_name = "bmp-resume-prefix"
                                                self.yang_parent_name = "bmpafi-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bmp-resume-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bmp-resume-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BmpFilterNeighborAddress(Entity):
                                            """
                                            Filter Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, self).__init__()

                                                self.yang_name = "bmp-filter-neighbor-address"
                                                self.yang_parent_name = "bmpafi-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "bmp-filter-neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ServerNeighbors(Entity):
                                """
                                Table of Neighbors for a BMP Server
                                
                                .. attribute:: server_neighbor
                                
                                	BMP Server under which neighbor info are needed
                                	**type**\: list of  		 :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors, self).__init__()

                                    self.yang_name = "server-neighbors"
                                    self.yang_parent_name = "bmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("server-neighbor", ("server_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.server_neighbor = YList(self)
                                    self._segment_path = lambda: "server-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors, [], name, value)


                                class ServerNeighbor(Entity):
                                    """
                                    BMP Server under which neighbor info are
                                    needed
                                    
                                    .. attribute:: server_id  (key)
                                    
                                    	BMP Server ID
                                    	**type**\: int
                                    
                                    	**range:** 1..8
                                    
                                    .. attribute:: monitored_neighbors
                                    
                                    	List of Neighbors under which BMP Server is confgiured
                                    	**type**\:  :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor, self).__init__()

                                        self.yang_name = "server-neighbor"
                                        self.yang_parent_name = "server-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['server_id']
                                        self._child_classes = OrderedDict([("monitored-neighbors", ("monitored_neighbors", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors))])
                                        self._leafs = OrderedDict([
                                            ('server_id', (YLeaf(YType.uint32, 'server-id'), ['int'])),
                                        ])
                                        self.server_id = None

                                        self.monitored_neighbors = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                        self.monitored_neighbors.parent = self
                                        self._children_name_map["monitored_neighbors"] = "monitored-neighbors"
                                        self._segment_path = lambda: "server-neighbor" + "[server-id='" + str(self.server_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor, ['server_id'], name, value)


                                    class MonitoredNeighbors(Entity):
                                        """
                                        List of Neighbors under which BMP Server is
                                        confgiured
                                        
                                        .. attribute:: monitored_neighbor
                                        
                                        	Information about a neighbor monitored by BMP server
                                        	**type**\: list of  		 :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, self).__init__()

                                            self.yang_name = "monitored-neighbors"
                                            self.yang_parent_name = "server-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("monitored-neighbor", ("monitored_neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor))])
                                            self._leafs = OrderedDict()

                                            self.monitored_neighbor = YList(self)
                                            self._segment_path = lambda: "monitored-neighbors"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, [], name, value)


                                        class MonitoredNeighbor(Entity):
                                            """
                                            Information about a neighbor monitored by
                                            BMP server
                                            
                                            .. attribute:: neighbor_address  (key)
                                            
                                            	Neighbor address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bmp_neighbor_address
                                            
                                            	Address of Nbr that logs to BMP server
                                            	**type**\:  :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                            
                                            .. attribute:: bmp_neighbor_msg_pending
                                            
                                            	Number of messages pending to be sent to BMP Server from this Neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_msg_dropped
                                            
                                            	Number of messages dropped sent from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_up_sent
                                            
                                            	Number of Peer UP Messages sent from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_down_sent
                                            
                                            	Number of Peer DOWN Messages sent from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_route_monitor_sent
                                            
                                            	Number of Route Monitor Messages sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_route_monitor_eor_sent
                                            
                                            	Number of Route Monitor EOR Messages sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_sent
                                            
                                            	Number of Path UpdateMessages sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_sent
                                            
                                            	Number of Path WithdrawMessages sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_drop
                                            
                                            	Number of path update drop 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_drop
                                            
                                            	Number of path wdraw drop 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_upd_msg_sent
                                            
                                            	Number of update message sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_wdraw_msg_sent
                                            
                                            	Number of withdraw message sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, self).__init__()

                                                self.yang_name = "monitored-neighbor"
                                                self.yang_parent_name = "monitored-neighbors"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['neighbor_address']
                                                self._child_classes = OrderedDict([("bmp-neighbor-address", ("bmp_neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                    ('bmp_neighbor_msg_pending', (YLeaf(YType.uint32, 'bmp-neighbor-msg-pending'), ['int'])),
                                                    ('bmp_neighbor_msg_dropped', (YLeaf(YType.uint32, 'bmp-neighbor-msg-dropped'), ['int'])),
                                                    ('bmp_neighbor_peer_up_sent', (YLeaf(YType.uint32, 'bmp-neighbor-peer-up-sent'), ['int'])),
                                                    ('bmp_neighbor_peer_down_sent', (YLeaf(YType.uint32, 'bmp-neighbor-peer-down-sent'), ['int'])),
                                                    ('bmp_neighbor_route_monitor_sent', (YLeaf(YType.uint32, 'bmp-neighbor-route-monitor-sent'), ['int'])),
                                                    ('bmp_neighbor_route_monitor_eor_sent', (YLeaf(YType.uint32, 'bmp-neighbor-route-monitor-eor-sent'), ['int'])),
                                                    ('bmp_neighbor_path_update_sent', (YLeaf(YType.uint32, 'bmp-neighbor-path-update-sent'), ['int'])),
                                                    ('bmp_neighbor_path_withdraw_sent', (YLeaf(YType.uint32, 'bmp-neighbor-path-withdraw-sent'), ['int'])),
                                                    ('bmp_neighbor_path_update_drop', (YLeaf(YType.uint32, 'bmp-neighbor-path-update-drop'), ['int'])),
                                                    ('bmp_neighbor_path_withdraw_drop', (YLeaf(YType.uint32, 'bmp-neighbor-path-withdraw-drop'), ['int'])),
                                                    ('bmp_neighbor_upd_msg_sent', (YLeaf(YType.uint32, 'bmp-neighbor-upd-msg-sent'), ['int'])),
                                                    ('bmp_neighbor_wdraw_msg_sent', (YLeaf(YType.uint32, 'bmp-neighbor-wdraw-msg-sent'), ['int'])),
                                                ])
                                                self.neighbor_address = None
                                                self.bmp_neighbor_msg_pending = None
                                                self.bmp_neighbor_msg_dropped = None
                                                self.bmp_neighbor_peer_up_sent = None
                                                self.bmp_neighbor_peer_down_sent = None
                                                self.bmp_neighbor_route_monitor_sent = None
                                                self.bmp_neighbor_route_monitor_eor_sent = None
                                                self.bmp_neighbor_path_update_sent = None
                                                self.bmp_neighbor_path_withdraw_sent = None
                                                self.bmp_neighbor_path_update_drop = None
                                                self.bmp_neighbor_path_withdraw_drop = None
                                                self.bmp_neighbor_upd_msg_sent = None
                                                self.bmp_neighbor_wdraw_msg_sent = None

                                                self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                                self.bmp_neighbor_address.parent = self
                                                self._children_name_map["bmp_neighbor_address"] = "bmp-neighbor-address"
                                                self._segment_path = lambda: "monitored-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, ['neighbor_address', u'bmp_neighbor_msg_pending', u'bmp_neighbor_msg_dropped', u'bmp_neighbor_peer_up_sent', u'bmp_neighbor_peer_down_sent', u'bmp_neighbor_route_monitor_sent', u'bmp_neighbor_route_monitor_eor_sent', u'bmp_neighbor_path_update_sent', u'bmp_neighbor_path_withdraw_sent', u'bmp_neighbor_path_update_drop', u'bmp_neighbor_path_withdraw_drop', u'bmp_neighbor_upd_msg_sent', u'bmp_neighbor_wdraw_msg_sent'], name, value)


                                            class BmpNeighborAddress(Entity):
                                                """
                                                Address of Nbr that logs to BMP server
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, self).__init__()

                                                    self.yang_name = "bmp-neighbor-address"
                                                    self.yang_parent_name = "monitored-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "bmp-neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class ProcessInfo(Entity):
                            """
                            A Process instance table entry
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf_>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics>`
                            
                            .. attribute:: process_instance
                            
                            	ID for the BGP process instance
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\: str
                            
                            .. attribute:: vrf_totals
                            
                            	per VRF counts aggregated across all VRFs
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo, self).__init__()

                                self.yang_name = "process-info"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf_)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics))])
                                self._leafs = OrderedDict([
                                    ('process_instance', (YLeaf(YType.uint8, 'process-instance'), ['int'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('vrf_totals', (YLeaf(YType.boolean, 'vrf-totals'), ['bool'])),
                                ])
                                self.process_instance = None
                                self.vrf_name = None
                                self.vrf_totals = None

                                self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"

                                self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self._children_name_map["performance_statistics"] = "performance-statistics"
                                self._segment_path = lambda: "process-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo, [u'process_instance', u'vrf_name', u'vrf_totals'], name, value)


                            class Global(Entity):
                                """
                                Global information
                                
                                .. attribute:: process_instance_node
                                
                                	Node the process instance is on
                                	**type**\: str
                                
                                .. attribute:: restart_count
                                
                                	No. of times BGP has started
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_attributes_entry_count
                                
                                	No. of path attribute entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_attribute_memory
                                
                                	Memory (bytes) used by path attribute entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: as_path_entry_count
                                
                                	Number of AS\-path entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_path_entries_memory
                                
                                	Memory (in bytes) used by AS\-path entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: community_entry_count
                                
                                	Number of community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: community_memory
                                
                                	Memory (in bytes) used by community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: extended_community_entry_count
                                
                                	Number of extended community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_memory
                                
                                	Memory (in bytes) used by extended community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: pe_distinguisher_label_entry_count
                                
                                	Number of PE distinguisher label entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pe_distinguisher_label_memory
                                
                                	Memory (in bytes) used by PE distinguisher labels entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: pta_entry_count
                                
                                	Number of PTA entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pta_memory
                                
                                	Memory (in bytes) used by PTA entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: tunnel_encap_entry_count
                                
                                	Number of Tunnel encap entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_memory
                                
                                	Memory (in bytes) used by tunnel encap entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ribrnh_entry_count
                                
                                	Number of RIBRNH entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ribrnh_memory
                                
                                	Memory (in bytes) used by RIBRNH entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ppmp_entry_count
                                
                                	Number of PPMP entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ppmp_memory
                                
                                	Memory (in bytes) used by PPMP entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: route_reflectors
                                
                                	Number of route reflector info entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_reflector_memory
                                
                                	Memory (in bytes) used by route reflector info entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: nexthop_count
                                
                                	Number of nexthop attribute info entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nexthop_memory
                                
                                	Memory (in bytes) used by nexthop attribute info entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: lsattr_entry_count
                                
                                	Number of LASATTR entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsattr_memory
                                
                                	Memory (in bytes) used by LSATTR entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: attr_set_entry_count
                                
                                	Number of ATTRSET entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attr_set_memory
                                
                                	Memory (in bytes) used by ATTRSET entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: lindex_entry_count
                                
                                	Number of LINDEX entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lindex_memory
                                
                                	Memory (in bytes) used by LINDEX entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_vrf_count
                                
                                	total vrf count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbors_count_total
                                
                                	Total number of neighbors
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: established_neighbors_count_total
                                
                                	Total umber of established neighbors
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs
                                
                                	sn num non dflt vrf nbrs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                                
                                	sn num non dflt vrf nbrs estab
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: large_community_entry_count
                                
                                	Number of large community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: large_community_memory
                                
                                	Memory (in bytes) used by large community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: pool_size
                                
                                	pool size
                                	**type**\: list of  		 :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolSize>`
                                
                                .. attribute:: pool_alloc_count
                                
                                	pool alloc count
                                	**type**\: list of  		 :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolAllocCount>`
                                
                                .. attribute:: pool_free_count
                                
                                	pool free count
                                	**type**\: list of  		 :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolFreeCount>`
                                
                                .. attribute:: msg_log_pool_size
                                
                                	msg log pool size
                                	**type**\: list of  		 :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolSize>`
                                
                                .. attribute:: msg_log_pool_alloc_count
                                
                                	msg log pool alloc count
                                	**type**\: list of  		 :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolAllocCount>`
                                
                                .. attribute:: msg_log_pool_free_count
                                
                                	msg log pool free count
                                	**type**\: list of  		 :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolFreeCount>`
                                
                                .. attribute:: bmp_pool_size
                                
                                	bmp pool size
                                	**type**\: list of  		 :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolSize>`
                                
                                .. attribute:: bmp_pool_alloc_count
                                
                                	bmp pool alloc count
                                	**type**\: list of  		 :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolAllocCount>`
                                
                                .. attribute:: bmp_pool_free_count
                                
                                	bmp pool free count
                                	**type**\: list of  		 :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolFreeCount>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pool-size", ("pool_size", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolSize)), ("pool-alloc-count", ("pool_alloc_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolAllocCount)), ("pool-free-count", ("pool_free_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolFreeCount)), ("msg-log-pool-size", ("msg_log_pool_size", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolSize)), ("msg-log-pool-alloc-count", ("msg_log_pool_alloc_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolAllocCount)), ("msg-log-pool-free-count", ("msg_log_pool_free_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolFreeCount)), ("bmp-pool-size", ("bmp_pool_size", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolSize)), ("bmp-pool-alloc-count", ("bmp_pool_alloc_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolAllocCount)), ("bmp-pool-free-count", ("bmp_pool_free_count", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolFreeCount))])
                                    self._leafs = OrderedDict([
                                        ('process_instance_node', (YLeaf(YType.str, 'process-instance-node'), ['str'])),
                                        ('restart_count', (YLeaf(YType.uint32, 'restart-count'), ['int'])),
                                        ('path_attributes_entry_count', (YLeaf(YType.uint32, 'path-attributes-entry-count'), ['int'])),
                                        ('path_attribute_memory', (YLeaf(YType.uint32, 'path-attribute-memory'), ['int'])),
                                        ('as_path_entry_count', (YLeaf(YType.uint32, 'as-path-entry-count'), ['int'])),
                                        ('as_path_entries_memory', (YLeaf(YType.uint32, 'as-path-entries-memory'), ['int'])),
                                        ('community_entry_count', (YLeaf(YType.uint32, 'community-entry-count'), ['int'])),
                                        ('community_memory', (YLeaf(YType.uint32, 'community-memory'), ['int'])),
                                        ('extended_community_entry_count', (YLeaf(YType.uint32, 'extended-community-entry-count'), ['int'])),
                                        ('extended_community_memory', (YLeaf(YType.uint32, 'extended-community-memory'), ['int'])),
                                        ('pe_distinguisher_label_entry_count', (YLeaf(YType.uint32, 'pe-distinguisher-label-entry-count'), ['int'])),
                                        ('pe_distinguisher_label_memory', (YLeaf(YType.uint32, 'pe-distinguisher-label-memory'), ['int'])),
                                        ('pta_entry_count', (YLeaf(YType.uint32, 'pta-entry-count'), ['int'])),
                                        ('pta_memory', (YLeaf(YType.uint32, 'pta-memory'), ['int'])),
                                        ('tunnel_encap_entry_count', (YLeaf(YType.uint32, 'tunnel-encap-entry-count'), ['int'])),
                                        ('tunnel_encap_memory', (YLeaf(YType.uint32, 'tunnel-encap-memory'), ['int'])),
                                        ('ribrnh_entry_count', (YLeaf(YType.uint32, 'ribrnh-entry-count'), ['int'])),
                                        ('ribrnh_memory', (YLeaf(YType.uint32, 'ribrnh-memory'), ['int'])),
                                        ('ppmp_entry_count', (YLeaf(YType.uint32, 'ppmp-entry-count'), ['int'])),
                                        ('ppmp_memory', (YLeaf(YType.uint32, 'ppmp-memory'), ['int'])),
                                        ('route_reflectors', (YLeaf(YType.uint32, 'route-reflectors'), ['int'])),
                                        ('route_reflector_memory', (YLeaf(YType.uint32, 'route-reflector-memory'), ['int'])),
                                        ('nexthop_count', (YLeaf(YType.uint32, 'nexthop-count'), ['int'])),
                                        ('nexthop_memory', (YLeaf(YType.uint32, 'nexthop-memory'), ['int'])),
                                        ('lsattr_entry_count', (YLeaf(YType.uint32, 'lsattr-entry-count'), ['int'])),
                                        ('lsattr_memory', (YLeaf(YType.uint32, 'lsattr-memory'), ['int'])),
                                        ('attr_set_entry_count', (YLeaf(YType.uint32, 'attr-set-entry-count'), ['int'])),
                                        ('attr_set_memory', (YLeaf(YType.uint32, 'attr-set-memory'), ['int'])),
                                        ('lindex_entry_count', (YLeaf(YType.uint32, 'lindex-entry-count'), ['int'])),
                                        ('lindex_memory', (YLeaf(YType.uint32, 'lindex-memory'), ['int'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('total_vrf_count', (YLeaf(YType.uint32, 'total-vrf-count'), ['int'])),
                                        ('neighbors_count_total', (YLeaf(YType.uint32, 'neighbors-count-total'), ['int'])),
                                        ('established_neighbors_count_total', (YLeaf(YType.uint32, 'established-neighbors-count-total'), ['int'])),
                                        ('sn_num_non_dflt_vrf_nbrs', (YLeaf(YType.uint32, 'sn-num-non-dflt-vrf-nbrs'), ['int'])),
                                        ('sn_num_non_dflt_vrf_nbrs_estab', (YLeaf(YType.uint32, 'sn-num-non-dflt-vrf-nbrs-estab'), ['int'])),
                                        ('large_community_entry_count', (YLeaf(YType.uint32, 'large-community-entry-count'), ['int'])),
                                        ('large_community_memory', (YLeaf(YType.uint32, 'large-community-memory'), ['int'])),
                                    ])
                                    self.process_instance_node = None
                                    self.restart_count = None
                                    self.path_attributes_entry_count = None
                                    self.path_attribute_memory = None
                                    self.as_path_entry_count = None
                                    self.as_path_entries_memory = None
                                    self.community_entry_count = None
                                    self.community_memory = None
                                    self.extended_community_entry_count = None
                                    self.extended_community_memory = None
                                    self.pe_distinguisher_label_entry_count = None
                                    self.pe_distinguisher_label_memory = None
                                    self.pta_entry_count = None
                                    self.pta_memory = None
                                    self.tunnel_encap_entry_count = None
                                    self.tunnel_encap_memory = None
                                    self.ribrnh_entry_count = None
                                    self.ribrnh_memory = None
                                    self.ppmp_entry_count = None
                                    self.ppmp_memory = None
                                    self.route_reflectors = None
                                    self.route_reflector_memory = None
                                    self.nexthop_count = None
                                    self.nexthop_memory = None
                                    self.lsattr_entry_count = None
                                    self.lsattr_memory = None
                                    self.attr_set_entry_count = None
                                    self.attr_set_memory = None
                                    self.lindex_entry_count = None
                                    self.lindex_memory = None
                                    self.local_as = None
                                    self.total_vrf_count = None
                                    self.neighbors_count_total = None
                                    self.established_neighbors_count_total = None
                                    self.sn_num_non_dflt_vrf_nbrs = None
                                    self.sn_num_non_dflt_vrf_nbrs_estab = None
                                    self.large_community_entry_count = None
                                    self.large_community_memory = None

                                    self.pool_size = YList(self)
                                    self.pool_alloc_count = YList(self)
                                    self.pool_free_count = YList(self)
                                    self.msg_log_pool_size = YList(self)
                                    self.msg_log_pool_alloc_count = YList(self)
                                    self.msg_log_pool_free_count = YList(self)
                                    self.bmp_pool_size = YList(self)
                                    self.bmp_pool_alloc_count = YList(self)
                                    self.bmp_pool_free_count = YList(self)
                                    self._segment_path = lambda: "global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global, [u'process_instance_node', u'restart_count', u'path_attributes_entry_count', u'path_attribute_memory', u'as_path_entry_count', u'as_path_entries_memory', u'community_entry_count', u'community_memory', u'extended_community_entry_count', u'extended_community_memory', u'pe_distinguisher_label_entry_count', u'pe_distinguisher_label_memory', u'pta_entry_count', u'pta_memory', u'tunnel_encap_entry_count', u'tunnel_encap_memory', u'ribrnh_entry_count', u'ribrnh_memory', u'ppmp_entry_count', u'ppmp_memory', u'route_reflectors', u'route_reflector_memory', u'nexthop_count', u'nexthop_memory', u'lsattr_entry_count', u'lsattr_memory', u'attr_set_entry_count', u'attr_set_memory', u'lindex_entry_count', u'lindex_memory', u'local_as', u'total_vrf_count', u'neighbors_count_total', u'established_neighbors_count_total', u'sn_num_non_dflt_vrf_nbrs', u'sn_num_non_dflt_vrf_nbrs_estab', u'large_community_entry_count', u'large_community_memory'], name, value)


                                class PoolSize(Entity):
                                    """
                                    pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolSize, self).__init__()

                                        self.yang_name = "pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "pool-size"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolSize, [u'entry'], name, value)


                                class PoolAllocCount(Entity):
                                    """
                                    pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolAllocCount, self).__init__()

                                        self.yang_name = "pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "pool-alloc-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolAllocCount, [u'entry'], name, value)


                                class PoolFreeCount(Entity):
                                    """
                                    pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolFreeCount, self).__init__()

                                        self.yang_name = "pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "pool-free-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.PoolFreeCount, [u'entry'], name, value)


                                class MsgLogPoolSize(Entity):
                                    """
                                    msg log pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolSize, self).__init__()

                                        self.yang_name = "msg-log-pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "msg-log-pool-size"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolSize, [u'entry'], name, value)


                                class MsgLogPoolAllocCount(Entity):
                                    """
                                    msg log pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolAllocCount, self).__init__()

                                        self.yang_name = "msg-log-pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "msg-log-pool-alloc-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolAllocCount, [u'entry'], name, value)


                                class MsgLogPoolFreeCount(Entity):
                                    """
                                    msg log pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolFreeCount, self).__init__()

                                        self.yang_name = "msg-log-pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "msg-log-pool-free-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolFreeCount, [u'entry'], name, value)


                                class BmpPoolSize(Entity):
                                    """
                                    bmp pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolSize, self).__init__()

                                        self.yang_name = "bmp-pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "bmp-pool-size"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolSize, [u'entry'], name, value)


                                class BmpPoolAllocCount(Entity):
                                    """
                                    bmp pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolAllocCount, self).__init__()

                                        self.yang_name = "bmp-pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "bmp-pool-alloc-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolAllocCount, [u'entry'], name, value)


                                class BmpPoolFreeCount(Entity):
                                    """
                                    bmp pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolFreeCount, self).__init__()

                                        self.yang_name = "bmp-pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "bmp-pool-free-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Global.BmpPoolFreeCount, [u'entry'], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: neighbors_count
                                
                                	Number of neighbors
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: established_neighbors_count
                                
                                	Number of established neighbors
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_received
                                
                                	Number of update messages received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_sent
                                
                                	No. of update messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_received
                                
                                	No. of notifications received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_sent
                                
                                	No. of notifications sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_count
                                
                                	Number of networks
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_count
                                
                                	Number of paths
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('neighbors_count', (YLeaf(YType.uint32, 'neighbors-count'), ['int'])),
                                        ('established_neighbors_count', (YLeaf(YType.uint32, 'established-neighbors-count'), ['int'])),
                                        ('update_messages_received', (YLeaf(YType.uint32, 'update-messages-received'), ['int'])),
                                        ('update_messages_sent', (YLeaf(YType.uint32, 'update-messages-sent'), ['int'])),
                                        ('notifications_received', (YLeaf(YType.uint32, 'notifications-received'), ['int'])),
                                        ('notifications_sent', (YLeaf(YType.uint32, 'notifications-sent'), ['int'])),
                                        ('network_count', (YLeaf(YType.uint32, 'network-count'), ['int'])),
                                        ('path_count', (YLeaf(YType.uint32, 'path-count'), ['int'])),
                                    ])
                                    self.neighbors_count = None
                                    self.established_neighbors_count = None
                                    self.update_messages_received = None
                                    self.update_messages_sent = None
                                    self.notifications_received = None
                                    self.notifications_sent = None
                                    self.network_count = None
                                    self.path_count = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.Vrf_, [u'neighbors_count', u'established_neighbors_count', u'update_messages_received', u'update_messages_sent', u'notifications_received', u'notifications_sent', u'network_count', u'path_count'], name, value)


                            class PerformanceStatistics(Entity):
                                """
                                Performance statistics
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics, self).__init__()

                                    self.yang_name = "performance-statistics"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_))])
                                    self._leafs = OrderedDict()

                                    self.global_ = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"

                                    self.vrf = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._segment_path = lambda: "performance-statistics"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics, [], name, value)


                                class Global(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: ipv4rib_server
                                    
                                    	IPv4 RIB server global info
                                    	**type**\:  :py:class:`Ipv4ribServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer>`
                                    
                                    .. attribute:: ipv6rib_server
                                    
                                    	IPv6 RIB server global info
                                    	**type**\:  :py:class:`Ipv6ribServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer>`
                                    
                                    .. attribute:: te_connection
                                    
                                    	MPLS TE server connection info
                                    	**type**\:  :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection>`
                                    
                                    .. attribute:: lsd_connection
                                    
                                    	MPLS LSD server connection info
                                    	**type**\:  :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection>`
                                    
                                    .. attribute:: ds_npl
                                    
                                    	NSR related DS and NPL information
                                    	**type**\:  :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl>`
                                    
                                    .. attribute:: configuration_items_processed
                                    
                                    	Number of config items processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configuration_processing_time
                                    
                                    	Time spent processing config (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: edm_requests_count
                                    
                                    	Number of EDM requests processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: edm_processing_time
                                    
                                    	Time spent processing EDM requests (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_messages_sent
                                    
                                    	bRIB API output messages sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_bytes_sent
                                    
                                    	bRIB API output bytes sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_bytes_generated
                                    
                                    	bRIB API output bytes generated
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_prefixes_advertised
                                    
                                    	bRIB API output prefixes advertised
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_prefixes_withdrawn
                                    
                                    	bRIB API output prefixes withdrawn
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_sending_time
                                    
                                    	Time spent sending output to bRIB API (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_generation_time
                                    
                                    	Time spent generating output for bRIB API (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: brib_api_output_calls
                                    
                                    	bRIB API calls to generate output
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_messages
                                    
                                    	bRIB API input messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_bytes
                                    
                                    	bRIB API input bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_input_prefixes_received
                                    
                                    	bRIB API input advertised prefixes received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_withdrawn_prefixes
                                    
                                    	bRIB API input withdrawn prefixes received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_processing_time
                                    
                                    	Time spent processing input from bRIB API (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: instance_node_role
                                    
                                    	Node role \- active/passive
                                    	**type**\: bool
                                    
                                    .. attribute:: active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: proc_scoped_sync_state
                                    
                                    	BGP scoped sync state
                                    	**type**\:  :py:class:`BgpScopedSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncState>`
                                    
                                    .. attribute:: initial_sync_sessions_added
                                    
                                    	If true, BGP has at least one established session when NSR initial synchronization is started
                                    	**type**\: bool
                                    
                                    .. attribute:: in_event_attach_calls
                                    
                                    	event\_file\_attach  calls for input
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: out_event_attach_calls
                                    
                                    	event\_file\_attach  calls for output
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: in_out_event_attach_calls
                                    
                                    	event\_file\_attach calls for input
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_timer_id
                                    
                                    	Updgen master timer ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: current_clock_time
                                    
                                    	Current time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_handler_tm
                                    
                                    	Timestamp when updgen timer handler got called
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_timer_id
                                    
                                    	IO master timer ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_handler_tm
                                    
                                    	Timestamp when IO timer handler got called
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: qad_messages_sent
                                    
                                    	Messages sent on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadack_sent
                                    
                                    	Acks sent on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_failure
                                    
                                    	Send failure on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_ac_ks_failure
                                    
                                    	Ack failure on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_suspends
                                    
                                    	QAD send suspend
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_resumes
                                    
                                    	QAD send resume 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_drops
                                    
                                    	Send packets dropped due to null peer 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_messages_received
                                    
                                    	Messages received on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_processed
                                    
                                    	Messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_ac_ks_received
                                    
                                    	Acks received on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_received
                                    
                                    	Timeouts received on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_init_drops
                                    
                                    	Packets dropped on standby during initialization
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadoos_drops
                                    
                                    	Packets dropped due to  out of sequence packetreceived
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_recv_drops
                                    
                                    	Received packet dropped due to null peer 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_recvd
                                    
                                    	Number of packet send timeouts 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_last_reset_reason
                                    
                                    	Reason for last nsr state  machine reset
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: redcon_nsr_ready
                                    
                                    	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                    	**type**\: bool
                                    
                                    .. attribute:: redcon_state_time
                                    
                                    	Time when nsr state wasconveyed to Redcon last
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: active_nsr_state
                                    
                                    	Current Active BGP nsrstate
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sec_active_nsr_state
                                    
                                    	Current Sec Active BGP nsrstate
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_outstanding_postits
                                    
                                    	Total outstanding postits across all neighbors
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_neighbors_with_pending_postits
                                    
                                    	Total nbrs with pending postits
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tep2p_auto_tunnel_enabled
                                    
                                    	TE support for P2P auto tunnel
                                    	**type**\: bool
                                    
                                    .. attribute:: active_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of  		 :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime>`
                                    
                                    .. attribute:: standby_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of  		 :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime>`
                                    
                                    .. attribute:: active_nsrfo_time
                                    
                                    	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                    	**type**\: list of  		 :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime>`
                                    
                                    .. attribute:: postit_count_info
                                    
                                    	List of neighbors and their postit counts
                                    	**type**\: list of  		 :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo>`
                                    
                                    .. attribute:: issu_milestone
                                    
                                    	ISSU Milestones
                                    	**type**\: list of  		 :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "performance-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ipv4rib-server", ("ipv4rib_server", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer)), ("ipv6rib-server", ("ipv6rib_server", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer)), ("te-connection", ("te_connection", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection)), ("lsd-connection", ("lsd_connection", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection)), ("ds-npl", ("ds_npl", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl)), ("active-nsr-mode-enter-time", ("active_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime)), ("standby-nsr-mode-enter-time", ("standby_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime)), ("active-nsrfo-time", ("active_nsrfo_time", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime)), ("postit-count-info", ("postit_count_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo)), ("issu-milestone", ("issu_milestone", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone))])
                                        self._leafs = OrderedDict([
                                            ('configuration_items_processed', (YLeaf(YType.uint32, 'configuration-items-processed'), ['int'])),
                                            ('configuration_processing_time', (YLeaf(YType.uint32, 'configuration-processing-time'), ['int'])),
                                            ('edm_requests_count', (YLeaf(YType.uint32, 'edm-requests-count'), ['int'])),
                                            ('edm_processing_time', (YLeaf(YType.uint32, 'edm-processing-time'), ['int'])),
                                            ('brib_api_output_messages_sent', (YLeaf(YType.uint32, 'brib-api-output-messages-sent'), ['int'])),
                                            ('brib_api_output_bytes_sent', (YLeaf(YType.uint32, 'brib-api-output-bytes-sent'), ['int'])),
                                            ('brib_api_output_bytes_generated', (YLeaf(YType.uint32, 'brib-api-output-bytes-generated'), ['int'])),
                                            ('brib_api_output_prefixes_advertised', (YLeaf(YType.uint32, 'brib-api-output-prefixes-advertised'), ['int'])),
                                            ('brib_api_output_prefixes_withdrawn', (YLeaf(YType.uint32, 'brib-api-output-prefixes-withdrawn'), ['int'])),
                                            ('brib_api_output_sending_time', (YLeaf(YType.uint32, 'brib-api-output-sending-time'), ['int'])),
                                            ('brib_api_output_generation_time', (YLeaf(YType.uint32, 'brib-api-output-generation-time'), ['int'])),
                                            ('brib_api_output_calls', (YLeaf(YType.uint32, 'brib-api-output-calls'), ['int'])),
                                            ('brib_api_input_messages', (YLeaf(YType.uint32, 'brib-api-input-messages'), ['int'])),
                                            ('brib_api_input_bytes', (YLeaf(YType.uint32, 'brib-api-input-bytes'), ['int'])),
                                            ('brib_api_input_prefixes_received', (YLeaf(YType.uint32, 'brib-api-input-prefixes-received'), ['int'])),
                                            ('brib_api_input_withdrawn_prefixes', (YLeaf(YType.uint32, 'brib-api-input-withdrawn-prefixes'), ['int'])),
                                            ('brib_api_input_processing_time', (YLeaf(YType.uint32, 'brib-api-input-processing-time'), ['int'])),
                                            ('instance_node_role', (YLeaf(YType.boolean, 'instance-node-role'), ['bool'])),
                                            ('active_nsrtcp_phase_two_enter_time', (YLeaf(YType.uint32, 'active-nsrtcp-phase-two-enter-time'), ['int'])),
                                            ('sec_active_nsrtcp_phase_two_enter_time', (YLeaf(YType.uint32, 'sec-active-nsrtcp-phase-two-enter-time'), ['int'])),
                                            ('proc_scoped_sync_state', (YLeaf(YType.enumeration, 'proc-scoped-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpScopedSyncState', '')])),
                                            ('initial_sync_sessions_added', (YLeaf(YType.boolean, 'initial-sync-sessions-added'), ['bool'])),
                                            ('in_event_attach_calls', (YLeaf(YType.uint32, 'in-event-attach-calls'), ['int'])),
                                            ('out_event_attach_calls', (YLeaf(YType.uint32, 'out-event-attach-calls'), ['int'])),
                                            ('in_out_event_attach_calls', (YLeaf(YType.uint32, 'in-out-event-attach-calls'), ['int'])),
                                            ('updgen_timer_id', (YLeaf(YType.uint32, 'updgen-timer-id'), ['int'])),
                                            ('updgen_tree_timer_left', (YLeaf(YType.uint64, 'updgen-tree-timer-left'), ['int'])),
                                            ('updgen_tree_timer_expiry', (YLeaf(YType.uint64, 'updgen-tree-timer-expiry'), ['int'])),
                                            ('current_clock_time', (YLeaf(YType.uint64, 'current-clock-time'), ['int'])),
                                            ('updgen_handler_tm', (YLeaf(YType.uint64, 'updgen-handler-tm'), ['int'])),
                                            ('io_timer_id', (YLeaf(YType.uint32, 'io-timer-id'), ['int'])),
                                            ('io_tree_timer_left', (YLeaf(YType.uint64, 'io-tree-timer-left'), ['int'])),
                                            ('io_tree_timer_expiry', (YLeaf(YType.uint64, 'io-tree-timer-expiry'), ['int'])),
                                            ('io_handler_tm', (YLeaf(YType.uint64, 'io-handler-tm'), ['int'])),
                                            ('qad_messages_sent', (YLeaf(YType.uint32, 'qad-messages-sent'), ['int'])),
                                            ('qadack_sent', (YLeaf(YType.uint32, 'qadack-sent'), ['int'])),
                                            ('qad_send_failure', (YLeaf(YType.uint32, 'qad-send-failure'), ['int'])),
                                            ('qad_ac_ks_failure', (YLeaf(YType.uint32, 'qad-ac-ks-failure'), ['int'])),
                                            ('qad_suspends', (YLeaf(YType.uint32, 'qad-suspends'), ['int'])),
                                            ('qad_resumes', (YLeaf(YType.uint32, 'qad-resumes'), ['int'])),
                                            ('qad_send_drops', (YLeaf(YType.uint32, 'qad-send-drops'), ['int'])),
                                            ('qad_messages_received', (YLeaf(YType.uint32, 'qad-messages-received'), ['int'])),
                                            ('qad_processed', (YLeaf(YType.uint32, 'qad-processed'), ['int'])),
                                            ('qad_ac_ks_received', (YLeaf(YType.uint32, 'qad-ac-ks-received'), ['int'])),
                                            ('qad_timeout_received', (YLeaf(YType.uint32, 'qad-timeout-received'), ['int'])),
                                            ('qad_init_drops', (YLeaf(YType.uint32, 'qad-init-drops'), ['int'])),
                                            ('qadoos_drops', (YLeaf(YType.uint32, 'qadoos-drops'), ['int'])),
                                            ('qad_recv_drops', (YLeaf(YType.uint32, 'qad-recv-drops'), ['int'])),
                                            ('qad_timeout_recvd', (YLeaf(YType.uint32, 'qad-timeout-recvd'), ['int'])),
                                            ('nsr_last_reset_reason', (YLeaf(YType.uint8, 'nsr-last-reset-reason'), ['int'])),
                                            ('redcon_nsr_ready', (YLeaf(YType.boolean, 'redcon-nsr-ready'), ['bool'])),
                                            ('redcon_state_time', (YLeaf(YType.uint32, 'redcon-state-time'), ['int'])),
                                            ('active_nsr_state', (YLeaf(YType.uint32, 'active-nsr-state'), ['int'])),
                                            ('sec_active_nsr_state', (YLeaf(YType.uint32, 'sec-active-nsr-state'), ['int'])),
                                            ('total_outstanding_postits', (YLeaf(YType.uint32, 'total-outstanding-postits'), ['int'])),
                                            ('total_neighbors_with_pending_postits', (YLeaf(YType.uint32, 'total-neighbors-with-pending-postits'), ['int'])),
                                            ('tep2p_auto_tunnel_enabled', (YLeaf(YType.boolean, 'tep2p-auto-tunnel-enabled'), ['bool'])),
                                        ])
                                        self.configuration_items_processed = None
                                        self.configuration_processing_time = None
                                        self.edm_requests_count = None
                                        self.edm_processing_time = None
                                        self.brib_api_output_messages_sent = None
                                        self.brib_api_output_bytes_sent = None
                                        self.brib_api_output_bytes_generated = None
                                        self.brib_api_output_prefixes_advertised = None
                                        self.brib_api_output_prefixes_withdrawn = None
                                        self.brib_api_output_sending_time = None
                                        self.brib_api_output_generation_time = None
                                        self.brib_api_output_calls = None
                                        self.brib_api_input_messages = None
                                        self.brib_api_input_bytes = None
                                        self.brib_api_input_prefixes_received = None
                                        self.brib_api_input_withdrawn_prefixes = None
                                        self.brib_api_input_processing_time = None
                                        self.instance_node_role = None
                                        self.active_nsrtcp_phase_two_enter_time = None
                                        self.sec_active_nsrtcp_phase_two_enter_time = None
                                        self.proc_scoped_sync_state = None
                                        self.initial_sync_sessions_added = None
                                        self.in_event_attach_calls = None
                                        self.out_event_attach_calls = None
                                        self.in_out_event_attach_calls = None
                                        self.updgen_timer_id = None
                                        self.updgen_tree_timer_left = None
                                        self.updgen_tree_timer_expiry = None
                                        self.current_clock_time = None
                                        self.updgen_handler_tm = None
                                        self.io_timer_id = None
                                        self.io_tree_timer_left = None
                                        self.io_tree_timer_expiry = None
                                        self.io_handler_tm = None
                                        self.qad_messages_sent = None
                                        self.qadack_sent = None
                                        self.qad_send_failure = None
                                        self.qad_ac_ks_failure = None
                                        self.qad_suspends = None
                                        self.qad_resumes = None
                                        self.qad_send_drops = None
                                        self.qad_messages_received = None
                                        self.qad_processed = None
                                        self.qad_ac_ks_received = None
                                        self.qad_timeout_received = None
                                        self.qad_init_drops = None
                                        self.qadoos_drops = None
                                        self.qad_recv_drops = None
                                        self.qad_timeout_recvd = None
                                        self.nsr_last_reset_reason = None
                                        self.redcon_nsr_ready = None
                                        self.redcon_state_time = None
                                        self.active_nsr_state = None
                                        self.sec_active_nsr_state = None
                                        self.total_outstanding_postits = None
                                        self.total_neighbors_with_pending_postits = None
                                        self.tep2p_auto_tunnel_enabled = None

                                        self.ipv4rib_server = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer()
                                        self.ipv4rib_server.parent = self
                                        self._children_name_map["ipv4rib_server"] = "ipv4rib-server"

                                        self.ipv6rib_server = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer()
                                        self.ipv6rib_server.parent = self
                                        self._children_name_map["ipv6rib_server"] = "ipv6rib-server"

                                        self.te_connection = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection()
                                        self.te_connection.parent = self
                                        self._children_name_map["te_connection"] = "te-connection"

                                        self.lsd_connection = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection()
                                        self.lsd_connection.parent = self
                                        self._children_name_map["lsd_connection"] = "lsd-connection"

                                        self.ds_npl = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl()
                                        self.ds_npl.parent = self
                                        self._children_name_map["ds_npl"] = "ds-npl"

                                        self.active_nsr_mode_enter_time = YList(self)
                                        self.standby_nsr_mode_enter_time = YList(self)
                                        self.active_nsrfo_time = YList(self)
                                        self.postit_count_info = YList(self)
                                        self.issu_milestone = YList(self)
                                        self._segment_path = lambda: "global"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global, [u'configuration_items_processed', u'configuration_processing_time', u'edm_requests_count', u'edm_processing_time', u'brib_api_output_messages_sent', u'brib_api_output_bytes_sent', u'brib_api_output_bytes_generated', u'brib_api_output_prefixes_advertised', u'brib_api_output_prefixes_withdrawn', u'brib_api_output_sending_time', u'brib_api_output_generation_time', u'brib_api_output_calls', u'brib_api_input_messages', u'brib_api_input_bytes', u'brib_api_input_prefixes_received', u'brib_api_input_withdrawn_prefixes', u'brib_api_input_processing_time', u'instance_node_role', u'active_nsrtcp_phase_two_enter_time', u'sec_active_nsrtcp_phase_two_enter_time', u'proc_scoped_sync_state', u'initial_sync_sessions_added', u'in_event_attach_calls', u'out_event_attach_calls', u'in_out_event_attach_calls', u'updgen_timer_id', u'updgen_tree_timer_left', u'updgen_tree_timer_expiry', u'current_clock_time', u'updgen_handler_tm', u'io_timer_id', u'io_tree_timer_left', u'io_tree_timer_expiry', u'io_handler_tm', u'qad_messages_sent', u'qadack_sent', u'qad_send_failure', u'qad_ac_ks_failure', u'qad_suspends', u'qad_resumes', u'qad_send_drops', u'qad_messages_received', u'qad_processed', u'qad_ac_ks_received', u'qad_timeout_received', u'qad_init_drops', u'qadoos_drops', u'qad_recv_drops', u'qad_timeout_recvd', u'nsr_last_reset_reason', u'redcon_nsr_ready', u'redcon_state_time', u'active_nsr_state', u'sec_active_nsr_state', u'total_outstanding_postits', u'total_neighbors_with_pending_postits', u'tep2p_auto_tunnel_enabled'], name, value)


                                    class Ipv4ribServer(Entity):
                                        """
                                        IPv4 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:  :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:  :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:  :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:  :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer, self).__init__()

                                            self.yang_name = "ipv4rib-server"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("first-rib-connection-up-timestamp", ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp)), ("last-rib-connection-up-timestamp", ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp)), ("first-rib-connection-down-timestamp", ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp)), ("last-rib-connection-down-timestamp", ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('is_rib_connection_up', (YLeaf(YType.boolean, 'is-rib-connection-up'), ['bool'])),
                                                ('rib_connection_up_count', (YLeaf(YType.uint32, 'rib-connection-up-count'), ['int'])),
                                                ('last_rib_connection_up_age', (YLeaf(YType.uint32, 'last-rib-connection-up-age'), ['int'])),
                                                ('rib_connection_down_count', (YLeaf(YType.uint32, 'rib-connection-down-count'), ['int'])),
                                                ('last_rib_connection_down_age', (YLeaf(YType.uint32, 'last-rib-connection-down-age'), ['int'])),
                                            ])
                                            self.is_rib_connection_up = None
                                            self.rib_connection_up_count = None
                                            self.last_rib_connection_up_age = None
                                            self.rib_connection_down_count = None
                                            self.last_rib_connection_down_age = None

                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"

                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"

                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"

                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                            self._segment_path = lambda: "ipv4rib-server"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer, [u'is_rib_connection_up', u'rib_connection_up_count', u'last_rib_connection_up_age', u'rib_connection_down_count', u'last_rib_connection_down_age'], name, value)


                                        class FirstRibConnectionUpTimestamp(Entity):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibConnectionUpTimestamp(Entity):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstRibConnectionDownTimestamp(Entity):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibConnectionDownTimestamp(Entity):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class Ipv6ribServer(Entity):
                                        """
                                        IPv6 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:  :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:  :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:  :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:  :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer, self).__init__()

                                            self.yang_name = "ipv6rib-server"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("first-rib-connection-up-timestamp", ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp)), ("last-rib-connection-up-timestamp", ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp)), ("first-rib-connection-down-timestamp", ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp)), ("last-rib-connection-down-timestamp", ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('is_rib_connection_up', (YLeaf(YType.boolean, 'is-rib-connection-up'), ['bool'])),
                                                ('rib_connection_up_count', (YLeaf(YType.uint32, 'rib-connection-up-count'), ['int'])),
                                                ('last_rib_connection_up_age', (YLeaf(YType.uint32, 'last-rib-connection-up-age'), ['int'])),
                                                ('rib_connection_down_count', (YLeaf(YType.uint32, 'rib-connection-down-count'), ['int'])),
                                                ('last_rib_connection_down_age', (YLeaf(YType.uint32, 'last-rib-connection-down-age'), ['int'])),
                                            ])
                                            self.is_rib_connection_up = None
                                            self.rib_connection_up_count = None
                                            self.last_rib_connection_up_age = None
                                            self.rib_connection_down_count = None
                                            self.last_rib_connection_down_age = None

                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"

                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"

                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"

                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                            self._segment_path = lambda: "ipv6rib-server"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer, [u'is_rib_connection_up', u'rib_connection_up_count', u'last_rib_connection_up_age', u'rib_connection_down_count', u'last_rib_connection_down_age'], name, value)


                                        class FirstRibConnectionUpTimestamp(Entity):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibConnectionUpTimestamp(Entity):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstRibConnectionDownTimestamp(Entity):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibConnectionDownTimestamp(Entity):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class TeConnection(Entity):
                                        """
                                        MPLS TE server connection info
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:  :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:  :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp>`
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:  :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:  :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\: bool
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection, self).__init__()

                                            self.yang_name = "te-connection"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("first-connection-up-timestamp", ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp)), ("last-connection-up-timestamp", ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp)), ("first-connection-down-timestamp", ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp)), ("last-connection-down-timestamp", ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('is_connection_up', (YLeaf(YType.boolean, 'is-connection-up'), ['bool'])),
                                                ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                                ('last_connection_up_age', (YLeaf(YType.uint32, 'last-connection-up-age'), ['int'])),
                                                ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                                ('last_connection_down_age', (YLeaf(YType.uint32, 'last-connection-down-age'), ['int'])),
                                            ])
                                            self.is_connection_up = None
                                            self.connection_up_count = None
                                            self.last_connection_up_age = None
                                            self.connection_down_count = None
                                            self.last_connection_down_age = None

                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"

                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self
                                            self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"

                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"

                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                            self._segment_path = lambda: "te-connection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection, [u'is_connection_up', u'connection_up_count', u'last_connection_up_age', u'connection_down_count', u'last_connection_down_age'], name, value)


                                        class FirstConnectionUpTimestamp(Entity):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-connection-up-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastConnectionUpTimestamp(Entity):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-connection-up-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstConnectionDownTimestamp(Entity):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-connection-down-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastConnectionDownTimestamp(Entity):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-connection-down-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LsdConnection(Entity):
                                        """
                                        MPLS LSD server connection info
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:  :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:  :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp>`
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:  :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:  :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\: bool
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection, self).__init__()

                                            self.yang_name = "lsd-connection"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("first-connection-up-timestamp", ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp)), ("last-connection-up-timestamp", ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp)), ("first-connection-down-timestamp", ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp)), ("last-connection-down-timestamp", ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('is_connection_up', (YLeaf(YType.boolean, 'is-connection-up'), ['bool'])),
                                                ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                                ('last_connection_up_age', (YLeaf(YType.uint32, 'last-connection-up-age'), ['int'])),
                                                ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                                ('last_connection_down_age', (YLeaf(YType.uint32, 'last-connection-down-age'), ['int'])),
                                            ])
                                            self.is_connection_up = None
                                            self.connection_up_count = None
                                            self.last_connection_up_age = None
                                            self.connection_down_count = None
                                            self.last_connection_down_age = None

                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"

                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self
                                            self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"

                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"

                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                            self._segment_path = lambda: "lsd-connection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection, [u'is_connection_up', u'connection_up_count', u'last_connection_up_age', u'connection_down_count', u'last_connection_down_age'], name, value)


                                        class FirstConnectionUpTimestamp(Entity):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-connection-up-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastConnectionUpTimestamp(Entity):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-connection-up-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstConnectionDownTimestamp(Entity):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-connection-down-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastConnectionDownTimestamp(Entity):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-connection-down-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class DsNpl(Entity):
                                        """
                                        NSR related DS and NPL information
                                        
                                        .. attribute:: dir_service_conn_state
                                        
                                        	Current Directory Service connectionstate
                                        	**type**\:  :py:class:`BgpDsConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnState>`
                                        
                                        .. attribute:: issu_mgr_conn_state
                                        
                                        	Current ISSU Mgr connection state
                                        	**type**\:  :py:class:`BgpIsmConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnState>`
                                        
                                        .. attribute:: issu_phase
                                        
                                        	Current ISSU Phase
                                        	**type**\: str
                                        
                                        .. attribute:: issu_type_ng
                                        
                                        	ISSU type is Next Gen
                                        	**type**\: bool
                                        
                                        .. attribute:: issuha_option
                                        
                                        	Current ISSU HA option
                                        	**type**\: str
                                        
                                        .. attribute:: local_ds_handle
                                        
                                        	Local Directory Service handle
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: service_name
                                        
                                        	Local DS service name
                                        	**type**\: str
                                        
                                        .. attribute:: dsissu_status_flag
                                        
                                        	DS ISSU status flag
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: npl_priority_statistic
                                        
                                        	NPL priority statistics
                                        	**type**\: list of  		 :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic>`
                                        
                                        .. attribute:: npl_endpoint
                                        
                                        	NPL endpoint information
                                        	**type**\: list of  		 :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl, self).__init__()

                                            self.yang_name = "ds-npl"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("npl-priority-statistic", ("npl_priority_statistic", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic)), ("npl-endpoint", ("npl_endpoint", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint))])
                                            self._leafs = OrderedDict([
                                                ('dir_service_conn_state', (YLeaf(YType.enumeration, 'dir-service-conn-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpDsConnState', '')])),
                                                ('issu_mgr_conn_state', (YLeaf(YType.enumeration, 'issu-mgr-conn-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpIsmConnState', '')])),
                                                ('issu_phase', (YLeaf(YType.str, 'issu-phase'), ['str'])),
                                                ('issu_type_ng', (YLeaf(YType.boolean, 'issu-type-ng'), ['bool'])),
                                                ('issuha_option', (YLeaf(YType.str, 'issuha-option'), ['str'])),
                                                ('local_ds_handle', (YLeaf(YType.uint64, 'local-ds-handle'), ['int'])),
                                                ('service_name', (YLeaf(YType.str, 'service-name'), ['str'])),
                                                ('dsissu_status_flag', (YLeaf(YType.uint32, 'dsissu-status-flag'), ['int'])),
                                            ])
                                            self.dir_service_conn_state = None
                                            self.issu_mgr_conn_state = None
                                            self.issu_phase = None
                                            self.issu_type_ng = None
                                            self.issuha_option = None
                                            self.local_ds_handle = None
                                            self.service_name = None
                                            self.dsissu_status_flag = None

                                            self.npl_priority_statistic = YList(self)
                                            self.npl_endpoint = YList(self)
                                            self._segment_path = lambda: "ds-npl"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl, [u'dir_service_conn_state', u'issu_mgr_conn_state', u'issu_phase', u'issu_type_ng', u'issuha_option', u'local_ds_handle', u'service_name', u'dsissu_status_flag'], name, value)


                                        class NplPriorityStatistic(Entity):
                                            """
                                            NPL priority statistics
                                            
                                            .. attribute:: num_sent
                                            
                                            	Total sent
                                            	**type**\: list of  		 :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent>`
                                            
                                            .. attribute:: num_recv
                                            
                                            	Total recvd
                                            	**type**\: list of  		 :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv>`
                                            
                                            .. attribute:: num_sent_drop
                                            
                                            	Sent Error/drops
                                            	**type**\: list of  		 :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                            
                                            .. attribute:: num_recv_drop
                                            
                                            	Recv Errors/drops
                                            	**type**\: list of  		 :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic, self).__init__()

                                                self.yang_name = "npl-priority-statistic"
                                                self.yang_parent_name = "ds-npl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("num-sent", ("num_sent", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent)), ("num-recv", ("num_recv", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv)), ("num-sent-drop", ("num_sent_drop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop)), ("num-recv-drop", ("num_recv_drop", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop))])
                                                self._leafs = OrderedDict()

                                                self.num_sent = YList(self)
                                                self.num_recv = YList(self)
                                                self.num_sent_drop = YList(self)
                                                self.num_recv_drop = YList(self)
                                                self._segment_path = lambda: "npl-priority-statistic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic, [], name, value)


                                            class NumSent(Entity):
                                                """
                                                Total sent
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent, self).__init__()

                                                    self.yang_name = "num-sent"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint64, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "num-sent"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent, [u'entry'], name, value)


                                            class NumRecv(Entity):
                                                """
                                                Total recvd
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv, self).__init__()

                                                    self.yang_name = "num-recv"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint64, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "num-recv"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv, [u'entry'], name, value)


                                            class NumSentDrop(Entity):
                                                """
                                                Sent Error/drops
                                                
                                                .. attribute:: nsr_pl_send_drop_array
                                                
                                                	nsr pl send drop array
                                                	**type**\: list of  		 :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop, self).__init__()

                                                    self.yang_name = "num-sent-drop"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nsr-pl-send-drop-array", ("nsr_pl_send_drop_array", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray))])
                                                    self._leafs = OrderedDict()

                                                    self.nsr_pl_send_drop_array = YList(self)
                                                    self._segment_path = lambda: "num-sent-drop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop, [], name, value)


                                                class NsrPlSendDropArray(Entity):
                                                    """
                                                    nsr pl send drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                                        self.yang_name = "nsr-pl-send-drop-array"
                                                        self.yang_parent_name = "num-sent-drop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "nsr-pl-send-drop-array"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, [u'entry'], name, value)


                                            class NumRecvDrop(Entity):
                                                """
                                                Recv Errors/drops
                                                
                                                .. attribute:: nsr_pl_recv_drop_array
                                                
                                                	nsr pl recv drop array
                                                	**type**\: list of  		 :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop, self).__init__()

                                                    self.yang_name = "num-recv-drop"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nsr-pl-recv-drop-array", ("nsr_pl_recv_drop_array", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray))])
                                                    self._leafs = OrderedDict()

                                                    self.nsr_pl_recv_drop_array = YList(self)
                                                    self._segment_path = lambda: "num-recv-drop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop, [], name, value)


                                                class NsrPlRecvDropArray(Entity):
                                                    """
                                                    nsr pl recv drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                                        self.yang_name = "nsr-pl-recv-drop-array"
                                                        self.yang_parent_name = "num-recv-drop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "nsr-pl-recv-drop-array"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, [u'entry'], name, value)


                                        class NplEndpoint(Entity):
                                            """
                                            NPL endpoint information
                                            
                                            .. attribute:: endpoint_name
                                            
                                            	Endpoint name
                                            	**type**\: str
                                            
                                            .. attribute:: sync_group_name
                                            
                                            	Syncgroup associated with this endpoint
                                            	**type**\: str
                                            
                                            .. attribute:: node_id
                                            
                                            	Node ID
                                            	**type**\: str
                                            
                                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                            
                                            .. attribute:: endpoint_handle
                                            
                                            	NCD endpoint handle
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: endpoint_stale_flag
                                            
                                            	Endpoint stale flag
                                            	**type**\: bool
                                            
                                            .. attribute:: endpoint_issu_role
                                            
                                            	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                            	**type**\: str
                                            
                                            .. attribute:: endpoint_active_flag
                                            
                                            	Endpoint active flag
                                            	**type**\: bool
                                            
                                            .. attribute:: msg_size
                                            
                                            	Message size for this entity
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: wheel_id
                                            
                                            	Wheel ID for this endpoint
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: expected_sequence_num
                                            
                                            	Expected sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: endpoint
                                            
                                            	NCD endpoint bytestream
                                            	**type**\: list of  		 :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint, self).__init__()

                                                self.yang_name = "npl-endpoint"
                                                self.yang_parent_name = "ds-npl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("endpoint", ("endpoint", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint))])
                                                self._leafs = OrderedDict([
                                                    ('endpoint_name', (YLeaf(YType.str, 'endpoint-name'), ['str'])),
                                                    ('sync_group_name', (YLeaf(YType.str, 'sync-group-name'), ['str'])),
                                                    ('node_id', (YLeaf(YType.str, 'node-id'), ['str'])),
                                                    ('endpoint_handle', (YLeaf(YType.uint64, 'endpoint-handle'), ['int'])),
                                                    ('endpoint_stale_flag', (YLeaf(YType.boolean, 'endpoint-stale-flag'), ['bool'])),
                                                    ('endpoint_issu_role', (YLeaf(YType.str, 'endpoint-issu-role'), ['str'])),
                                                    ('endpoint_active_flag', (YLeaf(YType.boolean, 'endpoint-active-flag'), ['bool'])),
                                                    ('msg_size', (YLeaf(YType.uint32, 'msg-size'), ['int'])),
                                                    ('wheel_id', (YLeaf(YType.uint32, 'wheel-id'), ['int'])),
                                                    ('expected_sequence_num', (YLeaf(YType.uint32, 'expected-sequence-num'), ['int'])),
                                                ])
                                                self.endpoint_name = None
                                                self.sync_group_name = None
                                                self.node_id = None
                                                self.endpoint_handle = None
                                                self.endpoint_stale_flag = None
                                                self.endpoint_issu_role = None
                                                self.endpoint_active_flag = None
                                                self.msg_size = None
                                                self.wheel_id = None
                                                self.expected_sequence_num = None

                                                self.endpoint = YList(self)
                                                self._segment_path = lambda: "npl-endpoint"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint, [u'endpoint_name', u'sync_group_name', u'node_id', u'endpoint_handle', u'endpoint_stale_flag', u'endpoint_issu_role', u'endpoint_active_flag', u'msg_size', u'wheel_id', u'expected_sequence_num'], name, value)


                                            class Endpoint(Entity):
                                                """
                                                NCD endpoint bytestream
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint, self).__init__()

                                                    self.yang_name = "endpoint"
                                                    self.yang_parent_name = "npl-endpoint"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "endpoint"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint, [u'entry'], name, value)


                                    class ActiveNsrModeEnterTime(Entity):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime, self).__init__()

                                            self.yang_name = "active-nsr-mode-enter-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "active-nsr-mode-enter-time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime, [u'entry'], name, value)


                                    class StandbyNsrModeEnterTime(Entity):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime, self).__init__()

                                            self.yang_name = "standby-nsr-mode-enter-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "standby-nsr-mode-enter-time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime, [u'entry'], name, value)


                                    class ActiveNsrfoTime(Entity):
                                        """
                                        Time that each thread isdone with its
                                        
                                        go\-activeprocessing (seconds since Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime, self).__init__()

                                            self.yang_name = "active-nsrfo-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "active-nsrfo-time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime, [u'entry'], name, value)


                                    class PostitCountInfo(Entity):
                                        """
                                        List of neighbors and their postit counts
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress>`
                                        
                                        .. attribute:: postit_count
                                        
                                        	Count of the number of postits for this nbr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo, self).__init__()

                                            self.yang_name = "postit-count-info"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('postit_count', (YLeaf(YType.uint32, 'postit-count'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.postit_count = None
                                            self.vrf_name = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "postit-count-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo, [u'postit_count', u'vrf_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "postit-count-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class IssuMilestone(Entity):
                                        """
                                        ISSU Milestones
                                        
                                        .. attribute:: milestone_name
                                        
                                        	Milestone name
                                        	**type**\: str
                                        
                                        .. attribute:: milestone_start_timestamp
                                        
                                        	Milestone start timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: milestone_met_timestamp
                                        
                                        	Milestone met timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone, self).__init__()

                                            self.yang_name = "issu-milestone"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('milestone_name', (YLeaf(YType.str, 'milestone-name'), ['str'])),
                                                ('milestone_start_timestamp', (YLeaf(YType.uint32, 'milestone-start-timestamp'), ['int'])),
                                                ('milestone_met_timestamp', (YLeaf(YType.uint32, 'milestone-met-timestamp'), ['int'])),
                                            ])
                                            self.milestone_name = None
                                            self.milestone_start_timestamp = None
                                            self.milestone_met_timestamp = None
                                            self._segment_path = lambda: "issu-milestone"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone, [u'milestone_name', u'milestone_start_timestamp', u'milestone_met_timestamp'], name, value)


                                class Vrf_(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: lpts_set_up_time
                                    
                                    	Time spent setting up LPTS socket opt (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lpts_calls
                                    
                                    	Number of times LPTS socket opt set up
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_throttles_count
                                    
                                    	Number of partial read throttles
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above low threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: high_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above high threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	Number of bytes of data written
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to to funvction to process sub\-group message list
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of Calls to function to process write queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing imbound update messages (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "performance-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lpts_set_up_time', (YLeaf(YType.uint32, 'lpts-set-up-time'), ['int'])),
                                            ('lpts_calls', (YLeaf(YType.uint32, 'lpts-calls'), ['int'])),
                                            ('read_throttles_count', (YLeaf(YType.uint32, 'read-throttles-count'), ['int'])),
                                            ('low_throttled_read_count', (YLeaf(YType.uint32, 'low-throttled-read-count'), ['int'])),
                                            ('high_throttled_read_count', (YLeaf(YType.uint32, 'high-throttled-read-count'), ['int'])),
                                            ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                            ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                            ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                            ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                            ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                            ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                            ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                            ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                            ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                            ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                            ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                            ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                            ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                            ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                            ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                        ])
                                        self.lpts_set_up_time = None
                                        self.lpts_calls = None
                                        self.read_throttles_count = None
                                        self.low_throttled_read_count = None
                                        self.high_throttled_read_count = None
                                        self.read_calls_count = None
                                        self.read_messages_count = None
                                        self.data_bytes_read = None
                                        self.io_read_time = None
                                        self.write_calls_count = None
                                        self.data_bytes_written = None
                                        self.io_write_time = None
                                        self.write_subgroup_calls_count = None
                                        self.write_subgroup_messages_count = None
                                        self.subgroup_list_time = None
                                        self.write_queue_calls_count = None
                                        self.write_queue_messages_count = None
                                        self.write_queue_time = None
                                        self.inbound_update_messages = None
                                        self.inbound_update_messages_time = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_, [u'lpts_set_up_time', u'lpts_calls', u'read_throttles_count', u'low_throttled_read_count', u'high_throttled_read_count', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time'], name, value)


                        class Sessions(Entity):
                            """
                            The BGP session table
                            
                            .. attribute:: session
                            
                            	A BGP session table entry
                            	**type**\: list of  		 :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("session", ("session", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session))])
                                self._leafs = OrderedDict()

                                self.session = YList(self)
                                self._segment_path = lambda: "sessions"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions, [], name, value)


                            class Session(Entity):
                                """
                                A BGP session table entry
                                
                                .. attribute:: neighbor_address  (key)
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress>`
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\: str
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\: bool
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\: str
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\: bool
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: postit_pending
                                
                                	Nbr has postits pending
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session, self).__init__()

                                    self.yang_name = "session"
                                    self.yang_parent_name = "sessions"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_address']
                                    self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                        ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                        ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                        ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                        ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                        ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                        ('postit_pending', (YLeaf(YType.boolean, 'postit-pending'), ['bool'])),
                                    ])
                                    self.neighbor_address = None
                                    self.speaker_id = None
                                    self.description = None
                                    self.local_as = None
                                    self.remote_as = None
                                    self.messages_queued_in = None
                                    self.messages_queued_out = None
                                    self.connection_state = None
                                    self.is_local_address_configured = None
                                    self.vrf_name = None
                                    self.nsr_enabled = None
                                    self.nsr_state = None
                                    self.postit_pending = None

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                    self._segment_path = lambda: "session" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'messages_queued_in', u'messages_queued_out', u'connection_state', u'is_local_address_configured', u'vrf_name', u'nsr_enabled', u'nsr_state', u'postit_pending'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "session"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-local-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "session"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-remote-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class Neighbors(Entity):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: neighbor
                            
                            	A BGP Neighbor table entry
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors, self).__init__()

                                self.yang_name = "neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor))])
                                self._leafs = OrderedDict()

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "neighbors"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors, [], name, value)


                            class Neighbor(Entity):
                                """
                                A BGP Neighbor table entry
                                
                                .. attribute:: neighbor_address  (key)
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                                
                                .. attribute:: send_notification_info
                                
                                	Information on the last notification sent
                                	**type**\:  :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo>`
                                
                                .. attribute:: received_notification_info
                                
                                	Information on the last notification received
                                	**type**\:  :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics>`
                                
                                .. attribute:: message_statistics
                                
                                	Message statistics
                                	**type**\:  :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics>`
                                
                                .. attribute:: tcp_init_sync_time_spec
                                
                                	Time When neighbor entered TCP Init Sync
                                	**type**\:  :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_phase_two_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Phase Two
                                	**type**\:  :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_done_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Done
                                	**type**\:  :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance>`
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\: str
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_external_neighbor_not_directly_connected
                                
                                	External neighbor not directly connected
                                	**type**\: bool
                                
                                .. attribute:: messages_received
                                
                                	Number of messages received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_sent
                                
                                	Number of messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_in
                                
                                	No. of update msgs received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_out
                                
                                	No. of update messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_established_time
                                
                                	Time (in secs) that the connection has been established
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                .. attribute:: previous_connection_state
                                
                                	Previous state of connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_admin_status
                                
                                	Administrative status of connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: open_check_error_code
                                
                                	Open check error code
                                	**type**\:  :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\: bool
                                
                                .. attribute:: connection_local_port
                                
                                	Local port for the connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_remote_port
                                
                                	Remote port for the connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_interface_handle
                                
                                	Interface Handle of Neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_notification_sent
                                
                                	Notification was sent during last reset
                                	**type**\: bool
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\: bool
                                
                                .. attribute:: is_out_of_memory_shutdown
                                
                                	Neighbor shut down during a SEVERE low memory condition
                                	**type**\: bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\: bool
                                
                                .. attribute:: is_ebgp_peer_as_league
                                
                                	EBGP peer belongs to AS League
                                	**type**\: bool
                                
                                .. attribute:: is_ebgp_peer_common_admin
                                
                                	EBGP peer with common administation
                                	**type**\: bool
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\: bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\: bool
                                
                                .. attribute:: bfd_session_state
                                
                                	BFD state for this peer
                                	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                
                                .. attribute:: bfd_session_created_state
                                
                                	BFD state for this peer
                                	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_state_ts
                                
                                	Timestamp since when nbr is in this bfd state
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: router_id
                                
                                	Router ID for the neighbor
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: negotiated_protocol_version
                                
                                	Negotiated protocol version
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\: bool
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\: bool
                                
                                .. attribute:: is_capability_negotiation_suppressed
                                
                                	Capability negotiation suppressed
                                	**type**\: bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\: bool
                                
                                .. attribute:: is_route_refresh_capability_received
                                
                                	Route refresh capability received
                                	**type**\: bool
                                
                                .. attribute:: is_route_refresh_old_capability_received
                                
                                	Route refresh old capability received
                                	**type**\: bool
                                
                                .. attribute:: is_gr_aware
                                
                                	GR awareness received
                                	**type**\: bool
                                
                                .. attribute:: is4_byte_as_capability_received
                                
                                	4\-byte AScapability received
                                	**type**\: bool
                                
                                .. attribute:: is4_byte_as_capability_sent
                                
                                	4\-byte AScapability Snt
                                	**type**\: bool
                                
                                .. attribute:: multi_protocol_capability_received
                                
                                	Multi\-protocol capability has been received
                                	**type**\: bool
                                
                                .. attribute:: hold_time
                                
                                	Hold time (in secs) negotiated for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: keep_alive_time
                                
                                	Keepalive time (in secs) negotiated for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connect_retry_interval
                                
                                	Time (in secs) for connect retry timer
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_update
                                
                                	Time (in secs) since last update message was received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read
                                
                                	Time (in secs) since last read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read_reset
                                
                                	Time (in secs) since last read before last reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_last_cb
                                
                                	CB
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: time_last_cb_reset
                                
                                	Last CB before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_last_fb
                                
                                	FB
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: count_last_write
                                
                                	Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_last_write
                                
                                	Time (in secs) since last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: attempted_last_write_bytes
                                
                                	Attempted size of last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_last_write_bytes
                                
                                	Actual size of last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_second_last_write
                                
                                	Time (in secs) since second  last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: attempted_second_last_write_bytes
                                
                                	Attempted size of second last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_bytes
                                
                                	Actual size of second last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: attempted_last_write_reset_bytes
                                
                                	Attempted size of last write before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_last_write_reset_bytes
                                
                                	Actual size of last write before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_second_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: attempted_second_last_write_reset_bytes
                                
                                	Attempted size of second last write before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_reset_bytes
                                
                                	Actual size of second last write before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_write_event
                                
                                	Time (in secs) since last write thread event
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_write_event
                                
                                	Time (in secs) since second last write thread event
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_aexpiry_reset
                                
                                	Time (in secs) since last KA timer expiry before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_k_aexpiry_reset
                                
                                	Time (in secs) since second last KA timer expiry before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_anotsent_reset
                                
                                	Duration (in secs) since last time that KA was not sent before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_aerror_reset
                                
                                	Duration (in secs) since last time that an error was encountered after KA expiry
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_astart_reset
                                
                                	Time (in secs) since the last KA timer start before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_k_astart_reset
                                
                                	Time (in secs) since the second last KA timer start before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: connection_up_count
                                
                                	Number of times the connection was established
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_down_count
                                
                                	Number of times connection was dropped
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_connection_last_dropped
                                
                                	Time since the connection last went down (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: reset_reason
                                
                                	Reason for last connection reset
                                	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                
                                .. attribute:: peer_reset_reason
                                
                                	Reason for last peer close event
                                	**type**\:  :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                
                                .. attribute:: peer_error_code
                                
                                	If peer closed, error received from transport
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_notify_error_code
                                
                                	Code for the last error notification seen on the connection
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_notify_error_subcode
                                
                                	Error subcode of the last error notification seen on the connection
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: error_notifies_received
                                
                                	Number of error notifications received on the connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: error_notifies_sent
                                
                                	Number of error notifications sent on the connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\: bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\: str
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\: bool
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\: bool
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\: bool
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: fssn_offset
                                
                                	First standby SeqNo offset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fpbsn_offset
                                
                                	First standby PDU boundary SeqNo offset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_ackd_seq_no
                                
                                	SeqNo of the last Ackd byte
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bytes_written
                                
                                	Total bytes written by write thread
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: bytes_read
                                
                                	Total bytes read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: socket_read_bytes
                                
                                	Total read bytes value insocket\-lib
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: is_read_disabled
                                
                                	If true, socket read isdisabled
                                	**type**\: bool
                                
                                .. attribute:: update_bytes_read
                                
                                	Total update bytes read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\: bool
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\: bool
                                
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\: bool
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\: bool
                                
                                .. attribute:: io_armed
                                
                                	If true, socket has beenauto\-armed for io control
                                	**type**\: bool
                                
                                .. attribute:: read_armed
                                
                                	If true, socket has beenauto\-armed for read
                                	**type**\: bool
                                
                                .. attribute:: write_armed
                                
                                	If true, socket has beenauto\-armed for write
                                	**type**\: bool
                                
                                .. attribute:: discard_data_bytes
                                
                                	Remaining discard data (bytes) on Standby
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\: bool
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\: bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\: bool
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\: bool
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\: bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\: bool
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\: bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\: bool
                                
                                .. attribute:: dynamic_neighbor
                                
                                	Dynamic neighbor
                                	**type**\: bool
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_address']
                                    self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress)), ("send-notification-info", ("send_notification_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo)), ("received-notification-info", ("received_notification_info", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics)), ("message-statistics", ("message_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics)), ("tcp-init-sync-time-spec", ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec)), ("tcp-init-sync-phase-two-time-spec", ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec)), ("tcp-init-sync-done-time-spec", ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                        ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                        ('is_external_neighbor_not_directly_connected', (YLeaf(YType.boolean, 'is-external-neighbor-not-directly-connected'), ['bool'])),
                                        ('messages_received', (YLeaf(YType.uint32, 'messages-received'), ['int'])),
                                        ('messages_sent', (YLeaf(YType.uint32, 'messages-sent'), ['int'])),
                                        ('update_messages_in', (YLeaf(YType.uint32, 'update-messages-in'), ['int'])),
                                        ('update_messages_out', (YLeaf(YType.uint32, 'update-messages-out'), ['int'])),
                                        ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                        ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                        ('connection_established_time', (YLeaf(YType.uint32, 'connection-established-time'), ['int'])),
                                        ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                        ('previous_connection_state', (YLeaf(YType.uint32, 'previous-connection-state'), ['int'])),
                                        ('connection_admin_status', (YLeaf(YType.uint32, 'connection-admin-status'), ['int'])),
                                        ('open_check_error_code', (YLeaf(YType.enumeration, 'open-check-error-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpOpenCheckErr', '')])),
                                        ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                        ('connection_local_port', (YLeaf(YType.uint32, 'connection-local-port'), ['int'])),
                                        ('connection_remote_port', (YLeaf(YType.uint32, 'connection-remote-port'), ['int'])),
                                        ('neighbor_interface_handle', (YLeaf(YType.uint32, 'neighbor-interface-handle'), ['int'])),
                                        ('reset_notification_sent', (YLeaf(YType.boolean, 'reset-notification-sent'), ['bool'])),
                                        ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                        ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                        ('is_out_of_memory_shutdown', (YLeaf(YType.boolean, 'is-out-of-memory-shutdown'), ['bool'])),
                                        ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                        ('is_ebgp_peer_as_league', (YLeaf(YType.boolean, 'is-ebgp-peer-as-league'), ['bool'])),
                                        ('is_ebgp_peer_common_admin', (YLeaf(YType.boolean, 'is-ebgp-peer-common-admin'), ['bool'])),
                                        ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                        ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                        ('bfd_session_state', (YLeaf(YType.enumeration, 'bfd-session-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                        ('bfd_session_created_state', (YLeaf(YType.enumeration, 'bfd-session-created-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                        ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                        ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                        ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                        ('bfd_state_ts', (YLeaf(YType.uint64, 'bfd-state-ts'), ['int'])),
                                        ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                        ('negotiated_protocol_version', (YLeaf(YType.uint16, 'negotiated-protocol-version'), ['int'])),
                                        ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                        ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                        ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                        ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                        ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                        ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                        ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                        ('is_capability_negotiation_suppressed', (YLeaf(YType.boolean, 'is-capability-negotiation-suppressed'), ['bool'])),
                                        ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                        ('is_route_refresh_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-capability-received'), ['bool'])),
                                        ('is_route_refresh_old_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-old-capability-received'), ['bool'])),
                                        ('is_gr_aware', (YLeaf(YType.boolean, 'is-gr-aware'), ['bool'])),
                                        ('is4_byte_as_capability_received', (YLeaf(YType.boolean, 'is4-byte-as-capability-received'), ['bool'])),
                                        ('is4_byte_as_capability_sent', (YLeaf(YType.boolean, 'is4-byte-as-capability-sent'), ['bool'])),
                                        ('multi_protocol_capability_received', (YLeaf(YType.boolean, 'multi-protocol-capability-received'), ['bool'])),
                                        ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                        ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                        ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                        ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                        ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                        ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                        ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                        ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                        ('connect_retry_interval', (YLeaf(YType.uint16, 'connect-retry-interval'), ['int'])),
                                        ('time_since_last_update', (YLeaf(YType.uint32, 'time-since-last-update'), ['int'])),
                                        ('time_since_last_read', (YLeaf(YType.uint32, 'time-since-last-read'), ['int'])),
                                        ('time_since_last_read_reset', (YLeaf(YType.uint32, 'time-since-last-read-reset'), ['int'])),
                                        ('time_last_cb', (YLeaf(YType.uint64, 'time-last-cb'), ['int'])),
                                        ('time_last_cb_reset', (YLeaf(YType.uint32, 'time-last-cb-reset'), ['int'])),
                                        ('time_last_fb', (YLeaf(YType.uint64, 'time-last-fb'), ['int'])),
                                        ('count_last_write', (YLeaf(YType.uint32, 'count-last-write'), ['int'])),
                                        ('time_since_last_write', (YLeaf(YType.uint32, 'time-since-last-write'), ['int'])),
                                        ('attempted_last_write_bytes', (YLeaf(YType.uint32, 'attempted-last-write-bytes'), ['int'])),
                                        ('actual_last_write_bytes', (YLeaf(YType.uint32, 'actual-last-write-bytes'), ['int'])),
                                        ('time_since_second_last_write', (YLeaf(YType.uint32, 'time-since-second-last-write'), ['int'])),
                                        ('attempted_second_last_write_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-bytes'), ['int'])),
                                        ('actual_second_last_write_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-bytes'), ['int'])),
                                        ('time_since_last_write_reset', (YLeaf(YType.uint32, 'time-since-last-write-reset'), ['int'])),
                                        ('attempted_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-last-write-reset-bytes'), ['int'])),
                                        ('actual_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-last-write-reset-bytes'), ['int'])),
                                        ('time_since_second_last_write_reset', (YLeaf(YType.uint32, 'time-since-second-last-write-reset'), ['int'])),
                                        ('attempted_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-reset-bytes'), ['int'])),
                                        ('actual_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-reset-bytes'), ['int'])),
                                        ('last_write_event', (YLeaf(YType.uint32, 'last-write-event'), ['int'])),
                                        ('second_last_write_event', (YLeaf(YType.uint32, 'second-last-write-event'), ['int'])),
                                        ('last_k_aexpiry_reset', (YLeaf(YType.uint32, 'last-k-aexpiry-reset'), ['int'])),
                                        ('second_last_k_aexpiry_reset', (YLeaf(YType.uint32, 'second-last-k-aexpiry-reset'), ['int'])),
                                        ('last_k_anotsent_reset', (YLeaf(YType.uint32, 'last-k-anotsent-reset'), ['int'])),
                                        ('last_k_aerror_reset', (YLeaf(YType.uint32, 'last-k-aerror-reset'), ['int'])),
                                        ('last_k_astart_reset', (YLeaf(YType.uint32, 'last-k-astart-reset'), ['int'])),
                                        ('second_last_k_astart_reset', (YLeaf(YType.uint32, 'second-last-k-astart-reset'), ['int'])),
                                        ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                        ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                        ('time_since_connection_last_dropped', (YLeaf(YType.uint32, 'time-since-connection-last-dropped'), ['int'])),
                                        ('reset_reason', (YLeaf(YType.enumeration, 'reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                        ('peer_reset_reason', (YLeaf(YType.enumeration, 'peer-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPeerResetReasonIndex', '')])),
                                        ('peer_error_code', (YLeaf(YType.uint32, 'peer-error-code'), ['int'])),
                                        ('last_notify_error_code', (YLeaf(YType.uint8, 'last-notify-error-code'), ['int'])),
                                        ('last_notify_error_subcode', (YLeaf(YType.uint8, 'last-notify-error-subcode'), ['int'])),
                                        ('error_notifies_received', (YLeaf(YType.uint32, 'error-notifies-received'), ['int'])),
                                        ('error_notifies_sent', (YLeaf(YType.uint32, 'error-notifies-sent'), ['int'])),
                                        ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                        ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                        ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                        ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                        ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                        ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                        ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                        ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                        ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                        ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                        ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                        ('fssn_offset', (YLeaf(YType.uint32, 'fssn-offset'), ['int'])),
                                        ('fpbsn_offset', (YLeaf(YType.uint32, 'fpbsn-offset'), ['int'])),
                                        ('last_ackd_seq_no', (YLeaf(YType.uint32, 'last-ackd-seq-no'), ['int'])),
                                        ('bytes_written', (YLeaf(YType.uint32, 'bytes-written'), ['int'])),
                                        ('bytes_read', (YLeaf(YType.uint32, 'bytes-read'), ['int'])),
                                        ('socket_read_bytes', (YLeaf(YType.uint32, 'socket-read-bytes'), ['int'])),
                                        ('is_read_disabled', (YLeaf(YType.boolean, 'is-read-disabled'), ['bool'])),
                                        ('update_bytes_read', (YLeaf(YType.uint32, 'update-bytes-read'), ['int'])),
                                        ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                        ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                        ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                        ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                        ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                        ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                        ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                        ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                        ('io_armed', (YLeaf(YType.boolean, 'io-armed'), ['bool'])),
                                        ('read_armed', (YLeaf(YType.boolean, 'read-armed'), ['bool'])),
                                        ('write_armed', (YLeaf(YType.boolean, 'write-armed'), ['bool'])),
                                        ('discard_data_bytes', (YLeaf(YType.uint32, 'discard-data-bytes'), ['int'])),
                                        ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                        ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                        ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                        ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                        ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                        ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                        ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                        ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                        ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                        ('dynamic_neighbor', (YLeaf(YType.boolean, 'dynamic-neighbor'), ['bool'])),
                                    ])
                                    self.neighbor_address = None
                                    self.speaker_id = None
                                    self.description = None
                                    self.local_as = None
                                    self.remote_as = None
                                    self.has_internal_link = None
                                    self.is_external_neighbor_not_directly_connected = None
                                    self.messages_received = None
                                    self.messages_sent = None
                                    self.update_messages_in = None
                                    self.update_messages_out = None
                                    self.messages_queued_in = None
                                    self.messages_queued_out = None
                                    self.connection_established_time = None
                                    self.connection_state = None
                                    self.previous_connection_state = None
                                    self.connection_admin_status = None
                                    self.open_check_error_code = None
                                    self.is_local_address_configured = None
                                    self.connection_local_port = None
                                    self.connection_remote_port = None
                                    self.neighbor_interface_handle = None
                                    self.reset_notification_sent = None
                                    self.is_administratively_shut_down = None
                                    self.is_neighbor_max_prefix_shutdown = None
                                    self.is_out_of_memory_shutdown = None
                                    self.is_out_of_memory_forced_up = None
                                    self.is_ebgp_peer_as_league = None
                                    self.is_ebgp_peer_common_admin = None
                                    self.ttl_security_enabled = None
                                    self.suppress4_byte_as = None
                                    self.bfd_session_state = None
                                    self.bfd_session_created_state = None
                                    self.bfd_session_enable_mode = None
                                    self.bfd_minintervalval = None
                                    self.bfd_multiplierval = None
                                    self.bfd_state_ts = None
                                    self.router_id = None
                                    self.negotiated_protocol_version = None
                                    self.ebgp_time_to_live = None
                                    self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                    self.tcpmss = None
                                    self.msg_log_in = None
                                    self.msg_log_out = None
                                    self.neighbor_local_as = None
                                    self.local_as_no_prepend = None
                                    self.is_capability_negotiation_suppressed = None
                                    self.is_capability_negotiation_performed = None
                                    self.is_route_refresh_capability_received = None
                                    self.is_route_refresh_old_capability_received = None
                                    self.is_gr_aware = None
                                    self.is4_byte_as_capability_received = None
                                    self.is4_byte_as_capability_sent = None
                                    self.multi_protocol_capability_received = None
                                    self.hold_time = None
                                    self.keep_alive_time = None
                                    self.configured_hold_time = None
                                    self.configured_keepalive = None
                                    self.configured_min_acc_hold_time = None
                                    self.min_advertise_interval = None
                                    self.min_advertise_interval_msecs = None
                                    self.min_origination_interval = None
                                    self.connect_retry_interval = None
                                    self.time_since_last_update = None
                                    self.time_since_last_read = None
                                    self.time_since_last_read_reset = None
                                    self.time_last_cb = None
                                    self.time_last_cb_reset = None
                                    self.time_last_fb = None
                                    self.count_last_write = None
                                    self.time_since_last_write = None
                                    self.attempted_last_write_bytes = None
                                    self.actual_last_write_bytes = None
                                    self.time_since_second_last_write = None
                                    self.attempted_second_last_write_bytes = None
                                    self.actual_second_last_write_bytes = None
                                    self.time_since_last_write_reset = None
                                    self.attempted_last_write_reset_bytes = None
                                    self.actual_last_write_reset_bytes = None
                                    self.time_since_second_last_write_reset = None
                                    self.attempted_second_last_write_reset_bytes = None
                                    self.actual_second_last_write_reset_bytes = None
                                    self.last_write_event = None
                                    self.second_last_write_event = None
                                    self.last_k_aexpiry_reset = None
                                    self.second_last_k_aexpiry_reset = None
                                    self.last_k_anotsent_reset = None
                                    self.last_k_aerror_reset = None
                                    self.last_k_astart_reset = None
                                    self.second_last_k_astart_reset = None
                                    self.connection_up_count = None
                                    self.connection_down_count = None
                                    self.time_since_connection_last_dropped = None
                                    self.reset_reason = None
                                    self.peer_reset_reason = None
                                    self.peer_error_code = None
                                    self.last_notify_error_code = None
                                    self.last_notify_error_subcode = None
                                    self.error_notifies_received = None
                                    self.error_notifies_sent = None
                                    self.remote_as_number = None
                                    self.dmz_link_bandwidth = None
                                    self.ebgp_recv_dmz = None
                                    self.ebgp_send_dmz_mode = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.tcp_session_open_mode = None
                                    self.vrf_name = None
                                    self.standby_rp = None
                                    self.nsr_enabled = None
                                    self.graceful_restart_enabled_nbr = None
                                    self.gr_restart_time = None
                                    self.gr_stale_path_time = None
                                    self.fssn_offset = None
                                    self.fpbsn_offset = None
                                    self.last_ackd_seq_no = None
                                    self.bytes_written = None
                                    self.bytes_read = None
                                    self.socket_read_bytes = None
                                    self.is_read_disabled = None
                                    self.update_bytes_read = None
                                    self.nsr_state = None
                                    self.is_passive_close = None
                                    self.nbr_enforce_first_as = None
                                    self.active_bmp_servers = None
                                    self.nbr_cluster_id = None
                                    self.nbr_in_cluster = None
                                    self.ignore_connected = None
                                    self.internal_vpn_client = None
                                    self.io_armed = None
                                    self.read_armed = None
                                    self.write_armed = None
                                    self.discard_data_bytes = None
                                    self.local_as_replace_as = None
                                    self.local_as_dual_as = None
                                    self.local_as_dual_as_mode_native = None
                                    self.egress_peer_engineering_enabled = None
                                    self.discard_as4_path = None
                                    self.rpki_disable = None
                                    self.rpki_use_validity = None
                                    self.rpki_allow_invalid = None
                                    self.rpki_signal_ibgp = None
                                    self.dynamic_neighbor = None

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                    self.send_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo()
                                    self.send_notification_info.parent = self
                                    self._children_name_map["send_notification_info"] = "send-notification-info"

                                    self.received_notification_info = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                    self.received_notification_info.parent = self
                                    self._children_name_map["received_notification_info"] = "received-notification-info"

                                    self.performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self._children_name_map["performance_statistics"] = "performance-statistics"

                                    self.message_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics()
                                    self.message_statistics.parent = self
                                    self._children_name_map["message_statistics"] = "message-statistics"

                                    self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                    self.tcp_init_sync_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"

                                    self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                    self.tcp_init_sync_phase_two_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"

                                    self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                    self.tcp_init_sync_done_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"

                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                    self.af_data = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_external_neighbor_not_directly_connected', u'messages_received', u'messages_sent', u'update_messages_in', u'update_messages_out', u'messages_queued_in', u'messages_queued_out', u'connection_established_time', u'connection_state', u'previous_connection_state', u'connection_admin_status', u'open_check_error_code', u'is_local_address_configured', u'connection_local_port', u'connection_remote_port', u'neighbor_interface_handle', u'reset_notification_sent', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_shutdown', u'is_out_of_memory_forced_up', u'is_ebgp_peer_as_league', u'is_ebgp_peer_common_admin', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_state', u'bfd_session_created_state', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'bfd_state_ts', u'router_id', u'negotiated_protocol_version', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_suppressed', u'is_capability_negotiation_performed', u'is_route_refresh_capability_received', u'is_route_refresh_old_capability_received', u'is_gr_aware', u'is4_byte_as_capability_received', u'is4_byte_as_capability_sent', u'multi_protocol_capability_received', u'hold_time', u'keep_alive_time', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'connect_retry_interval', u'time_since_last_update', u'time_since_last_read', u'time_since_last_read_reset', u'time_last_cb', u'time_last_cb_reset', u'time_last_fb', u'count_last_write', u'time_since_last_write', u'attempted_last_write_bytes', u'actual_last_write_bytes', u'time_since_second_last_write', u'attempted_second_last_write_bytes', u'actual_second_last_write_bytes', u'time_since_last_write_reset', u'attempted_last_write_reset_bytes', u'actual_last_write_reset_bytes', u'time_since_second_last_write_reset', u'attempted_second_last_write_reset_bytes', u'actual_second_last_write_reset_bytes', u'last_write_event', u'second_last_write_event', u'last_k_aexpiry_reset', u'second_last_k_aexpiry_reset', u'last_k_anotsent_reset', u'last_k_aerror_reset', u'last_k_astart_reset', u'second_last_k_astart_reset', u'connection_up_count', u'connection_down_count', u'time_since_connection_last_dropped', u'reset_reason', u'peer_reset_reason', u'peer_error_code', u'last_notify_error_code', u'last_notify_error_subcode', u'error_notifies_received', u'error_notifies_sent', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'fssn_offset', u'fpbsn_offset', u'last_ackd_seq_no', u'bytes_written', u'bytes_read', u'socket_read_bytes', u'is_read_disabled', u'update_bytes_read', u'nsr_state', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'io_armed', u'read_armed', u'write_armed', u'discard_data_bytes', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'dynamic_neighbor'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-local-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-remote-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SendNotificationInfo(Entity):
                                    """
                                    Information on the last notification sent
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo, self).__init__()

                                        self.yang_name = "send-notification-info"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData))])
                                        self._leafs = OrderedDict([
                                            ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                            ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                            ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                        ])
                                        self.time_since_last_notification = None
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "send-notification-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "send-notification-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "last-notification-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                class ReceivedNotificationInfo(Entity):
                                    """
                                    Information on the last notification received
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo, self).__init__()

                                        self.yang_name = "received-notification-info"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData))])
                                        self._leafs = OrderedDict([
                                            ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                            ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                            ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                        ])
                                        self.time_since_last_notification = None
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "received-notification-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "received-notification-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "last-notification-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                class PerformanceStatistics(Entity):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: read_throttles
                                    
                                    	Number of partial read throttles
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read
                                    
                                    	Num socket reads after nbrs crossed low threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: high_throttled_read
                                    
                                    	Num of socket reads after nbr crossed high threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_last_throttled_read
                                    
                                    	Time (in secs) since last read after being throttled
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	No. of data bytes written
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: last_sent_seq_no
                                    
                                    	Seq No of the last sent byte
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to function to process sub\-group message list
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group msgs processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list  (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of calls to function to process write queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing inbound update messages (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: maximum_read_size
                                    
                                    	Size of largest socket (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: actives
                                    
                                    	Number of retried Active opens for this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: failed_post_actives
                                    
                                    	Number of Active Opens that failed in the Post Active State for this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passives
                                    
                                    	Number of retried Passive opens for this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rejected_passives
                                    
                                    	Number of rejected Passive opens for this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: active_collision
                                    
                                    	Number of Closed Active connections for this neighbor due to collision 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passive_collision
                                    
                                    	Number of Closed Remote opens for this neighborneighbor due to collision 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_read_thread_trigger
                                    
                                    	Number of times io\-control thread trigger read thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_write_thread_trigger
                                    
                                    	Number of times io\-control thread trigger write thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_status
                                    
                                    	Socket status, TRUE if socket closed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_flags
                                    
                                    	Reset flags, per thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nbr_flags
                                    
                                    	Nbr flags, per thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nbr_fd
                                    
                                    	Primary FD, per nbr
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: reset_retries
                                    
                                    	Reset Retries, per nbr
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sync_flags
                                    
                                    	Sync flags, per nbr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_oper_down_count
                                    
                                    	Number of times NSR scoped sync has been done
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_nsr_scoped_sync
                                    
                                    	Last time NSR scoped syncwas done for the neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics, self).__init__()

                                        self.yang_name = "performance-statistics"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('read_throttles', (YLeaf(YType.uint32, 'read-throttles'), ['int'])),
                                            ('low_throttled_read', (YLeaf(YType.uint32, 'low-throttled-read'), ['int'])),
                                            ('high_throttled_read', (YLeaf(YType.uint32, 'high-throttled-read'), ['int'])),
                                            ('time_since_last_throttled_read', (YLeaf(YType.uint32, 'time-since-last-throttled-read'), ['int'])),
                                            ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                            ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                            ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                            ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                            ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                            ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                            ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                            ('last_sent_seq_no', (YLeaf(YType.uint32, 'last-sent-seq-no'), ['int'])),
                                            ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                            ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                            ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                            ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                            ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                            ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                            ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                            ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                            ('maximum_read_size', (YLeaf(YType.uint32, 'maximum-read-size'), ['int'])),
                                            ('actives', (YLeaf(YType.uint32, 'actives'), ['int'])),
                                            ('failed_post_actives', (YLeaf(YType.uint32, 'failed-post-actives'), ['int'])),
                                            ('passives', (YLeaf(YType.uint32, 'passives'), ['int'])),
                                            ('rejected_passives', (YLeaf(YType.uint32, 'rejected-passives'), ['int'])),
                                            ('active_collision', (YLeaf(YType.uint32, 'active-collision'), ['int'])),
                                            ('passive_collision', (YLeaf(YType.uint32, 'passive-collision'), ['int'])),
                                            ('control_to_read_thread_trigger', (YLeaf(YType.uint32, 'control-to-read-thread-trigger'), ['int'])),
                                            ('control_to_write_thread_trigger', (YLeaf(YType.uint32, 'control-to-write-thread-trigger'), ['int'])),
                                            ('network_status', (YLeaf(YType.uint32, 'network-status'), ['int'])),
                                            ('reset_flags', (YLeaf(YType.uint32, 'reset-flags'), ['int'])),
                                            ('nbr_flags', (YLeaf(YType.uint32, 'nbr-flags'), ['int'])),
                                            ('nbr_fd', (YLeaf(YType.int32, 'nbr-fd'), ['int'])),
                                            ('reset_retries', (YLeaf(YType.uint8, 'reset-retries'), ['int'])),
                                            ('sync_flags', (YLeaf(YType.uint32, 'sync-flags'), ['int'])),
                                            ('nsr_oper_down_count', (YLeaf(YType.uint32, 'nsr-oper-down-count'), ['int'])),
                                            ('last_nsr_scoped_sync', (YLeaf(YType.uint32, 'last-nsr-scoped-sync'), ['int'])),
                                        ])
                                        self.read_throttles = None
                                        self.low_throttled_read = None
                                        self.high_throttled_read = None
                                        self.time_since_last_throttled_read = None
                                        self.read_calls_count = None
                                        self.read_messages_count = None
                                        self.data_bytes_read = None
                                        self.io_read_time = None
                                        self.write_calls_count = None
                                        self.data_bytes_written = None
                                        self.io_write_time = None
                                        self.last_sent_seq_no = None
                                        self.write_subgroup_calls_count = None
                                        self.write_subgroup_messages_count = None
                                        self.subgroup_list_time = None
                                        self.write_queue_calls_count = None
                                        self.write_queue_messages_count = None
                                        self.write_queue_time = None
                                        self.inbound_update_messages = None
                                        self.inbound_update_messages_time = None
                                        self.maximum_read_size = None
                                        self.actives = None
                                        self.failed_post_actives = None
                                        self.passives = None
                                        self.rejected_passives = None
                                        self.active_collision = None
                                        self.passive_collision = None
                                        self.control_to_read_thread_trigger = None
                                        self.control_to_write_thread_trigger = None
                                        self.network_status = None
                                        self.reset_flags = None
                                        self.nbr_flags = None
                                        self.nbr_fd = None
                                        self.reset_retries = None
                                        self.sync_flags = None
                                        self.nsr_oper_down_count = None
                                        self.last_nsr_scoped_sync = None
                                        self._segment_path = lambda: "performance-statistics"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics, [u'read_throttles', u'low_throttled_read', u'high_throttled_read', u'time_since_last_throttled_read', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'last_sent_seq_no', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time', u'maximum_read_size', u'actives', u'failed_post_actives', u'passives', u'rejected_passives', u'active_collision', u'passive_collision', u'control_to_read_thread_trigger', u'control_to_write_thread_trigger', u'network_status', u'reset_flags', u'nbr_flags', u'nbr_fd', u'reset_retries', u'sync_flags', u'nsr_oper_down_count', u'last_nsr_scoped_sync'], name, value)


                                class MessageStatistics(Entity):
                                    """
                                    Message statistics
                                    
                                    .. attribute:: open
                                    
                                    	Open
                                    	**type**\:  :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                    
                                    .. attribute:: notification
                                    
                                    	Notification
                                    	**type**\:  :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                    
                                    .. attribute:: update
                                    
                                    	Update
                                    	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                    
                                    .. attribute:: keepalive
                                    
                                    	Keepalive
                                    	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                    
                                    .. attribute:: route_refresh
                                    
                                    	Route refresh
                                    	**type**\:  :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                    
                                    .. attribute:: total
                                    
                                    	Total
                                    	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics, self).__init__()

                                        self.yang_name = "message-statistics"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("open", ("open", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open)), ("notification", ("notification", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification)), ("update", ("update", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update)), ("keepalive", ("keepalive", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive)), ("route-refresh", ("route_refresh", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh)), ("total", ("total", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total))])
                                        self._leafs = OrderedDict()

                                        self.open = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open()
                                        self.open.parent = self
                                        self._children_name_map["open"] = "open"

                                        self.notification = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                        self.notification.parent = self
                                        self._children_name_map["notification"] = "notification"

                                        self.update = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update()
                                        self.update.parent = self
                                        self._children_name_map["update"] = "update"

                                        self.keepalive = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                        self.keepalive.parent = self
                                        self._children_name_map["keepalive"] = "keepalive"

                                        self.route_refresh = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                        self.route_refresh.parent = self
                                        self._children_name_map["route_refresh"] = "route-refresh"

                                        self.total = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total()
                                        self.total.parent = self
                                        self._children_name_map["total"] = "total"
                                        self._segment_path = lambda: "message-statistics"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics, [], name, value)


                                    class Open(Entity):
                                        """
                                        Open
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open, self).__init__()

                                            self.yang_name = "open"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "open"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "open"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "open"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Notification(Entity):
                                        """
                                        Notification
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification, self).__init__()

                                            self.yang_name = "notification"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "notification"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Update(Entity):
                                        """
                                        Update
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update, self).__init__()

                                            self.yang_name = "update"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "update"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Keepalive(Entity):
                                        """
                                        Keepalive
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                            self.yang_name = "keepalive"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "keepalive"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "keepalive"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "keepalive"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class RouteRefresh(Entity):
                                        """
                                        Route refresh
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                            self.yang_name = "route-refresh"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "route-refresh"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "route-refresh"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "route-refresh"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Total(Entity):
                                        """
                                        Total
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total, self).__init__()

                                            self.yang_name = "total"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "total"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "total"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "total"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class TcpInitSyncTimeSpec(Entity):
                                    """
                                    Time When neighbor entered TCP Init Sync
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "tcp-init-sync-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                    """
                                    Time when neighbor entered TCP Init Sync Phase
                                    Two
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class TcpInitSyncDoneTimeSpec(Entity):
                                    """
                                    Time when neighbor entered TCP Init Sync Done
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-done-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "tcp-init-sync-done-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                            ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                            ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                            ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                            ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                            ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                        ])
                                        self.gshut_exists = None
                                        self.gshut_local_active = None
                                        self.gshut_active = None
                                        self.gshut_locpref_set = None
                                        self.gshut_locpref = None
                                        self.gshut_prepends = None
                                        self._segment_path = lambda: "graceful-maintenance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                                class AfData(Entity):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: neighbor_af_performance_statistics
                                    
                                    	Neighbor AF statistics
                                    	**type**\:  :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\: bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\: bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\: str
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: advertise_afi_def_vrf_imp_disable
                                    
                                    	Advertise of default VRF import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                    
                                    	Advertise of v4 default VRF import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                    
                                    	Advertise of v6 default VRF import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_vrf_re_imp_disable
                                    
                                    	Advertise of VRF re\-import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                    
                                    	Advertise of v4 VRF re\-import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                    
                                    	Advertise of v6 VRF re\-import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_eo_r_ready
                                    
                                    	EoR Can be sent for Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\: bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\: bool
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_update_throttled
                                    
                                    	Updates Throttled becausewrite limit is reached
                                    	**type**\: bool
                                    
                                    .. attribute:: is_update_leaving
                                    
                                    	Nbr leaving update\-groupto another
                                    	**type**\: bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\: bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\: bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\: bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_version
                                    
                                    	Neighbor version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: prefixes_accepted
                                    
                                    	No. of prefixes accepted
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_synced
                                    
                                    	Number of prefixes synced to standby
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn_not_found
                                    
                                    	No. of prefixes withdrawn but not found
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied
                                    
                                    	No. of prefixes denied
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_no_policy
                                    
                                    	No. of prefixes denied because there was no inbound policy
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_rt_permit
                                    
                                    	No. of prefixes denied because RT extended community is not imported
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_orf_policy
                                    
                                    	No. of prefixes denied by prefix based ORF policy
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_policy
                                    
                                    	No. of prefixes denied by inbound policy
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_bestpaths
                                    
                                    	No. of bestpaths from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_best_externalpaths
                                    
                                    	No. of best\-external paths from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_advertised
                                    
                                    	No. of prefixes advertised
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_be_advertised
                                    
                                    	No BE prefixes advertised
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_suppressed
                                    
                                    	No. of prefixes suppressed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn
                                    
                                    	No. of prefixes withdrawn
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_received
                                    
                                    	Extended nexthop encoding capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_sent
                                    
                                    	Extended nexhop encoding capability Sent
                                    	**type**\: bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_refreshes_received
                                    
                                    	Number of route refresh requests received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_refreshes_sent
                                    
                                    	Number of route refresh requests sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_target_version
                                    
                                    	Target version for refresh update generation
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_version
                                    
                                    	Version till which refresh updates have been generated
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_acked_version
                                    
                                    	Version acked by the peer for refresh updates sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\: bool
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_default_originate_sent
                                    
                                    	Default origination update sent
                                    	**type**\: bool
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\: bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\: bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\: bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_received_in_read_only
                                    
                                    	An EoR was received while in read\-only mode
                                    	**type**\: bool
                                    
                                    .. attribute:: acked_version
                                    
                                    	Version mapped from acked seqNo
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: synced_acked_version
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version
                                    
                                    	No. of all outstanding version objects waiting for ack from the peer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_refresh_version
                                    
                                    	No. of only refresh version objects waiting for ack from the peer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_max
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\: bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\: bool
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\: bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\: bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with 
                                    	**type**\: bool
                                    
                                    .. attribute:: prefixes_denied_non_cumulative
                                    
                                    	No. of prefixes exactly denied (non cumulative)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: enable_label_stack
                                    
                                    	Enable label stack
                                    	**type**\: bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData, self).__init__()

                                        self.yang_name = "af-data"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-af-performance-statistics", ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby))])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                            ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                            ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                            ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                            ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                            ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                            ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                            ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                            ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                            ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                            ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                            ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                            ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                            ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                            ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                            ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                            ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                            ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                            ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                            ('advertise_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-def-vrf-imp-disable'), ['bool'])),
                                            ('advertise_evpnv4_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-def-vrf-imp-disable'), ['bool'])),
                                            ('advertise_evpnv6_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-def-vrf-imp-disable'), ['bool'])),
                                            ('advertise_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-vrf-re-imp-disable'), ['bool'])),
                                            ('advertise_evpnv4_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-vrf-re-imp-disable'), ['bool'])),
                                            ('advertise_evpnv6_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-vrf-re-imp-disable'), ['bool'])),
                                            ('advertise_afi_eo_r_ready', (YLeaf(YType.boolean, 'advertise-afi-eo-r-ready'), ['bool'])),
                                            ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                            ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                            ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                            ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                            ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                            ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                            ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                            ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                            ('is_update_throttled', (YLeaf(YType.boolean, 'is-update-throttled'), ['bool'])),
                                            ('is_update_leaving', (YLeaf(YType.boolean, 'is-update-leaving'), ['bool'])),
                                            ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                            ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                            ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                            ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                            ('neighbor_version', (YLeaf(YType.uint32, 'neighbor-version'), ['int'])),
                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                            ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                            ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                            ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                            ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                            ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                            ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                            ('prefixes_accepted', (YLeaf(YType.uint32, 'prefixes-accepted'), ['int'])),
                                            ('prefixes_synced', (YLeaf(YType.uint32, 'prefixes-synced'), ['int'])),
                                            ('prefixes_withdrawn_not_found', (YLeaf(YType.uint32, 'prefixes-withdrawn-not-found'), ['int'])),
                                            ('prefixes_denied', (YLeaf(YType.uint32, 'prefixes-denied'), ['int'])),
                                            ('prefixes_denied_no_policy', (YLeaf(YType.uint32, 'prefixes-denied-no-policy'), ['int'])),
                                            ('prefixes_denied_rt_permit', (YLeaf(YType.uint32, 'prefixes-denied-rt-permit'), ['int'])),
                                            ('prefixes_denied_orf_policy', (YLeaf(YType.uint32, 'prefixes-denied-orf-policy'), ['int'])),
                                            ('prefixes_denied_policy', (YLeaf(YType.uint32, 'prefixes-denied-policy'), ['int'])),
                                            ('number_of_bestpaths', (YLeaf(YType.uint32, 'number-of-bestpaths'), ['int'])),
                                            ('number_of_best_externalpaths', (YLeaf(YType.uint32, 'number-of-best-externalpaths'), ['int'])),
                                            ('prefixes_advertised', (YLeaf(YType.uint32, 'prefixes-advertised'), ['int'])),
                                            ('prefixes_be_advertised', (YLeaf(YType.uint32, 'prefixes-be-advertised'), ['int'])),
                                            ('prefixes_suppressed', (YLeaf(YType.uint32, 'prefixes-suppressed'), ['int'])),
                                            ('prefixes_withdrawn', (YLeaf(YType.uint32, 'prefixes-withdrawn'), ['int'])),
                                            ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                            ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                            ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                            ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                            ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                            ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                            ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                            ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                            ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                            ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                            ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                            ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                            ('is_ext_nh_encoding_capability_received', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-received'), ['bool'])),
                                            ('is_ext_nh_encoding_capability_sent', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-sent'), ['bool'])),
                                            ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                            ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                            ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                            ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                            ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                            ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                            ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                            ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                            ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                            ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                            ('route_refreshes_received', (YLeaf(YType.uint32, 'route-refreshes-received'), ['int'])),
                                            ('route_refreshes_sent', (YLeaf(YType.uint32, 'route-refreshes-sent'), ['int'])),
                                            ('refresh_target_version', (YLeaf(YType.uint32, 'refresh-target-version'), ['int'])),
                                            ('refresh_version', (YLeaf(YType.uint32, 'refresh-version'), ['int'])),
                                            ('refresh_acked_version', (YLeaf(YType.uint32, 'refresh-acked-version'), ['int'])),
                                            ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                            ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                            ('is_default_originate_sent', (YLeaf(YType.boolean, 'is-default-originate-sent'), ['bool'])),
                                            ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                            ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                            ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                            ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                            ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                            ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                            ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                            ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                            ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                            ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                            ('eo_r_received_in_read_only', (YLeaf(YType.boolean, 'eo-r-received-in-read-only'), ['bool'])),
                                            ('acked_version', (YLeaf(YType.uint32, 'acked-version'), ['int'])),
                                            ('synced_acked_version', (YLeaf(YType.uint32, 'synced-acked-version'), ['int'])),
                                            ('outstanding_version', (YLeaf(YType.uint32, 'outstanding-version'), ['int'])),
                                            ('outstanding_refresh_version', (YLeaf(YType.uint32, 'outstanding-refresh-version'), ['int'])),
                                            ('outstanding_version_max', (YLeaf(YType.uint32, 'outstanding-version-max'), ['int'])),
                                            ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                            ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                            ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                            ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                            ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                            ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                            ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                            ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                            ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                            ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                            ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                            ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                            ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                            ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                            ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                            ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                            ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                            ('prefixes_denied_non_cumulative', (YLeaf(YType.uint32, 'prefixes-denied-non-cumulative'), ['int'])),
                                            ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                        ])
                                        self.af_name = None
                                        self.is_neighbor_route_reflector_client = None
                                        self.is_legacy_pe_rt = None
                                        self.is_neighbor_af_capable = None
                                        self.is_soft_reconfiguration_inbound_allowed = None
                                        self.is_use_soft_reconfiguration_always_on = None
                                        self.remove_private_as_from_updates = None
                                        self.remove_private_as_entire_aspath_from_updates = None
                                        self.remove_private_as_from_inbound_updates = None
                                        self.remove_private_as_entire_aspath_from_inbound_updates = None
                                        self.flowspec_validation_d_isable = None
                                        self.flowspec_redirect_validation_d_isable = None
                                        self.orr_group_name = None
                                        self.orr_group_index = None
                                        self.is_orr_root_address_configured = None
                                        self.advertise_afi = None
                                        self.advertise_afi_reorg = None
                                        self.advertise_afi_disable = None
                                        self.encapsulation_type = None
                                        self.advertise_rt_type = None
                                        self.advertise_afi_def_vrf_imp_disable = None
                                        self.advertise_evpnv4_afi_def_vrf_imp_disable = None
                                        self.advertise_evpnv6_afi_def_vrf_imp_disable = None
                                        self.advertise_afi_vrf_re_imp_disable = None
                                        self.advertise_evpnv4_afi_vrf_re_imp_disable = None
                                        self.advertise_evpnv6_afi_vrf_re_imp_disable = None
                                        self.advertise_afi_eo_r_ready = None
                                        self.always_use_next_hop_local = None
                                        self.sent_community_to_neighbor = None
                                        self.sent_gshut_community_to_neighbor = None
                                        self.sent_extended_community_to_neighbor = None
                                        self.neighbor_default_originate = None
                                        self.is_orf_sent = None
                                        self.is_update_deferred = None
                                        self.is_orf_send_scheduled = None
                                        self.update_group_number = None
                                        self.filter_group_index = None
                                        self.is_update_throttled = None
                                        self.is_update_leaving = None
                                        self.vpn_update_gen_enabled = None
                                        self.vpn_update_gen_trigger_enabled = None
                                        self.is_addpath_send_operational = None
                                        self.is_addpath_receive_operational = None
                                        self.neighbor_version = None
                                        self.weight = None
                                        self.max_prefix_limit = None
                                        self.use_max_prefix_warning_only = None
                                        self.max_prefix_discard_extra_paths = None
                                        self.max_prefix_exceed_discard_paths = None
                                        self.max_prefix_threshold_percent = None
                                        self.max_prefix_restart_time = None
                                        self.prefixes_accepted = None
                                        self.prefixes_synced = None
                                        self.prefixes_withdrawn_not_found = None
                                        self.prefixes_denied = None
                                        self.prefixes_denied_no_policy = None
                                        self.prefixes_denied_rt_permit = None
                                        self.prefixes_denied_orf_policy = None
                                        self.prefixes_denied_policy = None
                                        self.number_of_bestpaths = None
                                        self.number_of_best_externalpaths = None
                                        self.prefixes_advertised = None
                                        self.prefixes_be_advertised = None
                                        self.prefixes_suppressed = None
                                        self.prefixes_withdrawn = None
                                        self.is_peer_orf_capable = None
                                        self.is_advertised_orf_send = None
                                        self.is_received_orf_send_capable = None
                                        self.is_advertised_orf_receive = None
                                        self.is_received_orf_receive_capable = None
                                        self.is_advertised_graceful_restart = None
                                        self.is_graceful_restart_state_flag = None
                                        self.is_received_graceful_restart_capable = None
                                        self.is_add_path_send_capability_advertised = None
                                        self.is_add_path_send_capability_received = None
                                        self.is_add_path_receive_capability_advertised = None
                                        self.is_add_path_receive_capability_received = None
                                        self.is_ext_nh_encoding_capability_received = None
                                        self.is_ext_nh_encoding_capability_sent = None
                                        self.restart_time = None
                                        self.local_restart_time = None
                                        self.stale_path_timeout = None
                                        self.rib_purge_timeout_value = None
                                        self.neighbor_preserved_forwarding_state = None
                                        self.long_lived_graceful_restart_stale_time_configured = None
                                        self.long_lived_graceful_restart_stale_time_sent = None
                                        self.long_lived_graceful_restart_stale_time_accept = None
                                        self.long_lived_graceful_restart_capability_received = None
                                        self.long_lived_graceful_restart_stale_time_received = None
                                        self.neighbor_preserved_long_lived_forwarding_state = None
                                        self.neighbor_long_lived_graceful_restart_capable = None
                                        self.neighbor_long_lived_graceful_restart_time_remaining = None
                                        self.route_refreshes_received = None
                                        self.route_refreshes_sent = None
                                        self.refresh_target_version = None
                                        self.refresh_version = None
                                        self.refresh_acked_version = None
                                        self.is_prefix_orf_present = None
                                        self.orf_entries_received = None
                                        self.is_default_originate_sent = None
                                        self.route_policy_prefix_orf = None
                                        self.route_policy_in = None
                                        self.route_policy_out = None
                                        self.route_policy_default_originate = None
                                        self.is_neighbor_ebgp_without_inbound_policy = None
                                        self.is_neighbor_ebgp_without_outbound_policy = None
                                        self.is_as_override_set = None
                                        self.is_allow_as_in_set = None
                                        self.allow_as_in_count = None
                                        self.address_family_long_lived_time = None
                                        self.eo_r_received_in_read_only = None
                                        self.acked_version = None
                                        self.synced_acked_version = None
                                        self.outstanding_version = None
                                        self.outstanding_refresh_version = None
                                        self.outstanding_version_max = None
                                        self.is_aigp_set = None
                                        self.is_rt_present = None
                                        self.is_rt_present_standby = None
                                        self.accept_own_enabled = None
                                        self.selective_multipath_eligible = None
                                        self.afrpki_disable = None
                                        self.afrpki_use_validity = None
                                        self.afrpki_allow_invalid = None
                                        self.afrpki_signal_ibgp = None
                                        self.is_advertise_permanent_network = None
                                        self.is_send_mcast_attr = None
                                        self.import_stitching = None
                                        self.import_reoriginate = None
                                        self.import_reoriginate_stitching = None
                                        self.advertise_v4_flags = None
                                        self.advertise_v6_flags = None
                                        self.advertise_local_labeled_route_unicast = None
                                        self.prefixes_denied_non_cumulative = None
                                        self.enable_label_stack = None

                                        self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                        self.neighbor_af_performance_statistics.parent = self
                                        self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"

                                        self.extended_community = YList(self)
                                        self.extended_community_standby = YList(self)
                                        self._segment_path = lambda: "af-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_disable', u'encapsulation_type', u'advertise_rt_type', u'advertise_afi_def_vrf_imp_disable', u'advertise_evpnv4_afi_def_vrf_imp_disable', u'advertise_evpnv6_afi_def_vrf_imp_disable', u'advertise_afi_vrf_re_imp_disable', u'advertise_evpnv4_afi_vrf_re_imp_disable', u'advertise_evpnv6_afi_vrf_re_imp_disable', u'advertise_afi_eo_r_ready', u'always_use_next_hop_local', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'update_group_number', u'filter_group_index', u'is_update_throttled', u'is_update_leaving', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'neighbor_version', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'prefixes_accepted', u'prefixes_synced', u'prefixes_withdrawn_not_found', u'prefixes_denied', u'prefixes_denied_no_policy', u'prefixes_denied_rt_permit', u'prefixes_denied_orf_policy', u'prefixes_denied_policy', u'number_of_bestpaths', u'number_of_best_externalpaths', u'prefixes_advertised', u'prefixes_be_advertised', u'prefixes_suppressed', u'prefixes_withdrawn', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'is_ext_nh_encoding_capability_received', u'is_ext_nh_encoding_capability_sent', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'route_refreshes_received', u'route_refreshes_sent', u'refresh_target_version', u'refresh_version', u'refresh_acked_version', u'is_prefix_orf_present', u'orf_entries_received', u'is_default_originate_sent', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'eo_r_received_in_read_only', u'acked_version', u'synced_acked_version', u'outstanding_version', u'outstanding_refresh_version', u'outstanding_version_max', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'advertise_local_labeled_route_unicast', u'prefixes_denied_non_cumulative', u'enable_label_stack'], name, value)


                                    class NeighborAfPerformanceStatistics(Entity):
                                        """
                                        Neighbor AF statistics
                                        
                                        .. attribute:: sub_group_pending_message_count
                                        
                                        	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: processed_messages
                                        
                                        	Number of messages processed from the neighbor's write queue
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sent_messages
                                        
                                        	Number of messages sent from the neighbor's write queue
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_transmit
                                        
                                        	No. of update messages with split\-horizon flag that were sent out
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_blocked
                                        
                                        	No. of update messages with split\-horizon flag that were blocked
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_transmit
                                        
                                        	No. of withdraw messages with split\-horizon flag that were sent out
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_blocked
                                        
                                        	No. of withdraw messages with split\-horizon flag that were blocked
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                            self.yang_name = "neighbor-af-performance-statistics"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sub_group_pending_message_count', (YLeaf(YType.uint32, 'sub-group-pending-message-count'), ['int'])),
                                                ('processed_messages', (YLeaf(YType.uint32, 'processed-messages'), ['int'])),
                                                ('sent_messages', (YLeaf(YType.uint32, 'sent-messages'), ['int'])),
                                                ('split_horizon_update_transmit', (YLeaf(YType.uint32, 'split-horizon-update-transmit'), ['int'])),
                                                ('split_horizon_update_blocked', (YLeaf(YType.uint32, 'split-horizon-update-blocked'), ['int'])),
                                                ('split_horizon_withdraw_transmit', (YLeaf(YType.uint32, 'split-horizon-withdraw-transmit'), ['int'])),
                                                ('split_horizon_withdraw_blocked', (YLeaf(YType.uint32, 'split-horizon-withdraw-blocked'), ['int'])),
                                            ])
                                            self.sub_group_pending_message_count = None
                                            self.processed_messages = None
                                            self.sent_messages = None
                                            self.split_horizon_update_transmit = None
                                            self.split_horizon_update_blocked = None
                                            self.split_horizon_withdraw_transmit = None
                                            self.split_horizon_withdraw_blocked = None
                                            self._segment_path = lambda: "neighbor-af-performance-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, [u'sub_group_pending_message_count', u'processed_messages', u'sent_messages', u'split_horizon_update_transmit', u'split_horizon_update_blocked', u'split_horizon_withdraw_transmit', u'split_horizon_withdraw_blocked'], name, value)


                                    class ExtendedCommunity(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                            self.yang_name = "extended-community"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "extended-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity, [u'entry'], name, value)


                                    class ExtendedCommunityStandby(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                            self.yang_name = "extended-community-standby"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "extended-community-standby"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                        class NextHopVrf(Entity):
                            """
                            A BGP Next\-hop VRF table entry
                            
                            .. attribute:: total_processing_time
                            
                            	Total time spent in processing
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_proc_notification_time
                            
                            	How long since the maximum processing time notifcation was received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_deletes
                            
                            	Number of bestpath deletes caused by notification which resulted in maximum processing
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_changes
                            
                            	Number of bestpath changes caused by notification which resulted in maximum processing
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_processing_time
                            
                            	Maximum time spent procesing a single batch notification
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_notificationication_time
                            
                            	Time since the last notification was received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_notification_processing_time
                            
                            	Processing time for the last notification
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf, self).__init__()

                                self.yang_name = "next-hop-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total_processing_time', (YLeaf(YType.uint32, 'total-processing-time'), ['int'])),
                                    ('max_proc_notification_time', (YLeaf(YType.uint32, 'max-proc-notification-time'), ['int'])),
                                    ('max_notification_bestpath_deletes', (YLeaf(YType.uint32, 'max-notification-bestpath-deletes'), ['int'])),
                                    ('max_notification_bestpath_changes', (YLeaf(YType.uint32, 'max-notification-bestpath-changes'), ['int'])),
                                    ('maximum_processing_time', (YLeaf(YType.uint32, 'maximum-processing-time'), ['int'])),
                                    ('last_notificationication_time', (YLeaf(YType.uint32, 'last-notificationication-time'), ['int'])),
                                    ('last_notification_processing_time', (YLeaf(YType.uint32, 'last-notification-processing-time'), ['int'])),
                                ])
                                self.total_processing_time = None
                                self.max_proc_notification_time = None
                                self.max_notification_bestpath_deletes = None
                                self.max_notification_bestpath_changes = None
                                self.maximum_processing_time = None
                                self.last_notificationication_time = None
                                self.last_notification_processing_time = None
                                self._segment_path = lambda: "next-hop-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NextHopVrf, [u'total_processing_time', u'max_proc_notification_time', u'max_notification_bestpath_deletes', u'max_notification_bestpath_changes', u'maximum_processing_time', u'last_notificationication_time', u'last_notification_processing_time'], name, value)


                        class NeighborRanges(Entity):
                            """
                            The BGP Dynamic Neighbor Range table
                            
                            .. attribute:: neighbor_range
                            
                            	A BGP Neighbor Range table entry
                            	**type**\: list of  		 :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges, self).__init__()

                                self.yang_name = "neighbor-ranges"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-range", ("neighbor_range", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange))])
                                self._leafs = OrderedDict()

                                self.neighbor_range = YList(self)
                                self._segment_path = lambda: "neighbor-ranges"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges, [], name, value)


                            class NeighborRange(Entity):
                                """
                                A BGP Neighbor Range table entry
                                
                                .. attribute:: neighbor_range_address  (key)
                                
                                	Neighbor Range prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                                
                                .. attribute:: cfg_local_address
                                
                                	Configured local address
                                	**type**\:  :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\: str
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\: bool
                                
                                .. attribute:: neighbor_range_prefix_length
                                
                                	Neighbor Range Prefix Length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\: bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\: bool
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\: bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\: bool
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\: bool
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\: bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\: bool
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\: bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\: str
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\: bool
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\: bool
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\: bool
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\: bool
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\: bool
                                
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\: bool
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\: bool
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\: bool
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\: bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\: bool
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\: bool
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\: bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\: bool
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\: bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\: bool
                                
                                .. attribute:: remote_as_list_name
                                
                                	Remote AS List Name
                                	**type**\: str
                                
                                .. attribute:: nbr_rcv_size
                                
                                	Nbr Receive Size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_send_size
                                
                                	Nbr Send Size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: islocal_address_cfg
                                
                                	Local address configured
                                	**type**\: bool
                                
                                .. attribute:: update_source
                                
                                	Update Source
                                	**type**\: str
                                
                                .. attribute:: addpath_send_enable
                                
                                	Addpath Send enabled
                                	**type**\: bool
                                
                                .. attribute:: addpath_receive_enable
                                
                                	Addpath Receive enable
                                	**type**\: bool
                                
                                .. attribute:: addpath_send_disable
                                
                                	Addpath Send Disabled
                                	**type**\: bool
                                
                                .. attribute:: addpath_receive_disable
                                
                                	Addpath Receive Disabled
                                	**type**\: bool
                                
                                .. attribute:: upd_errh_noreset
                                
                                	Update errh noreset
                                	**type**\: bool
                                
                                .. attribute:: msg_buf_count
                                
                                	Message Buf Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_bug_circular
                                
                                	Message Buf Circular
                                	**type**\: bool
                                
                                .. attribute:: syslog_enable
                                
                                	syslog enable
                                	**type**\: bool
                                
                                .. attribute:: oper_attrf_enable
                                
                                	Oper attrf Enable
                                	**type**\: bool
                                
                                .. attribute:: attrf_group_name
                                
                                	Attrf Group Name
                                	**type**\: str
                                
                                .. attribute:: max_peers
                                
                                	Max Dynamic nbrs in range
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: idle_watch_time
                                
                                	Dynamic Neighbor idle\-watch time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: current_peers
                                
                                	Current Dynamic nbrs in range
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_match
                                
                                	Passive open matching range
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_accepted
                                
                                	open accepted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_max_drop
                                
                                	open drop due to max peers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_inst_error
                                
                                	Error during instance creation
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData>`
                                
                                .. attribute:: instance
                                
                                	Dynamic Neighbor Instance List
                                	**type**\: list of  		 :py:class:`Instance_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange, self).__init__()

                                    self.yang_name = "neighbor-range"
                                    self.yang_parent_name = "neighbor-ranges"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_range_address']
                                    self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance)), ("cfg-local-address", ("cfg_local_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData)), ("instance", ("instance", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_range_address', (YLeaf(YType.str, 'neighbor-range-address'), ['str','str'])),
                                        ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                        ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                        ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                        ('neighbor_range_prefix_length', (YLeaf(YType.uint8, 'neighbor-range-prefix-length'), ['int'])),
                                        ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                        ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                        ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                        ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                        ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                        ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                        ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                        ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                        ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                        ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                        ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                        ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                        ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                        ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                        ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                        ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                        ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                        ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                        ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                        ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                        ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                        ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                        ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                        ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                        ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                        ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                        ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                        ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                        ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                        ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                        ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                        ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                        ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                        ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                        ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                        ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                        ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                        ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                        ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                        ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                        ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                        ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                        ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                        ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                        ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                        ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                        ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                        ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                        ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                        ('remote_as_list_name', (YLeaf(YType.str, 'remote-as-list-name'), ['str'])),
                                        ('nbr_rcv_size', (YLeaf(YType.uint32, 'nbr-rcv-size'), ['int'])),
                                        ('nbr_send_size', (YLeaf(YType.uint32, 'nbr-send-size'), ['int'])),
                                        ('islocal_address_cfg', (YLeaf(YType.boolean, 'islocal-address-cfg'), ['bool'])),
                                        ('update_source', (YLeaf(YType.str, 'update-source'), ['str'])),
                                        ('addpath_send_enable', (YLeaf(YType.boolean, 'addpath-send-enable'), ['bool'])),
                                        ('addpath_receive_enable', (YLeaf(YType.boolean, 'addpath-receive-enable'), ['bool'])),
                                        ('addpath_send_disable', (YLeaf(YType.boolean, 'addpath-send-disable'), ['bool'])),
                                        ('addpath_receive_disable', (YLeaf(YType.boolean, 'addpath-receive-disable'), ['bool'])),
                                        ('upd_errh_noreset', (YLeaf(YType.boolean, 'upd-errh-noreset'), ['bool'])),
                                        ('msg_buf_count', (YLeaf(YType.uint32, 'msg-buf-count'), ['int'])),
                                        ('msg_bug_circular', (YLeaf(YType.boolean, 'msg-bug-circular'), ['bool'])),
                                        ('syslog_enable', (YLeaf(YType.boolean, 'syslog-enable'), ['bool'])),
                                        ('oper_attrf_enable', (YLeaf(YType.boolean, 'oper-attrf-enable'), ['bool'])),
                                        ('attrf_group_name', (YLeaf(YType.str, 'attrf-group-name'), ['str'])),
                                        ('max_peers', (YLeaf(YType.uint32, 'max-peers'), ['int'])),
                                        ('idle_watch_time', (YLeaf(YType.uint32, 'idle-watch-time'), ['int'])),
                                        ('current_peers', (YLeaf(YType.uint32, 'current-peers'), ['int'])),
                                        ('range_open_match', (YLeaf(YType.uint32, 'range-open-match'), ['int'])),
                                        ('range_open_accepted', (YLeaf(YType.uint32, 'range-open-accepted'), ['int'])),
                                        ('range_max_drop', (YLeaf(YType.uint32, 'range-max-drop'), ['int'])),
                                        ('range_inst_error', (YLeaf(YType.uint32, 'range-inst-error'), ['int'])),
                                    ])
                                    self.neighbor_range_address = None
                                    self.speaker_id = None
                                    self.description = None
                                    self.local_as = None
                                    self.remote_as = None
                                    self.has_internal_link = None
                                    self.is_local_address_configured = None
                                    self.neighbor_range_prefix_length = None
                                    self.is_administratively_shut_down = None
                                    self.is_neighbor_max_prefix_shutdown = None
                                    self.is_out_of_memory_forced_up = None
                                    self.ttl_security_enabled = None
                                    self.suppress4_byte_as = None
                                    self.bfd_session_enable_mode = None
                                    self.bfd_minintervalval = None
                                    self.bfd_multiplierval = None
                                    self.ebgp_time_to_live = None
                                    self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                    self.tcpmss = None
                                    self.msg_log_in = None
                                    self.msg_log_out = None
                                    self.neighbor_local_as = None
                                    self.local_as_no_prepend = None
                                    self.is_capability_negotiation_performed = None
                                    self.configured_hold_time = None
                                    self.configured_keepalive = None
                                    self.configured_min_acc_hold_time = None
                                    self.min_advertise_interval = None
                                    self.min_advertise_interval_msecs = None
                                    self.min_origination_interval = None
                                    self.remote_as_number = None
                                    self.dmz_link_bandwidth = None
                                    self.ebgp_recv_dmz = None
                                    self.ebgp_send_dmz_mode = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.tcp_session_open_mode = None
                                    self.vrf_name = None
                                    self.standby_rp = None
                                    self.nsr_enabled = None
                                    self.graceful_restart_enabled_nbr = None
                                    self.gr_restart_time = None
                                    self.gr_stale_path_time = None
                                    self.is_passive_close = None
                                    self.nbr_enforce_first_as = None
                                    self.active_bmp_servers = None
                                    self.nbr_cluster_id = None
                                    self.nbr_in_cluster = None
                                    self.ignore_connected = None
                                    self.internal_vpn_client = None
                                    self.local_as_replace_as = None
                                    self.local_as_dual_as = None
                                    self.local_as_dual_as_mode_native = None
                                    self.egress_peer_engineering_enabled = None
                                    self.discard_as4_path = None
                                    self.rpki_disable = None
                                    self.rpki_use_validity = None
                                    self.rpki_allow_invalid = None
                                    self.rpki_signal_ibgp = None
                                    self.remote_as_list_name = None
                                    self.nbr_rcv_size = None
                                    self.nbr_send_size = None
                                    self.islocal_address_cfg = None
                                    self.update_source = None
                                    self.addpath_send_enable = None
                                    self.addpath_receive_enable = None
                                    self.addpath_send_disable = None
                                    self.addpath_receive_disable = None
                                    self.upd_errh_noreset = None
                                    self.msg_buf_count = None
                                    self.msg_bug_circular = None
                                    self.syslog_enable = None
                                    self.oper_attrf_enable = None
                                    self.attrf_group_name = None
                                    self.max_peers = None
                                    self.idle_watch_time = None
                                    self.current_peers = None
                                    self.range_open_match = None
                                    self.range_open_accepted = None
                                    self.range_max_drop = None
                                    self.range_inst_error = None

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                    self.cfg_local_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                    self.cfg_local_address.parent = self
                                    self._children_name_map["cfg_local_address"] = "cfg-local-address"

                                    self.af_data = YList(self)
                                    self.instance = YList(self)
                                    self._segment_path = lambda: "neighbor-range" + "[neighbor-range-address='" + str(self.neighbor_range_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange, ['neighbor_range_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_local_address_configured', u'neighbor_range_prefix_length', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_forced_up', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_performed', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'remote_as_list_name', u'nbr_rcv_size', u'nbr_send_size', u'islocal_address_cfg', u'update_source', u'addpath_send_enable', u'addpath_receive_enable', u'addpath_send_disable', u'addpath_receive_disable', u'upd_errh_noreset', u'msg_buf_count', u'msg_bug_circular', u'syslog_enable', u'oper_attrf_enable', u'attrf_group_name', u'max_peers', u'idle_watch_time', u'current_peers', u'range_open_match', u'range_open_accepted', u'range_max_drop', u'range_inst_error'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-local-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-remote-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                            ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                            ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                            ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                            ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                            ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                        ])
                                        self.gshut_exists = None
                                        self.gshut_local_active = None
                                        self.gshut_active = None
                                        self.gshut_locpref_set = None
                                        self.gshut_locpref = None
                                        self.gshut_prepends = None
                                        self._segment_path = lambda: "graceful-maintenance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                                class CfgLocalAddress(Entity):
                                    """
                                    Configured local address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress, self).__init__()

                                        self.yang_name = "cfg-local-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "cfg-local-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AfData(Entity):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\: bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\: bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\: str
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_local
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\: bool
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	router does not change next\-hop
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\: bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\: bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\: bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\: bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\: bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\: bool
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\: bool
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\: bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\: bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\: bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\: bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\: bool
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\: bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\: bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: enable_label_stack
                                    
                                    	Enable label stack
                                    	**type**\: bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData, self).__init__()

                                        self.yang_name = "af-data"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby))])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                            ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                            ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                            ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                            ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                            ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                            ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                            ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                            ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                            ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                            ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                            ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                            ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                            ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                            ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                            ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                            ('advertise_afi_local', (YLeaf(YType.boolean, 'advertise-afi-local'), ['bool'])),
                                            ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                            ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                            ('next_hop_unchanged', (YLeaf(YType.boolean, 'next-hop-unchanged'), ['bool'])),
                                            ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                            ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                            ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                            ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                            ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                            ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                            ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                            ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                            ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                            ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                            ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                            ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                            ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                            ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                            ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                            ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                            ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                            ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                            ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                            ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                            ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                            ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                            ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                            ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                            ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                            ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                            ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                            ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                            ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                            ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                            ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                            ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                            ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                            ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                            ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                            ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                            ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                            ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                            ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                            ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                            ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                            ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                            ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                            ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                            ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                            ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                            ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                            ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                            ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                            ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                            ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                            ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                            ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                            ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                            ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                            ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                            ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                            ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                            ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                            ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                            ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                            ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                            ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                            ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                            ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                            ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                            ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                            ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                        ])
                                        self.af_name = None
                                        self.is_neighbor_route_reflector_client = None
                                        self.is_legacy_pe_rt = None
                                        self.is_neighbor_af_capable = None
                                        self.is_soft_reconfiguration_inbound_allowed = None
                                        self.is_use_soft_reconfiguration_always_on = None
                                        self.remove_private_as_from_updates = None
                                        self.remove_private_as_entire_aspath_from_updates = None
                                        self.remove_private_as_from_inbound_updates = None
                                        self.remove_private_as_entire_aspath_from_inbound_updates = None
                                        self.flowspec_validation_d_isable = None
                                        self.flowspec_redirect_validation_d_isable = None
                                        self.orr_group_name = None
                                        self.orr_group_index = None
                                        self.is_orr_root_address_configured = None
                                        self.advertise_afi = None
                                        self.advertise_afi_reorg = None
                                        self.advertise_afi_local = None
                                        self.advertise_afi_disable = None
                                        self.always_use_next_hop_local = None
                                        self.next_hop_unchanged = None
                                        self.sent_community_to_neighbor = None
                                        self.sent_gshut_community_to_neighbor = None
                                        self.sent_extended_community_to_neighbor = None
                                        self.neighbor_default_originate = None
                                        self.is_orf_sent = None
                                        self.is_update_deferred = None
                                        self.is_orf_send_scheduled = None
                                        self.vpn_update_gen_enabled = None
                                        self.vpn_update_gen_trigger_enabled = None
                                        self.is_addpath_send_operational = None
                                        self.is_addpath_receive_operational = None
                                        self.weight = None
                                        self.max_prefix_limit = None
                                        self.use_max_prefix_warning_only = None
                                        self.max_prefix_discard_extra_paths = None
                                        self.max_prefix_exceed_discard_paths = None
                                        self.max_prefix_threshold_percent = None
                                        self.max_prefix_restart_time = None
                                        self.is_peer_orf_capable = None
                                        self.is_advertised_orf_send = None
                                        self.is_received_orf_send_capable = None
                                        self.is_advertised_orf_receive = None
                                        self.is_received_orf_receive_capable = None
                                        self.is_advertised_graceful_restart = None
                                        self.is_graceful_restart_state_flag = None
                                        self.is_received_graceful_restart_capable = None
                                        self.is_add_path_send_capability_advertised = None
                                        self.is_add_path_send_capability_received = None
                                        self.is_add_path_receive_capability_advertised = None
                                        self.is_add_path_receive_capability_received = None
                                        self.restart_time = None
                                        self.local_restart_time = None
                                        self.stale_path_timeout = None
                                        self.rib_purge_timeout_value = None
                                        self.neighbor_preserved_forwarding_state = None
                                        self.long_lived_graceful_restart_stale_time_configured = None
                                        self.long_lived_graceful_restart_stale_time_sent = None
                                        self.long_lived_graceful_restart_stale_time_accept = None
                                        self.long_lived_graceful_restart_capability_received = None
                                        self.long_lived_graceful_restart_stale_time_received = None
                                        self.neighbor_preserved_long_lived_forwarding_state = None
                                        self.neighbor_long_lived_graceful_restart_capable = None
                                        self.neighbor_long_lived_graceful_restart_time_remaining = None
                                        self.is_prefix_orf_present = None
                                        self.orf_entries_received = None
                                        self.route_policy_prefix_orf = None
                                        self.route_policy_in = None
                                        self.route_policy_out = None
                                        self.route_policy_default_originate = None
                                        self.is_neighbor_ebgp_without_inbound_policy = None
                                        self.is_neighbor_ebgp_without_outbound_policy = None
                                        self.is_as_override_set = None
                                        self.is_allow_as_in_set = None
                                        self.allow_as_in_count = None
                                        self.address_family_long_lived_time = None
                                        self.is_aigp_set = None
                                        self.is_rt_present = None
                                        self.is_rt_present_standby = None
                                        self.accept_own_enabled = None
                                        self.selective_multipath_eligible = None
                                        self.afrpki_disable = None
                                        self.afrpki_use_validity = None
                                        self.afrpki_allow_invalid = None
                                        self.afrpki_signal_ibgp = None
                                        self.is_advertise_permanent_network = None
                                        self.is_send_mcast_attr = None
                                        self.import_stitching = None
                                        self.import_reoriginate = None
                                        self.import_reoriginate_stitching = None
                                        self.advertise_v4_flags = None
                                        self.advertise_v6_flags = None
                                        self.enable_label_stack = None

                                        self.extended_community = YList(self)
                                        self.extended_community_standby = YList(self)
                                        self._segment_path = lambda: "af-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_local', u'advertise_afi_disable', u'always_use_next_hop_local', u'next_hop_unchanged', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'is_prefix_orf_present', u'orf_entries_received', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'enable_label_stack'], name, value)


                                    class ExtendedCommunity(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, self).__init__()

                                            self.yang_name = "extended-community"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "extended-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, [u'entry'], name, value)


                                    class ExtendedCommunityStandby(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, self).__init__()

                                            self.yang_name = "extended-community-standby"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "extended-community-standby"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                                class Instance_(Entity):
                                    """
                                    Dynamic Neighbor Instance List
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Dynamic Neighbor address
                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress>`
                                    
                                    .. attribute:: neighbor_age
                                    
                                    	Neighbor age
                                    	**type**\:  :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge>`
                                    
                                    .. attribute:: idle_watch_timer_remaining_value
                                    
                                    	Idle watch timer remaining time
                                    	**type**\:  :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue>`
                                    
                                    .. attribute:: is_idle_watch_timer_running
                                    
                                    	Is idle watch timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_, self).__init__()

                                        self.yang_name = "instance"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress)), ("neighbor-age", ("neighbor_age", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge)), ("idle-watch-timer-remaining-value", ("idle_watch_timer_remaining_value", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue))])
                                        self._leafs = OrderedDict([
                                            ('is_idle_watch_timer_running', (YLeaf(YType.boolean, 'is-idle-watch-timer-running'), ['bool'])),
                                            ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                        ])
                                        self.is_idle_watch_timer_running = None
                                        self.connection_state = None

                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"

                                        self.neighbor_age = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge()
                                        self.neighbor_age.parent = self
                                        self._children_name_map["neighbor_age"] = "neighbor-age"

                                        self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue()
                                        self.idle_watch_timer_remaining_value.parent = self
                                        self._children_name_map["idle_watch_timer_remaining_value"] = "idle-watch-timer-remaining-value"
                                        self._segment_path = lambda: "instance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_, [u'is_idle_watch_timer_running', u'connection_state'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Dynamic Neighbor address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class NeighborAge(Entity):
                                        """
                                        Neighbor age
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge, self).__init__()

                                            self.yang_name = "neighbor-age"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "neighbor-age"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge, [u'seconds', u'nanoseconds'], name, value)


                                    class IdleWatchTimerRemainingValue(Entity):
                                        """
                                        Idle watch timer remaining time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue, self).__init__()

                                            self.yang_name = "idle-watch-timer-remaining-value"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "idle-watch-timer-remaining-value"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue, [u'seconds', u'nanoseconds'], name, value)


                        class MessageLogs(Entity):
                            """
                            The BGP Neighbor Message table
                            
                            .. attribute:: message_log
                            
                            	A BGP Message log entry
                            	**type**\: list of  		 :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs, self).__init__()

                                self.yang_name = "message-logs"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("message-log", ("message_log", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog))])
                                self._leafs = OrderedDict()

                                self.message_log = YList(self)
                                self._segment_path = lambda: "message-logs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs, [], name, value)


                            class MessageLog(Entity):
                                """
                                A BGP Message log entry
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: direction
                                
                                	Direction
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_message
                                
                                	Array of Neighbor Messages in one direction
                                	**type**\: list of  		 :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog, self).__init__()

                                    self.yang_name = "message-log"
                                    self.yang_parent_name = "message-logs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-message", ("neighbor_message", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('direction', (YLeaf(YType.uint32, 'direction'), ['int'])),
                                    ])
                                    self.neighbor_address = None
                                    self.direction = None

                                    self.neighbor_message = YList(self)
                                    self._segment_path = lambda: "message-log"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog, ['neighbor_address', 'direction'], name, value)


                                class NeighborMessage(Entity):
                                    """
                                    Array of Neighbor Messages in one direction
                                    
                                    .. attribute:: message_timestamp
                                    
                                    	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                    	**type**\:  :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                    
                                    .. attribute:: message_type_received
                                    
                                    	Type of messages Received
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: total_logged_message_count
                                    
                                    	Total logged messages count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: message_data_length
                                    
                                    	Message data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: logged_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of  		 :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage, self).__init__()

                                        self.yang_name = "neighbor-message"
                                        self.yang_parent_name = "message-log"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("message-timestamp", ("message_timestamp", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp)), ("logged-message-data", ("logged_message_data", Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData))])
                                        self._leafs = OrderedDict([
                                            ('message_type_received', (YLeaf(YType.uint8, 'message-type-received'), ['int'])),
                                            ('total_logged_message_count', (YLeaf(YType.uint32, 'total-logged-message-count'), ['int'])),
                                            ('message_data_length', (YLeaf(YType.uint16, 'message-data-length'), ['int'])),
                                        ])
                                        self.message_type_received = None
                                        self.total_logged_message_count = None
                                        self.message_data_length = None

                                        self.message_timestamp = Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                        self.message_timestamp.parent = self
                                        self._children_name_map["message_timestamp"] = "message-timestamp"

                                        self.logged_message_data = YList(self)
                                        self._segment_path = lambda: "neighbor-message"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage, [u'message_type_received', u'total_logged_message_count', u'message_data_length'], name, value)


                                    class MessageTimestamp(Entity):
                                        """
                                        message received time\: time elapsed since 00\:00
                                        \:00 UTC, January 1, 1970
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, self).__init__()

                                            self.yang_name = "message-timestamp"
                                            self.yang_parent_name = "neighbor-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "message-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LoggedMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, self).__init__()

                                            self.yang_name = "logged-message-data"
                                            self.yang_parent_name = "neighbor-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "logged-message-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, [u'entry'], name, value)


                class DefaultVrf(Entity):
                    """
                    Default VRF related operational data
                    
                    .. attribute:: update_inbound_error_vrf
                    
                    	Update inbound error information for the VRF
                    	**type**\:  :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf>`
                    
                    .. attribute:: afs
                    
                    	BGP address family table
                    	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs>`
                    
                    .. attribute:: information
                    
                    	Meta data for VRF
                    	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information>`
                    
                    .. attribute:: update_inbound_filter_vrf
                    
                    	Update inbound filtering information for the VRF
                    	**type**\:  :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf>`
                    
                    .. attribute:: postits
                    
                    	The BGP Neighbor table
                    	**type**\:  :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits>`
                    
                    .. attribute:: global_process_info
                    
                    	The Global Process information table
                    	**type**\:  :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo>`
                    
                    .. attribute:: update_inbound_error_neighbors
                    
                    	Update inbound error information for all neighbors
                    	**type**\:  :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors>`
                    
                    .. attribute:: update_inbound_filter_neighbors
                    
                    	Update inbound filtering information for all neighbors
                    	**type**\:  :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors>`
                    
                    .. attribute:: bmp
                    
                    	BMP related Operational Data
                    	**type**\:  :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp>`
                    
                    .. attribute:: process_info
                    
                    	A Process instance table entry
                    	**type**\:  :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo>`
                    
                    .. attribute:: sessions
                    
                    	The BGP session table
                    	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions>`
                    
                    .. attribute:: neighbors
                    
                    	The BGP Neighbor table
                    	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors>`
                    
                    .. attribute:: next_hop_vrf
                    
                    	A BGP Next\-hop VRF table entry
                    	**type**\:  :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf>`
                    
                    .. attribute:: neighbor_ranges
                    
                    	The BGP Dynamic Neighbor Range table
                    	**type**\:  :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges>`
                    
                    .. attribute:: message_logs
                    
                    	The BGP Neighbor Message table
                    	**type**\:  :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf, self).__init__()

                        self.yang_name = "default-vrf"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("update-inbound-error-vrf", ("update_inbound_error_vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf)), ("afs", ("afs", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs)), ("information", ("information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information)), ("update-inbound-filter-vrf", ("update_inbound_filter_vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf)), ("postits", ("postits", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits)), ("global-process-info", ("global_process_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo)), ("update-inbound-error-neighbors", ("update_inbound_error_neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors)), ("update-inbound-filter-neighbors", ("update_inbound_filter_neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors)), ("bmp", ("bmp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp)), ("process-info", ("process_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo)), ("sessions", ("sessions", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions)), ("neighbors", ("neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors)), ("next-hop-vrf", ("next_hop_vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf)), ("neighbor-ranges", ("neighbor_ranges", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges)), ("message-logs", ("message_logs", Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs))])
                        self._leafs = OrderedDict()

                        self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf()
                        self.update_inbound_error_vrf.parent = self
                        self._children_name_map["update_inbound_error_vrf"] = "update-inbound-error-vrf"

                        self.afs = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"

                        self.information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information()
                        self.information.parent = self
                        self._children_name_map["information"] = "information"

                        self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf()
                        self.update_inbound_filter_vrf.parent = self
                        self._children_name_map["update_inbound_filter_vrf"] = "update-inbound-filter-vrf"

                        self.postits = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits()
                        self.postits.parent = self
                        self._children_name_map["postits"] = "postits"

                        self.global_process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo()
                        self.global_process_info.parent = self
                        self._children_name_map["global_process_info"] = "global-process-info"

                        self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors()
                        self.update_inbound_error_neighbors.parent = self
                        self._children_name_map["update_inbound_error_neighbors"] = "update-inbound-error-neighbors"

                        self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors()
                        self.update_inbound_filter_neighbors.parent = self
                        self._children_name_map["update_inbound_filter_neighbors"] = "update-inbound-filter-neighbors"

                        self.bmp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp()
                        self.bmp.parent = self
                        self._children_name_map["bmp"] = "bmp"

                        self.process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo()
                        self.process_info.parent = self
                        self._children_name_map["process_info"] = "process-info"

                        self.sessions = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions()
                        self.sessions.parent = self
                        self._children_name_map["sessions"] = "sessions"

                        self.neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"

                        self.next_hop_vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf()
                        self.next_hop_vrf.parent = self
                        self._children_name_map["next_hop_vrf"] = "next-hop-vrf"

                        self.neighbor_ranges = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges()
                        self.neighbor_ranges.parent = self
                        self._children_name_map["neighbor_ranges"] = "neighbor-ranges"

                        self.message_logs = Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs()
                        self.message_logs.parent = self
                        self._children_name_map["message_logs"] = "message-logs"
                        self._segment_path = lambda: "default-vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf, [], name, value)


                    class UpdateInboundErrorVrf(Entity):
                        """
                        Update inbound error information for the VRF
                        
                        .. attribute:: last_update_malformed_timestamp
                        
                        	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:  :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: update_malformed_message_count
                        
                        	Malformed messages count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_malformed_neighbor_count
                        
                        	Count of neighbors that received malformed messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_update_malformed_age
                        
                        	Time since last malformed messages received event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf, self).__init__()

                            self.yang_name = "update-inbound-error-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("last-update-malformed-timestamp", ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp))])
                            self._leafs = OrderedDict([
                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                ('update_malformed_message_count', (YLeaf(YType.uint32, 'update-malformed-message-count'), ['int'])),
                                ('update_malformed_neighbor_count', (YLeaf(YType.uint32, 'update-malformed-neighbor-count'), ['int'])),
                                ('last_update_malformed_age', (YLeaf(YType.uint32, 'last-update-malformed-age'), ['int'])),
                            ])
                            self.update_vrf_name = None
                            self.update_malformed_message_count = None
                            self.update_malformed_neighbor_count = None
                            self.last_update_malformed_age = None

                            self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                            self.last_update_malformed_timestamp.parent = self
                            self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                            self._segment_path = lambda: "update-inbound-error-vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf, [u'update_vrf_name', u'update_malformed_message_count', u'update_malformed_neighbor_count', u'last_update_malformed_age'], name, value)


                        class LastUpdateMalformedTimestamp(Entity):
                            """
                            Last malformed messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, self).__init__()

                                self.yang_name = "last-update-malformed-timestamp"
                                self.yang_parent_name = "update-inbound-error-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-malformed-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                    class Afs(Entity):
                        """
                        BGP address family table
                        
                        .. attribute:: af
                        
                        	A particular address family
                        	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs, self).__init__()

                            self.yang_name = "afs"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("af", ("af", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af))])
                            self._leafs = OrderedDict()

                            self.af = YList(self)
                            self._segment_path = lambda: "afs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs, [], name, value)


                        class Af(Entity):
                            """
                            A particular address family
                            
                            .. attribute:: af_name  (key)
                            
                            	Address family
                            	**type**\:  :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                            
                            .. attribute:: rpki_refresh_af_table
                            
                            	RPKI Refresh Table (per AF)
                            	**type**\:  :py:class:`RpkiRefreshAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable>`
                            
                            .. attribute:: policies
                            
                            	The BGP Policy Table
                            	**type**\:  :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies>`
                            
                            .. attribute:: convergence
                            
                            	A BGP Convergence table entry
                            	**type**\:  :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence>`
                            
                            .. attribute:: af_process_info
                            
                            	A BGP Process address family table entry
                            	**type**\:  :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo>`
                            
                            .. attribute:: path_used_table
                            
                            	The BGP Path Used Table
                            	**type**\:  :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable>`
                            
                            .. attribute:: bmp_path_table_generic
                            
                            	Summary Info about BMP Table
                            	**type**\:  :py:class:`BmpPathTableGeneric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric>`
                            
                            .. attribute:: rpc_sets
                            
                            	BGP next\-hop set table
                            	**type**\:  :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets>`
                            
                            .. attribute:: global_af_process_info
                            
                            	The Global Address Family Process information table
                            	**type**\:  :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo>`
                            
                            .. attribute:: advertised_path_xr
                            
                            	The BGP Advertised path table (bestpath)
                            	**type**\:  :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr>`
                            
                            .. attribute:: sourced_networks
                            
                            	The BGP Convergence table
                            	**type**\:  :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks>`
                            
                            .. attribute:: update_groups
                            
                            	The BGP Update group table
                            	**type**\:  :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups>`
                            
                            .. attribute:: update_generation_sub_groups
                            
                            	Update generation for all sub\-groups
                            	**type**\:  :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups>`
                            
                            .. attribute:: next_hop_address_families
                            
                            	Address family of nexthop table
                            	**type**\:  :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies>`
                            
                            .. attribute:: rt_set_counters
                            
                            	The RT\-set counter table
                            	**type**\:  :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters>`
                            
                            .. attribute:: bmp_paths
                            
                            	The paths in BMP Table
                            	**type**\:  :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths>`
                            
                            .. attribute:: update_generation_update_groups
                            
                            	Update generation for all update\-groups
                            	**type**\:  :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups>`
                            
                            .. attribute:: update_generation_filter_groups
                            
                            	Update generation for all filter\-groups under a sub\-group
                            	**type**\:  :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups>`
                            
                            .. attribute:: networks
                            
                            	The BGP Network Table
                            	**type**\:  :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks>`
                            
                            .. attribute:: path_table
                            
                            	The BGP Path Table
                            	**type**\:  :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable>`
                            
                            .. attribute:: epes
                            
                            	The BGP Egress Engineering table
                            	**type**\:  :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes>`
                            
                            .. attribute:: advertised_path_counts
                            
                            	The BGP Advertised paths table (bestpath)
                            	**type**\:  :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts>`
                            
                            .. attribute:: path_labeled_table
                            
                            	The BGP Path Labeled Table
                            	**type**\:  :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable>`
                            
                            .. attribute:: advertised_paths
                            
                            	The BGP Advertised paths table (add\-paths)
                            	**type**\:  :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths>`
                            
                            .. attribute:: neighbor_af_table
                            
                            	The BGP Neighbor AF table
                            	**type**\:  :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable>`
                            
                            .. attribute:: update_generation_neighbors
                            
                            	Update generation for all neighbors
                            	**type**\:  :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors>`
                            
                            .. attribute:: update_generation_address_family
                            
                            	Update generation for address\-family
                            	**type**\:  :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily>`
                            
                            .. attribute:: dampenings
                            
                            	The BGP Dampening table
                            	**type**\:  :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings>`
                            
                            .. attribute:: prefix_filters
                            
                            	The BGP Prefix Filter table
                            	**type**\:  :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters>`
                            
                            .. attribute:: attributes
                            
                            	The BGP Attribute table
                            	**type**\:  :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af, self).__init__()

                                self.yang_name = "af"
                                self.yang_parent_name = "afs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['af_name']
                                self._child_classes = OrderedDict([("rpki-refresh-af-table", ("rpki_refresh_af_table", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable)), ("policies", ("policies", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies)), ("convergence", ("convergence", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence)), ("af-process-info", ("af_process_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo)), ("path-used-table", ("path_used_table", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable)), ("bmp-path-table-generic", ("bmp_path_table_generic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric)), ("rpc-sets", ("rpc_sets", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets)), ("global-af-process-info", ("global_af_process_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo)), ("advertised-path-xr", ("advertised_path_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr)), ("sourced-networks", ("sourced_networks", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks)), ("update-groups", ("update_groups", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups)), ("update-generation-sub-groups", ("update_generation_sub_groups", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups)), ("next-hop-address-families", ("next_hop_address_families", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies)), ("rt-set-counters", ("rt_set_counters", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters)), ("bmp-paths", ("bmp_paths", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths)), ("update-generation-update-groups", ("update_generation_update_groups", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups)), ("update-generation-filter-groups", ("update_generation_filter_groups", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups)), ("networks", ("networks", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks)), ("path-table", ("path_table", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable)), ("epes", ("epes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes)), ("advertised-path-counts", ("advertised_path_counts", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts)), ("path-labeled-table", ("path_labeled_table", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable)), ("advertised-paths", ("advertised_paths", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths)), ("neighbor-af-table", ("neighbor_af_table", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable)), ("update-generation-neighbors", ("update_generation_neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors)), ("update-generation-address-family", ("update_generation_address_family", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily)), ("dampenings", ("dampenings", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings)), ("prefix-filters", ("prefix_filters", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters)), ("attributes", ("attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes))])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes', 'BgpAddressFamily', '')])),
                                ])
                                self.af_name = None

                                self.rpki_refresh_af_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable()
                                self.rpki_refresh_af_table.parent = self
                                self._children_name_map["rpki_refresh_af_table"] = "rpki-refresh-af-table"

                                self.policies = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies()
                                self.policies.parent = self
                                self._children_name_map["policies"] = "policies"

                                self.convergence = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence()
                                self.convergence.parent = self
                                self._children_name_map["convergence"] = "convergence"

                                self.af_process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo()
                                self.af_process_info.parent = self
                                self._children_name_map["af_process_info"] = "af-process-info"

                                self.path_used_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable()
                                self.path_used_table.parent = self
                                self._children_name_map["path_used_table"] = "path-used-table"

                                self.bmp_path_table_generic = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric()
                                self.bmp_path_table_generic.parent = self
                                self._children_name_map["bmp_path_table_generic"] = "bmp-path-table-generic"

                                self.rpc_sets = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets()
                                self.rpc_sets.parent = self
                                self._children_name_map["rpc_sets"] = "rpc-sets"

                                self.global_af_process_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo()
                                self.global_af_process_info.parent = self
                                self._children_name_map["global_af_process_info"] = "global-af-process-info"

                                self.advertised_path_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr()
                                self.advertised_path_xr.parent = self
                                self._children_name_map["advertised_path_xr"] = "advertised-path-xr"

                                self.sourced_networks = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks()
                                self.sourced_networks.parent = self
                                self._children_name_map["sourced_networks"] = "sourced-networks"

                                self.update_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups()
                                self.update_groups.parent = self
                                self._children_name_map["update_groups"] = "update-groups"

                                self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups()
                                self.update_generation_sub_groups.parent = self
                                self._children_name_map["update_generation_sub_groups"] = "update-generation-sub-groups"

                                self.next_hop_address_families = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies()
                                self.next_hop_address_families.parent = self
                                self._children_name_map["next_hop_address_families"] = "next-hop-address-families"

                                self.rt_set_counters = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters()
                                self.rt_set_counters.parent = self
                                self._children_name_map["rt_set_counters"] = "rt-set-counters"

                                self.bmp_paths = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths()
                                self.bmp_paths.parent = self
                                self._children_name_map["bmp_paths"] = "bmp-paths"

                                self.update_generation_update_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups()
                                self.update_generation_update_groups.parent = self
                                self._children_name_map["update_generation_update_groups"] = "update-generation-update-groups"

                                self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups()
                                self.update_generation_filter_groups.parent = self
                                self._children_name_map["update_generation_filter_groups"] = "update-generation-filter-groups"

                                self.networks = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks()
                                self.networks.parent = self
                                self._children_name_map["networks"] = "networks"

                                self.path_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable()
                                self.path_table.parent = self
                                self._children_name_map["path_table"] = "path-table"

                                self.epes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes()
                                self.epes.parent = self
                                self._children_name_map["epes"] = "epes"

                                self.advertised_path_counts = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts()
                                self.advertised_path_counts.parent = self
                                self._children_name_map["advertised_path_counts"] = "advertised-path-counts"

                                self.path_labeled_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable()
                                self.path_labeled_table.parent = self
                                self._children_name_map["path_labeled_table"] = "path-labeled-table"

                                self.advertised_paths = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths()
                                self.advertised_paths.parent = self
                                self._children_name_map["advertised_paths"] = "advertised-paths"

                                self.neighbor_af_table = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable()
                                self.neighbor_af_table.parent = self
                                self._children_name_map["neighbor_af_table"] = "neighbor-af-table"

                                self.update_generation_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors()
                                self.update_generation_neighbors.parent = self
                                self._children_name_map["update_generation_neighbors"] = "update-generation-neighbors"

                                self.update_generation_address_family = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily()
                                self.update_generation_address_family.parent = self
                                self._children_name_map["update_generation_address_family"] = "update-generation-address-family"

                                self.dampenings = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings()
                                self.dampenings.parent = self
                                self._children_name_map["dampenings"] = "dampenings"

                                self.prefix_filters = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters()
                                self.prefix_filters.parent = self
                                self._children_name_map["prefix_filters"] = "prefix-filters"

                                self.attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes()
                                self.attributes.parent = self
                                self._children_name_map["attributes"] = "attributes"
                                self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af, ['af_name'], name, value)


                            class RpkiRefreshAfTable(Entity):
                                """
                                RPKI Refresh Table (per AF)
                                
                                .. attribute:: rpki_refresh_af
                                
                                	RPKI Refresh List
                                	**type**\:  :py:class:`RpkiRefreshAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable, self).__init__()

                                    self.yang_name = "rpki-refresh-af-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpki-refresh-af", ("rpki_refresh_af", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf))])
                                    self._leafs = OrderedDict()

                                    self.rpki_refresh_af = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf()
                                    self.rpki_refresh_af.parent = self
                                    self._children_name_map["rpki_refresh_af"] = "rpki-refresh-af"
                                    self._segment_path = lambda: "rpki-refresh-af-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable, [], name, value)


                                class RpkiRefreshAf(Entity):
                                    """
                                    RPKI Refresh List
                                    
                                    .. attribute:: refresh_entry
                                    
                                    	Array of refresh entries
                                    	**type**\: list of  		 :py:class:`RefreshEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf, self).__init__()

                                        self.yang_name = "rpki-refresh-af"
                                        self.yang_parent_name = "rpki-refresh-af-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("refresh-entry", ("refresh_entry", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry))])
                                        self._leafs = OrderedDict()

                                        self.refresh_entry = YList(self)
                                        self._segment_path = lambda: "rpki-refresh-af"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf, [], name, value)


                                    class RefreshEntry(Entity):
                                        """
                                        Array of refresh entries
                                        
                                        .. attribute:: af_name
                                        
                                        	Address Family
                                        	**type**\:  :py:class:`BgpRpkiAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAf>`
                                        
                                        .. attribute:: neighbor
                                        
                                        	BGP neighbor
                                        	**type**\: str
                                        
                                        .. attribute:: policy
                                        
                                        	Route Policy
                                        	**type**\: str
                                        
                                        .. attribute:: paths
                                        
                                        	Number of BGP paths modified or dropped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: drop
                                        
                                        	BGP paths were dropped
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry, self).__init__()

                                            self.yang_name = "refresh-entry"
                                            self.yang_parent_name = "rpki-refresh-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiAf', '')])),
                                                ('neighbor', (YLeaf(YType.str, 'neighbor'), ['str'])),
                                                ('policy', (YLeaf(YType.str, 'policy'), ['str'])),
                                                ('paths', (YLeaf(YType.uint32, 'paths'), ['int'])),
                                                ('drop', (YLeaf(YType.boolean, 'drop'), ['bool'])),
                                            ])
                                            self.af_name = None
                                            self.neighbor = None
                                            self.policy = None
                                            self.paths = None
                                            self.drop = None
                                            self._segment_path = lambda: "refresh-entry"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry, [u'af_name', u'neighbor', u'policy', u'paths', u'drop'], name, value)


                            class Policies(Entity):
                                """
                                The BGP Policy Table
                                
                                .. attribute:: policy
                                
                                	A BGP Policy table entry
                                	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies, self).__init__()

                                    self.yang_name = "policies"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("policy", ("policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy))])
                                    self._leafs = OrderedDict()

                                    self.policy = YList(self)
                                    self._segment_path = lambda: "policies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies, [], name, value)


                                class Policy(Entity):
                                    """
                                    A BGP Policy table entry
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                    
                                    .. attribute:: path_info_after_policy_in
                                    
                                    	Path information after inbound policy
                                    	**type**\:  :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                    
                                    .. attribute:: path_info_after_policy_out
                                    
                                    	Path information after outbound policy
                                    	**type**\:  :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: attributes_after_policy_out
                                    
                                    	Attributes after outbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy, self).__init__()

                                        self.yang_name = "policy"
                                        self.yang_parent_name = "policies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr)), ("path-info-after-policy-in", ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn)), ("path-info-after-policy-out", ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn)), ("attributes-after-policy-out", ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.vrf_name = None

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                        self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                        self.path_info_after_policy_in.parent = self
                                        self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"

                                        self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                        self.path_info_after_policy_out.parent = self
                                        self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"

                                        self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                        self.attributes_after_policy_out.parent = self
                                        self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                        self._segment_path = lambda: "policy"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy, ['rd', 'network', 'prefix_length', 'neighbor_address', u'no_path', u'af_name', u'route_distinguisher', u'source_route_distinguisher', u'vrf_name'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address-xr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInfoAfterPolicyIn(Entity):
                                        """
                                        Path information after inbound policy
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, self).__init__()

                                            self.yang_name = "path-info-after-policy-in"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-info-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInfoAfterPolicyOut(Entity):
                                        """
                                        Path information after outbound policy
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, self).__init__()

                                            self.yang_name = "path-info-after-policy-out"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-info-after-policy-out"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyOut(Entity):
                                        """
                                        Attributes after outbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, self).__init__()

                                            self.yang_name = "attributes-after-policy-out"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-out"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class Convergence(Entity):
                                """
                                A BGP Convergence table entry
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: has_converged
                                
                                	Convergence has been reached
                                	**type**\: bool
                                
                                .. attribute:: are_write_queues_empty
                                
                                	All neighbor write queues are empty
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence, self).__init__()

                                    self.yang_name = "convergence"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('has_converged', (YLeaf(YType.boolean, 'has-converged'), ['bool'])),
                                        ('are_write_queues_empty', (YLeaf(YType.boolean, 'are-write-queues-empty'), ['bool'])),
                                    ])
                                    self.af_name = None
                                    self.has_converged = None
                                    self.are_write_queues_empty = None
                                    self._segment_path = lambda: "convergence"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Convergence, [u'af_name', u'has_converged', u'are_write_queues_empty'], name, value)


                            class AfProcessInfo(Entity):
                                """
                                A BGP Process address family table entry
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: process_instance
                                
                                	ID for the BGP process instance
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\: str
                                
                                .. attribute:: vrf_totals
                                
                                	per VRF information aggregated across all VRFs
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo, self).__init__()

                                    self.yang_name = "af-process-info"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('process_instance', (YLeaf(YType.uint8, 'process-instance'), ['int'])),
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('vrf_totals', (YLeaf(YType.boolean, 'vrf-totals'), ['bool'])),
                                    ])
                                    self.af_name = None
                                    self.process_instance = None
                                    self.vrf_name = None
                                    self.vrf_totals = None

                                    self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"

                                    self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self._children_name_map["performance_statistics"] = "performance-statistics"
                                    self._segment_path = lambda: "af-process-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo, [u'af_name', u'process_instance', u'vrf_name', u'vrf_totals'], name, value)


                                class Global(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: version_wrap_time_spec
                                    
                                    	Version Wrap timestamp
                                    	**type**\:  :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec>`
                                    
                                    .. attribute:: version_wrap_start_time_spec
                                    
                                    	Version Wrap handle start timestamp
                                    	**type**\:  :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec>`
                                    
                                    .. attribute:: version_wrap_done_time_spec
                                    
                                    	Version Wrap handle Done timestamp
                                    	**type**\:  :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec>`
                                    
                                    .. attribute:: trigger_rib
                                    
                                    	Trigger RIB
                                    	**type**\:  :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib>`
                                    
                                    .. attribute:: trigger_import
                                    
                                    	Trigger import
                                    	**type**\:  :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport>`
                                    
                                    .. attribute:: trigger_update
                                    
                                    	Trigger update
                                    	**type**\:  :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate>`
                                    
                                    .. attribute:: trigger_label
                                    
                                    	Trigger label
                                    	**type**\:  :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel>`
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:  :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall>`
                                    
                                    .. attribute:: router_state
                                    
                                    	Router state
                                    	**type**\:  :py:class:`BgpRtrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrState>`
                                    
                                    .. attribute:: table_version
                                    
                                    	BGP table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrapped
                                    
                                    	Number of times Version Wrap happened
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrapped_tid
                                    
                                    	Version Wrapped trigger tid
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_active_pelem_version
                                    
                                    	Maximum Active Pelem Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: merged_table_version
                                    
                                    	Merged Table Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_download_go_active_done_pending
                                    
                                    	Route Download Go Active Done Pending
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_brib_received_version
                                    
                                    	Version received from 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Version sent to RIB/bRIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_version
                                    
                                    	Version updated by label thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_version
                                    
                                    	Version updated by import thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: standby_version
                                    
                                    	Version updated by sync thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: send_version
                                    
                                    	Version for sending updates to peers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_init_sync_pfx
                                    
                                    	Num of prefix synced during Initsync
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_label_stack_depth_v4_next_hop
                                    
                                    	Max supported label stack depth for IPv4 Nexthop
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_label_stack_depth_v6_next_hop
                                    
                                    	Max supported label stack depth for IPv6 Nexthop
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_num
                                    
                                    	Total local networks
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_memory
                                    
                                    	Total local networks memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_malloced_num
                                    
                                    	Total local networks malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_freed_num
                                    
                                    	Total local networks freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_num
                                    
                                    	Total local paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_memory
                                    
                                    	Total local paths memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_malloced_num
                                    
                                    	Total local paths malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_freed_num
                                    
                                    	Total local paths freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_num
                                    
                                    	Total impoorted paths 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_memory
                                    
                                    	Total imported paths memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_num
                                    
                                    	Total Num of networks
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_memory
                                    
                                    	Total networks memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_malloced_num
                                    
                                    	Total networks malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_freed_num
                                    
                                    	Total networks freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_num
                                    
                                    	Total Num of paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_memory
                                    
                                    	Total paths memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_malloced_num
                                    
                                    	Total paths malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_freed_num
                                    
                                    	Total paths freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_num
                                    
                                    	Total Num of path\-elems
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_memory
                                    
                                    	Total path\-elems memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_malloced_num
                                    
                                    	Total path\-elems malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_freed_num
                                    
                                    	Total path\-elems freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_last_trigger
                                    
                                    	Timestamp when Label thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_label_version
                                    
                                    	Label thread version when last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_bgp_version
                                    
                                    	BGP version when label thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_triggers
                                    
                                    	Label thread triggers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_last_trigger
                                    
                                    	Timestamp when RIB thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_rib_version
                                    
                                    	RIB thread version when last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_bgp_version
                                    
                                    	BGP version when RIB thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_triggers
                                    
                                    	RIB thread triggers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_last_trigger
                                    
                                    	Timestamp when Import thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_import_version
                                    
                                    	Import thread version when last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_bgp_version
                                    
                                    	BGP version when Import thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_triggers
                                    
                                    	Import thread triggers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_gen_last_trigger
                                    
                                    	Timestamp when Update generation thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_gen_bgp_version
                                    
                                    	BGP version when Update generation thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_triggers
                                    
                                    	Update thread triggers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_r_ds_num
                                    
                                    	Total Num of RDs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_remote_r_ds_num
                                    
                                    	Total Num of remote RDs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_same_r_ds_num
                                    
                                    	Total Num of same RDs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_rd_count
                                    
                                    	Activity\: Number of RDs malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_rd_count
                                    
                                    	Activity\: Number of RDs freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rd_memory
                                    
                                    	Memory (in bytes) used by RD data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: multipath_network_entry_count
                                    
                                    	Number of multipath network entries
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_network_entry_memory
                                    
                                    	Memory (in bytes) used bymultipath network entries
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: multipath_paths_count
                                    
                                    	Number of multipath paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_paths_memory
                                    
                                    	Memory (in bytes) used bymultimpath paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("version-wrap-time-spec", ("version_wrap_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec)), ("version-wrap-start-time-spec", ("version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec)), ("version-wrap-done-time-spec", ("version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec)), ("trigger-rib", ("trigger_rib", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib)), ("trigger-import", ("trigger_import", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport)), ("trigger-update", ("trigger_update", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate)), ("trigger-label", ("trigger_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel)), ("rib-install", ("rib_install", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall))])
                                        self._leafs = OrderedDict([
                                            ('router_state', (YLeaf(YType.enumeration, 'router-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRtrState', '')])),
                                            ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                            ('version_wrapped', (YLeaf(YType.uint32, 'version-wrapped'), ['int'])),
                                            ('version_wrapped_tid', (YLeaf(YType.uint32, 'version-wrapped-tid'), ['int'])),
                                            ('max_active_pelem_version', (YLeaf(YType.uint32, 'max-active-pelem-version'), ['int'])),
                                            ('merged_table_version', (YLeaf(YType.uint32, 'merged-table-version'), ['int'])),
                                            ('route_download_go_active_done_pending', (YLeaf(YType.uint32, 'route-download-go-active-done-pending'), ['int'])),
                                            ('rib_brib_received_version', (YLeaf(YType.uint32, 'rib-brib-received-version'), ['int'])),
                                            ('table_brib_version', (YLeaf(YType.uint32, 'table-brib-version'), ['int'])),
                                            ('label_version', (YLeaf(YType.uint32, 'label-version'), ['int'])),
                                            ('import_version', (YLeaf(YType.uint32, 'import-version'), ['int'])),
                                            ('standby_version', (YLeaf(YType.uint32, 'standby-version'), ['int'])),
                                            ('send_version', (YLeaf(YType.uint32, 'send-version'), ['int'])),
                                            ('num_init_sync_pfx', (YLeaf(YType.uint32, 'num-init-sync-pfx'), ['int'])),
                                            ('max_label_stack_depth_v4_next_hop', (YLeaf(YType.uint32, 'max-label-stack-depth-v4-next-hop'), ['int'])),
                                            ('max_label_stack_depth_v6_next_hop', (YLeaf(YType.uint32, 'max-label-stack-depth-v6-next-hop'), ['int'])),
                                            ('local_networks_num', (YLeaf(YType.uint32, 'local-networks-num'), ['int'])),
                                            ('local_networks_memory', (YLeaf(YType.uint32, 'local-networks-memory'), ['int'])),
                                            ('local_networks_malloced_num', (YLeaf(YType.uint32, 'local-networks-malloced-num'), ['int'])),
                                            ('local_networks_freed_num', (YLeaf(YType.uint32, 'local-networks-freed-num'), ['int'])),
                                            ('local_paths_num', (YLeaf(YType.uint32, 'local-paths-num'), ['int'])),
                                            ('local_paths_memory', (YLeaf(YType.uint32, 'local-paths-memory'), ['int'])),
                                            ('local_paths_malloced_num', (YLeaf(YType.uint32, 'local-paths-malloced-num'), ['int'])),
                                            ('local_paths_freed_num', (YLeaf(YType.uint32, 'local-paths-freed-num'), ['int'])),
                                            ('imported_paths_num', (YLeaf(YType.uint32, 'imported-paths-num'), ['int'])),
                                            ('imported_paths_memory', (YLeaf(YType.uint32, 'imported-paths-memory'), ['int'])),
                                            ('networks_num', (YLeaf(YType.uint32, 'networks-num'), ['int'])),
                                            ('networks_memory', (YLeaf(YType.uint32, 'networks-memory'), ['int'])),
                                            ('networks_malloced_num', (YLeaf(YType.uint32, 'networks-malloced-num'), ['int'])),
                                            ('networks_freed_num', (YLeaf(YType.uint32, 'networks-freed-num'), ['int'])),
                                            ('paths_num', (YLeaf(YType.uint32, 'paths-num'), ['int'])),
                                            ('paths_memory', (YLeaf(YType.uint32, 'paths-memory'), ['int'])),
                                            ('paths_malloced_num', (YLeaf(YType.uint32, 'paths-malloced-num'), ['int'])),
                                            ('paths_freed_num', (YLeaf(YType.uint32, 'paths-freed-num'), ['int'])),
                                            ('path_elems_num', (YLeaf(YType.uint32, 'path-elems-num'), ['int'])),
                                            ('path_elems_memory', (YLeaf(YType.uint32, 'path-elems-memory'), ['int'])),
                                            ('path_elems_malloced_num', (YLeaf(YType.uint32, 'path-elems-malloced-num'), ['int'])),
                                            ('path_elems_freed_num', (YLeaf(YType.uint32, 'path-elems-freed-num'), ['int'])),
                                            ('label_last_trigger', (YLeaf(YType.uint64, 'label-last-trigger'), ['int'])),
                                            ('last_label_version', (YLeaf(YType.uint32, 'last-label-version'), ['int'])),
                                            ('label_bgp_version', (YLeaf(YType.uint32, 'label-bgp-version'), ['int'])),
                                            ('label_triggers', (YLeaf(YType.uint32, 'label-triggers'), ['int'])),
                                            ('rib_last_trigger', (YLeaf(YType.uint64, 'rib-last-trigger'), ['int'])),
                                            ('last_rib_version', (YLeaf(YType.uint32, 'last-rib-version'), ['int'])),
                                            ('rib_bgp_version', (YLeaf(YType.uint32, 'rib-bgp-version'), ['int'])),
                                            ('rib_triggers', (YLeaf(YType.uint32, 'rib-triggers'), ['int'])),
                                            ('import_last_trigger', (YLeaf(YType.uint64, 'import-last-trigger'), ['int'])),
                                            ('last_import_version', (YLeaf(YType.uint32, 'last-import-version'), ['int'])),
                                            ('import_bgp_version', (YLeaf(YType.uint32, 'import-bgp-version'), ['int'])),
                                            ('import_triggers', (YLeaf(YType.uint32, 'import-triggers'), ['int'])),
                                            ('update_gen_last_trigger', (YLeaf(YType.uint64, 'update-gen-last-trigger'), ['int'])),
                                            ('update_gen_bgp_version', (YLeaf(YType.uint32, 'update-gen-bgp-version'), ['int'])),
                                            ('update_triggers', (YLeaf(YType.uint32, 'update-triggers'), ['int'])),
                                            ('total_r_ds_num', (YLeaf(YType.uint32, 'total-r-ds-num'), ['int'])),
                                            ('total_remote_r_ds_num', (YLeaf(YType.uint32, 'total-remote-r-ds-num'), ['int'])),
                                            ('total_same_r_ds_num', (YLeaf(YType.uint32, 'total-same-r-ds-num'), ['int'])),
                                            ('malloced_rd_count', (YLeaf(YType.uint32, 'malloced-rd-count'), ['int'])),
                                            ('freed_rd_count', (YLeaf(YType.uint32, 'freed-rd-count'), ['int'])),
                                            ('rd_memory', (YLeaf(YType.uint32, 'rd-memory'), ['int'])),
                                            ('multipath_network_entry_count', (YLeaf(YType.uint32, 'multipath-network-entry-count'), ['int'])),
                                            ('multipath_network_entry_memory', (YLeaf(YType.uint32, 'multipath-network-entry-memory'), ['int'])),
                                            ('multipath_paths_count', (YLeaf(YType.uint32, 'multipath-paths-count'), ['int'])),
                                            ('multipath_paths_memory', (YLeaf(YType.uint32, 'multipath-paths-memory'), ['int'])),
                                            ('update_wait_install_enabled', (YLeaf(YType.uint32, 'update-wait-install-enabled'), ['int'])),
                                            ('rib_acked_table_version', (YLeaf(YType.uint32, 'rib-acked-table-version'), ['int'])),
                                            ('rib_ack_requests', (YLeaf(YType.uint32, 'rib-ack-requests'), ['int'])),
                                            ('rib_acks_received', (YLeaf(YType.uint32, 'rib-acks-received'), ['int'])),
                                            ('rib_slow_acks', (YLeaf(YType.uint32, 'rib-slow-acks'), ['int'])),
                                        ])
                                        self.router_state = None
                                        self.table_version = None
                                        self.version_wrapped = None
                                        self.version_wrapped_tid = None
                                        self.max_active_pelem_version = None
                                        self.merged_table_version = None
                                        self.route_download_go_active_done_pending = None
                                        self.rib_brib_received_version = None
                                        self.table_brib_version = None
                                        self.label_version = None
                                        self.import_version = None
                                        self.standby_version = None
                                        self.send_version = None
                                        self.num_init_sync_pfx = None
                                        self.max_label_stack_depth_v4_next_hop = None
                                        self.max_label_stack_depth_v6_next_hop = None
                                        self.local_networks_num = None
                                        self.local_networks_memory = None
                                        self.local_networks_malloced_num = None
                                        self.local_networks_freed_num = None
                                        self.local_paths_num = None
                                        self.local_paths_memory = None
                                        self.local_paths_malloced_num = None
                                        self.local_paths_freed_num = None
                                        self.imported_paths_num = None
                                        self.imported_paths_memory = None
                                        self.networks_num = None
                                        self.networks_memory = None
                                        self.networks_malloced_num = None
                                        self.networks_freed_num = None
                                        self.paths_num = None
                                        self.paths_memory = None
                                        self.paths_malloced_num = None
                                        self.paths_freed_num = None
                                        self.path_elems_num = None
                                        self.path_elems_memory = None
                                        self.path_elems_malloced_num = None
                                        self.path_elems_freed_num = None
                                        self.label_last_trigger = None
                                        self.last_label_version = None
                                        self.label_bgp_version = None
                                        self.label_triggers = None
                                        self.rib_last_trigger = None
                                        self.last_rib_version = None
                                        self.rib_bgp_version = None
                                        self.rib_triggers = None
                                        self.import_last_trigger = None
                                        self.last_import_version = None
                                        self.import_bgp_version = None
                                        self.import_triggers = None
                                        self.update_gen_last_trigger = None
                                        self.update_gen_bgp_version = None
                                        self.update_triggers = None
                                        self.total_r_ds_num = None
                                        self.total_remote_r_ds_num = None
                                        self.total_same_r_ds_num = None
                                        self.malloced_rd_count = None
                                        self.freed_rd_count = None
                                        self.rd_memory = None
                                        self.multipath_network_entry_count = None
                                        self.multipath_network_entry_memory = None
                                        self.multipath_paths_count = None
                                        self.multipath_paths_memory = None
                                        self.update_wait_install_enabled = None
                                        self.rib_acked_table_version = None
                                        self.rib_ack_requests = None
                                        self.rib_acks_received = None
                                        self.rib_slow_acks = None

                                        self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec()
                                        self.version_wrap_time_spec.parent = self
                                        self._children_name_map["version_wrap_time_spec"] = "version-wrap-time-spec"

                                        self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec()
                                        self.version_wrap_start_time_spec.parent = self
                                        self._children_name_map["version_wrap_start_time_spec"] = "version-wrap-start-time-spec"

                                        self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec()
                                        self.version_wrap_done_time_spec.parent = self
                                        self._children_name_map["version_wrap_done_time_spec"] = "version-wrap-done-time-spec"

                                        self.trigger_rib = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib()
                                        self.trigger_rib.parent = self
                                        self._children_name_map["trigger_rib"] = "trigger-rib"

                                        self.trigger_import = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport()
                                        self.trigger_import.parent = self
                                        self._children_name_map["trigger_import"] = "trigger-import"

                                        self.trigger_update = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate()
                                        self.trigger_update.parent = self
                                        self._children_name_map["trigger_update"] = "trigger-update"

                                        self.trigger_label = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel()
                                        self.trigger_label.parent = self
                                        self._children_name_map["trigger_label"] = "trigger-label"

                                        self.rib_install = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall()
                                        self.rib_install.parent = self
                                        self._children_name_map["rib_install"] = "rib-install"
                                        self._segment_path = lambda: "global"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global, [u'router_state', u'table_version', u'version_wrapped', u'version_wrapped_tid', u'max_active_pelem_version', u'merged_table_version', u'route_download_go_active_done_pending', u'rib_brib_received_version', u'table_brib_version', u'label_version', u'import_version', u'standby_version', u'send_version', u'num_init_sync_pfx', u'max_label_stack_depth_v4_next_hop', u'max_label_stack_depth_v6_next_hop', u'local_networks_num', u'local_networks_memory', u'local_networks_malloced_num', u'local_networks_freed_num', u'local_paths_num', u'local_paths_memory', u'local_paths_malloced_num', u'local_paths_freed_num', u'imported_paths_num', u'imported_paths_memory', u'networks_num', u'networks_memory', u'networks_malloced_num', u'networks_freed_num', u'paths_num', u'paths_memory', u'paths_malloced_num', u'paths_freed_num', u'path_elems_num', u'path_elems_memory', u'path_elems_malloced_num', u'path_elems_freed_num', u'label_last_trigger', u'last_label_version', u'label_bgp_version', u'label_triggers', u'rib_last_trigger', u'last_rib_version', u'rib_bgp_version', u'rib_triggers', u'import_last_trigger', u'last_import_version', u'import_bgp_version', u'import_triggers', u'update_gen_last_trigger', u'update_gen_bgp_version', u'update_triggers', u'total_r_ds_num', u'total_remote_r_ds_num', u'total_same_r_ds_num', u'malloced_rd_count', u'freed_rd_count', u'rd_memory', u'multipath_network_entry_count', u'multipath_network_entry_memory', u'multipath_paths_count', u'multipath_paths_memory', u'update_wait_install_enabled', u'rib_acked_table_version', u'rib_ack_requests', u'rib_acks_received', u'rib_slow_acks'], name, value)


                                    class VersionWrapTimeSpec(Entity):
                                        """
                                        Version Wrap timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-wrap-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class VersionWrapStartTimeSpec(Entity):
                                        """
                                        Version Wrap handle start timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-start-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-wrap-start-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class VersionWrapDoneTimeSpec(Entity):
                                        """
                                        Version Wrap handle Done timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-done-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-wrap-done-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TriggerRib(Entity):
                                        """
                                        Trigger RIB
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib, self).__init__()

                                            self.yang_name = "trigger-rib"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic))])
                                            self._leafs = OrderedDict([
                                                ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                            ])
                                            self.triggers = None

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-rib"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib, [u'triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-rib"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                    ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                ])
                                                self.trigger_version = None
                                                self.trigger_table_version = None

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._segment_path = lambda: "statistic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "trigger-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TriggerImport(Entity):
                                        """
                                        Trigger import
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport, self).__init__()

                                            self.yang_name = "trigger-import"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic))])
                                            self._leafs = OrderedDict([
                                                ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                            ])
                                            self.triggers = None

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport, [u'triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                    ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                ])
                                                self.trigger_version = None
                                                self.trigger_table_version = None

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._segment_path = lambda: "statistic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "trigger-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TriggerUpdate(Entity):
                                        """
                                        Trigger update
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate, self).__init__()

                                            self.yang_name = "trigger-update"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic))])
                                            self._leafs = OrderedDict([
                                                ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                            ])
                                            self.triggers = None

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-update"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate, [u'triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                    ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                ])
                                                self.trigger_version = None
                                                self.trigger_table_version = None

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._segment_path = lambda: "statistic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "trigger-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TriggerLabel(Entity):
                                        """
                                        Trigger label
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel, self).__init__()

                                            self.yang_name = "trigger-label"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic))])
                                            self._leafs = OrderedDict([
                                                ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                            ])
                                            self.triggers = None

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-label"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel, [u'triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-label"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                    ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                ])
                                                self.trigger_version = None
                                                self.trigger_table_version = None

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._segment_path = lambda: "statistic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "trigger-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class RibInstall(Entity):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:  :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:  :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: skipped_count
                                        
                                        	Skipped routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall, self).__init__()

                                            self.yang_name = "rib-install"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("update-time", ("update_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime)), ("install-time", ("install_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime))])
                                            self._leafs = OrderedDict([
                                                ('installed_count', (YLeaf(YType.uint32, 'installed-count'), ['int'])),
                                                ('modified_count', (YLeaf(YType.uint32, 'modified-count'), ['int'])),
                                                ('skipped_count', (YLeaf(YType.uint32, 'skipped-count'), ['int'])),
                                                ('withdrawn_count', (YLeaf(YType.uint32, 'withdrawn-count'), ['int'])),
                                                ('start_version', (YLeaf(YType.uint32, 'start-version'), ['int'])),
                                                ('target_version', (YLeaf(YType.uint32, 'target-version'), ['int'])),
                                            ])
                                            self.installed_count = None
                                            self.modified_count = None
                                            self.skipped_count = None
                                            self.withdrawn_count = None
                                            self.start_version = None
                                            self.target_version = None

                                            self.update_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self._children_name_map["update_time"] = "update-time"

                                            self.install_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self._children_name_map["install_time"] = "install-time"
                                            self._segment_path = lambda: "rib-install"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall, [u'installed_count', u'modified_count', u'skipped_count', u'withdrawn_count', u'start_version', u'target_version'], name, value)


                                        class UpdateTime(Entity):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime, self).__init__()

                                                self.yang_name = "update-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "update-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime, [u'seconds', u'nanoseconds'], name, value)


                                        class InstallTime(Entity):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime, self).__init__()

                                                self.yang_name = "install-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "install-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime, [u'seconds', u'nanoseconds'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: network_entry_count
                                    
                                    	Number of network entries
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_count
                                    
                                    	Number of paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths
                                    
                                    	Number of imported paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths
                                    
                                    	Number of local paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_count
                                    
                                    	Number of path elems
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: imported_path_memory
                                    
                                    	Memory (in bytes) used by imported paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: local_path_memory
                                    
                                    	Memory (in bytes) used by local paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: path_elem_memory
                                    
                                    	Memory (in bytes) used by pathelem data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_path_count
                                    
                                    	Number of (unused) received paths for inbound soft reconfiguration
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: history_path_count
                                    
                                    	Number of history paths (for dampening)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: damped_path_count
                                    
                                    	Number of dampened paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_prefix_count
                                    
                                    	Activity\: Number of prefixes malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_prefix_count
                                    
                                    	Activity\: Number of prefixes freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_count
                                    
                                    	Activity\: Number of paths malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_count
                                    
                                    	Activity\: Number of paths freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_elem_count
                                    
                                    	Activity\: Number of path elems malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_elem_count
                                    
                                    	Activity\: Number of pathelems freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: any_ebgp_neighbor_missing_policy
                                    
                                    	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                    	**type**\: bool
                                    
                                    .. attribute:: attribute_download
                                    
                                    	Attribute download is 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_target_download
                                    
                                    	Route Target download is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: srms_prefix_sid
                                    
                                    	SRMS Prefix SID is 
                                    	**type**\: bool
                                    
                                    .. attribute:: add_path_install_enable
                                    
                                    	Additional paths installation is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: add_path_install_disable
                                    
                                    	Additional paths installation is disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: best_external
                                    
                                    	Best External is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: best_external_disable
                                    
                                    	Best External is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: label_retain
                                    
                                    	Label retention is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: label_retainvalue
                                    
                                    	Label retention value enabled
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tbl_bitf_size
                                    
                                    	Bitfield size on table
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: tbl_chunk_bitf_size
                                    
                                    	Chunk Bitfield size on table
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: is_route_reflector
                                    
                                    	Router is an RR for this AF
                                    	**type**\: bool
                                    
                                    .. attribute:: asbr
                                    
                                    	Router is an ASBR for this AF
                                    	**type**\: bool
                                    
                                    .. attribute:: retain_rt_all
                                    
                                    	Retain\-RT\-All enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: ibgp_nexthop_self_count
                                    
                                    	Number of iBGP sessions configured with nh\-self
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: use_igpsr_label
                                    
                                    	Use IGP SR label for resolution
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_network_entry_count
                                    
                                    	Number of BMP net entries
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_paths_count
                                    
                                    	Total Number of BMP paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bmp_path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('network_entry_count', (YLeaf(YType.uint32, 'network-entry-count'), ['int'])),
                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                            ('imported_paths', (YLeaf(YType.uint32, 'imported-paths'), ['int'])),
                                            ('local_paths', (YLeaf(YType.uint32, 'local-paths'), ['int'])),
                                            ('path_elems_count', (YLeaf(YType.uint32, 'path-elems-count'), ['int'])),
                                            ('path_memory', (YLeaf(YType.uint32, 'path-memory'), ['int'])),
                                            ('imported_path_memory', (YLeaf(YType.uint32, 'imported-path-memory'), ['int'])),
                                            ('local_path_memory', (YLeaf(YType.uint32, 'local-path-memory'), ['int'])),
                                            ('prefix_memory', (YLeaf(YType.uint32, 'prefix-memory'), ['int'])),
                                            ('path_elem_memory', (YLeaf(YType.uint32, 'path-elem-memory'), ['int'])),
                                            ('received_path_count', (YLeaf(YType.uint32, 'received-path-count'), ['int'])),
                                            ('history_path_count', (YLeaf(YType.uint32, 'history-path-count'), ['int'])),
                                            ('damped_path_count', (YLeaf(YType.uint32, 'damped-path-count'), ['int'])),
                                            ('malloced_prefix_count', (YLeaf(YType.uint32, 'malloced-prefix-count'), ['int'])),
                                            ('freed_prefix_count', (YLeaf(YType.uint32, 'freed-prefix-count'), ['int'])),
                                            ('malloced_path_count', (YLeaf(YType.uint32, 'malloced-path-count'), ['int'])),
                                            ('freed_path_count', (YLeaf(YType.uint32, 'freed-path-count'), ['int'])),
                                            ('malloced_path_elem_count', (YLeaf(YType.uint32, 'malloced-path-elem-count'), ['int'])),
                                            ('freed_path_elem_count', (YLeaf(YType.uint32, 'freed-path-elem-count'), ['int'])),
                                            ('any_ebgp_neighbor_missing_policy', (YLeaf(YType.boolean, 'any-ebgp-neighbor-missing-policy'), ['bool'])),
                                            ('attribute_download', (YLeaf(YType.boolean, 'attribute-download'), ['bool'])),
                                            ('route_target_download', (YLeaf(YType.boolean, 'route-target-download'), ['bool'])),
                                            ('srms_prefix_sid', (YLeaf(YType.boolean, 'srms-prefix-sid'), ['bool'])),
                                            ('add_path_install_enable', (YLeaf(YType.boolean, 'add-path-install-enable'), ['bool'])),
                                            ('add_path_install_disable', (YLeaf(YType.boolean, 'add-path-install-disable'), ['bool'])),
                                            ('best_external', (YLeaf(YType.boolean, 'best-external'), ['bool'])),
                                            ('best_external_disable', (YLeaf(YType.boolean, 'best-external-disable'), ['bool'])),
                                            ('label_retain', (YLeaf(YType.boolean, 'label-retain'), ['bool'])),
                                            ('label_retainvalue', (YLeaf(YType.uint32, 'label-retainvalue'), ['int'])),
                                            ('tbl_bitf_size', (YLeaf(YType.uint16, 'tbl-bitf-size'), ['int'])),
                                            ('tbl_chunk_bitf_size', (YLeaf(YType.uint16, 'tbl-chunk-bitf-size'), ['int'])),
                                            ('is_route_reflector', (YLeaf(YType.boolean, 'is-route-reflector'), ['bool'])),
                                            ('asbr', (YLeaf(YType.boolean, 'asbr'), ['bool'])),
                                            ('retain_rt_all', (YLeaf(YType.boolean, 'retain-rt-all'), ['bool'])),
                                            ('ibgp_nexthop_self_count', (YLeaf(YType.uint32, 'ibgp-nexthop-self-count'), ['int'])),
                                            ('use_igpsr_label', (YLeaf(YType.boolean, 'use-igpsr-label'), ['bool'])),
                                            ('bmp_network_entry_count', (YLeaf(YType.uint32, 'bmp-network-entry-count'), ['int'])),
                                            ('bmp_paths_count', (YLeaf(YType.uint32, 'bmp-paths-count'), ['int'])),
                                            ('bmp_prefix_memory', (YLeaf(YType.uint32, 'bmp-prefix-memory'), ['int'])),
                                            ('bmp_path_memory', (YLeaf(YType.uint32, 'bmp-path-memory'), ['int'])),
                                        ])
                                        self.network_entry_count = None
                                        self.paths_count = None
                                        self.imported_paths = None
                                        self.local_paths = None
                                        self.path_elems_count = None
                                        self.path_memory = None
                                        self.imported_path_memory = None
                                        self.local_path_memory = None
                                        self.prefix_memory = None
                                        self.path_elem_memory = None
                                        self.received_path_count = None
                                        self.history_path_count = None
                                        self.damped_path_count = None
                                        self.malloced_prefix_count = None
                                        self.freed_prefix_count = None
                                        self.malloced_path_count = None
                                        self.freed_path_count = None
                                        self.malloced_path_elem_count = None
                                        self.freed_path_elem_count = None
                                        self.any_ebgp_neighbor_missing_policy = None
                                        self.attribute_download = None
                                        self.route_target_download = None
                                        self.srms_prefix_sid = None
                                        self.add_path_install_enable = None
                                        self.add_path_install_disable = None
                                        self.best_external = None
                                        self.best_external_disable = None
                                        self.label_retain = None
                                        self.label_retainvalue = None
                                        self.tbl_bitf_size = None
                                        self.tbl_chunk_bitf_size = None
                                        self.is_route_reflector = None
                                        self.asbr = None
                                        self.retain_rt_all = None
                                        self.ibgp_nexthop_self_count = None
                                        self.use_igpsr_label = None
                                        self.bmp_network_entry_count = None
                                        self.bmp_paths_count = None
                                        self.bmp_prefix_memory = None
                                        self.bmp_path_memory = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.Vrf, [u'network_entry_count', u'paths_count', u'imported_paths', u'local_paths', u'path_elems_count', u'path_memory', u'imported_path_memory', u'local_path_memory', u'prefix_memory', u'path_elem_memory', u'received_path_count', u'history_path_count', u'damped_path_count', u'malloced_prefix_count', u'freed_prefix_count', u'malloced_path_count', u'freed_path_count', u'malloced_path_elem_count', u'freed_path_elem_count', u'any_ebgp_neighbor_missing_policy', u'attribute_download', u'route_target_download', u'srms_prefix_sid', u'add_path_install_enable', u'add_path_install_disable', u'best_external', u'best_external_disable', u'label_retain', u'label_retainvalue', u'tbl_bitf_size', u'tbl_chunk_bitf_size', u'is_route_reflector', u'asbr', u'retain_rt_all', u'ibgp_nexthop_self_count', u'use_igpsr_label', u'bmp_network_entry_count', u'bmp_paths_count', u'bmp_prefix_memory', u'bmp_path_memory'], name, value)


                                class PerformanceStatistics(Entity):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics, self).__init__()

                                        self.yang_name = "performance-statistics"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf))])
                                        self._leafs = OrderedDict()

                                        self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"

                                        self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._segment_path = lambda: "performance-statistics"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics, [], name, value)


                                    class Global(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: has_converged
                                        
                                        	TRUE if process has converged
                                        	**type**\: bool
                                        
                                        .. attribute:: first_nbr_up_time
                                        
                                        	Time when first peer came up (seconds since Jan 1 1970)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: total_pim_install
                                        
                                        	Total number of install to PIM
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_callbacks
                                        
                                        	Total number of PIM callbacks
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_callback_batch
                                        
                                        	Total number of Pim callback batches
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mode_enter_time
                                        
                                        	Time that each mode was entered (seconds since  Jan 1 1970)
                                        	**type**\: list of  		 :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime>`
                                        
                                        .. attribute:: total_pim_install_add
                                        
                                        	Total number of install to PIM for add
                                        	**type**\: list of  		 :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd>`
                                        
                                        .. attribute:: total_pim_install_del
                                        
                                        	Total number of install to PIM for del
                                        	**type**\: list of  		 :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel>`
                                        
                                        .. attribute:: total_pim_callback_add
                                        
                                        	Total number of Pim callbacks for add
                                        	**type**\: list of  		 :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd>`
                                        
                                        .. attribute:: total_pim_callback_del
                                        
                                        	Total number of Pim callbacks for del
                                        	**type**\: list of  		 :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel>`
                                        
                                        .. attribute:: total_pim_callback_add_local
                                        
                                        	Total number of Pim callbacks for local add
                                        	**type**\: list of  		 :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal>`
                                        
                                        .. attribute:: total_pim_callback_del_local
                                        
                                        	Total number of Pim callbacks for Local del
                                        	**type**\: list of  		 :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "performance-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("mode-enter-time", ("mode_enter_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime)), ("total-pim-install-add", ("total_pim_install_add", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd)), ("total-pim-install-del", ("total_pim_install_del", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel)), ("total-pim-callback-add", ("total_pim_callback_add", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd)), ("total-pim-callback-del", ("total_pim_callback_del", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel)), ("total-pim-callback-add-local", ("total_pim_callback_add_local", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal)), ("total-pim-callback-del-local", ("total_pim_callback_del_local", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal))])
                                            self._leafs = OrderedDict([
                                                ('has_converged', (YLeaf(YType.boolean, 'has-converged'), ['bool'])),
                                                ('first_nbr_up_time', (YLeaf(YType.uint32, 'first-nbr-up-time'), ['int'])),
                                                ('total_pim_install', (YLeaf(YType.uint32, 'total-pim-install'), ['int'])),
                                                ('total_pim_callbacks', (YLeaf(YType.uint32, 'total-pim-callbacks'), ['int'])),
                                                ('total_pim_callback_batch', (YLeaf(YType.uint32, 'total-pim-callback-batch'), ['int'])),
                                            ])
                                            self.has_converged = None
                                            self.first_nbr_up_time = None
                                            self.total_pim_install = None
                                            self.total_pim_callbacks = None
                                            self.total_pim_callback_batch = None

                                            self.mode_enter_time = YList(self)
                                            self.total_pim_install_add = YList(self)
                                            self.total_pim_install_del = YList(self)
                                            self.total_pim_callback_add = YList(self)
                                            self.total_pim_callback_del = YList(self)
                                            self.total_pim_callback_add_local = YList(self)
                                            self.total_pim_callback_del_local = YList(self)
                                            self._segment_path = lambda: "global"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global, [u'has_converged', u'first_nbr_up_time', u'total_pim_install', u'total_pim_callbacks', u'total_pim_callback_batch'], name, value)


                                        class ModeEnterTime(Entity):
                                            """
                                            Time that each mode was entered (seconds since
                                            
                                            Jan 1 1970)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime, self).__init__()

                                                self.yang_name = "mode-enter-time"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mode-enter-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime, [u'entry'], name, value)


                                        class TotalPimInstallAdd(Entity):
                                            """
                                            Total number of install to PIM for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd, self).__init__()

                                                self.yang_name = "total-pim-install-add"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-install-add"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd, [u'entry'], name, value)


                                        class TotalPimInstallDel(Entity):
                                            """
                                            Total number of install to PIM for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel, self).__init__()

                                                self.yang_name = "total-pim-install-del"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-install-del"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel, [u'entry'], name, value)


                                        class TotalPimCallbackAdd(Entity):
                                            """
                                            Total number of Pim callbacks for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd, self).__init__()

                                                self.yang_name = "total-pim-callback-add"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-callback-add"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd, [u'entry'], name, value)


                                        class TotalPimCallbackDel(Entity):
                                            """
                                            Total number of Pim callbacks for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel, self).__init__()

                                                self.yang_name = "total-pim-callback-del"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-callback-del"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel, [u'entry'], name, value)


                                        class TotalPimCallbackAddLocal(Entity):
                                            """
                                            Total number of Pim callbacks for local add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal, self).__init__()

                                                self.yang_name = "total-pim-callback-add-local"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-callback-add-local"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal, [u'entry'], name, value)


                                        class TotalPimCallbackDelLocal(Entity):
                                            """
                                            Total number of Pim callbacks for Local del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal, self).__init__()

                                                self.yang_name = "total-pim-callback-del-local"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-callback-del-local"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal, [u'entry'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: time_rib_coverged
                                        
                                        	Time last RIB ack was sent 
                                        	**type**\:  :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged>`
                                        
                                        .. attribute:: time_rib_down
                                        
                                        	Time last RIB down wassent. This field is deprecated
                                        	**type**\:  :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown>`
                                        
                                        .. attribute:: first_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the first time
                                        	**type**\:  :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp>`
                                        
                                        .. attribute:: last_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the last time
                                        	**type**\:  :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp>`
                                        
                                        .. attribute:: first_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the first time
                                        	**type**\:  :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: last_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the last time
                                        	**type**\:  :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: time_label_retain
                                        
                                        	Time last label retentiontriggered 
                                        	**type**\:  :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain>`
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: rib_update_calls
                                        
                                        	No. of calls to RIB update function
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_update_time
                                        
                                        	Time spent sending RIB updates (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: prefixes_sent_to_rib
                                        
                                        	No. of prefixes sent to RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_resent_to_rib
                                        
                                        	No. of prefixes re\-sent to RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_not_sent_to_rib
                                        
                                        	No. of prefixes not sent to RIB due to unsupported label stack size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_removed_from_rib
                                        
                                        	No. of prefixes withdrawn from RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_sent_to_rib
                                        
                                        	No. of attributes sent to RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_removed_from_rib
                                        
                                        	No. of attributes withdrawn from RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_recover_from_rib
                                        
                                        	No. of attributes recovered from RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scanner_runs
                                        
                                        	# of times scanner has run
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scanner_time
                                        
                                        	Time spent running scanner (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: rib_tbl_del_calls
                                        
                                        	No. of rib update skipped on account of table delete
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_invalid_calls
                                        
                                        	No. of  rib update skipped due to table invalid
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_skip_calls
                                        
                                        	No. of rib update skipped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_local_label
                                        
                                        	No. of rib update skipped. due to no local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_retry
                                        
                                        	No. of table rib retires
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_update_sent
                                        
                                        	Time last update was sent (seconds since Jan 1 1970)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_rib_table_full_version
                                        
                                        	Version when RIB table was full for the first time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_full_version
                                        
                                        	Version when RIB table was full for the last time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_full_age
                                        
                                        	Time since RIB table was full for the last time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: first_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the first time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the last time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_has_space_age
                                        
                                        	Times since RIB table had space for the last time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_trigger
                                        
                                        	Rib trigger enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: vrf_flags
                                        
                                        	VRF flags for debug display
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_calls
                                        
                                        	No. of calls to label allocation processing function
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_time
                                        
                                        	Time spent running label processing (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: label_rewrite_count
                                        
                                        	Number of label rewrites created
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_release_count
                                        
                                        	Number of labels released
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_added_count
                                        
                                        	Number of labels requested
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_calls
                                        
                                        	Number of calls to import processing function
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_time
                                        
                                        	Time spent in import processing (milliseconds) Note time accounted against source nets
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: import_src_net_processed_count
                                        
                                        	Number of source nets processed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_dest_net_processed_count
                                        
                                        	Number of destination nets processed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_added_path_count
                                        
                                        	Number of imported paths added
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_removed_path_count
                                        
                                        	Number of imported paths removed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_replaced_path_count
                                        
                                        	Number of imported paths 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_count
                                        
                                        	No. of update group
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: subgroup_count
                                        
                                        	No. of update subgroup
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "performance-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("time-rib-coverged", ("time_rib_coverged", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged)), ("time-rib-down", ("time_rib_down", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown)), ("first-rib-table-full-timestamp", ("first_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp)), ("last-rib-table-full-timestamp", ("last_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp)), ("first-rib-table-has-space-timestamp", ("first_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp)), ("last-rib-table-has-space-timestamp", ("last_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp)), ("time-label-retain", ("time_label_retain", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain))])
                                            self._leafs = OrderedDict([
                                                ('update_generation_calls', (YLeaf(YType.uint32, 'update-generation-calls'), ['int'])),
                                                ('update_generation_prefixes_count', (YLeaf(YType.uint32, 'update-generation-prefixes-count'), ['int'])),
                                                ('update_generation_be_prefixes_count', (YLeaf(YType.uint32, 'update-generation-be-prefixes-count'), ['int'])),
                                                ('update_generation_messages_count', (YLeaf(YType.uint32, 'update-generation-messages-count'), ['int'])),
                                                ('update_generation_time', (YLeaf(YType.uint32, 'update-generation-time'), ['int'])),
                                                ('rib_update_calls', (YLeaf(YType.uint32, 'rib-update-calls'), ['int'])),
                                                ('rib_update_time', (YLeaf(YType.uint32, 'rib-update-time'), ['int'])),
                                                ('prefixes_sent_to_rib', (YLeaf(YType.uint32, 'prefixes-sent-to-rib'), ['int'])),
                                                ('prefixes_resent_to_rib', (YLeaf(YType.uint32, 'prefixes-resent-to-rib'), ['int'])),
                                                ('prefixes_not_sent_to_rib', (YLeaf(YType.uint32, 'prefixes-not-sent-to-rib'), ['int'])),
                                                ('prefixes_removed_from_rib', (YLeaf(YType.uint32, 'prefixes-removed-from-rib'), ['int'])),
                                                ('attributes_sent_to_rib', (YLeaf(YType.uint32, 'attributes-sent-to-rib'), ['int'])),
                                                ('attributes_removed_from_rib', (YLeaf(YType.uint32, 'attributes-removed-from-rib'), ['int'])),
                                                ('attributes_recover_from_rib', (YLeaf(YType.uint32, 'attributes-recover-from-rib'), ['int'])),
                                                ('scanner_runs', (YLeaf(YType.uint32, 'scanner-runs'), ['int'])),
                                                ('scanner_time', (YLeaf(YType.uint32, 'scanner-time'), ['int'])),
                                                ('rib_tbl_del_calls', (YLeaf(YType.uint32, 'rib-tbl-del-calls'), ['int'])),
                                                ('rib_tbl_invalid_calls', (YLeaf(YType.uint32, 'rib-tbl-invalid-calls'), ['int'])),
                                                ('rib_tbl_skip_calls', (YLeaf(YType.uint32, 'rib-tbl-skip-calls'), ['int'])),
                                                ('rib_tbl_local_label', (YLeaf(YType.uint32, 'rib-tbl-local-label'), ['int'])),
                                                ('rib_tbl_retry', (YLeaf(YType.uint32, 'rib-tbl-retry'), ['int'])),
                                                ('time_last_update_sent', (YLeaf(YType.uint32, 'time-last-update-sent'), ['int'])),
                                                ('is_rib_table_full', (YLeaf(YType.boolean, 'is-rib-table-full'), ['bool'])),
                                                ('rib_table_full_version', (YLeaf(YType.uint32, 'rib-table-full-version'), ['int'])),
                                                ('first_rib_table_full_version', (YLeaf(YType.uint32, 'first-rib-table-full-version'), ['int'])),
                                                ('last_rib_table_full_version', (YLeaf(YType.uint32, 'last-rib-table-full-version'), ['int'])),
                                                ('last_rib_table_full_age', (YLeaf(YType.uint32, 'last-rib-table-full-age'), ['int'])),
                                                ('first_rib_table_has_space_version', (YLeaf(YType.uint32, 'first-rib-table-has-space-version'), ['int'])),
                                                ('last_rib_table_has_space_version', (YLeaf(YType.uint32, 'last-rib-table-has-space-version'), ['int'])),
                                                ('last_rib_table_has_space_age', (YLeaf(YType.uint32, 'last-rib-table-has-space-age'), ['int'])),
                                                ('rib_trigger', (YLeaf(YType.boolean, 'rib-trigger'), ['bool'])),
                                                ('vrf_flags', (YLeaf(YType.uint32, 'vrf-flags'), ['int'])),
                                                ('label_calls', (YLeaf(YType.uint32, 'label-calls'), ['int'])),
                                                ('label_time', (YLeaf(YType.uint32, 'label-time'), ['int'])),
                                                ('label_rewrite_count', (YLeaf(YType.uint32, 'label-rewrite-count'), ['int'])),
                                                ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                                ('label_added_count', (YLeaf(YType.uint32, 'label-added-count'), ['int'])),
                                                ('import_calls', (YLeaf(YType.uint32, 'import-calls'), ['int'])),
                                                ('import_time', (YLeaf(YType.uint32, 'import-time'), ['int'])),
                                                ('import_src_net_processed_count', (YLeaf(YType.uint32, 'import-src-net-processed-count'), ['int'])),
                                                ('import_dest_net_processed_count', (YLeaf(YType.uint32, 'import-dest-net-processed-count'), ['int'])),
                                                ('import_added_path_count', (YLeaf(YType.uint32, 'import-added-path-count'), ['int'])),
                                                ('import_removed_path_count', (YLeaf(YType.uint32, 'import-removed-path-count'), ['int'])),
                                                ('import_replaced_path_count', (YLeaf(YType.uint32, 'import-replaced-path-count'), ['int'])),
                                                ('update_group_count', (YLeaf(YType.uint32, 'update-group-count'), ['int'])),
                                                ('subgroup_count', (YLeaf(YType.uint32, 'subgroup-count'), ['int'])),
                                            ])
                                            self.update_generation_calls = None
                                            self.update_generation_prefixes_count = None
                                            self.update_generation_be_prefixes_count = None
                                            self.update_generation_messages_count = None
                                            self.update_generation_time = None
                                            self.rib_update_calls = None
                                            self.rib_update_time = None
                                            self.prefixes_sent_to_rib = None
                                            self.prefixes_resent_to_rib = None
                                            self.prefixes_not_sent_to_rib = None
                                            self.prefixes_removed_from_rib = None
                                            self.attributes_sent_to_rib = None
                                            self.attributes_removed_from_rib = None
                                            self.attributes_recover_from_rib = None
                                            self.scanner_runs = None
                                            self.scanner_time = None
                                            self.rib_tbl_del_calls = None
                                            self.rib_tbl_invalid_calls = None
                                            self.rib_tbl_skip_calls = None
                                            self.rib_tbl_local_label = None
                                            self.rib_tbl_retry = None
                                            self.time_last_update_sent = None
                                            self.is_rib_table_full = None
                                            self.rib_table_full_version = None
                                            self.first_rib_table_full_version = None
                                            self.last_rib_table_full_version = None
                                            self.last_rib_table_full_age = None
                                            self.first_rib_table_has_space_version = None
                                            self.last_rib_table_has_space_version = None
                                            self.last_rib_table_has_space_age = None
                                            self.rib_trigger = None
                                            self.vrf_flags = None
                                            self.label_calls = None
                                            self.label_time = None
                                            self.label_rewrite_count = None
                                            self.label_release_count = None
                                            self.label_added_count = None
                                            self.import_calls = None
                                            self.import_time = None
                                            self.import_src_net_processed_count = None
                                            self.import_dest_net_processed_count = None
                                            self.import_added_path_count = None
                                            self.import_removed_path_count = None
                                            self.import_replaced_path_count = None
                                            self.update_group_count = None
                                            self.subgroup_count = None

                                            self.time_rib_coverged = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged()
                                            self.time_rib_coverged.parent = self
                                            self._children_name_map["time_rib_coverged"] = "time-rib-coverged"

                                            self.time_rib_down = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown()
                                            self.time_rib_down.parent = self
                                            self._children_name_map["time_rib_down"] = "time-rib-down"

                                            self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp()
                                            self.first_rib_table_full_timestamp.parent = self
                                            self._children_name_map["first_rib_table_full_timestamp"] = "first-rib-table-full-timestamp"

                                            self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp()
                                            self.last_rib_table_full_timestamp.parent = self
                                            self._children_name_map["last_rib_table_full_timestamp"] = "last-rib-table-full-timestamp"

                                            self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp()
                                            self.first_rib_table_has_space_timestamp.parent = self
                                            self._children_name_map["first_rib_table_has_space_timestamp"] = "first-rib-table-has-space-timestamp"

                                            self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp()
                                            self.last_rib_table_has_space_timestamp.parent = self
                                            self._children_name_map["last_rib_table_has_space_timestamp"] = "last-rib-table-has-space-timestamp"

                                            self.time_label_retain = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain()
                                            self.time_label_retain.parent = self
                                            self._children_name_map["time_label_retain"] = "time-label-retain"
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, [u'update_generation_calls', u'update_generation_prefixes_count', u'update_generation_be_prefixes_count', u'update_generation_messages_count', u'update_generation_time', u'rib_update_calls', u'rib_update_time', u'prefixes_sent_to_rib', u'prefixes_resent_to_rib', u'prefixes_not_sent_to_rib', u'prefixes_removed_from_rib', u'attributes_sent_to_rib', u'attributes_removed_from_rib', u'attributes_recover_from_rib', u'scanner_runs', u'scanner_time', u'rib_tbl_del_calls', u'rib_tbl_invalid_calls', u'rib_tbl_skip_calls', u'rib_tbl_local_label', u'rib_tbl_retry', u'time_last_update_sent', u'is_rib_table_full', u'rib_table_full_version', u'first_rib_table_full_version', u'last_rib_table_full_version', u'last_rib_table_full_age', u'first_rib_table_has_space_version', u'last_rib_table_has_space_version', u'last_rib_table_has_space_age', u'rib_trigger', u'vrf_flags', u'label_calls', u'label_time', u'label_rewrite_count', u'label_release_count', u'label_added_count', u'import_calls', u'import_time', u'import_src_net_processed_count', u'import_dest_net_processed_count', u'import_added_path_count', u'import_removed_path_count', u'import_replaced_path_count', u'update_group_count', u'subgroup_count'], name, value)


                                        class TimeRibCoverged(Entity):
                                            """
                                            Time last RIB ack was sent 
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, self).__init__()

                                                self.yang_name = "time-rib-coverged"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "time-rib-coverged"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, [u'seconds', u'nanoseconds'], name, value)


                                        class TimeRibDown(Entity):
                                            """
                                            Time last RIB down wassent. This field is
                                            deprecated
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, self).__init__()

                                                self.yang_name = "time-rib-down"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "time-rib-down"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstRibTableFullTimestamp(Entity):
                                            """
                                            Timestamp when RIB table was full for the first
                                            time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, self).__init__()

                                                self.yang_name = "first-rib-table-full-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-table-full-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibTableFullTimestamp(Entity):
                                            """
                                            Timestamp when RIB table was full for the last
                                            time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, self).__init__()

                                                self.yang_name = "last-rib-table-full-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-table-full-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstRibTableHasSpaceTimestamp(Entity):
                                            """
                                            Timestamp when RIB table had space for the first
                                            time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, self).__init__()

                                                self.yang_name = "first-rib-table-has-space-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-table-has-space-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibTableHasSpaceTimestamp(Entity):
                                            """
                                            Timestamp when RIB table had space for the last
                                            time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, self).__init__()

                                                self.yang_name = "last-rib-table-has-space-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-table-has-space-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class TimeLabelRetain(Entity):
                                            """
                                            Time last label retentiontriggered 
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, self).__init__()

                                                self.yang_name = "time-label-retain"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "time-label-retain"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, [u'seconds', u'nanoseconds'], name, value)


                            class PathUsedTable(Entity):
                                """
                                The BGP Path Used Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable, self).__init__()

                                    self.yang_name = "path-used-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path))])
                                    self._leafs = OrderedDict()

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-used-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: orig_source_rd
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertised_neighbor
                                    
                                    	Advertised Neighbor Address. Valid in the case of Advertised table
                                    	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor>`
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: original_source_route_distinguisher
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\: str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-used-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                            ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                            ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                            ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                            ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                            ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                            ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.orig_source_rd = None
                                        self.path_id = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.label_oor = None
                                        self.label_oor_version = None
                                        self.label_fail = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.original_source_route_distinguisher = None
                                        self.prefix_version = None
                                        self.vrf_name = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None

                                        self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor()
                                        self.advertised_neighbor.parent = self
                                        self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                    class AdvertisedNeighbor(Entity):
                                        """
                                        Advertised Neighbor Address. Valid in the case
                                        of Advertised table
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor, self).__init__()

                                            self.yang_name = "advertised-neighbor"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "advertised-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied. In the
                                        case of path type received\-only this will be
                                        attributes before inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class BmpPathTableGeneric(Entity):
                                """
                                Summary Info about BMP Table
                                
                                .. attribute:: bmp_version_wrap_time_spec
                                
                                	Version Wrap timestamp
                                	**type**\:  :py:class:`BmpVersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec>`
                                
                                .. attribute:: bmp_version_wrap_start_time_spec
                                
                                	Version Wrap handle start timestamp
                                	**type**\:  :py:class:`BmpVersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec>`
                                
                                .. attribute:: bmp_version_wrap_done_time_spec
                                
                                	Version Wrap handle Done timestamp
                                	**type**\:  :py:class:`BmpVersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec>`
                                
                                .. attribute:: bmp_route_monitoringe_enabled
                                
                                	Is Route Monitoring mode enabled
                                	**type**\: bool
                                
                                .. attribute:: bmp_table_version
                                
                                	Table version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_count
                                
                                	Number of nets in the table
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_count
                                
                                	Number of paths in the table
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_version_wrapped
                                
                                	Number of times Table Version Wrapped
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_version_wrapped_tid
                                
                                	Version Wrapped trigger thread id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_version_inprogress
                                
                                	Is Version wrap in progress
                                	**type**\: bool
                                
                                .. attribute:: bmp_version_incremented
                                
                                	Is Version being incremented
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric, self).__init__()

                                    self.yang_name = "bmp-path-table-generic"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bmp-version-wrap-time-spec", ("bmp_version_wrap_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec)), ("bmp-version-wrap-start-time-spec", ("bmp_version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec)), ("bmp-version-wrap-done-time-spec", ("bmp_version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec))])
                                    self._leafs = OrderedDict([
                                        ('bmp_route_monitoringe_enabled', (YLeaf(YType.boolean, 'bmp-route-monitoringe-enabled'), ['bool'])),
                                        ('bmp_table_version', (YLeaf(YType.uint32, 'bmp-table-version'), ['int'])),
                                        ('network_count', (YLeaf(YType.uint32, 'network-count'), ['int'])),
                                        ('path_count', (YLeaf(YType.uint32, 'path-count'), ['int'])),
                                        ('bmp_version_wrapped', (YLeaf(YType.uint32, 'bmp-version-wrapped'), ['int'])),
                                        ('bmp_version_wrapped_tid', (YLeaf(YType.uint32, 'bmp-version-wrapped-tid'), ['int'])),
                                        ('bmp_version_inprogress', (YLeaf(YType.boolean, 'bmp-version-inprogress'), ['bool'])),
                                        ('bmp_version_incremented', (YLeaf(YType.boolean, 'bmp-version-incremented'), ['bool'])),
                                    ])
                                    self.bmp_route_monitoringe_enabled = None
                                    self.bmp_table_version = None
                                    self.network_count = None
                                    self.path_count = None
                                    self.bmp_version_wrapped = None
                                    self.bmp_version_wrapped_tid = None
                                    self.bmp_version_inprogress = None
                                    self.bmp_version_incremented = None

                                    self.bmp_version_wrap_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec()
                                    self.bmp_version_wrap_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_time_spec"] = "bmp-version-wrap-time-spec"

                                    self.bmp_version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec()
                                    self.bmp_version_wrap_start_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_start_time_spec"] = "bmp-version-wrap-start-time-spec"

                                    self.bmp_version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec()
                                    self.bmp_version_wrap_done_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_done_time_spec"] = "bmp-version-wrap-done-time-spec"
                                    self._segment_path = lambda: "bmp-path-table-generic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric, [u'bmp_route_monitoringe_enabled', u'bmp_table_version', u'network_count', u'path_count', u'bmp_version_wrapped', u'bmp_version_wrapped_tid', u'bmp_version_inprogress', u'bmp_version_incremented'], name, value)


                                class BmpVersionWrapTimeSpec(Entity):
                                    """
                                    Version Wrap timestamp
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-version-wrap-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class BmpVersionWrapStartTimeSpec(Entity):
                                    """
                                    Version Wrap handle start timestamp
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-start-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-version-wrap-start-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class BmpVersionWrapDoneTimeSpec(Entity):
                                    """
                                    Version Wrap handle Done timestamp
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-done-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-version-wrap-done-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                            class RpcSets(Entity):
                                """
                                BGP next\-hop set table
                                
                                .. attribute:: rpc_set
                                
                                	A BGP next\-hop set
                                	**type**\: list of  		 :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets, self).__init__()

                                    self.yang_name = "rpc-sets"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpc-set", ("rpc_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet))])
                                    self._leafs = OrderedDict()

                                    self.rpc_set = YList(self)
                                    self._segment_path = lambda: "rpc-sets"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets, [], name, value)


                                class RpcSet(Entity):
                                    """
                                    A BGP next\-hop set
                                    
                                    .. attribute:: rpc_set_index  (key)
                                    
                                    	Nexthop set index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_xr
                                    
                                    	Number of multipath next\-hops
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: srv6sid_address
                                    
                                    	SRv6 SID address value
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: srv6sid_address_len
                                    
                                    	SRv6 SID address Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	List of multipath next\-hops
                                    	**type**\: list of  		 :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet, self).__init__()

                                        self.yang_name = "rpc-set"
                                        self.yang_parent_name = "rpc-sets"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['rpc_set_index']
                                        self._child_classes = OrderedDict([("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop))])
                                        self._leafs = OrderedDict([
                                            ('rpc_set_index', (YLeaf(YType.uint32, 'rpc-set-index'), ['int'])),
                                            ('next_hop_xr', (YLeaf(YType.uint32, 'next-hop-xr'), ['int'])),
                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                            ('ref_count', (YLeaf(YType.uint32, 'ref-count'), ['int'])),
                                            ('srv6sid_address', (YLeaf(YType.str, 'srv6sid-address'), ['str'])),
                                            ('srv6sid_address_len', (YLeaf(YType.uint32, 'srv6sid-address-len'), ['int'])),
                                        ])
                                        self.rpc_set_index = None
                                        self.next_hop_xr = None
                                        self.label = None
                                        self.ref_count = None
                                        self.srv6sid_address = None
                                        self.srv6sid_address_len = None

                                        self.next_hop = YList(self)
                                        self._segment_path = lambda: "rpc-set" + "[rpc-set-index='" + str(self.rpc_set_index) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet, ['rpc_set_index', u'next_hop_xr', u'label', u'ref_count', u'srv6sid_address', u'srv6sid_address_len'], name, value)


                                    class NextHop(Entity):
                                        """
                                        List of multipath next\-hops
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop, self).__init__()

                                            self.yang_name = "next-hop"
                                            self.yang_parent_name = "rpc-set"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "next-hop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class GlobalAfProcessInfo(Entity):
                                """
                                The Global Address Family Process information
                                table
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\: str
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: is_nsr_enabled
                                
                                	Non\-stop routing enabled
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo, self).__init__()

                                    self.yang_name = "global-af-process-info"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf))])
                                    self._leafs = OrderedDict([
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('is_nsr_enabled', (YLeaf(YType.boolean, 'is-nsr-enabled'), ['bool'])),
                                    ])
                                    self.vrf_name = None
                                    self.af_name = None
                                    self.is_nsr_enabled = None

                                    self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"

                                    self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._segment_path = lambda: "global-af-process-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo, [u'vrf_name', u'af_name', u'is_nsr_enabled'], name, value)


                                class Global(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:  :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall>`
                                    
                                    .. attribute:: scanner_period
                                    
                                    	Period (in seconds) of address\-family scanner runs
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nh_tunnel_version
                                    
                                    	NH Tunnel Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_prefixes
                                    
                                    	Total prefixes of address\-family scanned
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segment_prefixes
                                    
                                    	Number of prefixes scanned in a segment of address\-family
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segments
                                    
                                    	Number of segments to scan all prefixes of address\-family
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: inter_as_install_enabled
                                    
                                    	Is inter\-AS install to pim on ASBR enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: global_mcast_enabled
                                    
                                    	Is global table mcast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: segmented_mcast_enabled
                                    
                                    	Is segmented mcast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: gblafrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: gblafrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\: bool
                                    
                                    .. attribute:: gblafrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: gblafrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\: bool
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_perm_net_cfg
                                    
                                    	Permanent Network Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: perm_net_del_count
                                    
                                    	Count of removed perm paths
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_del_count
                                    
                                    	Count of stale perm paths
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_mark_count
                                    
                                    	Count of stale marked perm paths
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_insert_count
                                    
                                    	Count of inserted perm paths
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_existing_count
                                    
                                    	Count of existing perm paths
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_query_count
                                    
                                    	Count of perm nets given by RPL
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_process_count
                                    
                                    	Count of perm nets processed in RPL
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_nbr_count
                                    
                                    	Count of neighbors configured with perm net
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_not_found_count
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_path_not_found_count
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_found_count
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_reg_path_found_count
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_path_found_count
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_free_count
                                    
                                    	Count of freed perm pelems
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_path_refresh_count
                                    
                                    	Count of perm paths refreshed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_all_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: syncgrp_version
                                    
                                    	Sync\-group Version
                                    	**type**\: list of  		 :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "global-af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rib-install", ("rib_install", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall)), ("syncgrp-version", ("syncgrp_version", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion))])
                                        self._leafs = OrderedDict([
                                            ('scanner_period', (YLeaf(YType.uint16, 'scanner-period'), ['int'])),
                                            ('nh_tunnel_version', (YLeaf(YType.uint32, 'nh-tunnel-version'), ['int'])),
                                            ('scan_prefixes', (YLeaf(YType.uint32, 'scan-prefixes'), ['int'])),
                                            ('scan_segment_prefixes', (YLeaf(YType.uint32, 'scan-segment-prefixes'), ['int'])),
                                            ('scan_segments', (YLeaf(YType.uint8, 'scan-segments'), ['int'])),
                                            ('inter_as_install_enabled', (YLeaf(YType.boolean, 'inter-as-install-enabled'), ['bool'])),
                                            ('global_mcast_enabled', (YLeaf(YType.boolean, 'global-mcast-enabled'), ['bool'])),
                                            ('segmented_mcast_enabled', (YLeaf(YType.boolean, 'segmented-mcast-enabled'), ['bool'])),
                                            ('gblafrpki_disable', (YLeaf(YType.boolean, 'gblafrpki-disable'), ['bool'])),
                                            ('gblafrpki_use_validity', (YLeaf(YType.boolean, 'gblafrpki-use-validity'), ['bool'])),
                                            ('gblafrpki_allow_invalid', (YLeaf(YType.boolean, 'gblafrpki-allow-invalid'), ['bool'])),
                                            ('gblafrpki_signal_ibgp', (YLeaf(YType.boolean, 'gblafrpki-signal-ibgp'), ['bool'])),
                                            ('update_wait_install_enabled', (YLeaf(YType.boolean, 'update-wait-install-enabled'), ['bool'])),
                                            ('rib_ack_requests', (YLeaf(YType.uint32, 'rib-ack-requests'), ['int'])),
                                            ('rib_acks_received', (YLeaf(YType.uint32, 'rib-acks-received'), ['int'])),
                                            ('rib_slow_acks', (YLeaf(YType.uint32, 'rib-slow-acks'), ['int'])),
                                            ('is_perm_net_cfg', (YLeaf(YType.boolean, 'is-perm-net-cfg'), ['bool'])),
                                            ('perm_net_del_count', (YLeaf(YType.uint16, 'perm-net-del-count'), ['int'])),
                                            ('perm_net_stale_del_count', (YLeaf(YType.uint16, 'perm-net-stale-del-count'), ['int'])),
                                            ('perm_net_stale_mark_count', (YLeaf(YType.uint16, 'perm-net-stale-mark-count'), ['int'])),
                                            ('perm_net_insert_count', (YLeaf(YType.uint16, 'perm-net-insert-count'), ['int'])),
                                            ('perm_net_existing_count', (YLeaf(YType.uint16, 'perm-net-existing-count'), ['int'])),
                                            ('perm_net_rpl_query_count', (YLeaf(YType.uint16, 'perm-net-rpl-query-count'), ['int'])),
                                            ('perm_net_rpl_process_count', (YLeaf(YType.uint16, 'perm-net-rpl-process-count'), ['int'])),
                                            ('perm_nbr_count', (YLeaf(YType.uint16, 'perm-nbr-count'), ['int'])),
                                            ('rib_perm_pelem_not_found_count', (YLeaf(YType.uint16, 'rib-perm-pelem-not-found-count'), ['int'])),
                                            ('rib_perm_path_not_found_count', (YLeaf(YType.uint16, 'rib-perm-path-not-found-count'), ['int'])),
                                            ('rib_perm_pelem_found_count', (YLeaf(YType.uint16, 'rib-perm-pelem-found-count'), ['int'])),
                                            ('rib_reg_path_found_count', (YLeaf(YType.uint16, 'rib-reg-path-found-count'), ['int'])),
                                            ('rib_perm_path_found_count', (YLeaf(YType.uint16, 'rib-perm-path-found-count'), ['int'])),
                                            ('perm_pelem_free_count', (YLeaf(YType.uint16, 'perm-pelem-free-count'), ['int'])),
                                            ('perm_path_refresh_count', (YLeaf(YType.uint16, 'perm-path-refresh-count'), ['int'])),
                                            ('perm_pelem_bump_count', (YLeaf(YType.uint16, 'perm-pelem-bump-count'), ['int'])),
                                            ('perm_pelem_all_bump_count', (YLeaf(YType.uint16, 'perm-pelem-all-bump-count'), ['int'])),
                                        ])
                                        self.scanner_period = None
                                        self.nh_tunnel_version = None
                                        self.scan_prefixes = None
                                        self.scan_segment_prefixes = None
                                        self.scan_segments = None
                                        self.inter_as_install_enabled = None
                                        self.global_mcast_enabled = None
                                        self.segmented_mcast_enabled = None
                                        self.gblafrpki_disable = None
                                        self.gblafrpki_use_validity = None
                                        self.gblafrpki_allow_invalid = None
                                        self.gblafrpki_signal_ibgp = None
                                        self.update_wait_install_enabled = None
                                        self.rib_ack_requests = None
                                        self.rib_acks_received = None
                                        self.rib_slow_acks = None
                                        self.is_perm_net_cfg = None
                                        self.perm_net_del_count = None
                                        self.perm_net_stale_del_count = None
                                        self.perm_net_stale_mark_count = None
                                        self.perm_net_insert_count = None
                                        self.perm_net_existing_count = None
                                        self.perm_net_rpl_query_count = None
                                        self.perm_net_rpl_process_count = None
                                        self.perm_nbr_count = None
                                        self.rib_perm_pelem_not_found_count = None
                                        self.rib_perm_path_not_found_count = None
                                        self.rib_perm_pelem_found_count = None
                                        self.rib_reg_path_found_count = None
                                        self.rib_perm_path_found_count = None
                                        self.perm_pelem_free_count = None
                                        self.perm_path_refresh_count = None
                                        self.perm_pelem_bump_count = None
                                        self.perm_pelem_all_bump_count = None

                                        self.rib_install = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall()
                                        self.rib_install.parent = self
                                        self._children_name_map["rib_install"] = "rib-install"

                                        self.syncgrp_version = YList(self)
                                        self._segment_path = lambda: "global"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global, [u'scanner_period', u'nh_tunnel_version', u'scan_prefixes', u'scan_segment_prefixes', u'scan_segments', u'inter_as_install_enabled', u'global_mcast_enabled', u'segmented_mcast_enabled', u'gblafrpki_disable', u'gblafrpki_use_validity', u'gblafrpki_allow_invalid', u'gblafrpki_signal_ibgp', u'update_wait_install_enabled', u'rib_ack_requests', u'rib_acks_received', u'rib_slow_acks', u'is_perm_net_cfg', u'perm_net_del_count', u'perm_net_stale_del_count', u'perm_net_stale_mark_count', u'perm_net_insert_count', u'perm_net_existing_count', u'perm_net_rpl_query_count', u'perm_net_rpl_process_count', u'perm_nbr_count', u'rib_perm_pelem_not_found_count', u'rib_perm_path_not_found_count', u'rib_perm_pelem_found_count', u'rib_reg_path_found_count', u'rib_perm_path_found_count', u'perm_pelem_free_count', u'perm_path_refresh_count', u'perm_pelem_bump_count', u'perm_pelem_all_bump_count'], name, value)


                                    class RibInstall(Entity):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:  :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:  :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: skipped_count
                                        
                                        	Skipped routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall, self).__init__()

                                            self.yang_name = "rib-install"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("update-time", ("update_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime)), ("install-time", ("install_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime))])
                                            self._leafs = OrderedDict([
                                                ('installed_count', (YLeaf(YType.uint32, 'installed-count'), ['int'])),
                                                ('modified_count', (YLeaf(YType.uint32, 'modified-count'), ['int'])),
                                                ('skipped_count', (YLeaf(YType.uint32, 'skipped-count'), ['int'])),
                                                ('withdrawn_count', (YLeaf(YType.uint32, 'withdrawn-count'), ['int'])),
                                                ('start_version', (YLeaf(YType.uint32, 'start-version'), ['int'])),
                                                ('target_version', (YLeaf(YType.uint32, 'target-version'), ['int'])),
                                            ])
                                            self.installed_count = None
                                            self.modified_count = None
                                            self.skipped_count = None
                                            self.withdrawn_count = None
                                            self.start_version = None
                                            self.target_version = None

                                            self.update_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self._children_name_map["update_time"] = "update-time"

                                            self.install_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self._children_name_map["install_time"] = "install-time"
                                            self._segment_path = lambda: "rib-install"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall, [u'installed_count', u'modified_count', u'skipped_count', u'withdrawn_count', u'start_version', u'target_version'], name, value)


                                        class UpdateTime(Entity):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime, self).__init__()

                                                self.yang_name = "update-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "update-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime, [u'seconds', u'nanoseconds'], name, value)


                                        class InstallTime(Entity):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime, self).__init__()

                                                self.yang_name = "install-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "install-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime, [u'seconds', u'nanoseconds'], name, value)


                                    class SyncgrpVersion(Entity):
                                        """
                                        Sync\-group Version
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion, self).__init__()

                                            self.yang_name = "syncgrp-version"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "syncgrp-version"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion, [u'entry'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: table_is_active
                                    
                                    	Table state is active
                                    	**type**\: bool
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rd_version
                                    
                                    	RD version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_version
                                    
                                    	Table version synced to RIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_conv_version
                                    
                                    	NSR conv version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_is_conv
                                    
                                    	NSR is converged
                                    	**type**\: bool
                                    
                                    .. attribute:: client_reflection_enabled
                                    
                                    	Client reflection enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dampening_enabled
                                    
                                    	Dampening enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: ebgp_distance
                                    
                                    	Distance for eBGP routes (external)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ibgp_distance
                                    
                                    	Distance for iBGP routes (internal)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: aggregates_distance
                                    
                                    	Dist for aggregate routes (local)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dynamic_med_enabled
                                    
                                    	Update generation enabled for MED change
                                    	**type**\: bool
                                    
                                    .. attribute:: dynamic_med_interval
                                    
                                    	Delay in update generation after a MED change (in minutes)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: dynamic_med_timer_running
                                    
                                    	Dynamic MED timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: dynamic_med_timer_value
                                    
                                    	Dynamic MED timer value (in seconds) left on the timer
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: dynamic_med_periodic_timer_running
                                    
                                    	Dynamic MED periodic timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: dynamic_med_periodic_timer_value
                                    
                                    	Dynamic MED periodic timer value (in seconds) left on the timer
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_has_converged
                                    
                                    	Received convergence notification from RIB
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_convergence_version
                                    
                                    	Last convergence version received from RIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_rib_table_full
                                    
                                    	Indicates if RIB table is in prefix\-limit state
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_table_full_version
                                    
                                    	Version when RIB table became full (from non\-full)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                    
                                    	Is nexthop resoultion minimum prefix\-length configured ?
                                    	**type**\: bool
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length
                                    
                                    	Nexthop resoultion minimum prefix\-length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: selective_ebgp_multipath_enabled
                                    
                                    	Selective eBGP multipath isenabled
                                    	**type**\: bool
                                    
                                    .. attribute:: selective_ibgp_multipath_enabled
                                    
                                    	Selective iBGP multipath isenabled
                                    	**type**\: bool
                                    
                                    .. attribute:: selective_eibgp_multipath_enabled
                                    
                                    	Selective eiBGP multipath isenabled
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "global-af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('table_is_active', (YLeaf(YType.boolean, 'table-is-active'), ['bool'])),
                                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                            ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                            ('rd_version', (YLeaf(YType.uint32, 'rd-version'), ['int'])),
                                            ('rib_version', (YLeaf(YType.uint32, 'rib-version'), ['int'])),
                                            ('nsr_conv_version', (YLeaf(YType.uint32, 'nsr-conv-version'), ['int'])),
                                            ('nsr_is_conv', (YLeaf(YType.boolean, 'nsr-is-conv'), ['bool'])),
                                            ('client_reflection_enabled', (YLeaf(YType.boolean, 'client-reflection-enabled'), ['bool'])),
                                            ('dampening_enabled', (YLeaf(YType.boolean, 'dampening-enabled'), ['bool'])),
                                            ('ebgp_distance', (YLeaf(YType.uint16, 'ebgp-distance'), ['int'])),
                                            ('ibgp_distance', (YLeaf(YType.uint16, 'ibgp-distance'), ['int'])),
                                            ('aggregates_distance', (YLeaf(YType.uint16, 'aggregates-distance'), ['int'])),
                                            ('dynamic_med_enabled', (YLeaf(YType.boolean, 'dynamic-med-enabled'), ['bool'])),
                                            ('dynamic_med_interval', (YLeaf(YType.uint16, 'dynamic-med-interval'), ['int'])),
                                            ('dynamic_med_timer_running', (YLeaf(YType.boolean, 'dynamic-med-timer-running'), ['bool'])),
                                            ('dynamic_med_timer_value', (YLeaf(YType.uint16, 'dynamic-med-timer-value'), ['int'])),
                                            ('dynamic_med_periodic_timer_running', (YLeaf(YType.boolean, 'dynamic-med-periodic-timer-running'), ['bool'])),
                                            ('dynamic_med_periodic_timer_value', (YLeaf(YType.uint16, 'dynamic-med-periodic-timer-value'), ['int'])),
                                            ('rib_has_converged', (YLeaf(YType.boolean, 'rib-has-converged'), ['bool'])),
                                            ('rib_convergence_version', (YLeaf(YType.uint32, 'rib-convergence-version'), ['int'])),
                                            ('is_rib_table_full', (YLeaf(YType.boolean, 'is-rib-table-full'), ['bool'])),
                                            ('rib_table_full_version', (YLeaf(YType.uint32, 'rib-table-full-version'), ['int'])),
                                            ('nexthop_resolution_minimum_prefix_length_configured', (YLeaf(YType.boolean, 'nexthop-resolution-minimum-prefix-length-configured'), ['bool'])),
                                            ('nexthop_resolution_minimum_prefix_length', (YLeaf(YType.uint32, 'nexthop-resolution-minimum-prefix-length'), ['int'])),
                                            ('selective_ebgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-ebgp-multipath-enabled'), ['bool'])),
                                            ('selective_ibgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-ibgp-multipath-enabled'), ['bool'])),
                                            ('selective_eibgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-eibgp-multipath-enabled'), ['bool'])),
                                            ('rib_acked_table_version', (YLeaf(YType.uint32, 'rib-acked-table-version'), ['int'])),
                                        ])
                                        self.table_is_active = None
                                        self.table_id = None
                                        self.table_version = None
                                        self.rd_version = None
                                        self.rib_version = None
                                        self.nsr_conv_version = None
                                        self.nsr_is_conv = None
                                        self.client_reflection_enabled = None
                                        self.dampening_enabled = None
                                        self.ebgp_distance = None
                                        self.ibgp_distance = None
                                        self.aggregates_distance = None
                                        self.dynamic_med_enabled = None
                                        self.dynamic_med_interval = None
                                        self.dynamic_med_timer_running = None
                                        self.dynamic_med_timer_value = None
                                        self.dynamic_med_periodic_timer_running = None
                                        self.dynamic_med_periodic_timer_value = None
                                        self.rib_has_converged = None
                                        self.rib_convergence_version = None
                                        self.is_rib_table_full = None
                                        self.rib_table_full_version = None
                                        self.nexthop_resolution_minimum_prefix_length_configured = None
                                        self.nexthop_resolution_minimum_prefix_length = None
                                        self.selective_ebgp_multipath_enabled = None
                                        self.selective_ibgp_multipath_enabled = None
                                        self.selective_eibgp_multipath_enabled = None
                                        self.rib_acked_table_version = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf, [u'table_is_active', u'table_id', u'table_version', u'rd_version', u'rib_version', u'nsr_conv_version', u'nsr_is_conv', u'client_reflection_enabled', u'dampening_enabled', u'ebgp_distance', u'ibgp_distance', u'aggregates_distance', u'dynamic_med_enabled', u'dynamic_med_interval', u'dynamic_med_timer_running', u'dynamic_med_timer_value', u'dynamic_med_periodic_timer_running', u'dynamic_med_periodic_timer_value', u'rib_has_converged', u'rib_convergence_version', u'is_rib_table_full', u'rib_table_full_version', u'nexthop_resolution_minimum_prefix_length_configured', u'nexthop_resolution_minimum_prefix_length', u'selective_ebgp_multipath_enabled', u'selective_ibgp_multipath_enabled', u'selective_eibgp_multipath_enabled', u'rib_acked_table_version'], name, value)


                            class AdvertisedPathXr(Entity):
                                """
                                The BGP Advertised path table (bestpath)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised path table entry (bestpath)
                                	**type**\: list of  		 :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr, self).__init__()

                                    self.yang_name = "advertised-path-xr"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("advertised-path", ("advertised_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath))])
                                    self._leafs = OrderedDict()

                                    self.advertised_path = YList(self)
                                    self._segment_path = lambda: "advertised-path-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr, [], name, value)


                                class AdvertisedPath(Entity):
                                    """
                                    A BGP Advertised path table entry (bestpath)
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: advertised_neighbor
                                    
                                    	Advertised Neighbor Address. Valid in the case of Advertised table
                                    	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor>`
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: original_source_route_distinguisher
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\: str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, self).__init__()

                                        self.yang_name = "advertised-path"
                                        self.yang_parent_name = "advertised-path-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                            ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                            ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                            ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.label_oor = None
                                        self.label_oor_version = None
                                        self.label_fail = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.original_source_route_distinguisher = None
                                        self.prefix_version = None
                                        self.vrf_name = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None

                                        self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor()
                                        self.advertised_neighbor.parent = self
                                        self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._segment_path = lambda: "advertised-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, ['rd', 'network', 'prefix_length', 'neighbor_address', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                    class AdvertisedNeighbor(Entity):
                                        """
                                        Advertised Neighbor Address. Valid in the case
                                        of Advertised table
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor, self).__init__()

                                            self.yang_name = "advertised-neighbor"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "advertised-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied. In the
                                        case of path type received\-only this will be
                                        attributes before inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SourcedNetworks(Entity):
                                """
                                The BGP Convergence table
                                
                                .. attribute:: sourced_network
                                
                                	A BGP network command table entry
                                	**type**\: list of  		 :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks, self).__init__()

                                    self.yang_name = "sourced-networks"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sourced-network", ("sourced_network", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork))])
                                    self._leafs = OrderedDict()

                                    self.sourced_network = YList(self)
                                    self._segment_path = lambda: "sourced-networks"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks, [], name, value)


                                class SourcedNetwork(Entity):
                                    """
                                    A BGP network command table entry
                                    
                                    .. attribute:: network  (key)
                                    
                                    	Network in prefix/length format
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: sourced_prefix
                                    
                                    	Prefix length
                                    	**type**\:  :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: is_backdoor
                                    
                                    	TRUE if net is a backdoor route
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork, self).__init__()

                                        self.yang_name = "sourced-network"
                                        self.yang_parent_name = "sourced-networks"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['network']
                                        self._child_classes = OrderedDict([("sourced-prefix", ("sourced_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix))])
                                        self._leafs = OrderedDict([
                                            ('network', (YLeaf(YType.str, 'network'), ['str','str'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('is_backdoor', (YLeaf(YType.boolean, 'is-backdoor'), ['bool'])),
                                        ])
                                        self.network = None
                                        self.af_name = None
                                        self.is_backdoor = None

                                        self.sourced_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                        self.sourced_prefix.parent = self
                                        self._children_name_map["sourced_prefix"] = "sourced-prefix"
                                        self._segment_path = lambda: "sourced-network" + "[network='" + str(self.network) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork, ['network', u'af_name', u'is_backdoor'], name, value)


                                    class SourcedPrefix(Entity):
                                        """
                                        Prefix length
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, self).__init__()

                                            self.yang_name = "sourced-prefix"
                                            self.yang_parent_name = "sourced-network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix_length = None

                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._segment_path = lambda: "sourced-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, [u'prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "sourced-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class UpdateGroups(Entity):
                                """
                                The BGP Update group table
                                
                                .. attribute:: update_group
                                
                                	A BGP Update group table entry
                                	**type**\: list of  		 :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups, self).__init__()

                                    self.yang_name = "update-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-group", ("update_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup))])
                                    self._leafs = OrderedDict()

                                    self.update_group = YList(self)
                                    self._segment_path = lambda: "update-groups"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups, [], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    A BGP Update group table entry
                                    
                                    .. attribute:: update_group_id
                                    
                                    	Update group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_id
                                    
                                    	Filter group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: session_af_name
                                    
                                    	Neighbor session Address family
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family for update group
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: should_send_communities
                                    
                                    	Send communities
                                    	**type**\: bool
                                    
                                    .. attribute:: should_send_ext_communities
                                    
                                    	Send Extended communities
                                    	**type**\: bool
                                    
                                    .. attribute:: should_send_stitching_rt
                                    
                                    	Send Stitching RT
                                    	**type**\: bool
                                    
                                    .. attribute:: has_orf_receive_capability
                                    
                                    	ORF receive capability
                                    	**type**\: bool
                                    
                                    .. attribute:: is_route_reflector_client
                                    
                                    	Route\-reflector client
                                    	**type**\: bool
                                    
                                    .. attribute:: is_client_reflection_disabled
                                    
                                    	True if client\-to\-client reflection is disabled 
                                    	**type**\: bool
                                    
                                    .. attribute:: accepts_legacy_pe_rt_route
                                    
                                    	accept\-legacy\-pe\-RT route
                                    	**type**\: bool
                                    
                                    .. attribute:: updgrp_cluster_id
                                    
                                    	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgrp_cluster_type
                                    
                                    	Cluster ID type\:undefined/number/Ip address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\: str
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\: bool
                                    
                                    .. attribute:: should_remove_private_a_ss
                                    
                                    	Remove private AS numbers
                                    	**type**\: bool
                                    
                                    .. attribute:: should_remove_private_as_ent_path
                                    
                                    	Remove private AS numbersif the entire path consistsof private ASes
                                    	**type**\: bool
                                    
                                    .. attribute:: use_next_hop_self
                                    
                                    	Next hop self
                                    	**type**\: bool
                                    
                                    .. attribute:: use_next_hop_unchanged_mpath
                                    
                                    	Next\-hop\-unchanged multipath
                                    	**type**\: bool
                                    
                                    .. attribute:: is_internal_peers
                                    
                                    	Internal peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is_common_admin_peers
                                    
                                    	Common admin peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is4_byte_as_peer
                                    
                                    	4\-byte AS capable peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is_addpath_capable
                                    
                                    	Add\-path capable peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is_send_mcast_attr_enabled
                                    
                                    	Send mcast attribute enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_aigp_capable
                                    
                                    	AIGP capable peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is_aigp_cost_community_capable
                                    
                                    	Send AIGP cost community to peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is_aigp_med_capable
                                    
                                    	Send AIGP cost in MED
                                    	**type**\: bool
                                    
                                    .. attribute:: is_llgr_capable
                                    
                                    	Send Long\-lived Stale paths
                                    	**type**\: bool
                                    
                                    .. attribute:: is_adv_capable
                                    
                                    	Send tranlsated paths
                                    	**type**\: bool
                                    
                                    .. attribute:: is_adv_reorg_capable
                                    
                                    	Send Re\-orig paths
                                    	**type**\: bool
                                    
                                    .. attribute:: disable_native_advertisement
                                    
                                    	Disable advertising native routes
                                    	**type**\: bool
                                    
                                    .. attribute:: disable_def_vrf_imp_advertisement
                                    
                                    	Disable advertising default VRF  imported routes
                                    	**type**\: bool
                                    
                                    .. attribute:: disable_vrf_re_imp_advertisement
                                    
                                    	Disable advertising VRF re\-imported routes
                                    	**type**\: bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: is_directly_connected_ebgp_v6_peers
                                    
                                    	Directly connected EBGP v6 peers
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_advertisement_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outbound route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: desync_count
                                    
                                    	Number of times the update has been desynchronized
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subgrp_merge_count
                                    
                                    	Number of times sub\-groups have been merged
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_subgrp_count
                                    
                                    	Current count of refresh subgroups
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updates_formatted
                                    
                                    	Number of updates formatted
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updates_replicated
                                    
                                    	No. of updates replicated
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\: bool
                                    
                                    .. attribute:: as_override
                                    
                                    	AS Override option
                                    	**type**\: bool
                                    
                                    .. attribute:: soo_value
                                    
                                    	Site\-of\-origin value
                                    	**type**\: str
                                    
                                    .. attribute:: split_horizon
                                    
                                    	Split horizon check
                                    	**type**\: bool
                                    
                                    .. attribute:: is_labeled_afi_enabled
                                    
                                    	Update group has labeled AFI enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_unlabeled_afi_enabled
                                    
                                    	Update group has unlabeled AFI enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: ext_nh_encoding
                                    
                                    	Extended nexthop encoding cap received
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_adv_perm_net_capable
                                    
                                    	Advertise Permanent\-Net capable peers
                                    	**type**\: bool
                                    
                                    .. attribute:: should_send_gshut_community
                                    
                                    	Send GSHUT community
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_active
                                    
                                    	GSHUT active
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	GSHUT local preference set
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	GSHUT local preference
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	GSHUT AS prepends
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with local\-label via Unicast SAFI
                                    	**type**\: bool
                                    
                                    .. attribute:: enable_label_stack
                                    
                                    	Enable label stack
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor
                                    
                                    	Neighbors in this update group which are not in any sub\-group
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                    
                                    .. attribute:: update_sub_group
                                    
                                    	Update sub\-group list
                                    	**type**\: list of  		 :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "update-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor)), ("update-sub-group", ("update_sub_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup))])
                                        self._leafs = OrderedDict([
                                            ('update_group_id', (YLeaf(YType.uint32, 'update-group-id'), ['int'])),
                                            ('filter_group_id', (YLeaf(YType.uint32, 'filter-group-id'), ['int'])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('session_af_name', (YLeaf(YType.uint8, 'session-af-name'), ['int'])),
                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('should_send_communities', (YLeaf(YType.boolean, 'should-send-communities'), ['bool'])),
                                            ('should_send_ext_communities', (YLeaf(YType.boolean, 'should-send-ext-communities'), ['bool'])),
                                            ('should_send_stitching_rt', (YLeaf(YType.boolean, 'should-send-stitching-rt'), ['bool'])),
                                            ('has_orf_receive_capability', (YLeaf(YType.boolean, 'has-orf-receive-capability'), ['bool'])),
                                            ('is_route_reflector_client', (YLeaf(YType.boolean, 'is-route-reflector-client'), ['bool'])),
                                            ('is_client_reflection_disabled', (YLeaf(YType.boolean, 'is-client-reflection-disabled'), ['bool'])),
                                            ('accepts_legacy_pe_rt_route', (YLeaf(YType.boolean, 'accepts-legacy-pe-rt-route'), ['bool'])),
                                            ('updgrp_cluster_id', (YLeaf(YType.uint32, 'updgrp-cluster-id'), ['int'])),
                                            ('updgrp_cluster_type', (YLeaf(YType.uint8, 'updgrp-cluster-type'), ['int'])),
                                            ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                            ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                            ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                            ('should_remove_private_a_ss', (YLeaf(YType.boolean, 'should-remove-private-a-ss'), ['bool'])),
                                            ('should_remove_private_as_ent_path', (YLeaf(YType.boolean, 'should-remove-private-as-ent-path'), ['bool'])),
                                            ('use_next_hop_self', (YLeaf(YType.boolean, 'use-next-hop-self'), ['bool'])),
                                            ('use_next_hop_unchanged_mpath', (YLeaf(YType.boolean, 'use-next-hop-unchanged-mpath'), ['bool'])),
                                            ('is_internal_peers', (YLeaf(YType.boolean, 'is-internal-peers'), ['bool'])),
                                            ('is_common_admin_peers', (YLeaf(YType.boolean, 'is-common-admin-peers'), ['bool'])),
                                            ('is4_byte_as_peer', (YLeaf(YType.boolean, 'is4-byte-as-peer'), ['bool'])),
                                            ('is_addpath_capable', (YLeaf(YType.boolean, 'is-addpath-capable'), ['bool'])),
                                            ('is_send_mcast_attr_enabled', (YLeaf(YType.boolean, 'is-send-mcast-attr-enabled'), ['bool'])),
                                            ('is_aigp_capable', (YLeaf(YType.boolean, 'is-aigp-capable'), ['bool'])),
                                            ('is_aigp_cost_community_capable', (YLeaf(YType.boolean, 'is-aigp-cost-community-capable'), ['bool'])),
                                            ('is_aigp_med_capable', (YLeaf(YType.boolean, 'is-aigp-med-capable'), ['bool'])),
                                            ('is_llgr_capable', (YLeaf(YType.boolean, 'is-llgr-capable'), ['bool'])),
                                            ('is_adv_capable', (YLeaf(YType.boolean, 'is-adv-capable'), ['bool'])),
                                            ('is_adv_reorg_capable', (YLeaf(YType.boolean, 'is-adv-reorg-capable'), ['bool'])),
                                            ('disable_native_advertisement', (YLeaf(YType.boolean, 'disable-native-advertisement'), ['bool'])),
                                            ('disable_def_vrf_imp_advertisement', (YLeaf(YType.boolean, 'disable-def-vrf-imp-advertisement'), ['bool'])),
                                            ('disable_vrf_re_imp_advertisement', (YLeaf(YType.boolean, 'disable-vrf-re-imp-advertisement'), ['bool'])),
                                            ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                            ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                            ('is_directly_connected_ebgp_v6_peers', (YLeaf(YType.boolean, 'is-directly-connected-ebgp-v6-peers'), ['bool'])),
                                            ('minimum_advertisement_interval', (YLeaf(YType.uint32, 'minimum-advertisement-interval'), ['int'])),
                                            ('minimum_advertisement_interval_msecs', (YLeaf(YType.uint32, 'minimum-advertisement-interval-msecs'), ['int'])),
                                            ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                            ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                            ('desync_count', (YLeaf(YType.uint32, 'desync-count'), ['int'])),
                                            ('subgrp_merge_count', (YLeaf(YType.uint32, 'subgrp-merge-count'), ['int'])),
                                            ('refresh_subgrp_count', (YLeaf(YType.uint32, 'refresh-subgrp-count'), ['int'])),
                                            ('updates_formatted', (YLeaf(YType.uint32, 'updates-formatted'), ['int'])),
                                            ('updates_replicated', (YLeaf(YType.uint32, 'updates-replicated'), ['int'])),
                                            ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                            ('as_override', (YLeaf(YType.boolean, 'as-override'), ['bool'])),
                                            ('soo_value', (YLeaf(YType.str, 'soo-value'), ['str'])),
                                            ('split_horizon', (YLeaf(YType.boolean, 'split-horizon'), ['bool'])),
                                            ('is_labeled_afi_enabled', (YLeaf(YType.boolean, 'is-labeled-afi-enabled'), ['bool'])),
                                            ('is_unlabeled_afi_enabled', (YLeaf(YType.boolean, 'is-unlabeled-afi-enabled'), ['bool'])),
                                            ('ext_nh_encoding', (YLeaf(YType.boolean, 'ext-nh-encoding'), ['bool'])),
                                            ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                            ('is_adv_perm_net_capable', (YLeaf(YType.boolean, 'is-adv-perm-net-capable'), ['bool'])),
                                            ('should_send_gshut_community', (YLeaf(YType.boolean, 'should-send-gshut-community'), ['bool'])),
                                            ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                            ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                            ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                            ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                            ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                            ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                        ])
                                        self.update_group_id = None
                                        self.filter_group_id = None
                                        self.process_instance_id = None
                                        self.session_af_name = None
                                        self.update_group_number = None
                                        self.update_group_af_name = None
                                        self.should_send_communities = None
                                        self.should_send_ext_communities = None
                                        self.should_send_stitching_rt = None
                                        self.has_orf_receive_capability = None
                                        self.is_route_reflector_client = None
                                        self.is_client_reflection_disabled = None
                                        self.accepts_legacy_pe_rt_route = None
                                        self.updgrp_cluster_id = None
                                        self.updgrp_cluster_type = None
                                        self.orr_group_name = None
                                        self.orr_group_index = None
                                        self.is_orr_root_address_configured = None
                                        self.should_remove_private_a_ss = None
                                        self.should_remove_private_as_ent_path = None
                                        self.use_next_hop_self = None
                                        self.use_next_hop_unchanged_mpath = None
                                        self.is_internal_peers = None
                                        self.is_common_admin_peers = None
                                        self.is4_byte_as_peer = None
                                        self.is_addpath_capable = None
                                        self.is_send_mcast_attr_enabled = None
                                        self.is_aigp_capable = None
                                        self.is_aigp_cost_community_capable = None
                                        self.is_aigp_med_capable = None
                                        self.is_llgr_capable = None
                                        self.is_adv_capable = None
                                        self.is_adv_reorg_capable = None
                                        self.disable_native_advertisement = None
                                        self.disable_def_vrf_imp_advertisement = None
                                        self.disable_vrf_re_imp_advertisement = None
                                        self.encapsulation_type = None
                                        self.advertise_rt_type = None
                                        self.is_directly_connected_ebgp_v6_peers = None
                                        self.minimum_advertisement_interval = None
                                        self.minimum_advertisement_interval_msecs = None
                                        self.local_as = None
                                        self.route_policy_out = None
                                        self.desync_count = None
                                        self.subgrp_merge_count = None
                                        self.refresh_subgrp_count = None
                                        self.updates_formatted = None
                                        self.updates_replicated = None
                                        self.local_as_replace_as = None
                                        self.as_override = None
                                        self.soo_value = None
                                        self.split_horizon = None
                                        self.is_labeled_afi_enabled = None
                                        self.is_unlabeled_afi_enabled = None
                                        self.ext_nh_encoding = None
                                        self.remote_as = None
                                        self.is_adv_perm_net_capable = None
                                        self.should_send_gshut_community = None
                                        self.gshut_active = None
                                        self.gshut_locpref_set = None
                                        self.gshut_locpref = None
                                        self.gshut_prepends = None
                                        self.advertise_local_labeled_route_unicast = None
                                        self.enable_label_stack = None

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"

                                        self.neighbor = YList(self)
                                        self.update_sub_group = YList(self)
                                        self._segment_path = lambda: "update-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup, ['update_group_id', 'filter_group_id', u'process_instance_id', u'session_af_name', u'update_group_number', u'update_group_af_name', u'should_send_communities', u'should_send_ext_communities', u'should_send_stitching_rt', u'has_orf_receive_capability', u'is_route_reflector_client', u'is_client_reflection_disabled', u'accepts_legacy_pe_rt_route', u'updgrp_cluster_id', u'updgrp_cluster_type', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'should_remove_private_a_ss', u'should_remove_private_as_ent_path', u'use_next_hop_self', u'use_next_hop_unchanged_mpath', u'is_internal_peers', u'is_common_admin_peers', u'is4_byte_as_peer', u'is_addpath_capable', u'is_send_mcast_attr_enabled', u'is_aigp_capable', u'is_aigp_cost_community_capable', u'is_aigp_med_capable', u'is_llgr_capable', u'is_adv_capable', u'is_adv_reorg_capable', u'disable_native_advertisement', u'disable_def_vrf_imp_advertisement', u'disable_vrf_re_imp_advertisement', u'encapsulation_type', u'advertise_rt_type', u'is_directly_connected_ebgp_v6_peers', u'minimum_advertisement_interval', u'minimum_advertisement_interval_msecs', u'local_as', u'route_policy_out', u'desync_count', u'subgrp_merge_count', u'refresh_subgrp_count', u'updates_formatted', u'updates_replicated', u'local_as_replace_as', u'as_override', u'soo_value', u'split_horizon', u'is_labeled_afi_enabled', u'is_unlabeled_afi_enabled', u'ext_nh_encoding', u'remote_as', u'is_adv_perm_net_capable', u'should_send_gshut_community', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends', u'advertise_local_labeled_route_unicast', u'enable_label_stack'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: updgen_timer_start_time
                                        
                                        	Timestamp when update timer started for updgrp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_stop_time
                                        
                                        	Timestamp when update timer stopped for updgrp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_process_time
                                        
                                        	Timestamp when update timer processed for updgrp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update_generation_calls', (YLeaf(YType.uint32, 'update-generation-calls'), ['int'])),
                                                ('update_generation_prefixes_count', (YLeaf(YType.uint32, 'update-generation-prefixes-count'), ['int'])),
                                                ('update_generation_be_prefixes_count', (YLeaf(YType.uint32, 'update-generation-be-prefixes-count'), ['int'])),
                                                ('update_generation_messages_count', (YLeaf(YType.uint32, 'update-generation-messages-count'), ['int'])),
                                                ('update_generation_time', (YLeaf(YType.uint32, 'update-generation-time'), ['int'])),
                                                ('updgen_timer_start_time', (YLeaf(YType.uint64, 'updgen-timer-start-time'), ['int'])),
                                                ('updgen_timer_stop_time', (YLeaf(YType.uint64, 'updgen-timer-stop-time'), ['int'])),
                                                ('updgen_timer_process_time', (YLeaf(YType.uint64, 'updgen-timer-process-time'), ['int'])),
                                            ])
                                            self.update_generation_calls = None
                                            self.update_generation_prefixes_count = None
                                            self.update_generation_be_prefixes_count = None
                                            self.update_generation_messages_count = None
                                            self.update_generation_time = None
                                            self.updgen_timer_start_time = None
                                            self.updgen_timer_stop_time = None
                                            self.updgen_timer_process_time = None
                                            self._segment_path = lambda: "performance-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, [u'update_generation_calls', u'update_generation_prefixes_count', u'update_generation_be_prefixes_count', u'update_generation_messages_count', u'update_generation_time', u'updgen_timer_start_time', u'updgen_timer_stop_time', u'updgen_timer_process_time'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Neighbors in this update group which are not in
                                        any sub\-group
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class UpdateSubGroup(Entity):
                                        """
                                        Update sub\-group list
                                        
                                        .. attribute:: update_sub_group_number
                                        
                                        	Update sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group
                                        
                                        	Update sub\-group fgrp\-num
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: wait_for_eo_rs
                                        
                                        	Wait for  RT Nbr EoRs
                                        	**type**\: bool
                                        
                                        .. attribute:: update_filter_group
                                        
                                        	Update f\-group list
                                        	**type**\: list of  		 :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this subgrp not in any filtergrp
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, self).__init__()

                                            self.yang_name = "update-sub-group"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("update-filter-group", ("update_filter_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor))])
                                            self._leafs = OrderedDict([
                                                ('update_sub_group_number', (YLeaf(YType.uint32, 'update-sub-group-number'), ['int'])),
                                                ('filter_group', (YLeaf(YType.uint16, 'filter-group'), ['int'])),
                                                ('wait_for_eo_rs', (YLeaf(YType.boolean, 'wait-for-eo-rs'), ['bool'])),
                                            ])
                                            self.update_sub_group_number = None
                                            self.filter_group = None
                                            self.wait_for_eo_rs = None

                                            self.update_filter_group = YList(self)
                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "update-sub-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, [u'update_sub_group_number', u'filter_group', u'wait_for_eo_rs'], name, value)


                                        class UpdateFilterGroup(Entity):
                                            """
                                            Update f\-group list
                                            
                                            .. attribute:: update_filter_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rts
                                            
                                            	RT count per filter group
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_flags
                                            
                                            	Flags per filter group
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fgroup_neighbors
                                            
                                            	Nbrs per filter group
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: fgroup_created_message_elements
                                            
                                            	Number of message elems created for filtergroup
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_deleted_message_elements
                                            
                                            	Number of message elems deleted
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_queued_message_elements
                                            
                                            	Number of message elems queued
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in last update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in all update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_non_optimised_prefixes
                                            
                                            	Number of prefixes  non\-optm from filtergroupin all update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_skipped_prefixes
                                            
                                            	Number of prefixes skipped for filtergroup in last update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_suppressed_prefixes
                                            
                                            	Number of prefixes suppressed for filtergroup in last update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\: bool
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this update sub\-group
                                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, self).__init__()

                                                self.yang_name = "update-filter-group"
                                                self.yang_parent_name = "update-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor))])
                                                self._leafs = OrderedDict([
                                                    ('update_filter_group_number', (YLeaf(YType.uint32, 'update-filter-group-number'), ['int'])),
                                                    ('rts', (YLeaf(YType.uint32, 'rts'), ['int'])),
                                                    ('fgroup_flags', (YLeaf(YType.uint8, 'fgroup-flags'), ['int'])),
                                                    ('fgroup_neighbors', (YLeaf(YType.uint16, 'fgroup-neighbors'), ['int'])),
                                                    ('fgroup_created_message_elements', (YLeaf(YType.uint32, 'fgroup-created-message-elements'), ['int'])),
                                                    ('fgroup_deleted_message_elements', (YLeaf(YType.uint32, 'fgroup-deleted-message-elements'), ['int'])),
                                                    ('fgroup_queued_message_elements', (YLeaf(YType.uint32, 'fgroup-queued-message-elements'), ['int'])),
                                                    ('fgroup_advertised_prefixes', (YLeaf(YType.uint32, 'fgroup-advertised-prefixes'), ['int'])),
                                                    ('fgroup_total_advertised_prefixes', (YLeaf(YType.uint32, 'fgroup-total-advertised-prefixes'), ['int'])),
                                                    ('fgroup_withdrawn_prefixes', (YLeaf(YType.uint32, 'fgroup-withdrawn-prefixes'), ['int'])),
                                                    ('fgroup_total_withdrawn_prefixes', (YLeaf(YType.uint32, 'fgroup-total-withdrawn-prefixes'), ['int'])),
                                                    ('fgroup_total_non_optimised_prefixes', (YLeaf(YType.uint32, 'fgroup-total-non-optimised-prefixes'), ['int'])),
                                                    ('fgroup_skipped_prefixes', (YLeaf(YType.uint32, 'fgroup-skipped-prefixes'), ['int'])),
                                                    ('fgroup_suppressed_prefixes', (YLeaf(YType.uint32, 'fgroup-suppressed-prefixes'), ['int'])),
                                                    ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                                ])
                                                self.update_filter_group_number = None
                                                self.rts = None
                                                self.fgroup_flags = None
                                                self.fgroup_neighbors = None
                                                self.fgroup_created_message_elements = None
                                                self.fgroup_deleted_message_elements = None
                                                self.fgroup_queued_message_elements = None
                                                self.fgroup_advertised_prefixes = None
                                                self.fgroup_total_advertised_prefixes = None
                                                self.fgroup_withdrawn_prefixes = None
                                                self.fgroup_total_withdrawn_prefixes = None
                                                self.fgroup_total_non_optimised_prefixes = None
                                                self.fgroup_skipped_prefixes = None
                                                self.fgroup_suppressed_prefixes = None
                                                self.is_rt_present = None

                                                self.extended_community = YList(self)
                                                self.neighbor = YList(self)
                                                self._segment_path = lambda: "update-filter-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, [u'update_filter_group_number', u'rts', u'fgroup_flags', u'fgroup_neighbors', u'fgroup_created_message_elements', u'fgroup_deleted_message_elements', u'fgroup_queued_message_elements', u'fgroup_advertised_prefixes', u'fgroup_total_advertised_prefixes', u'fgroup_withdrawn_prefixes', u'fgroup_total_withdrawn_prefixes', u'fgroup_total_non_optimised_prefixes', u'fgroup_skipped_prefixes', u'fgroup_suppressed_prefixes', u'is_rt_present'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "update-filter-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, [u'entry'], name, value)


                                            class Neighbor(Entity):
                                                """
                                                Neighbors in this update sub\-group
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, self).__init__()

                                                    self.yang_name = "neighbor"
                                                    self.yang_parent_name = "update-filter-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Neighbors in this subgrp not in any filtergrp
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "update-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class UpdateGenerationSubGroups(Entity):
                                """
                                Update generation for all sub\-groups
                                
                                .. attribute:: update_generation_sub_group
                                
                                	Update generation for sub\-group
                                	**type**\: list of  		 :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups, self).__init__()

                                    self.yang_name = "update-generation-sub-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-generation-sub-group", ("update_generation_sub_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup))])
                                    self._leafs = OrderedDict()

                                    self.update_generation_sub_group = YList(self)
                                    self._segment_path = lambda: "update-generation-sub-groups"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups, [], name, value)


                                class UpdateGenerationSubGroup(Entity):
                                    """
                                    Update generation for sub\-group
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: creation_timestamp
                                    
                                    	Creation time
                                    	**type**\:  :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                    
                                    .. attribute:: last_merge_timestamp
                                    
                                    	Last merge time
                                    	**type**\:  :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                    
                                    .. attribute:: first_update_walk_start_timestamp
                                    
                                    	First update walk start time
                                    	**type**\:  :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: first_update_walk_end_timestamp
                                    
                                    	First update walk end time
                                    	**type**\:  :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: last_update_walk_start_timestamp
                                    
                                    	Last update walk start time
                                    	**type**\:  :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: last_update_walk_end_timestamp
                                    
                                    	Last update walk end time
                                    	**type**\:  :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:  :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_sub_group
                                    
                                    	Current update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_sub_group
                                    
                                    	Configured update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is update throttled
                                    	**type**\: bool
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_version
                                    
                                    	NSR version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_resume_version
                                    
                                    	Next resume version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_write_event_pending
                                    
                                    	Is IO write event pending
                                    	**type**\: bool
                                    
                                    .. attribute:: update_default_route_sent
                                    
                                    	Is default route sent
                                    	**type**\: bool
                                    
                                    .. attribute:: merge_count
                                    
                                    	Merge count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_merged_sub_group_index
                                    
                                    	Last merged sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_attempted
                                    
                                    	Sending EoR has been attempted
                                    	**type**\: bool
                                    
                                    .. attribute:: last_update_walk_end_age
                                    
                                    	Time since last update walk end event
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, self).__init__()

                                        self.yang_name = "update-generation-sub-group"
                                        self.yang_parent_name = "update-generation-sub-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("creation-timestamp", ("creation_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp)), ("last-merge-timestamp", ("last_merge_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp)), ("first-update-walk-start-timestamp", ("first_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp)), ("first-update-walk-end-timestamp", ("first_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp)), ("last-update-walk-start-timestamp", ("last_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp)), ("last-update-walk-end-timestamp", ("last_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp)), ("last-update-queued-timestamp", ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics))])
                                        self._leafs = OrderedDict([
                                            ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                            ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                            ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                            ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                            ('sub_group_id_xr', (YLeaf(YType.uint32, 'sub-group-id-xr'), ['int'])),
                                            ('parent_sub_group_index', (YLeaf(YType.uint32, 'parent-sub-group-index'), ['int'])),
                                            ('parent_sub_group_id', (YLeaf(YType.uint32, 'parent-sub-group-id'), ['int'])),
                                            ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                            ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                            ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                            ('current_update_limit_sub_group', (YLeaf(YType.uint32, 'current-update-limit-sub-group'), ['int'])),
                                            ('configured_update_limit_sub_group', (YLeaf(YType.uint32, 'configured-update-limit-sub-group'), ['int'])),
                                            ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                            ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                            ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                                            ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                            ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                            ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                            ('nsr_version', (YLeaf(YType.uint32, 'nsr-version'), ['int'])),
                                            ('pending_target_version', (YLeaf(YType.uint32, 'pending-target-version'), ['int'])),
                                            ('next_resume_version', (YLeaf(YType.uint32, 'next-resume-version'), ['int'])),
                                            ('update_refresh_target_version', (YLeaf(YType.uint32, 'update-refresh-target-version'), ['int'])),
                                            ('io_write_event_pending', (YLeaf(YType.boolean, 'io-write-event-pending'), ['bool'])),
                                            ('update_default_route_sent', (YLeaf(YType.boolean, 'update-default-route-sent'), ['bool'])),
                                            ('merge_count', (YLeaf(YType.uint32, 'merge-count'), ['int'])),
                                            ('last_merged_sub_group_index', (YLeaf(YType.uint32, 'last-merged-sub-group-index'), ['int'])),
                                            ('eo_r_attempted', (YLeaf(YType.boolean, 'eo-r-attempted'), ['bool'])),
                                            ('last_update_walk_end_age', (YLeaf(YType.uint32, 'last-update-walk-end-age'), ['int'])),
                                            ('last_update_queued_age', (YLeaf(YType.uint32, 'last-update-queued-age'), ['int'])),
                                        ])
                                        self.update_group_index = None
                                        self.sub_group_index = None
                                        self.sub_group_id = None
                                        self.process_id = None
                                        self.update_vrf_name = None
                                        self.update_group_af_name = None
                                        self.sub_group_index_xr = None
                                        self.sub_group_id_xr = None
                                        self.parent_sub_group_index = None
                                        self.parent_sub_group_id = None
                                        self.update_group_index_xr = None
                                        self.update_main_table_version = None
                                        self.update_vrf_table_rib_version = None
                                        self.current_update_limit_sub_group = None
                                        self.configured_update_limit_sub_group = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_throttled = None
                                        self.refresh_sub_group_count = None
                                        self.filter_group_count = None
                                        self.neighbor_count = None
                                        self.version = None
                                        self.nsr_version = None
                                        self.pending_target_version = None
                                        self.next_resume_version = None
                                        self.update_refresh_target_version = None
                                        self.io_write_event_pending = None
                                        self.update_default_route_sent = None
                                        self.merge_count = None
                                        self.last_merged_sub_group_index = None
                                        self.eo_r_attempted = None
                                        self.last_update_walk_end_age = None
                                        self.last_update_queued_age = None

                                        self.creation_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                        self.creation_timestamp.parent = self
                                        self._children_name_map["creation_timestamp"] = "creation-timestamp"

                                        self.last_merge_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                        self.last_merge_timestamp.parent = self
                                        self._children_name_map["last_merge_timestamp"] = "last-merge-timestamp"

                                        self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                        self.first_update_walk_start_timestamp.parent = self
                                        self._children_name_map["first_update_walk_start_timestamp"] = "first-update-walk-start-timestamp"

                                        self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                        self.first_update_walk_end_timestamp.parent = self
                                        self._children_name_map["first_update_walk_end_timestamp"] = "first-update-walk-end-timestamp"

                                        self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                        self.last_update_walk_start_timestamp.parent = self
                                        self._children_name_map["last_update_walk_start_timestamp"] = "last-update-walk-start-timestamp"

                                        self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                        self.last_update_walk_end_timestamp.parent = self
                                        self._children_name_map["last_update_walk_end_timestamp"] = "last-update-walk-end-timestamp"

                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"

                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._segment_path = lambda: "update-generation-sub-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, ['update_group_index', 'sub_group_index', 'sub_group_id', u'process_id', u'update_vrf_name', u'update_group_af_name', u'sub_group_index_xr', u'sub_group_id_xr', u'parent_sub_group_index', u'parent_sub_group_id', u'update_group_index_xr', u'update_main_table_version', u'update_vrf_table_rib_version', u'current_update_limit_sub_group', u'configured_update_limit_sub_group', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled', u'refresh_sub_group_count', u'filter_group_count', u'neighbor_count', u'version', u'nsr_version', u'pending_target_version', u'next_resume_version', u'update_refresh_target_version', u'io_write_event_pending', u'update_default_route_sent', u'merge_count', u'last_merged_sub_group_index', u'eo_r_attempted', u'last_update_walk_end_age', u'last_update_queued_age'], name, value)


                                    class CreationTimestamp(Entity):
                                        """
                                        Creation time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, self).__init__()

                                            self.yang_name = "creation-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "creation-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastMergeTimestamp(Entity):
                                        """
                                        Last merge time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, self).__init__()

                                            self.yang_name = "last-merge-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-merge-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstUpdateWalkStartTimestamp(Entity):
                                        """
                                        First update walk start time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, self).__init__()

                                            self.yang_name = "first-update-walk-start-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-update-walk-start-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstUpdateWalkEndTimestamp(Entity):
                                        """
                                        First update walk end time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, self).__init__()

                                            self.yang_name = "first-update-walk-end-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-update-walk-end-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateWalkStartTimestamp(Entity):
                                        """
                                        Last update walk start time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-walk-start-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-walk-start-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateWalkEndTimestamp(Entity):
                                        """
                                        Last update walk end time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, self).__init__()

                                            self.yang_name = "last-update-walk-end-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-walk-end-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateQueuedTimestamp(Entity):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-queued-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                            ])
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_size_high = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_cleared = None
                                            self.last_update_discard_age = None
                                            self.last_update_cleard_age = None
                                            self.update_throttle_count = None
                                            self.last_update_throttle_age = None
                                            self.update_recovery_count = None
                                            self.last_update_recovery_age = None
                                            self.update_memory_allocation_fail_count = None
                                            self.last_update_memory_allocation_fail_age = None

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._segment_path = lambda: "update-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-discard-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-cleared-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-throttle-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-recovery-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class NextHopAddressFamilies(Entity):
                                """
                                Address family of nexthop table
                                
                                .. attribute:: next_hop_address_family
                                
                                	Nexthop Address family
                                	**type**\: list of  		 :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies, self).__init__()

                                    self.yang_name = "next-hop-address-families"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("next-hop-address-family", ("next_hop_address_family", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily))])
                                    self._leafs = OrderedDict()

                                    self.next_hop_address_family = YList(self)
                                    self._segment_path = lambda: "next-hop-address-families"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies, [], name, value)


                                class NextHopAddressFamily(Entity):
                                    """
                                    Nexthop Address family
                                    
                                    .. attribute:: next_hop_af_name  (key)
                                    
                                    	Address family
                                    	**type**\:  :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                    
                                    .. attribute:: next_hop_af_vrf_af
                                    
                                    	A BGP Next\-hop VRF AF table entry
                                    	**type**\:  :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                    
                                    .. attribute:: next_hop_afs
                                    
                                    	The BGP Next\-hop table
                                    	**type**\:  :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, self).__init__()

                                        self.yang_name = "next-hop-address-family"
                                        self.yang_parent_name = "next-hop-address-families"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['next_hop_af_name']
                                        self._child_classes = OrderedDict([("next-hop-af-vrf-af", ("next_hop_af_vrf_af", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf)), ("next-hop-afs", ("next_hop_afs", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs))])
                                        self._leafs = OrderedDict([
                                            ('next_hop_af_name', (YLeaf(YType.enumeration, 'next-hop-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes', 'BgpAddressFamily', '')])),
                                        ])
                                        self.next_hop_af_name = None

                                        self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                        self.next_hop_af_vrf_af.parent = self
                                        self._children_name_map["next_hop_af_vrf_af"] = "next-hop-af-vrf-af"

                                        self.next_hop_afs = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                        self.next_hop_afs.parent = self
                                        self._children_name_map["next_hop_afs"] = "next-hop-afs"
                                        self._segment_path = lambda: "next-hop-address-family" + "[next-hop-af-name='" + str(self.next_hop_af_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, ['next_hop_af_name'], name, value)


                                    class NextHopAfVrfAf(Entity):
                                        """
                                        A BGP Next\-hop VRF AF table entry
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: gwaf_name
                                        
                                        	GW Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: total_nexthops
                                        
                                        	Total number of nexthops
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: critical_trigger_delay
                                        
                                        	Trigger delay for critical event processing
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: non_critical_trigger_delay
                                        
                                        	Trigger delay for non\-critical event processing
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_active
                                        
                                        	Whether the VRF is active
                                        	**type**\: bool
                                        
                                        .. attribute:: nh_rib_up
                                        
                                        	Whether the VRF is active
                                        	**type**\: bool
                                        
                                        .. attribute:: nh_rib_version
                                        
                                        	RIB version for gw\_ctx
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_nexthop_version
                                        
                                        	NH version for gw\_ctx
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_table_id
                                        
                                        	Gateway context table id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_table_version
                                        
                                        	Version of the EPE table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_label_version
                                        
                                        	Version of the EPE label walk
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_downloaded_version
                                        
                                        	Version of the EPE table downloaded
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_standby_version
                                        
                                        	Version of the EPE table processed by sync thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, self).__init__()

                                            self.yang_name = "next-hop-af-vrf-af"
                                            self.yang_parent_name = "next-hop-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics))])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('gwaf_name', (YLeaf(YType.enumeration, 'gwaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('total_nexthops', (YLeaf(YType.uint32, 'total-nexthops'), ['int'])),
                                                ('critical_trigger_delay', (YLeaf(YType.uint32, 'critical-trigger-delay'), ['int'])),
                                                ('non_critical_trigger_delay', (YLeaf(YType.uint32, 'non-critical-trigger-delay'), ['int'])),
                                                ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                                                ('nh_rib_up', (YLeaf(YType.boolean, 'nh-rib-up'), ['bool'])),
                                                ('nh_rib_version', (YLeaf(YType.uint32, 'nh-rib-version'), ['int'])),
                                                ('nh_nexthop_version', (YLeaf(YType.uint32, 'nh-nexthop-version'), ['int'])),
                                                ('nh_table_id', (YLeaf(YType.uint32, 'nh-table-id'), ['int'])),
                                                ('epe_table_version', (YLeaf(YType.uint32, 'epe-table-version'), ['int'])),
                                                ('epe_label_version', (YLeaf(YType.uint32, 'epe-label-version'), ['int'])),
                                                ('epe_downloaded_version', (YLeaf(YType.uint32, 'epe-downloaded-version'), ['int'])),
                                                ('epe_standby_version', (YLeaf(YType.uint32, 'epe-standby-version'), ['int'])),
                                            ])
                                            self.af_name = None
                                            self.gwaf_name = None
                                            self.total_nexthops = None
                                            self.critical_trigger_delay = None
                                            self.non_critical_trigger_delay = None
                                            self.table_active = None
                                            self.nh_rib_up = None
                                            self.nh_rib_version = None
                                            self.nh_nexthop_version = None
                                            self.nh_table_id = None
                                            self.epe_table_version = None
                                            self.epe_label_version = None
                                            self.epe_downloaded_version = None
                                            self.epe_standby_version = None

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"
                                            self._segment_path = lambda: "next-hop-af-vrf-af"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, [u'af_name', u'gwaf_name', u'total_nexthops', u'critical_trigger_delay', u'non_critical_trigger_delay', u'table_active', u'nh_rib_up', u'nh_rib_version', u'nh_nexthop_version', u'nh_table_id', u'epe_table_version', u'epe_label_version', u'epe_downloaded_version', u'epe_standby_version'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: critical_notf_count
                                            
                                            	Number of critical event notifications from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: noncritical_notf_count
                                            
                                            	Number of non\-critical event notifications from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_deletes
                                            
                                            	Number of bestpath deletes due to last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_changes
                                            
                                            	Number of bestpath changes due to last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_sync_reg_calls
                                            
                                            	NH sync register calls
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_reg_calls
                                            
                                            	NH async register calls
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_un_reg_calls
                                            
                                            	NH async unregister calls
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_pending_registrations
                                            
                                            	NH Registration List Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_peak_registrations
                                            
                                            	NH Registration List Count Peak
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_batch_finish_calls
                                            
                                            	NH batch finish calls
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_flush_timer_calls
                                            
                                            	NH flush timer calls
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_sync_reg_ts
                                            
                                            	NH Last sync Register TS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_reg_ts
                                            
                                            	NH Last async Register TS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_un_reg_ts
                                            
                                            	NH Last async UnRegister TS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_batch_finish_ts
                                            
                                            	NH Last batch finish TS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_flush_timer_ts
                                            
                                            	NH Last flush timer TS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: nexthops_sent_to_rib
                                            
                                            	No. of nexthops sent to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_resent_to_rib
                                            
                                            	No. of nexthops re\-sent to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_removed_from_rib
                                            
                                            	No. of nexthops withdrawn from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_sync_registers_failed
                                            
                                            	No. of sync registers with RIB that failed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: riba_sync_registers_failed
                                            
                                            	No. of async registers with RIB that failed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                            
                                            	No. of nh registers failed because of no tbl\-id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                            
                                            	No. of nh registers failed because of no rib conn
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_nh_not_found
                                            
                                            	No. of times nexthop was not found during tunnel walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_gw_not_found
                                            
                                            	No. of times gw was not found during tunnel walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_backup_creates
                                            
                                            	No. of times backup tid created during tunnel walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "next-hop-af-vrf-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('critical_notf_count', (YLeaf(YType.uint32, 'critical-notf-count'), ['int'])),
                                                    ('noncritical_notf_count', (YLeaf(YType.uint32, 'noncritical-notf-count'), ['int'])),
                                                    ('last_notf_bestpath_deletes', (YLeaf(YType.uint32, 'last-notf-bestpath-deletes'), ['int'])),
                                                    ('last_notf_bestpath_changes', (YLeaf(YType.uint32, 'last-notf-bestpath-changes'), ['int'])),
                                                    ('nh_sync_reg_calls', (YLeaf(YType.uint32, 'nh-sync-reg-calls'), ['int'])),
                                                    ('nha_sync_reg_calls', (YLeaf(YType.uint32, 'nha-sync-reg-calls'), ['int'])),
                                                    ('nha_sync_un_reg_calls', (YLeaf(YType.uint32, 'nha-sync-un-reg-calls'), ['int'])),
                                                    ('nh_pending_registrations', (YLeaf(YType.uint32, 'nh-pending-registrations'), ['int'])),
                                                    ('nh_peak_registrations', (YLeaf(YType.uint32, 'nh-peak-registrations'), ['int'])),
                                                    ('nh_batch_finish_calls', (YLeaf(YType.uint32, 'nh-batch-finish-calls'), ['int'])),
                                                    ('nh_flush_timer_calls', (YLeaf(YType.uint32, 'nh-flush-timer-calls'), ['int'])),
                                                    ('nh_last_sync_reg_ts', (YLeaf(YType.uint32, 'nh-last-sync-reg-ts'), ['int'])),
                                                    ('nh_last_a_sync_reg_ts', (YLeaf(YType.uint32, 'nh-last-a-sync-reg-ts'), ['int'])),
                                                    ('nh_last_a_sync_un_reg_ts', (YLeaf(YType.uint32, 'nh-last-a-sync-un-reg-ts'), ['int'])),
                                                    ('nh_last_batch_finish_ts', (YLeaf(YType.uint32, 'nh-last-batch-finish-ts'), ['int'])),
                                                    ('nh_last_flush_timer_ts', (YLeaf(YType.uint32, 'nh-last-flush-timer-ts'), ['int'])),
                                                    ('nhrib_update_calls', (YLeaf(YType.uint32, 'nhrib-update-calls'), ['int'])),
                                                    ('nhrib_update_time', (YLeaf(YType.uint32, 'nhrib-update-time'), ['int'])),
                                                    ('nexthops_sent_to_rib', (YLeaf(YType.uint32, 'nexthops-sent-to-rib'), ['int'])),
                                                    ('nexthops_resent_to_rib', (YLeaf(YType.uint32, 'nexthops-resent-to-rib'), ['int'])),
                                                    ('nexthops_removed_from_rib', (YLeaf(YType.uint32, 'nexthops-removed-from-rib'), ['int'])),
                                                    ('rib_sync_registers_failed', (YLeaf(YType.uint32, 'rib-sync-registers-failed'), ['int'])),
                                                    ('riba_sync_registers_failed', (YLeaf(YType.uint32, 'riba-sync-registers-failed'), ['int'])),
                                                    ('ribnh_reg_failed_for_no_tbl_id', (YLeaf(YType.uint32, 'ribnh-reg-failed-for-no-tbl-id'), ['int'])),
                                                    ('ribnh_reg_failed_for_no_rib_conn', (YLeaf(YType.uint32, 'ribnh-reg-failed-for-no-rib-conn'), ['int'])),
                                                    ('tunnel_walk_nh_not_found', (YLeaf(YType.uint32, 'tunnel-walk-nh-not-found'), ['int'])),
                                                    ('tunnel_walk_gw_not_found', (YLeaf(YType.uint32, 'tunnel-walk-gw-not-found'), ['int'])),
                                                    ('tunnel_walk_backup_creates', (YLeaf(YType.uint32, 'tunnel-walk-backup-creates'), ['int'])),
                                                ])
                                                self.critical_notf_count = None
                                                self.noncritical_notf_count = None
                                                self.last_notf_bestpath_deletes = None
                                                self.last_notf_bestpath_changes = None
                                                self.nh_sync_reg_calls = None
                                                self.nha_sync_reg_calls = None
                                                self.nha_sync_un_reg_calls = None
                                                self.nh_pending_registrations = None
                                                self.nh_peak_registrations = None
                                                self.nh_batch_finish_calls = None
                                                self.nh_flush_timer_calls = None
                                                self.nh_last_sync_reg_ts = None
                                                self.nh_last_a_sync_reg_ts = None
                                                self.nh_last_a_sync_un_reg_ts = None
                                                self.nh_last_batch_finish_ts = None
                                                self.nh_last_flush_timer_ts = None
                                                self.nhrib_update_calls = None
                                                self.nhrib_update_time = None
                                                self.nexthops_sent_to_rib = None
                                                self.nexthops_resent_to_rib = None
                                                self.nexthops_removed_from_rib = None
                                                self.rib_sync_registers_failed = None
                                                self.riba_sync_registers_failed = None
                                                self.ribnh_reg_failed_for_no_tbl_id = None
                                                self.ribnh_reg_failed_for_no_rib_conn = None
                                                self.tunnel_walk_nh_not_found = None
                                                self.tunnel_walk_gw_not_found = None
                                                self.tunnel_walk_backup_creates = None
                                                self._segment_path = lambda: "performance-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, [u'critical_notf_count', u'noncritical_notf_count', u'last_notf_bestpath_deletes', u'last_notf_bestpath_changes', u'nh_sync_reg_calls', u'nha_sync_reg_calls', u'nha_sync_un_reg_calls', u'nh_pending_registrations', u'nh_peak_registrations', u'nh_batch_finish_calls', u'nh_flush_timer_calls', u'nh_last_sync_reg_ts', u'nh_last_a_sync_reg_ts', u'nh_last_a_sync_un_reg_ts', u'nh_last_batch_finish_ts', u'nh_last_flush_timer_ts', u'nhrib_update_calls', u'nhrib_update_time', u'nexthops_sent_to_rib', u'nexthops_resent_to_rib', u'nexthops_removed_from_rib', u'rib_sync_registers_failed', u'riba_sync_registers_failed', u'ribnh_reg_failed_for_no_tbl_id', u'ribnh_reg_failed_for_no_rib_conn', u'tunnel_walk_nh_not_found', u'tunnel_walk_gw_not_found', u'tunnel_walk_backup_creates'], name, value)


                                    class NextHopAfs(Entity):
                                        """
                                        The BGP Next\-hop table
                                        
                                        .. attribute:: next_hop_af
                                        
                                        	A BGP Next hop entry
                                        	**type**\: list of  		 :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, self).__init__()

                                            self.yang_name = "next-hop-afs"
                                            self.yang_parent_name = "next-hop-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop-af", ("next_hop_af", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf))])
                                            self._leafs = OrderedDict()

                                            self.next_hop_af = YList(self)
                                            self._segment_path = lambda: "next-hop-afs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, [], name, value)


                                        class NextHopAf(Entity):
                                            """
                                            A BGP Next hop entry
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_set
                                            
                                            	Attribute Set Name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: nexthop_address
                                            
                                            	Nexthop address
                                            	**type**\:  :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel>`
                                            
                                            .. attribute:: nexthop_internal_info
                                            
                                            	Internal nexthop info
                                            	**type**\:  :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: rib_nexthop_id
                                            
                                            	RIB Nexthop Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_pending_registration
                                            
                                            	Nexthop registration is pending
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nexthop_reference_count
                                            
                                            	Number of neighbors/prefixes referencing this nexthop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_reference_count_total
                                            
                                            	Number of neighbors/prefixes referencing this nexthop (AFs)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_first_hop_if_handle
                                            
                                            	First\-hop interface handle
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: nexthop_aigp_metric
                                            
                                            	AIGP metrice of nexthop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_reachable
                                            
                                            	Is Gateway reachable ?
                                            	**type**\: bool
                                            
                                            .. attribute:: nexthop_gateway_prefix_connected
                                            
                                            	Is Gateway resolved through Connected route ?
                                            	**type**\: bool
                                            
                                            .. attribute:: nexthop_gateway_prefix_length
                                            
                                            	Gateway prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_info
                                            
                                            	Gateway related info, includingOptimal Route Reflector Gateways
                                            	**type**\: list of  		 :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address List
                                            	**type**\: list of  		 :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, self).__init__()

                                                self.yang_name = "next-hop-af"
                                                self.yang_parent_name = "next-hop-afs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nexthop-address", ("nexthop_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel)), ("nexthop-internal-info", ("nexthop_internal_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo)), ("nexthop-gateway-info", ("nexthop_gateway_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('attribute_set', (YLeaf(YType.str, 'attribute-set'), ['str'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('rib_nexthop_id', (YLeaf(YType.uint32, 'rib-nexthop-id'), ['int'])),
                                                    ('nexthop_pending_registration', (YLeaf(YType.uint8, 'nexthop-pending-registration'), ['int'])),
                                                    ('nexthop_reference_count', (YLeaf(YType.uint32, 'nexthop-reference-count'), ['int'])),
                                                    ('nh_reference_count_total', (YLeaf(YType.uint32, 'nh-reference-count-total'), ['int'])),
                                                    ('nh_first_hop_if_handle', (YLeaf(YType.str, 'nh-first-hop-if-handle'), ['str'])),
                                                    ('nexthop_aigp_metric', (YLeaf(YType.uint32, 'nexthop-aigp-metric'), ['int'])),
                                                    ('nexthop_gateway_reachable', (YLeaf(YType.boolean, 'nexthop-gateway-reachable'), ['bool'])),
                                                    ('nexthop_gateway_prefix_connected', (YLeaf(YType.boolean, 'nexthop-gateway-prefix-connected'), ['bool'])),
                                                    ('nexthop_gateway_prefix_length', (YLeaf(YType.uint32, 'nexthop-gateway-prefix-length'), ['int'])),
                                                ])
                                                self.next_hop_address = None
                                                self.attribute_set = None
                                                self.af_name = None
                                                self.rib_nexthop_id = None
                                                self.nexthop_pending_registration = None
                                                self.nexthop_reference_count = None
                                                self.nh_reference_count_total = None
                                                self.nh_first_hop_if_handle = None
                                                self.nexthop_aigp_metric = None
                                                self.nexthop_gateway_reachable = None
                                                self.nexthop_gateway_prefix_connected = None
                                                self.nexthop_gateway_prefix_length = None

                                                self.nexthop_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                self.nexthop_address.parent = self
                                                self._children_name_map["nexthop_address"] = "nexthop-address"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.nexthop_internal_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                self.nexthop_internal_info.parent = self
                                                self._children_name_map["nexthop_internal_info"] = "nexthop-internal-info"

                                                self.nexthop_gateway_info = YList(self)
                                                self.neighbor_address = YList(self)
                                                self._segment_path = lambda: "next-hop-af"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, ['next_hop_address', 'attribute_set', u'af_name', u'rib_nexthop_id', u'nexthop_pending_registration', u'nexthop_reference_count', u'nh_reference_count_total', u'nh_first_hop_if_handle', u'nexthop_aigp_metric', u'nexthop_gateway_reachable', u'nexthop_gateway_prefix_connected', u'nexthop_gateway_prefix_length'], name, value)


                                            class NexthopAddress(Entity):
                                                """
                                                Nexthop address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, self).__init__()

                                                    self.yang_name = "nexthop-address"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "nexthop-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class NexthopInternalInfo(Entity):
                                                """
                                                Internal nexthop info
                                                
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:  :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                
                                                .. attribute:: nexthop_id
                                                
                                                	Comm librray ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_version
                                                
                                                	Table version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_flags
                                                
                                                	Nexthop flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_if_handle
                                                
                                                	Nexthop ifhandle
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_af_user_bits
                                                
                                                	Bitmask indicating the AFs which share the nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_label
                                                
                                                	Nexthop label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: gateway_flags
                                                
                                                	Gateway flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_metrice
                                                
                                                	Nexthop metrices
                                                	**type**\: list of  		 :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                
                                                .. attribute:: nexthop_refcount
                                                
                                                	Nexthop refcounts
                                                	**type**\: list of  		 :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                
                                                .. attribute:: nexthop_gateway_internal_info
                                                
                                                	Internal nexthop Gateway info
                                                	**type**\: list of  		 :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, self).__init__()

                                                    self.yang_name = "nexthop-internal-info"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nexthop-address", ("nexthop_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress)), ("nexthop-metrice", ("nexthop_metrice", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice)), ("nexthop-refcount", ("nexthop_refcount", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount)), ("nexthop-gateway-internal-info", ("nexthop_gateway_internal_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo))])
                                                    self._leafs = OrderedDict([
                                                        ('nexthop_id', (YLeaf(YType.uint32, 'nexthop-id'), ['int'])),
                                                        ('nexthop_version', (YLeaf(YType.uint32, 'nexthop-version'), ['int'])),
                                                        ('nexthop_flags', (YLeaf(YType.uint32, 'nexthop-flags'), ['int'])),
                                                        ('nexthop_if_handle', (YLeaf(YType.uint32, 'nexthop-if-handle'), ['int'])),
                                                        ('nexthop_af_user_bits', (YLeaf(YType.uint32, 'nexthop-af-user-bits'), ['int'])),
                                                        ('nexthop_label', (YLeaf(YType.uint32, 'nexthop-label'), ['int'])),
                                                        ('gateway_flags', (YLeaf(YType.uint32, 'gateway-flags'), ['int'])),
                                                    ])
                                                    self.nexthop_id = None
                                                    self.nexthop_version = None
                                                    self.nexthop_flags = None
                                                    self.nexthop_if_handle = None
                                                    self.nexthop_af_user_bits = None
                                                    self.nexthop_label = None
                                                    self.gateway_flags = None

                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self._children_name_map["nexthop_address"] = "nexthop-address"

                                                    self.nexthop_metrice = YList(self)
                                                    self.nexthop_refcount = YList(self)
                                                    self.nexthop_gateway_internal_info = YList(self)
                                                    self._segment_path = lambda: "nexthop-internal-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, [u'nexthop_id', u'nexthop_version', u'nexthop_flags', u'nexthop_if_handle', u'nexthop_af_user_bits', u'nexthop_label', u'gateway_flags'], name, value)


                                                class NexthopAddress(Entity):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, self).__init__()

                                                        self.yang_name = "nexthop-address"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "nexthop-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NexthopMetrice(Entity):
                                                    """
                                                    Nexthop metrices
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, self).__init__()

                                                        self.yang_name = "nexthop-metrice"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "nexthop-metrice"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, [u'entry'], name, value)


                                                class NexthopRefcount(Entity):
                                                    """
                                                    Nexthop refcounts
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, self).__init__()

                                                        self.yang_name = "nexthop-refcount"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "nexthop-refcount"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, [u'entry'], name, value)


                                                class NexthopGatewayInternalInfo(Entity):
                                                    """
                                                    Internal nexthop Gateway info
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: registration_type
                                                    
                                                    	Nexthop registration type
                                                    	**type**\:  :py:class:`BgpNhValidate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidate>`
                                                    
                                                    .. attribute:: registration_since
                                                    
                                                    	Time since registration
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, self).__init__()

                                                        self.yang_name = "nexthop-gateway-internal-info"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('gateway_flags', (YLeaf(YType.uint32, 'gateway-flags'), ['int'])),
                                                            ('registration_type', (YLeaf(YType.enumeration, 'registration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhValidate', '')])),
                                                            ('registration_since', (YLeaf(YType.uint32, 'registration-since'), ['int'])),
                                                        ])
                                                        self.gateway_flags = None
                                                        self.registration_type = None
                                                        self.registration_since = None
                                                        self._segment_path = lambda: "nexthop-gateway-internal-info"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, [u'gateway_flags', u'registration_type', u'registration_since'], name, value)


                                            class NexthopGatewayInfo(Entity):
                                                """
                                                Gateway related info, includingOptimal Route
                                                Reflector Gateways
                                                
                                                .. attribute:: nexthop_route
                                                
                                                	Route resolving the nethop
                                                	**type**\:  :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                
                                                .. attribute:: nexthop_route_prefix_length
                                                
                                                	Prefix length of the route resolving the nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_route_protocol
                                                
                                                	Protocol that resolves the route to the nexthop
                                                	**type**\: str
                                                
                                                .. attribute:: nexthop_route_path_count
                                                
                                                	Number of paths in the resolving route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_af_invalid_bits
                                                
                                                	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: nexthop_status
                                                
                                                	Nexthop status
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_tableid
                                                
                                                	Nexthop Table id
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: nexthop_metric
                                                
                                                	IGP metric for nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_type
                                                
                                                	Last nexthop event type
                                                	**type**\:  :py:class:`BgpNhEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEvent>`
                                                
                                                .. attribute:: last_update_type
                                                
                                                	Last nexthop update type
                                                	**type**\:  :py:class:`BgpNhUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdate>`
                                                
                                                .. attribute:: critical_events
                                                
                                                	Number of critical events received from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: non_critical_events
                                                
                                                	Number of non\-critical events received from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_since
                                                
                                                	Time since the last event sent to or received from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_rib_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_enabled
                                                
                                                	TRUE if MPLS is configured for IAS/CsC application
                                                	**type**\: bool
                                                
                                                .. attribute:: nexthop_mpls_interfaces
                                                
                                                	Number of interfaces on which MPLS is enabled
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_label
                                                
                                                	Local label allocated for IAS/CsC application
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_route_path
                                                
                                                	Nexthops of the resolving route
                                                	**type**\: list of  		 :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, self).__init__()

                                                    self.yang_name = "nexthop-gateway-info"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nexthop-route", ("nexthop_route", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute)), ("nexthop-route-path", ("nexthop_route_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath))])
                                                    self._leafs = OrderedDict([
                                                        ('nexthop_route_prefix_length', (YLeaf(YType.uint8, 'nexthop-route-prefix-length'), ['int'])),
                                                        ('nexthop_route_protocol', (YLeaf(YType.str, 'nexthop-route-protocol'), ['str'])),
                                                        ('nexthop_route_path_count', (YLeaf(YType.uint32, 'nexthop-route-path-count'), ['int'])),
                                                        ('nexthop_af_invalid_bits', (YLeaf(YType.uint16, 'nexthop-af-invalid-bits'), ['int'])),
                                                        ('nexthop_status', (YLeaf(YType.uint8, 'nexthop-status'), ['int'])),
                                                        ('nexthop_tableid', (YLeaf(YType.uint64, 'nexthop-tableid'), ['int'])),
                                                        ('nexthop_metric', (YLeaf(YType.uint32, 'nexthop-metric'), ['int'])),
                                                        ('last_event_type', (YLeaf(YType.enumeration, 'last-event-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhEvent', '')])),
                                                        ('last_update_type', (YLeaf(YType.enumeration, 'last-update-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhUpdate', '')])),
                                                        ('critical_events', (YLeaf(YType.uint32, 'critical-events'), ['int'])),
                                                        ('non_critical_events', (YLeaf(YType.uint32, 'non-critical-events'), ['int'])),
                                                        ('last_event_since', (YLeaf(YType.uint32, 'last-event-since'), ['int'])),
                                                        ('last_rib_update', (YLeaf(YType.uint32, 'last-rib-update'), ['int'])),
                                                        ('nexthop_mpls_enabled', (YLeaf(YType.boolean, 'nexthop-mpls-enabled'), ['bool'])),
                                                        ('nexthop_mpls_interfaces', (YLeaf(YType.uint32, 'nexthop-mpls-interfaces'), ['int'])),
                                                        ('nexthop_mpls_label', (YLeaf(YType.uint32, 'nexthop-mpls-label'), ['int'])),
                                                    ])
                                                    self.nexthop_route_prefix_length = None
                                                    self.nexthop_route_protocol = None
                                                    self.nexthop_route_path_count = None
                                                    self.nexthop_af_invalid_bits = None
                                                    self.nexthop_status = None
                                                    self.nexthop_tableid = None
                                                    self.nexthop_metric = None
                                                    self.last_event_type = None
                                                    self.last_update_type = None
                                                    self.critical_events = None
                                                    self.non_critical_events = None
                                                    self.last_event_since = None
                                                    self.last_rib_update = None
                                                    self.nexthop_mpls_enabled = None
                                                    self.nexthop_mpls_interfaces = None
                                                    self.nexthop_mpls_label = None

                                                    self.nexthop_route = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                    self.nexthop_route.parent = self
                                                    self._children_name_map["nexthop_route"] = "nexthop-route"

                                                    self.nexthop_route_path = YList(self)
                                                    self._segment_path = lambda: "nexthop-gateway-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, [u'nexthop_route_prefix_length', u'nexthop_route_protocol', u'nexthop_route_path_count', u'nexthop_af_invalid_bits', u'nexthop_status', u'nexthop_tableid', u'nexthop_metric', u'last_event_type', u'last_update_type', u'critical_events', u'non_critical_events', u'last_event_since', u'last_rib_update', u'nexthop_mpls_enabled', u'nexthop_mpls_interfaces', u'nexthop_mpls_label'], name, value)


                                                class NexthopRoute(Entity):
                                                    """
                                                    Route resolving the nethop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, self).__init__()

                                                        self.yang_name = "nexthop-route"
                                                        self.yang_parent_name = "nexthop-gateway-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "nexthop-route"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NexthopRoutePath(Entity):
                                                    """
                                                    Nexthops of the resolving route
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, self).__init__()

                                                        self.yang_name = "nexthop-route-path"
                                                        self.yang_parent_name = "nexthop-gateway-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "nexthop-route-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address List
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class RtSetCounters(Entity):
                                """
                                The RT\-set counter table
                                
                                .. attribute:: rt_set_counter
                                
                                	One RT\-set counter table entry
                                	**type**\: list of  		 :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters, self).__init__()

                                    self.yang_name = "rt-set-counters"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rt-set-counter", ("rt_set_counter", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter))])
                                    self._leafs = OrderedDict()

                                    self.rt_set_counter = YList(self)
                                    self._segment_path = lambda: "rt-set-counters"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters, [], name, value)


                                class RtSetCounter(Entity):
                                    """
                                    One RT\-set counter table entry
                                    
                                    .. attribute:: rt_set_id  (key)
                                    
                                    	RTSet ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_target_set
                                    
                                    	Route Target set
                                    	**type**\:  :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter, self).__init__()

                                        self.yang_name = "rt-set-counter"
                                        self.yang_parent_name = "rt-set-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['rt_set_id']
                                        self._child_classes = OrderedDict([("route-target-set", ("route_target_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet))])
                                        self._leafs = OrderedDict([
                                            ('rt_set_id', (YLeaf(YType.uint32, 'rt-set-id'), ['int'])),
                                        ])
                                        self.rt_set_id = None

                                        self.route_target_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                        self.route_target_set.parent = self
                                        self._children_name_map["route_target_set"] = "route-target-set"
                                        self._segment_path = lambda: "rt-set-counter" + "[rt-set-id='" + str(self.rt_set_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter, ['rt_set_id'], name, value)


                                    class RouteTargetSet(Entity):
                                        """
                                        Route Target set
                                        
                                        .. attribute:: rt_set_len
                                        
                                        	Length in bytes of set of route targets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rt_set_id
                                        
                                        	Identifier of the rtset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rt_set_net_count
                                        
                                        	Count of nets with paths with the rtset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rt_set
                                        
                                        	Set of route targets
                                        	**type**\: list of  		 :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, self).__init__()

                                            self.yang_name = "route-target-set"
                                            self.yang_parent_name = "rt-set-counter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rt-set", ("rt_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet))])
                                            self._leafs = OrderedDict([
                                                ('rt_set_len', (YLeaf(YType.uint8, 'rt-set-len'), ['int'])),
                                                ('rt_set_id', (YLeaf(YType.uint32, 'rt-set-id'), ['int'])),
                                                ('rt_set_net_count', (YLeaf(YType.uint32, 'rt-set-net-count'), ['int'])),
                                            ])
                                            self.rt_set_len = None
                                            self.rt_set_id = None
                                            self.rt_set_net_count = None

                                            self.rt_set = YList(self)
                                            self._segment_path = lambda: "route-target-set"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, [u'rt_set_len', u'rt_set_id', u'rt_set_net_count'], name, value)


                                        class RtSet(Entity):
                                            """
                                            Set of route targets
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, self).__init__()

                                                self.yang_name = "rt-set"
                                                self.yang_parent_name = "route-target-set"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rt-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, [u'entry'], name, value)


                            class BmpPaths(Entity):
                                """
                                The paths in BMP Table
                                
                                .. attribute:: bmp_path
                                
                                	A BMP path table entry
                                	**type**\: list of  		 :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths, self).__init__()

                                    self.yang_name = "bmp-paths"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bmp-path", ("bmp_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath))])
                                    self._leafs = OrderedDict()

                                    self.bmp_path = YList(self)
                                    self._segment_path = lambda: "bmp-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths, [], name, value)


                                class BmpPath(Entity):
                                    """
                                    A BMP path table entry
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Net Version bump timestamp
                                    	**type**\:  :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                    
                                    .. attribute:: version_age
                                    
                                    	Net Version bump age
                                    	**type**\:  :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: bmp_net_flags
                                    
                                    	Flags associated with net
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_net_version
                                    
                                    	Net's version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for the net
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\: bool
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_path
                                    
                                    	List of paths under the BMP net
                                    	**type**\: list of  		 :py:class:`BmpPath_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath, self).__init__()

                                        self.yang_name = "bmp-path"
                                        self.yang_parent_name = "bmp-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix)), ("version-timestamp", ("version_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp)), ("version-age", ("version_age", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge)), ("bmp-path", ("bmp_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_))])
                                        self._leafs = OrderedDict([
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('bmp_net_flags', (YLeaf(YType.uint32, 'bmp-net-flags'), ['int'])),
                                            ('bmp_net_version', (YLeaf(YType.uint32, 'bmp-net-version'), ['int'])),
                                            ('num_of_path', (YLeaf(YType.uint32, 'num-of-path'), ['int'])),
                                            ('has_local_label', (YLeaf(YType.boolean, 'has-local-label'), ['bool'])),
                                            ('net_local_label', (YLeaf(YType.uint32, 'net-local-label'), ['int'])),
                                        ])
                                        self.network = None
                                        self.prefix_length = None
                                        self.af_name = None
                                        self.bmp_net_flags = None
                                        self.bmp_net_version = None
                                        self.num_of_path = None
                                        self.has_local_label = None
                                        self.net_local_label = None

                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                        self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self._children_name_map["version_timestamp"] = "version-timestamp"

                                        self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                        self.version_age.parent = self
                                        self._children_name_map["version_age"] = "version-age"

                                        self.bmp_path = YList(self)
                                        self._segment_path = lambda: "bmp-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath, ['network', 'prefix_length', u'af_name', u'bmp_net_flags', u'bmp_net_version', u'num_of_path', u'has_local_label', u'net_local_label'], name, value)


                                    class BgpPrefix(Entity):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, self).__init__()

                                            self.yang_name = "bgp-prefix"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix_length = None

                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._segment_path = lambda: "bgp-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, [u'prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bgp-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class VersionTimestamp(Entity):
                                        """
                                        Net Version bump timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, self).__init__()

                                            self.yang_name = "version-timestamp"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class VersionAge(Entity):
                                        """
                                        Net Version bump age
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge, self).__init__()

                                            self.yang_name = "version-age"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-age"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge, [u'seconds', u'nanoseconds'], name, value)


                                    class BmpPath_(Entity):
                                        """
                                        List of paths under the BMP net
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress>`
                                        
                                        .. attribute:: bmp_path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_adv_bit_map
                                        
                                        	Path's Adv bit map
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bmp_path_snd_bit_map
                                        
                                        	Path's pending snd bit map
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bmp_nbr_bit_map
                                        
                                        	Paths Nbr bmp bit map
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path
                                        
                                        	Is path originated locally?
                                        	**type**\: bool
                                        
                                        .. attribute:: bpath_pointer
                                        
                                        	BGP Path pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: received_label
                                        
                                        	Set of received label stack
                                        	**type**\: list of  		 :py:class:`ReceivedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_, self).__init__()

                                            self.yang_name = "bmp-path"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress)), ("received-label", ("received_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel))])
                                            self._leafs = OrderedDict([
                                                ('bmp_path_flags', (YLeaf(YType.uint32, 'bmp-path-flags'), ['int'])),
                                                ('bmp_path_adv_bit_map', (YLeaf(YType.uint16, 'bmp-path-adv-bit-map'), ['int'])),
                                                ('bmp_path_snd_bit_map', (YLeaf(YType.uint16, 'bmp-path-snd-bit-map'), ['int'])),
                                                ('bmp_nbr_bit_map', (YLeaf(YType.uint32, 'bmp-nbr-bit-map'), ['int'])),
                                                ('local_path', (YLeaf(YType.boolean, 'local-path'), ['bool'])),
                                                ('bpath_pointer', (YLeaf(YType.uint64, 'bpath-pointer'), ['int'])),
                                            ])
                                            self.bmp_path_flags = None
                                            self.bmp_path_adv_bit_map = None
                                            self.bmp_path_snd_bit_map = None
                                            self.bmp_nbr_bit_map = None
                                            self.local_path = None
                                            self.bpath_pointer = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.received_label = YList(self)
                                            self._segment_path = lambda: "bmp-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_, [u'bmp_path_flags', u'bmp_path_adv_bit_map', u'bmp_path_snd_bit_map', u'bmp_nbr_bit_map', u'local_path', u'bpath_pointer'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class ReceivedLabel(Entity):
                                            """
                                            Set of received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel, self).__init__()

                                                self.yang_name = "received-label"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "received-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel, [u'entry'], name, value)


                            class UpdateGenerationUpdateGroups(Entity):
                                """
                                Update generation for all update\-groups
                                
                                .. attribute:: update_generation_update_group
                                
                                	Update generation for update\-group
                                	**type**\: list of  		 :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups, self).__init__()

                                    self.yang_name = "update-generation-update-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-generation-update-group", ("update_generation_update_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup))])
                                    self._leafs = OrderedDict()

                                    self.update_generation_update_group = YList(self)
                                    self._segment_path = lambda: "update-generation-update-groups"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups, [], name, value)


                                class UpdateGenerationUpdateGroup(Entity):
                                    """
                                    Update generation for update\-group
                                    
                                    .. attribute:: update_group_index  (key)
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_timer_start_timestamp
                                    
                                    	Last update timer start time
                                    	**type**\:  :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                    
                                    .. attribute:: last_update_timer_stop_timestamp
                                    
                                    	Last update timer stop time
                                    	**type**\:  :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                    
                                    .. attribute:: last_update_timer_expiry_timestamp
                                    
                                    	Last update timer expiry time
                                    	**type**\:  :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                    
                                    .. attribute:: last_update_timer_remaining_value
                                    
                                    	Update timer remaining time
                                    	**type**\:  :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                    
                                    .. attribute:: last_update_timer_delay_value
                                    
                                    	Last update timer delay value
                                    	**type**\:  :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: neighbor_session_af_name
                                    
                                    	Neighbor session address family
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_flags2
                                    
                                    	Update\-group internal flags2
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue Messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue Size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_leaving_count
                                    
                                    	Count of neighbors leaving the update\-group
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_generation_recovery_pending
                                    
                                    	Is update generation recovery pending
                                    	**type**\: bool
                                    
                                    .. attribute:: last_update_timer_expiry_age
                                    
                                    	Time since last update timer expiry event
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_update_timer_running
                                    
                                    	Is update timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: perm_pelem_encountered
                                    
                                    	Count of Perm Pelems seen by updgen
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_allowed
                                    
                                    	Count of Perm Pelems allowed by updgen
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_not_allowed
                                    
                                    	Count of Perm Pelems not allowed by updgen
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_exp_wdr
                                    
                                    	Count of Perm Pelems explicitly wdrn by updgen
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_spur_wdr
                                    
                                    	Count of Perm Pelems Spurious withdraws by updgen
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_permanent
                                    
                                    	Permanent UG check
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, self).__init__()

                                        self.yang_name = "update-generation-update-group"
                                        self.yang_parent_name = "update-generation-update-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['update_group_index']
                                        self._child_classes = OrderedDict([("last-update-timer-start-timestamp", ("last_update_timer_start_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp)), ("last-update-timer-stop-timestamp", ("last_update_timer_stop_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp)), ("last-update-timer-expiry-timestamp", ("last_update_timer_expiry_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp)), ("last-update-timer-remaining-value", ("last_update_timer_remaining_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue)), ("last-update-timer-delay-value", ("last_update_timer_delay_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics))])
                                        self._leafs = OrderedDict([
                                            ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                            ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('neighbor_session_af_name', (YLeaf(YType.uint8, 'neighbor-session-af-name'), ['int'])),
                                            ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                            ('update_group_flags2', (YLeaf(YType.uint32, 'update-group-flags2'), ['int'])),
                                            ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                            ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                            ('update_sub_group_count', (YLeaf(YType.uint32, 'update-sub-group-count'), ['int'])),
                                            ('sub_group_throttled_count', (YLeaf(YType.uint32, 'sub-group-throttled-count'), ['int'])),
                                            ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                            ('refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'refresh-sub-group-throttled-count'), ['int'])),
                                            ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                            ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                            ('neighbor_leaving_count', (YLeaf(YType.uint32, 'neighbor-leaving-count'), ['int'])),
                                            ('update_generation_recovery_pending', (YLeaf(YType.boolean, 'update-generation-recovery-pending'), ['bool'])),
                                            ('last_update_timer_expiry_age', (YLeaf(YType.uint32, 'last-update-timer-expiry-age'), ['int'])),
                                            ('is_update_timer_running', (YLeaf(YType.boolean, 'is-update-timer-running'), ['bool'])),
                                            ('perm_pelem_encountered', (YLeaf(YType.uint32, 'perm-pelem-encountered'), ['int'])),
                                            ('perm_pelem_allowed', (YLeaf(YType.uint32, 'perm-pelem-allowed'), ['int'])),
                                            ('perm_pelem_not_allowed', (YLeaf(YType.uint32, 'perm-pelem-not-allowed'), ['int'])),
                                            ('perm_pelem_exp_wdr', (YLeaf(YType.uint32, 'perm-pelem-exp-wdr'), ['int'])),
                                            ('perm_pelem_spur_wdr', (YLeaf(YType.uint32, 'perm-pelem-spur-wdr'), ['int'])),
                                            ('is_permanent', (YLeaf(YType.boolean, 'is-permanent'), ['bool'])),
                                        ])
                                        self.update_group_index = None
                                        self.process_id = None
                                        self.update_vrf_name = None
                                        self.update_group_af_name = None
                                        self.neighbor_session_af_name = None
                                        self.update_group_index_xr = None
                                        self.update_group_flags2 = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_sub_group_count = None
                                        self.sub_group_throttled_count = None
                                        self.refresh_sub_group_count = None
                                        self.refresh_sub_group_throttled_count = None
                                        self.filter_group_count = None
                                        self.neighbor_count = None
                                        self.neighbor_leaving_count = None
                                        self.update_generation_recovery_pending = None
                                        self.last_update_timer_expiry_age = None
                                        self.is_update_timer_running = None
                                        self.perm_pelem_encountered = None
                                        self.perm_pelem_allowed = None
                                        self.perm_pelem_not_allowed = None
                                        self.perm_pelem_exp_wdr = None
                                        self.perm_pelem_spur_wdr = None
                                        self.is_permanent = None

                                        self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                        self.last_update_timer_start_timestamp.parent = self
                                        self._children_name_map["last_update_timer_start_timestamp"] = "last-update-timer-start-timestamp"

                                        self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                        self.last_update_timer_stop_timestamp.parent = self
                                        self._children_name_map["last_update_timer_stop_timestamp"] = "last-update-timer-stop-timestamp"

                                        self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                        self.last_update_timer_expiry_timestamp.parent = self
                                        self._children_name_map["last_update_timer_expiry_timestamp"] = "last-update-timer-expiry-timestamp"

                                        self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                        self.last_update_timer_remaining_value.parent = self
                                        self._children_name_map["last_update_timer_remaining_value"] = "last-update-timer-remaining-value"

                                        self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                        self.last_update_timer_delay_value.parent = self
                                        self._children_name_map["last_update_timer_delay_value"] = "last-update-timer-delay-value"

                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._segment_path = lambda: "update-generation-update-group" + "[update-group-index='" + str(self.update_group_index) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, ['update_group_index', u'process_id', u'update_vrf_name', u'update_group_af_name', u'neighbor_session_af_name', u'update_group_index_xr', u'update_group_flags2', u'update_out_queue_messages', u'update_out_queue_size', u'update_sub_group_count', u'sub_group_throttled_count', u'refresh_sub_group_count', u'refresh_sub_group_throttled_count', u'filter_group_count', u'neighbor_count', u'neighbor_leaving_count', u'update_generation_recovery_pending', u'last_update_timer_expiry_age', u'is_update_timer_running', u'perm_pelem_encountered', u'perm_pelem_allowed', u'perm_pelem_not_allowed', u'perm_pelem_exp_wdr', u'perm_pelem_spur_wdr', u'is_permanent'], name, value)


                                    class LastUpdateTimerStartTimestamp(Entity):
                                        """
                                        Last update timer start time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-start-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-timer-start-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateTimerStopTimestamp(Entity):
                                        """
                                        Last update timer stop time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-stop-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-timer-stop-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateTimerExpiryTimestamp(Entity):
                                        """
                                        Last update timer expiry time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-expiry-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-timer-expiry-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateTimerRemainingValue(Entity):
                                        """
                                        Update timer remaining time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, self).__init__()

                                            self.yang_name = "last-update-timer-remaining-value"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-timer-remaining-value"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateTimerDelayValue(Entity):
                                        """
                                        Last update timer delay value
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, self).__init__()

                                            self.yang_name = "last-update-timer-delay-value"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-timer-delay-value"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                            ])
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_size_high = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_cleared = None
                                            self.last_update_discard_age = None
                                            self.last_update_cleard_age = None
                                            self.update_throttle_count = None
                                            self.last_update_throttle_age = None
                                            self.update_recovery_count = None
                                            self.last_update_recovery_age = None
                                            self.update_memory_allocation_fail_count = None
                                            self.last_update_memory_allocation_fail_age = None

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._segment_path = lambda: "update-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-discard-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-cleared-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-throttle-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-recovery-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class UpdateGenerationFilterGroups(Entity):
                                """
                                Update generation for all filter\-groups under
                                a sub\-group
                                
                                .. attribute:: update_generation_filter_group
                                
                                	Update generation for filter\-group
                                	**type**\: list of  		 :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups, self).__init__()

                                    self.yang_name = "update-generation-filter-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-generation-filter-group", ("update_generation_filter_group", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup))])
                                    self._leafs = OrderedDict()

                                    self.update_generation_filter_group = YList(self)
                                    self._segment_path = lambda: "update-generation-filter-groups"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups, [], name, value)


                                class UpdateGenerationFilterGroup(Entity):
                                    """
                                    Update generation for filter\-group
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_filter_group_index
                                    
                                    	Parent Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, self).__init__()

                                        self.yang_name = "update-generation-filter-group"
                                        self.yang_parent_name = "update-generation-filter-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                            ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                            ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                            ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                            ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('update_filter_group_index', (YLeaf(YType.uint32, 'update-filter-group-index'), ['int'])),
                                            ('parent_filter_group_index', (YLeaf(YType.uint32, 'parent-filter-group-index'), ['int'])),
                                            ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                            ('sub_group_id_xr', (YLeaf(YType.uint32, 'sub-group-id-xr'), ['int'])),
                                            ('parent_sub_group_index', (YLeaf(YType.uint32, 'parent-sub-group-index'), ['int'])),
                                            ('parent_sub_group_id', (YLeaf(YType.uint32, 'parent-sub-group-id'), ['int'])),
                                            ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                            ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                        ])
                                        self.update_group_index = None
                                        self.sub_group_index = None
                                        self.sub_group_id = None
                                        self.filter_group_index = None
                                        self.process_id = None
                                        self.update_vrf_name = None
                                        self.update_group_af_name = None
                                        self.update_filter_group_index = None
                                        self.parent_filter_group_index = None
                                        self.sub_group_index_xr = None
                                        self.sub_group_id_xr = None
                                        self.parent_sub_group_index = None
                                        self.parent_sub_group_id = None
                                        self.update_group_index_xr = None
                                        self.neighbor_count = None
                                        self._segment_path = lambda: "update-generation-filter-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, ['update_group_index', 'sub_group_index', 'sub_group_id', 'filter_group_index', u'process_id', u'update_vrf_name', u'update_group_af_name', u'update_filter_group_index', u'parent_filter_group_index', u'sub_group_index_xr', u'sub_group_id_xr', u'parent_sub_group_index', u'parent_sub_group_id', u'update_group_index_xr', u'neighbor_count'], name, value)


                            class Networks(Entity):
                                """
                                The BGP Network Table
                                
                                .. attribute:: network
                                
                                	A BGP Network table entry
                                	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks, self).__init__()

                                    self.yang_name = "networks"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("network", ("network", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network))])
                                    self._leafs = OrderedDict()

                                    self.network = YList(self)
                                    self._segment_path = lambda: "networks"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks, [], name, value)


                                class Network(Entity):
                                    """
                                    A BGP Network table entry
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Version timestamp
                                    	**type**\:  :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                    
                                    .. attribute:: version_age
                                    
                                    	Version age
                                    	**type**\:  :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: has_inconsistent_paths
                                    
                                    	Net has inconsistent paths
                                    	**type**\: bool
                                    
                                    .. attribute:: is_net_aggregation_suppressed
                                    
                                    	Net suppressed due to aggregation
                                    	**type**\: bool
                                    
                                    .. attribute:: is_net_ldp_signaled
                                    
                                    	L2VPN Net LDP signaled  aggregation
                                    	**type**\: bool
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version # for net
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Table version # for updates
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertisedto_pe
                                    
                                    	Net could be advertised                          to PE peers
                                    	**type**\: bool
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\: bool
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label_rewrite
                                    
                                    	Net label has rewrite
                                    	**type**\: bool
                                    
                                    .. attribute:: net_local_label_srgb
                                    
                                    	Net label allocated fromSegment routing global block
                                    	**type**\: bool
                                    
                                    .. attribute:: has_lbl_retained
                                    
                                    	Net has label retained
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: net_flags
                                    
                                    	Flags associated with                            net
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_extended_flags
                                    
                                    	Net extended flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_multipath
                                    
                                    	Net has multipaths
                                    	**type**\: bool
                                    
                                    .. attribute:: net_eibgp_multipath
                                    
                                    	Net has EIBGP multipaths
                                    	**type**\: bool
                                    
                                    .. attribute:: net_backup_available
                                    
                                    	Net has backup path
                                    	**type**\: bool
                                    
                                    .. attribute:: net_backup_label_rewrite_available
                                    
                                    	Net has label rewrite for backup path
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_failed
                                    
                                    	RIB install failed
                                    	**type**\: bool
                                    
                                    .. attribute:: gateway_array
                                    
                                    	Gateway array ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: resilient_nexthop_set
                                    
                                    	Resilient nexthop set ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_permanent_network
                                    
                                    	Permanent Network
                                    	**type**\: bool
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for this net
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bit
                                    
                                    	Bit
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: flags
                                    
                                    	Flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: has_s_rv6sid_allocated
                                    
                                    	Net has SRv6 SID allocated
                                    	**type**\: bool
                                    
                                    .. attribute:: srv6sid_address
                                    
                                    	SRv6 SID address value
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: srv6sid_address_len
                                    
                                    	SRv6 SID address Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_peers_advertised_to
                                    
                                    	Local peers that this prefix has been advertised to
                                    	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                    
                                    .. attribute:: pe_peers_advertised_to
                                    
                                    	PE peers that this prefix has been advertised to
                                    	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                    
                                    .. attribute:: best_path_orr_bitfield
                                    
                                    	ORR Best path Bitfields
                                    	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                    
                                    .. attribute:: add_path_orr_bitfield
                                    
                                    	ORR Add path Bitfields
                                    	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                    
                                    .. attribute:: local_process_instance_path
                                    
                                    	Local (to process instance) paths for this net 
                                    	**type**\: list of  		 :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                    
                                    .. attribute:: active_process_instance_path
                                    
                                    	Active's paths for this net 
                                    	**type**\: list of  		 :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                    
                                    .. attribute:: local_path_element
                                    
                                    	Local path element list
                                    	**type**\: list of  		 :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement>`
                                    
                                    .. attribute:: active_path_element
                                    
                                    	Path element list received from Active inst
                                    	**type**\: list of  		 :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "networks"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix)), ("version-timestamp", ("version_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp)), ("version-age", ("version_age", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield)), ("local-process-instance-path", ("local_process_instance_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath)), ("active-process-instance-path", ("active_process_instance_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath)), ("local-path-element", ("local_path_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement)), ("active-path-element", ("active_path_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('has_inconsistent_paths', (YLeaf(YType.boolean, 'has-inconsistent-paths'), ['bool'])),
                                            ('is_net_aggregation_suppressed', (YLeaf(YType.boolean, 'is-net-aggregation-suppressed'), ['bool'])),
                                            ('is_net_ldp_signaled', (YLeaf(YType.boolean, 'is-net-ldp-signaled'), ['bool'])),
                                            ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                            ('table_brib_version', (YLeaf(YType.uint32, 'table-brib-version'), ['int'])),
                                            ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                            ('has_local_label', (YLeaf(YType.boolean, 'has-local-label'), ['bool'])),
                                            ('net_local_label', (YLeaf(YType.uint32, 'net-local-label'), ['int'])),
                                            ('net_local_label_rewrite', (YLeaf(YType.boolean, 'net-local-label-rewrite'), ['bool'])),
                                            ('net_local_label_srgb', (YLeaf(YType.boolean, 'net-local-label-srgb'), ['bool'])),
                                            ('has_lbl_retained', (YLeaf(YType.boolean, 'has-lbl-retained'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('net_flags', (YLeaf(YType.uint32, 'net-flags'), ['int'])),
                                            ('net_extended_flags', (YLeaf(YType.uint32, 'net-extended-flags'), ['int'])),
                                            ('net_multipath', (YLeaf(YType.boolean, 'net-multipath'), ['bool'])),
                                            ('net_eibgp_multipath', (YLeaf(YType.boolean, 'net-eibgp-multipath'), ['bool'])),
                                            ('net_backup_available', (YLeaf(YType.boolean, 'net-backup-available'), ['bool'])),
                                            ('net_backup_label_rewrite_available', (YLeaf(YType.boolean, 'net-backup-label-rewrite-available'), ['bool'])),
                                            ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                            ('gateway_array', (YLeaf(YType.uint32, 'gateway-array'), ['int'])),
                                            ('resilient_nexthop_set', (YLeaf(YType.uint32, 'resilient-nexthop-set'), ['int'])),
                                            ('is_permanent_network', (YLeaf(YType.boolean, 'is-permanent-network'), ['bool'])),
                                            ('num_of_path', (YLeaf(YType.uint32, 'num-of-path'), ['int'])),
                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                            ('bit', (YLeaf(YType.uint16, 'bit'), ['int'])),
                                            ('flags', (YLeaf(YType.uint8, 'flags'), ['int'])),
                                            ('has_s_rv6sid_allocated', (YLeaf(YType.boolean, 'has-s-rv6sid-allocated'), ['bool'])),
                                            ('srv6sid_address', (YLeaf(YType.str, 'srv6sid-address'), ['str'])),
                                            ('srv6sid_address_len', (YLeaf(YType.uint32, 'srv6sid-address-len'), ['int'])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.has_inconsistent_paths = None
                                        self.is_net_aggregation_suppressed = None
                                        self.is_net_ldp_signaled = None
                                        self.table_version = None
                                        self.table_brib_version = None
                                        self.advertisedto_pe = None
                                        self.has_local_label = None
                                        self.net_local_label = None
                                        self.net_local_label_rewrite = None
                                        self.net_local_label_srgb = None
                                        self.has_lbl_retained = None
                                        self.route_distinguisher = None
                                        self.vrf_name = None
                                        self.net_flags = None
                                        self.net_extended_flags = None
                                        self.net_multipath = None
                                        self.net_eibgp_multipath = None
                                        self.net_backup_available = None
                                        self.net_backup_label_rewrite_available = None
                                        self.rib_failed = None
                                        self.gateway_array = None
                                        self.resilient_nexthop_set = None
                                        self.is_permanent_network = None
                                        self.num_of_path = None
                                        self.version = None
                                        self.bit = None
                                        self.flags = None
                                        self.has_s_rv6sid_allocated = None
                                        self.srv6sid_address = None
                                        self.srv6sid_address_len = None

                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                        self.version_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self._children_name_map["version_timestamp"] = "version-timestamp"

                                        self.version_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge()
                                        self.version_age.parent = self
                                        self._children_name_map["version_age"] = "version-age"

                                        self.local_peers_advertised_to = YList(self)
                                        self.pe_peers_advertised_to = YList(self)
                                        self.best_path_orr_bitfield = YList(self)
                                        self.add_path_orr_bitfield = YList(self)
                                        self.local_process_instance_path = YList(self)
                                        self.active_process_instance_path = YList(self)
                                        self.local_path_element = YList(self)
                                        self.active_path_element = YList(self)
                                        self._segment_path = lambda: "network"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network, ['rd', 'network', 'prefix_length', u'af_name', u'process_instance_id', u'has_inconsistent_paths', u'is_net_aggregation_suppressed', u'is_net_ldp_signaled', u'table_version', u'table_brib_version', u'advertisedto_pe', u'has_local_label', u'net_local_label', u'net_local_label_rewrite', u'net_local_label_srgb', u'has_lbl_retained', u'route_distinguisher', u'vrf_name', u'net_flags', u'net_extended_flags', u'net_multipath', u'net_eibgp_multipath', u'net_backup_available', u'net_backup_label_rewrite_available', u'rib_failed', u'gateway_array', u'resilient_nexthop_set', u'is_permanent_network', u'num_of_path', u'version', u'bit', u'flags', u'has_s_rv6sid_allocated', u'srv6sid_address', u'srv6sid_address_len'], name, value)


                                    class BgpPrefix(Entity):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix, self).__init__()

                                            self.yang_name = "bgp-prefix"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix_length = None

                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._segment_path = lambda: "bgp-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix, [u'prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bgp-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class VersionTimestamp(Entity):
                                        """
                                        Version timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp, self).__init__()

                                            self.yang_name = "version-timestamp"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class VersionAge(Entity):
                                        """
                                        Version age
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge, self).__init__()

                                            self.yang_name = "version-age"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-age"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.VersionAge, [u'seconds', u'nanoseconds'], name, value)


                                    class LocalPeersAdvertisedTo(Entity):
                                        """
                                        Local peers that this prefix has been advertised
                                        to
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\: bool
                                        
                                        .. attribute:: update_group_afi
                                        
                                        	AFI of the Update group it is advertised to
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, self).__init__()

                                            self.yang_name = "local-peers-advertised-to"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ])
                                            self.is_neighbor = None
                                            self.update_group_afi = None
                                            self.update_group_number = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "local-peers-advertised-to"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "local-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PePeersAdvertisedTo(Entity):
                                        """
                                        PE peers that this prefix has been advertised to
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\: bool
                                        
                                        .. attribute:: update_group_afi
                                        
                                        	AFI of the Update group it is advertised to
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, self).__init__()

                                            self.yang_name = "pe-peers-advertised-to"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ])
                                            self.is_neighbor = None
                                            self.update_group_afi = None
                                            self.update_group_number = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "pe-peers-advertised-to"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class BestPathOrrBitfield(Entity):
                                        """
                                        ORR Best path Bitfields
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\: bool
                                        
                                        .. attribute:: update_group_afi
                                        
                                        	AFI of the Update group it is advertised to
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield, self).__init__()

                                            self.yang_name = "best-path-orr-bitfield"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ])
                                            self.is_neighbor = None
                                            self.update_group_afi = None
                                            self.update_group_number = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "best-path-orr-bitfield"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AddPathOrrBitfield(Entity):
                                        """
                                        ORR Add path Bitfields
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\: bool
                                        
                                        .. attribute:: update_group_afi
                                        
                                        	AFI of the Update group it is advertised to
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield, self).__init__()

                                            self.yang_name = "add-path-orr-bitfield"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ])
                                            self.is_neighbor = None
                                            self.update_group_afi = None
                                            self.update_group_number = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "add-path-orr-bitfield"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class LocalProcessInstancePath(Entity):
                                        """
                                        Local (to process instance) paths for this net 
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath, self).__init__()

                                            self.yang_name = "local-process-instance-path"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "local-process-instance-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class ActiveProcessInstancePath(Entity):
                                        """
                                        Active's paths for this net 
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, self).__init__()

                                            self.yang_name = "active-process-instance-path"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "active-process-instance-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class LocalPathElement(Entity):
                                        """
                                        Local path element list
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:  :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:  :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement, self).__init__()

                                            self.yang_name = "local-path-element"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("pelem-path-nexthop", ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel)), ("pelem-path-neighbor-addr", ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr))])
                                            self._leafs = OrderedDict([
                                                ('pelem_path_id', (YLeaf(YType.uint32, 'pelem-path-id'), ['int'])),
                                                ('pelem_version', (YLeaf(YType.uint32, 'pelem-version'), ['int'])),
                                                ('pelem_flags', (YLeaf(YType.uint32, 'pelem-flags'), ['int'])),
                                                ('pelem_gw_metric', (YLeaf(YType.uint32, 'pelem-gw-metric'), ['int'])),
                                                ('pelem_path_flags', (YLeaf(YType.uint64, 'pelem-path-flags'), ['int'])),
                                                ('pelem_path_peer_path_id', (YLeaf(YType.uint32, 'pelem-path-peer-path-id'), ['int'])),
                                                ('pelem_table_attr_version', (YLeaf(YType.uint32, 'pelem-table-attr-version'), ['int'])),
                                                ('pelem_path_table_attr_version', (YLeaf(YType.uint32, 'pelem-path-table-attr-version'), ['int'])),
                                                ('pelem_no_bestpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-bestpath-table-attr-version'), ['int'])),
                                                ('pelem_no_addpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-addpath-table-attr-version'), ['int'])),
                                                ('is_perm_path_pelem', (YLeaf(YType.boolean, 'is-perm-path-pelem'), ['bool'])),
                                            ])
                                            self.pelem_path_id = None
                                            self.pelem_version = None
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.is_perm_path_pelem = None

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._segment_path = lambda: "local-path-element"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement, [u'pelem_path_id', u'pelem_version', u'pelem_flags', u'pelem_gw_metric', u'pelem_path_flags', u'pelem_path_peer_path_id', u'pelem_table_attr_version', u'pelem_path_table_attr_version', u'pelem_no_bestpath_table_attr_version', u'pelem_no_addpath_table_attr_version', u'is_perm_path_pelem'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "pelem-path-nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class ActivePathElement(Entity):
                                        """
                                        Path element list received from Active inst
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:  :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:  :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement, self).__init__()

                                            self.yang_name = "active-path-element"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("pelem-path-nexthop", ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel)), ("pelem-path-neighbor-addr", ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr))])
                                            self._leafs = OrderedDict([
                                                ('pelem_path_id', (YLeaf(YType.uint32, 'pelem-path-id'), ['int'])),
                                                ('pelem_version', (YLeaf(YType.uint32, 'pelem-version'), ['int'])),
                                                ('pelem_flags', (YLeaf(YType.uint32, 'pelem-flags'), ['int'])),
                                                ('pelem_gw_metric', (YLeaf(YType.uint32, 'pelem-gw-metric'), ['int'])),
                                                ('pelem_path_flags', (YLeaf(YType.uint64, 'pelem-path-flags'), ['int'])),
                                                ('pelem_path_peer_path_id', (YLeaf(YType.uint32, 'pelem-path-peer-path-id'), ['int'])),
                                                ('pelem_table_attr_version', (YLeaf(YType.uint32, 'pelem-table-attr-version'), ['int'])),
                                                ('pelem_path_table_attr_version', (YLeaf(YType.uint32, 'pelem-path-table-attr-version'), ['int'])),
                                                ('pelem_no_bestpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-bestpath-table-attr-version'), ['int'])),
                                                ('pelem_no_addpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-addpath-table-attr-version'), ['int'])),
                                                ('is_perm_path_pelem', (YLeaf(YType.boolean, 'is-perm-path-pelem'), ['bool'])),
                                            ])
                                            self.pelem_path_id = None
                                            self.pelem_version = None
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.is_perm_path_pelem = None

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._segment_path = lambda: "active-path-element"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement, [u'pelem_path_id', u'pelem_version', u'pelem_flags', u'pelem_gw_metric', u'pelem_path_flags', u'pelem_path_peer_path_id', u'pelem_table_attr_version', u'pelem_path_table_attr_version', u'pelem_no_bestpath_table_attr_version', u'pelem_no_addpath_table_attr_version', u'is_perm_path_pelem'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "pelem-path-nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class PathTable(Entity):
                                """
                                The BGP Path Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable, self).__init__()

                                    self.yang_name = "path-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path))])
                                    self._leafs = OrderedDict()

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: orig_source_rd
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertised_neighbor
                                    
                                    	Advertised Neighbor Address. Valid in the case of Advertised table
                                    	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor>`
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: original_source_route_distinguisher
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\: str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                            ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                            ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                            ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                            ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                            ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                            ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.orig_source_rd = None
                                        self.path_id = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.label_oor = None
                                        self.label_oor_version = None
                                        self.label_fail = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.original_source_route_distinguisher = None
                                        self.prefix_version = None
                                        self.vrf_name = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None

                                        self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor()
                                        self.advertised_neighbor.parent = self
                                        self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                    class AdvertisedNeighbor(Entity):
                                        """
                                        Advertised Neighbor Address. Valid in the case
                                        of Advertised table
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor, self).__init__()

                                            self.yang_name = "advertised-neighbor"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "advertised-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied. In the
                                        case of path type received\-only this will be
                                        attributes before inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class Epes(Entity):
                                """
                                The BGP Egress Engineering table
                                
                                .. attribute:: epe
                                
                                	A BGP Egress Engineering table entry
                                	**type**\: list of  		 :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes, self).__init__()

                                    self.yang_name = "epes"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("epe", ("epe", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe))])
                                    self._leafs = OrderedDict()

                                    self.epe = YList(self)
                                    self._segment_path = lambda: "epes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes, [], name, value)


                                class Epe(Entity):
                                    """
                                    A BGP Egress Engineering table entry
                                    
                                    .. attribute:: epe_key_length
                                    
                                    	Epe Key Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_set_key
                                    
                                    	Epe Set Key
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: epe_local_address
                                    
                                    	Local address
                                    	**type**\:  :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                    
                                    .. attribute:: epe_next_hop
                                    
                                    	Nexthop address
                                    	**type**\:  :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                    
                                    .. attribute:: epe_key_length_xr
                                    
                                    	EPE key length in bits
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_version
                                    
                                    	EPE object's version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_flags
                                    
                                    	EPE object's flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_local_asn
                                    
                                    	Local AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_remote_asn
                                    
                                    	Remote AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_remote_router_id
                                    
                                    	Remote router id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_local_router_id
                                    
                                    	Local router id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rpc_set_object_id
                                    
                                    	RPC set object ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_key
                                    
                                    	Key of EPE object
                                    	**type**\: list of  		 :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeKey>`
                                    
                                    .. attribute:: nexthop_id
                                    
                                    	List of nexthop ID of EPE
                                    	**type**\: list of  		 :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.NexthopId>`
                                    
                                    .. attribute:: ifhandle
                                    
                                    	List of ifhandle of EPE
                                    	**type**\: list of  		 :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle>`
                                    
                                    .. attribute:: first_hop
                                    
                                    	List of firsthops of EPE
                                    	**type**\: list of  		 :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe, self).__init__()

                                        self.yang_name = "epe"
                                        self.yang_parent_name = "epes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("epe-local-address", ("epe_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress)), ("epe-next-hop", ("epe_next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop)), ("epe-key", ("epe_key", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeKey)), ("nexthop-id", ("nexthop_id", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.NexthopId)), ("ifhandle", ("ifhandle", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle)), ("first-hop", ("first_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop))])
                                        self._leafs = OrderedDict([
                                            ('epe_key_length', (YLeaf(YType.uint32, 'epe-key-length'), ['int'])),
                                            ('epe_set_key', (YLeaf(YType.str, 'epe-set-key'), ['str'])),
                                            ('epe_key_length_xr', (YLeaf(YType.uint8, 'epe-key-length-xr'), ['int'])),
                                            ('epe_version', (YLeaf(YType.uint32, 'epe-version'), ['int'])),
                                            ('epe_flags', (YLeaf(YType.uint8, 'epe-flags'), ['int'])),
                                            ('epe_local_asn', (YLeaf(YType.uint32, 'epe-local-asn'), ['int'])),
                                            ('epe_remote_asn', (YLeaf(YType.uint32, 'epe-remote-asn'), ['int'])),
                                            ('epe_remote_router_id', (YLeaf(YType.uint32, 'epe-remote-router-id'), ['int'])),
                                            ('epe_local_router_id', (YLeaf(YType.uint32, 'epe-local-router-id'), ['int'])),
                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                            ('ref_count', (YLeaf(YType.uint32, 'ref-count'), ['int'])),
                                            ('rpc_set_object_id', (YLeaf(YType.uint32, 'rpc-set-object-id'), ['int'])),
                                        ])
                                        self.epe_key_length = None
                                        self.epe_set_key = None
                                        self.epe_key_length_xr = None
                                        self.epe_version = None
                                        self.epe_flags = None
                                        self.epe_local_asn = None
                                        self.epe_remote_asn = None
                                        self.epe_remote_router_id = None
                                        self.epe_local_router_id = None
                                        self.label = None
                                        self.ref_count = None
                                        self.rpc_set_object_id = None

                                        self.epe_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                        self.epe_local_address.parent = self
                                        self._children_name_map["epe_local_address"] = "epe-local-address"

                                        self.epe_next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop()
                                        self.epe_next_hop.parent = self
                                        self._children_name_map["epe_next_hop"] = "epe-next-hop"

                                        self.epe_key = YList(self)
                                        self.nexthop_id = YList(self)
                                        self.ifhandle = YList(self)
                                        self.first_hop = YList(self)
                                        self._segment_path = lambda: "epe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe, ['epe_key_length', 'epe_set_key', u'epe_key_length_xr', u'epe_version', u'epe_flags', u'epe_local_asn', u'epe_remote_asn', u'epe_remote_router_id', u'epe_local_router_id', u'label', u'ref_count', u'rpc_set_object_id'], name, value)


                                    class EpeLocalAddress(Entity):
                                        """
                                        Local address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress, self).__init__()

                                            self.yang_name = "epe-local-address"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "epe-local-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class EpeNextHop(Entity):
                                        """
                                        Nexthop address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop, self).__init__()

                                            self.yang_name = "epe-next-hop"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "epe-next-hop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class EpeKey(Entity):
                                        """
                                        Key of EPE object
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeKey, self).__init__()

                                            self.yang_name = "epe-key"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "epe-key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.EpeKey, [u'entry'], name, value)


                                    class NexthopId(Entity):
                                        """
                                        List of nexthop ID of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.NexthopId, self).__init__()

                                            self.yang_name = "nexthop-id"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "nexthop-id"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.NexthopId, [u'entry'], name, value)


                                    class Ifhandle(Entity):
                                        """
                                        List of ifhandle of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle, self).__init__()

                                            self.yang_name = "ifhandle"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "ifhandle"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle, [u'entry'], name, value)


                                    class FirstHop(Entity):
                                        """
                                        List of firsthops of EPE
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop, self).__init__()

                                            self.yang_name = "first-hop"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "first-hop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertisedPathCounts(Entity):
                                """
                                The BGP Advertised paths table (bestpath)
                                
                                .. attribute:: advertised_path_count
                                
                                	The BGP Advertised path table Count (bestpath)
                                	**type**\: list of  		 :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts, self).__init__()

                                    self.yang_name = "advertised-path-counts"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("advertised-path-count", ("advertised_path_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount))])
                                    self._leafs = OrderedDict()

                                    self.advertised_path_count = YList(self)
                                    self._segment_path = lambda: "advertised-path-counts"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts, [], name, value)


                                class AdvertisedPathCount(Entity):
                                    """
                                    The BGP Advertised path table Count
                                    (bestpath)
                                    
                                    .. attribute:: neighbor_address  (key)
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: max_prefix_advertisedcount
                                    
                                    	Number of prefixes advertsied to neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, self).__init__()

                                        self.yang_name = "advertised-path-count"
                                        self.yang_parent_name = "advertised-path-counts"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['neighbor_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('max_prefix_advertisedcount', (YLeaf(YType.uint32, 'max-prefix-advertisedcount'), ['int'])),
                                        ])
                                        self.neighbor_address = None
                                        self.max_prefix_advertisedcount = None
                                        self._segment_path = lambda: "advertised-path-count" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, ['neighbor_address', u'max_prefix_advertisedcount'], name, value)


                            class PathLabeledTable(Entity):
                                """
                                The BGP Path Labeled Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable, self).__init__()

                                    self.yang_name = "path-labeled-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path))])
                                    self._leafs = OrderedDict()

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-labeled-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: orig_source_rd
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertised_neighbor
                                    
                                    	Advertised Neighbor Address. Valid in the case of Advertised table
                                    	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor>`
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: original_source_route_distinguisher
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\: str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-labeled-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                            ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                            ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                            ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                            ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                            ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                            ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.orig_source_rd = None
                                        self.path_id = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.label_oor = None
                                        self.label_oor_version = None
                                        self.label_fail = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.original_source_route_distinguisher = None
                                        self.prefix_version = None
                                        self.vrf_name = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None

                                        self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor()
                                        self.advertised_neighbor.parent = self
                                        self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                    class AdvertisedNeighbor(Entity):
                                        """
                                        Advertised Neighbor Address. Valid in the case
                                        of Advertised table
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor, self).__init__()

                                            self.yang_name = "advertised-neighbor"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "advertised-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied. In the
                                        case of path type received\-only this will be
                                        attributes before inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertisedPaths(Entity):
                                """
                                The BGP Advertised paths table (add\-paths)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised paths table entry (add\-paths)
                                	**type**\: list of  		 :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths, self).__init__()

                                    self.yang_name = "advertised-paths"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("advertised-path", ("advertised_path", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath))])
                                    self._leafs = OrderedDict()

                                    self.advertised_path = YList(self)
                                    self._segment_path = lambda: "advertised-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths, [], name, value)


                                class AdvertisedPath(Entity):
                                    """
                                    A BGP Advertised paths table entry
                                    (add\-paths)
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor 
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: paths
                                    
                                    	paths
                                    	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                    
                                    .. attribute:: adv_path_info
                                    
                                    	Net Advertized Paths
                                    	**type**\: list of  		 :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath, self).__init__()

                                        self.yang_name = "advertised-path"
                                        self.yang_parent_name = "advertised-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("paths", ("paths", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths)), ("adv-path-info", ("adv_path_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None

                                        self.paths = YList(self)
                                        self.adv_path_info = YList(self)
                                        self._segment_path = lambda: "advertised-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath, ['rd', 'network', 'prefix_length', 'neighbor_address'], name, value)


                                    class Paths(Entity):
                                        """
                                        paths
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, self).__init__()

                                            self.yang_name = "paths"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AdvPathInfo(Entity):
                                        """
                                        Net Advertized Paths
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:  :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:  :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, self).__init__()

                                            self.yang_name = "adv-path-info"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr)), ("path-info-after-policy-in", ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn)), ("path-info-after-policy-out", ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn)), ("attributes-after-policy-out", ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut))])
                                            self._leafs = OrderedDict([
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.no_path = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.vrf_name = None

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"

                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"

                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                            self._segment_path = lambda: "adv-path-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, [u'no_path', u'af_name', u'route_distinguisher', u'source_route_distinguisher', u'vrf_name'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address-xr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInfoAfterPolicyIn(Entity):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, self).__init__()

                                                self.yang_name = "path-info-after-policy-in"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInfoAfterPolicyOut(Entity):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, self).__init__()

                                                self.yang_name = "path-info-after-policy-out"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-out"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyOut(Entity):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, self).__init__()

                                                self.yang_name = "attributes-after-policy-out"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-out"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NeighborAfTable(Entity):
                                """
                                The BGP Neighbor AF table
                                
                                .. attribute:: neighbor
                                
                                	A BGP Neighbor table entry
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable, self).__init__()

                                    self.yang_name = "neighbor-af-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "neighbor-af-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    A BGP Neighbor table entry
                                    
                                    .. attribute:: neighbor_address  (key)
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: connection_local_address
                                    
                                    	Local address for the connection
                                    	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                    
                                    .. attribute:: connection_remote_address
                                    
                                    	Remote address for the connection
                                    	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                    
                                    .. attribute:: send_notification_info
                                    
                                    	Information on the last notification sent
                                    	**type**\:  :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                    
                                    .. attribute:: received_notification_info
                                    
                                    	Information on the last notification received
                                    	**type**\:  :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                    
                                    .. attribute:: message_statistics
                                    
                                    	Message statistics
                                    	**type**\:  :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                    
                                    .. attribute:: tcp_init_sync_time_spec
                                    
                                    	Time When neighbor entered TCP Init Sync
                                    	**type**\:  :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_phase_two_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Phase Two
                                    	**type**\:  :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_done_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Done
                                    	**type**\:  :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                    
                                    .. attribute:: graceful_maintenance
                                    
                                    	Graceful Maintenance
                                    	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                    
                                    .. attribute:: speaker_id
                                    
                                    	Speaker this neighbor is allocated to
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: description
                                    
                                    	Description
                                    	**type**\: str
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_internal_link
                                    
                                    	Internal link to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: is_external_neighbor_not_directly_connected
                                    
                                    	External neighbor not directly connected
                                    	**type**\: bool
                                    
                                    .. attribute:: messages_received
                                    
                                    	Number of messages received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_sent
                                    
                                    	Number of messages sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_messages_in
                                    
                                    	No. of update msgs received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_messages_out
                                    
                                    	No. of update messages sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_queued_in
                                    
                                    	No. of msgs on receive queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_queued_out
                                    
                                    	No. of messages on send queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_established_time
                                    
                                    	Time (in secs) that the connection has been established
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                    
                                    .. attribute:: previous_connection_state
                                    
                                    	Previous state of connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_admin_status
                                    
                                    	Administrative status of connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: open_check_error_code
                                    
                                    	Open check error code
                                    	**type**\:  :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                    
                                    .. attribute:: is_local_address_configured
                                    
                                    	Local address configured for the neighbor connection
                                    	**type**\: bool
                                    
                                    .. attribute:: connection_local_port
                                    
                                    	Local port for the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_remote_port
                                    
                                    	Remote port for the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_interface_handle
                                    
                                    	Interface Handle of Neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_notification_sent
                                    
                                    	Notification was sent during last reset
                                    	**type**\: bool
                                    
                                    .. attribute:: is_administratively_shut_down
                                    
                                    	Neighbor is administratively shut down
                                    	**type**\: bool
                                    
                                    .. attribute:: is_neighbor_max_prefix_shutdown
                                    
                                    	Neighbor shut down because it exceeded max prfx count
                                    	**type**\: bool
                                    
                                    .. attribute:: is_out_of_memory_shutdown
                                    
                                    	Neighbor shut down during a SEVERE low memory condition
                                    	**type**\: bool
                                    
                                    .. attribute:: is_out_of_memory_forced_up
                                    
                                    	Neighbor forced up during a low memory condition
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ebgp_peer_as_league
                                    
                                    	EBGP peer belongs to AS League
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ebgp_peer_common_admin
                                    
                                    	EBGP peer with common administation
                                    	**type**\: bool
                                    
                                    .. attribute:: ttl_security_enabled
                                    
                                    	TTL Security enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: suppress4_byte_as
                                    
                                    	Suppress 4byteas capability
                                    	**type**\: bool
                                    
                                    .. attribute:: bfd_session_state
                                    
                                    	BFD state for this peer
                                    	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                    
                                    .. attribute:: bfd_session_created_state
                                    
                                    	BFD state for this peer
                                    	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                    
                                    .. attribute:: bfd_session_enable_mode
                                    
                                    	BFD enable mode for this peer
                                    	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                    
                                    .. attribute:: bfd_minintervalval
                                    
                                    	BFD Mininterval for this peer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_multiplierval
                                    
                                    	BFD Multiplier for this peer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_state_ts
                                    
                                    	Timestamp since when nbr is in this bfd state
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: router_id
                                    
                                    	Router ID for the neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: negotiated_protocol_version
                                    
                                    	Negotiated protocol version
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ebgp_time_to_live
                                    
                                    	Maximum number of hops for external BGP neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                    
                                    	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: tcpmss
                                    
                                    	Neighbor TCP Maximum Segment                     size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: msg_log_in
                                    
                                    	Message in log count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: msg_log_out
                                    
                                    	Message out log count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_local_as
                                    
                                    	Local AS configured on the neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_no_prepend
                                    
                                    	Option to not prepend the Local AS to announcements
                                    	**type**\: bool
                                    
                                    .. attribute:: is_capability_negotiation_suppressed
                                    
                                    	Capability negotiation suppressed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_capability_negotiation_performed
                                    
                                    	Capability negotiation performed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_route_refresh_capability_received
                                    
                                    	Route refresh capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_route_refresh_old_capability_received
                                    
                                    	Route refresh old capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_gr_aware
                                    
                                    	GR awareness received
                                    	**type**\: bool
                                    
                                    .. attribute:: is4_byte_as_capability_received
                                    
                                    	4\-byte AScapability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is4_byte_as_capability_sent
                                    
                                    	4\-byte AScapability Snt
                                    	**type**\: bool
                                    
                                    .. attribute:: multi_protocol_capability_received
                                    
                                    	Multi\-protocol capability has been received
                                    	**type**\: bool
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time (in secs) negotiated for this connection
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: keep_alive_time
                                    
                                    	Keepalive time (in secs) negotiated for this connection
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_hold_time
                                    
                                    	Hold time (in secs) configured for this connection
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_keepalive
                                    
                                    	Keepalive time (in secs) configured for this connection
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_min_acc_hold_time
                                    
                                    	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: min_advertise_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: min_advertise_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: min_origination_interval
                                    
                                    	Minimum origination interval (in secs)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connect_retry_interval
                                    
                                    	Time (in secs) for connect retry timer
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_update
                                    
                                    	Time (in secs) since last update message was received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read
                                    
                                    	Time (in secs) since last read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read_reset
                                    
                                    	Time (in secs) since last read before last reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_last_cb
                                    
                                    	CB
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: time_last_cb_reset
                                    
                                    	Last CB before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_last_fb
                                    
                                    	FB
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: count_last_write
                                    
                                    	Count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_last_write
                                    
                                    	Time (in secs) since last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: attempted_last_write_bytes
                                    
                                    	Attempted size of last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_last_write_bytes
                                    
                                    	Actual size of last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_second_last_write
                                    
                                    	Time (in secs) since second  last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: attempted_second_last_write_bytes
                                    
                                    	Attempted size of second last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_bytes
                                    
                                    	Actual size of second last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: attempted_last_write_reset_bytes
                                    
                                    	Attempted size of last write before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_last_write_reset_bytes
                                    
                                    	Actual size of last write before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_second_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: attempted_second_last_write_reset_bytes
                                    
                                    	Attempted size of second last write before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_reset_bytes
                                    
                                    	Actual size of second last write before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_write_event
                                    
                                    	Time (in secs) since last write thread event
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_write_event
                                    
                                    	Time (in secs) since second last write thread event
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_aexpiry_reset
                                    
                                    	Time (in secs) since last KA timer expiry before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_k_aexpiry_reset
                                    
                                    	Time (in secs) since second last KA timer expiry before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_anotsent_reset
                                    
                                    	Duration (in secs) since last time that KA was not sent before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_aerror_reset
                                    
                                    	Duration (in secs) since last time that an error was encountered after KA expiry
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_astart_reset
                                    
                                    	Time (in secs) since the last KA timer start before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_k_astart_reset
                                    
                                    	Time (in secs) since the second last KA timer start before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of times the connection was established
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of times connection was dropped
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_connection_last_dropped
                                    
                                    	Time since the connection last went down (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: reset_reason
                                    
                                    	Reason for last connection reset
                                    	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    .. attribute:: peer_reset_reason
                                    
                                    	Reason for last peer close event
                                    	**type**\:  :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                    
                                    .. attribute:: peer_error_code
                                    
                                    	If peer closed, error received from transport
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_notify_error_code
                                    
                                    	Code for the last error notification seen on the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notify_error_subcode
                                    
                                    	Error subcode of the last error notification seen on the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: error_notifies_received
                                    
                                    	Number of error notifications received on the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: error_notifies_sent
                                    
                                    	Number of error notifications sent on the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as_number
                                    
                                    	Remote AS number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dmz_link_bandwidth
                                    
                                    	Bandwidth of link to single\-hop eBGP peer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ebgp_recv_dmz
                                    
                                    	Receive Bandwidth of link to single\-hop eBGP peer
                                    	**type**\: bool
                                    
                                    .. attribute:: ebgp_send_dmz_mode
                                    
                                    	Ebgp send dmz link bw mode
                                    	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence or DSCP type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tcp_session_open_mode
                                    
                                    	The TCP mode to be used to set up BGP session with the neighbor
                                    	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: standby_rp
                                    
                                    	Standby RP socket inited for Active Open
                                    	**type**\: bool
                                    
                                    .. attribute:: nsr_enabled
                                    
                                    	Neighbor supports NSR
                                    	**type**\: bool
                                    
                                    .. attribute:: graceful_restart_enabled_nbr
                                    
                                    	Neighbor supports graceful\-restart
                                    	**type**\: bool
                                    
                                    .. attribute:: gr_restart_time
                                    
                                    	Neighbor restart time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: gr_stale_path_time
                                    
                                    	Neighbor stale\-path time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: fssn_offset
                                    
                                    	First standby SeqNo offset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fpbsn_offset
                                    
                                    	First standby PDU boundary SeqNo offset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_ackd_seq_no
                                    
                                    	SeqNo of the last Ackd byte
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bytes_written
                                    
                                    	Total bytes written by write thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bytes_read
                                    
                                    	Total bytes read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: socket_read_bytes
                                    
                                    	Total read bytes value insocket\-lib
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: is_read_disabled
                                    
                                    	If true, socket read isdisabled
                                    	**type**\: bool
                                    
                                    .. attribute:: update_bytes_read
                                    
                                    	Total update bytes read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: nsr_state
                                    
                                    	NSR state
                                    	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                    
                                    .. attribute:: is_passive_close
                                    
                                    	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: nbr_enforce_first_as
                                    
                                    	Neighbor enforce first AS
                                    	**type**\: bool
                                    
                                    .. attribute:: active_bmp_servers
                                    
                                    	BMP Servers to which the neighbor sends logs
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nbr_cluster_id
                                    
                                    	Cluster id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nbr_in_cluster
                                    
                                    	Type of cluster\_id\:undefined/number/Ip address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ignore_connected
                                    
                                    	If true, the VPN client isan IBGP CE peer
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_vpn_client
                                    
                                    	If true, don't do NHconnected check for nbr
                                    	**type**\: bool
                                    
                                    .. attribute:: io_armed
                                    
                                    	If true, socket has beenauto\-armed for io control
                                    	**type**\: bool
                                    
                                    .. attribute:: read_armed
                                    
                                    	If true, socket has beenauto\-armed for read
                                    	**type**\: bool
                                    
                                    .. attribute:: write_armed
                                    
                                    	If true, socket has beenauto\-armed for write
                                    	**type**\: bool
                                    
                                    .. attribute:: discard_data_bytes
                                    
                                    	Remaining discard data (bytes) on Standby
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\: bool
                                    
                                    .. attribute:: local_as_dual_as
                                    
                                    	Local AS Dual\-AS option
                                    	**type**\: bool
                                    
                                    .. attribute:: local_as_dual_as_mode_native
                                    
                                    	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                    	**type**\: bool
                                    
                                    .. attribute:: egress_peer_engineering_enabled
                                    
                                    	Indicates if Egress Peer Engineering is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: discard_as4_path
                                    
                                    	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: rpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\: bool
                                    
                                    .. attribute:: rpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: rpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\: bool
                                    
                                    .. attribute:: dynamic_neighbor
                                    
                                    	Dynamic neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: af_data
                                    
                                    	Address family specific neighbor data
                                    	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "neighbor-af-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['neighbor_address']
                                        self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress)), ("send-notification-info", ("send_notification_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo)), ("received-notification-info", ("received_notification_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics)), ("message-statistics", ("message_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics)), ("tcp-init-sync-time-spec", ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec)), ("tcp-init-sync-phase-two-time-spec", ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec)), ("tcp-init-sync-done-time-spec", ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData))])
                                        self._leafs = OrderedDict([
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                            ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                            ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                            ('is_external_neighbor_not_directly_connected', (YLeaf(YType.boolean, 'is-external-neighbor-not-directly-connected'), ['bool'])),
                                            ('messages_received', (YLeaf(YType.uint32, 'messages-received'), ['int'])),
                                            ('messages_sent', (YLeaf(YType.uint32, 'messages-sent'), ['int'])),
                                            ('update_messages_in', (YLeaf(YType.uint32, 'update-messages-in'), ['int'])),
                                            ('update_messages_out', (YLeaf(YType.uint32, 'update-messages-out'), ['int'])),
                                            ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                            ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                            ('connection_established_time', (YLeaf(YType.uint32, 'connection-established-time'), ['int'])),
                                            ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                            ('previous_connection_state', (YLeaf(YType.uint32, 'previous-connection-state'), ['int'])),
                                            ('connection_admin_status', (YLeaf(YType.uint32, 'connection-admin-status'), ['int'])),
                                            ('open_check_error_code', (YLeaf(YType.enumeration, 'open-check-error-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpOpenCheckErr', '')])),
                                            ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                            ('connection_local_port', (YLeaf(YType.uint32, 'connection-local-port'), ['int'])),
                                            ('connection_remote_port', (YLeaf(YType.uint32, 'connection-remote-port'), ['int'])),
                                            ('neighbor_interface_handle', (YLeaf(YType.uint32, 'neighbor-interface-handle'), ['int'])),
                                            ('reset_notification_sent', (YLeaf(YType.boolean, 'reset-notification-sent'), ['bool'])),
                                            ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                            ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                            ('is_out_of_memory_shutdown', (YLeaf(YType.boolean, 'is-out-of-memory-shutdown'), ['bool'])),
                                            ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                            ('is_ebgp_peer_as_league', (YLeaf(YType.boolean, 'is-ebgp-peer-as-league'), ['bool'])),
                                            ('is_ebgp_peer_common_admin', (YLeaf(YType.boolean, 'is-ebgp-peer-common-admin'), ['bool'])),
                                            ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                            ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                            ('bfd_session_state', (YLeaf(YType.enumeration, 'bfd-session-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                            ('bfd_session_created_state', (YLeaf(YType.enumeration, 'bfd-session-created-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                            ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                            ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                            ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                            ('bfd_state_ts', (YLeaf(YType.uint64, 'bfd-state-ts'), ['int'])),
                                            ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                            ('negotiated_protocol_version', (YLeaf(YType.uint16, 'negotiated-protocol-version'), ['int'])),
                                            ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                            ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                            ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                            ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                            ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                            ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                            ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                            ('is_capability_negotiation_suppressed', (YLeaf(YType.boolean, 'is-capability-negotiation-suppressed'), ['bool'])),
                                            ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                            ('is_route_refresh_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-capability-received'), ['bool'])),
                                            ('is_route_refresh_old_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-old-capability-received'), ['bool'])),
                                            ('is_gr_aware', (YLeaf(YType.boolean, 'is-gr-aware'), ['bool'])),
                                            ('is4_byte_as_capability_received', (YLeaf(YType.boolean, 'is4-byte-as-capability-received'), ['bool'])),
                                            ('is4_byte_as_capability_sent', (YLeaf(YType.boolean, 'is4-byte-as-capability-sent'), ['bool'])),
                                            ('multi_protocol_capability_received', (YLeaf(YType.boolean, 'multi-protocol-capability-received'), ['bool'])),
                                            ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                            ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                            ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                            ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                            ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                            ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                            ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                            ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                            ('connect_retry_interval', (YLeaf(YType.uint16, 'connect-retry-interval'), ['int'])),
                                            ('time_since_last_update', (YLeaf(YType.uint32, 'time-since-last-update'), ['int'])),
                                            ('time_since_last_read', (YLeaf(YType.uint32, 'time-since-last-read'), ['int'])),
                                            ('time_since_last_read_reset', (YLeaf(YType.uint32, 'time-since-last-read-reset'), ['int'])),
                                            ('time_last_cb', (YLeaf(YType.uint64, 'time-last-cb'), ['int'])),
                                            ('time_last_cb_reset', (YLeaf(YType.uint32, 'time-last-cb-reset'), ['int'])),
                                            ('time_last_fb', (YLeaf(YType.uint64, 'time-last-fb'), ['int'])),
                                            ('count_last_write', (YLeaf(YType.uint32, 'count-last-write'), ['int'])),
                                            ('time_since_last_write', (YLeaf(YType.uint32, 'time-since-last-write'), ['int'])),
                                            ('attempted_last_write_bytes', (YLeaf(YType.uint32, 'attempted-last-write-bytes'), ['int'])),
                                            ('actual_last_write_bytes', (YLeaf(YType.uint32, 'actual-last-write-bytes'), ['int'])),
                                            ('time_since_second_last_write', (YLeaf(YType.uint32, 'time-since-second-last-write'), ['int'])),
                                            ('attempted_second_last_write_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-bytes'), ['int'])),
                                            ('actual_second_last_write_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-bytes'), ['int'])),
                                            ('time_since_last_write_reset', (YLeaf(YType.uint32, 'time-since-last-write-reset'), ['int'])),
                                            ('attempted_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-last-write-reset-bytes'), ['int'])),
                                            ('actual_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-last-write-reset-bytes'), ['int'])),
                                            ('time_since_second_last_write_reset', (YLeaf(YType.uint32, 'time-since-second-last-write-reset'), ['int'])),
                                            ('attempted_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-reset-bytes'), ['int'])),
                                            ('actual_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-reset-bytes'), ['int'])),
                                            ('last_write_event', (YLeaf(YType.uint32, 'last-write-event'), ['int'])),
                                            ('second_last_write_event', (YLeaf(YType.uint32, 'second-last-write-event'), ['int'])),
                                            ('last_k_aexpiry_reset', (YLeaf(YType.uint32, 'last-k-aexpiry-reset'), ['int'])),
                                            ('second_last_k_aexpiry_reset', (YLeaf(YType.uint32, 'second-last-k-aexpiry-reset'), ['int'])),
                                            ('last_k_anotsent_reset', (YLeaf(YType.uint32, 'last-k-anotsent-reset'), ['int'])),
                                            ('last_k_aerror_reset', (YLeaf(YType.uint32, 'last-k-aerror-reset'), ['int'])),
                                            ('last_k_astart_reset', (YLeaf(YType.uint32, 'last-k-astart-reset'), ['int'])),
                                            ('second_last_k_astart_reset', (YLeaf(YType.uint32, 'second-last-k-astart-reset'), ['int'])),
                                            ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                            ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                            ('time_since_connection_last_dropped', (YLeaf(YType.uint32, 'time-since-connection-last-dropped'), ['int'])),
                                            ('reset_reason', (YLeaf(YType.enumeration, 'reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                            ('peer_reset_reason', (YLeaf(YType.enumeration, 'peer-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPeerResetReasonIndex', '')])),
                                            ('peer_error_code', (YLeaf(YType.uint32, 'peer-error-code'), ['int'])),
                                            ('last_notify_error_code', (YLeaf(YType.uint8, 'last-notify-error-code'), ['int'])),
                                            ('last_notify_error_subcode', (YLeaf(YType.uint8, 'last-notify-error-subcode'), ['int'])),
                                            ('error_notifies_received', (YLeaf(YType.uint32, 'error-notifies-received'), ['int'])),
                                            ('error_notifies_sent', (YLeaf(YType.uint32, 'error-notifies-sent'), ['int'])),
                                            ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                            ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                            ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                            ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                            ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                            ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                            ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                            ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                            ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                            ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                            ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                            ('fssn_offset', (YLeaf(YType.uint32, 'fssn-offset'), ['int'])),
                                            ('fpbsn_offset', (YLeaf(YType.uint32, 'fpbsn-offset'), ['int'])),
                                            ('last_ackd_seq_no', (YLeaf(YType.uint32, 'last-ackd-seq-no'), ['int'])),
                                            ('bytes_written', (YLeaf(YType.uint32, 'bytes-written'), ['int'])),
                                            ('bytes_read', (YLeaf(YType.uint32, 'bytes-read'), ['int'])),
                                            ('socket_read_bytes', (YLeaf(YType.uint32, 'socket-read-bytes'), ['int'])),
                                            ('is_read_disabled', (YLeaf(YType.boolean, 'is-read-disabled'), ['bool'])),
                                            ('update_bytes_read', (YLeaf(YType.uint32, 'update-bytes-read'), ['int'])),
                                            ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                            ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                            ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                            ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                            ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                            ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                            ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                            ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                            ('io_armed', (YLeaf(YType.boolean, 'io-armed'), ['bool'])),
                                            ('read_armed', (YLeaf(YType.boolean, 'read-armed'), ['bool'])),
                                            ('write_armed', (YLeaf(YType.boolean, 'write-armed'), ['bool'])),
                                            ('discard_data_bytes', (YLeaf(YType.uint32, 'discard-data-bytes'), ['int'])),
                                            ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                            ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                            ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                            ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                            ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                            ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                            ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                            ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                            ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                            ('dynamic_neighbor', (YLeaf(YType.boolean, 'dynamic-neighbor'), ['bool'])),
                                        ])
                                        self.neighbor_address = None
                                        self.speaker_id = None
                                        self.description = None
                                        self.local_as = None
                                        self.remote_as = None
                                        self.has_internal_link = None
                                        self.is_external_neighbor_not_directly_connected = None
                                        self.messages_received = None
                                        self.messages_sent = None
                                        self.update_messages_in = None
                                        self.update_messages_out = None
                                        self.messages_queued_in = None
                                        self.messages_queued_out = None
                                        self.connection_established_time = None
                                        self.connection_state = None
                                        self.previous_connection_state = None
                                        self.connection_admin_status = None
                                        self.open_check_error_code = None
                                        self.is_local_address_configured = None
                                        self.connection_local_port = None
                                        self.connection_remote_port = None
                                        self.neighbor_interface_handle = None
                                        self.reset_notification_sent = None
                                        self.is_administratively_shut_down = None
                                        self.is_neighbor_max_prefix_shutdown = None
                                        self.is_out_of_memory_shutdown = None
                                        self.is_out_of_memory_forced_up = None
                                        self.is_ebgp_peer_as_league = None
                                        self.is_ebgp_peer_common_admin = None
                                        self.ttl_security_enabled = None
                                        self.suppress4_byte_as = None
                                        self.bfd_session_state = None
                                        self.bfd_session_created_state = None
                                        self.bfd_session_enable_mode = None
                                        self.bfd_minintervalval = None
                                        self.bfd_multiplierval = None
                                        self.bfd_state_ts = None
                                        self.router_id = None
                                        self.negotiated_protocol_version = None
                                        self.ebgp_time_to_live = None
                                        self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                        self.tcpmss = None
                                        self.msg_log_in = None
                                        self.msg_log_out = None
                                        self.neighbor_local_as = None
                                        self.local_as_no_prepend = None
                                        self.is_capability_negotiation_suppressed = None
                                        self.is_capability_negotiation_performed = None
                                        self.is_route_refresh_capability_received = None
                                        self.is_route_refresh_old_capability_received = None
                                        self.is_gr_aware = None
                                        self.is4_byte_as_capability_received = None
                                        self.is4_byte_as_capability_sent = None
                                        self.multi_protocol_capability_received = None
                                        self.hold_time = None
                                        self.keep_alive_time = None
                                        self.configured_hold_time = None
                                        self.configured_keepalive = None
                                        self.configured_min_acc_hold_time = None
                                        self.min_advertise_interval = None
                                        self.min_advertise_interval_msecs = None
                                        self.min_origination_interval = None
                                        self.connect_retry_interval = None
                                        self.time_since_last_update = None
                                        self.time_since_last_read = None
                                        self.time_since_last_read_reset = None
                                        self.time_last_cb = None
                                        self.time_last_cb_reset = None
                                        self.time_last_fb = None
                                        self.count_last_write = None
                                        self.time_since_last_write = None
                                        self.attempted_last_write_bytes = None
                                        self.actual_last_write_bytes = None
                                        self.time_since_second_last_write = None
                                        self.attempted_second_last_write_bytes = None
                                        self.actual_second_last_write_bytes = None
                                        self.time_since_last_write_reset = None
                                        self.attempted_last_write_reset_bytes = None
                                        self.actual_last_write_reset_bytes = None
                                        self.time_since_second_last_write_reset = None
                                        self.attempted_second_last_write_reset_bytes = None
                                        self.actual_second_last_write_reset_bytes = None
                                        self.last_write_event = None
                                        self.second_last_write_event = None
                                        self.last_k_aexpiry_reset = None
                                        self.second_last_k_aexpiry_reset = None
                                        self.last_k_anotsent_reset = None
                                        self.last_k_aerror_reset = None
                                        self.last_k_astart_reset = None
                                        self.second_last_k_astart_reset = None
                                        self.connection_up_count = None
                                        self.connection_down_count = None
                                        self.time_since_connection_last_dropped = None
                                        self.reset_reason = None
                                        self.peer_reset_reason = None
                                        self.peer_error_code = None
                                        self.last_notify_error_code = None
                                        self.last_notify_error_subcode = None
                                        self.error_notifies_received = None
                                        self.error_notifies_sent = None
                                        self.remote_as_number = None
                                        self.dmz_link_bandwidth = None
                                        self.ebgp_recv_dmz = None
                                        self.ebgp_send_dmz_mode = None
                                        self.tos_type = None
                                        self.tos_value = None
                                        self.tcp_session_open_mode = None
                                        self.vrf_name = None
                                        self.standby_rp = None
                                        self.nsr_enabled = None
                                        self.graceful_restart_enabled_nbr = None
                                        self.gr_restart_time = None
                                        self.gr_stale_path_time = None
                                        self.fssn_offset = None
                                        self.fpbsn_offset = None
                                        self.last_ackd_seq_no = None
                                        self.bytes_written = None
                                        self.bytes_read = None
                                        self.socket_read_bytes = None
                                        self.is_read_disabled = None
                                        self.update_bytes_read = None
                                        self.nsr_state = None
                                        self.is_passive_close = None
                                        self.nbr_enforce_first_as = None
                                        self.active_bmp_servers = None
                                        self.nbr_cluster_id = None
                                        self.nbr_in_cluster = None
                                        self.ignore_connected = None
                                        self.internal_vpn_client = None
                                        self.io_armed = None
                                        self.read_armed = None
                                        self.write_armed = None
                                        self.discard_data_bytes = None
                                        self.local_as_replace_as = None
                                        self.local_as_dual_as = None
                                        self.local_as_dual_as_mode_native = None
                                        self.egress_peer_engineering_enabled = None
                                        self.discard_as4_path = None
                                        self.rpki_disable = None
                                        self.rpki_use_validity = None
                                        self.rpki_allow_invalid = None
                                        self.rpki_signal_ibgp = None
                                        self.dynamic_neighbor = None

                                        self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                        self.connection_local_address.parent = self
                                        self._children_name_map["connection_local_address"] = "connection-local-address"

                                        self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                        self.connection_remote_address.parent = self
                                        self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                        self.send_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                        self.send_notification_info.parent = self
                                        self._children_name_map["send_notification_info"] = "send-notification-info"

                                        self.received_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                        self.received_notification_info.parent = self
                                        self._children_name_map["received_notification_info"] = "received-notification-info"

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"

                                        self.message_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                        self.message_statistics.parent = self
                                        self._children_name_map["message_statistics"] = "message-statistics"

                                        self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                        self.tcp_init_sync_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"

                                        self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                        self.tcp_init_sync_phase_two_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"

                                        self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                        self.tcp_init_sync_done_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"

                                        self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                        self.graceful_maintenance.parent = self
                                        self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                        self.af_data = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_external_neighbor_not_directly_connected', u'messages_received', u'messages_sent', u'update_messages_in', u'update_messages_out', u'messages_queued_in', u'messages_queued_out', u'connection_established_time', u'connection_state', u'previous_connection_state', u'connection_admin_status', u'open_check_error_code', u'is_local_address_configured', u'connection_local_port', u'connection_remote_port', u'neighbor_interface_handle', u'reset_notification_sent', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_shutdown', u'is_out_of_memory_forced_up', u'is_ebgp_peer_as_league', u'is_ebgp_peer_common_admin', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_state', u'bfd_session_created_state', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'bfd_state_ts', u'router_id', u'negotiated_protocol_version', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_suppressed', u'is_capability_negotiation_performed', u'is_route_refresh_capability_received', u'is_route_refresh_old_capability_received', u'is_gr_aware', u'is4_byte_as_capability_received', u'is4_byte_as_capability_sent', u'multi_protocol_capability_received', u'hold_time', u'keep_alive_time', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'connect_retry_interval', u'time_since_last_update', u'time_since_last_read', u'time_since_last_read_reset', u'time_last_cb', u'time_last_cb_reset', u'time_last_fb', u'count_last_write', u'time_since_last_write', u'attempted_last_write_bytes', u'actual_last_write_bytes', u'time_since_second_last_write', u'attempted_second_last_write_bytes', u'actual_second_last_write_bytes', u'time_since_last_write_reset', u'attempted_last_write_reset_bytes', u'actual_last_write_reset_bytes', u'time_since_second_last_write_reset', u'attempted_second_last_write_reset_bytes', u'actual_second_last_write_reset_bytes', u'last_write_event', u'second_last_write_event', u'last_k_aexpiry_reset', u'second_last_k_aexpiry_reset', u'last_k_anotsent_reset', u'last_k_aerror_reset', u'last_k_astart_reset', u'second_last_k_astart_reset', u'connection_up_count', u'connection_down_count', u'time_since_connection_last_dropped', u'reset_reason', u'peer_reset_reason', u'peer_error_code', u'last_notify_error_code', u'last_notify_error_subcode', u'error_notifies_received', u'error_notifies_sent', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'fssn_offset', u'fpbsn_offset', u'last_ackd_seq_no', u'bytes_written', u'bytes_read', u'socket_read_bytes', u'is_read_disabled', u'update_bytes_read', u'nsr_state', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'io_armed', u'read_armed', u'write_armed', u'discard_data_bytes', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'dynamic_neighbor'], name, value)


                                    class ConnectionLocalAddress(Entity):
                                        """
                                        Local address for the connection
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, self).__init__()

                                            self.yang_name = "connection-local-address"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "connection-local-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class ConnectionRemoteAddress(Entity):
                                        """
                                        Remote address for the connection
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, self).__init__()

                                            self.yang_name = "connection-remote-address"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "connection-remote-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class SendNotificationInfo(Entity):
                                        """
                                        Information on the last notification sent
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, self).__init__()

                                            self.yang_name = "send-notification-info"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData))])
                                            self._leafs = OrderedDict([
                                                ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                                ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                                ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                            ])
                                            self.time_since_last_notification = None
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "send-notification-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "send-notification-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "last-notification-data"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                    class ReceivedNotificationInfo(Entity):
                                        """
                                        Information on the last notification received
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, self).__init__()

                                            self.yang_name = "received-notification-info"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData))])
                                            self._leafs = OrderedDict([
                                                ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                                ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                                ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                            ])
                                            self.time_since_last_notification = None
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "received-notification-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "received-notification-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "last-notification-data"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: read_throttles
                                        
                                        	Number of partial read throttles
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_throttled_read
                                        
                                        	Num socket reads after nbrs crossed low threshold
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: high_throttled_read
                                        
                                        	Num of socket reads after nbr crossed high threshold
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_last_throttled_read
                                        
                                        	Time (in secs) since last read after being throttled
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: read_calls_count
                                        
                                        	No. of calls to function to read inbound data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_messages_count
                                        
                                        	Number of BGP messages read
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: data_bytes_read
                                        
                                        	No. of bytes of data read
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: io_read_time
                                        
                                        	Time spent reading inbound data (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: write_calls_count
                                        
                                        	No. of calls to function to write outbound data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: data_bytes_written
                                        
                                        	No. of data bytes written
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: io_write_time
                                        
                                        	Time spent writing outbound data (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: last_sent_seq_no
                                        
                                        	Seq No of the last sent byte
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_subgroup_calls_count
                                        
                                        	No. of calls to function to process sub\-group message list
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_subgroup_messages_count
                                        
                                        	Number of sub\-group msgs processed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: subgroup_list_time
                                        
                                        	Time spent processing sub\-group message list  (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: write_queue_calls_count
                                        
                                        	No. of calls to function to process write queue
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_messages_count
                                        
                                        	Number of write queue messages processed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_time
                                        
                                        	Time spent processing write queue (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: inbound_update_messages
                                        
                                        	Number of inbound update messages processed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_update_messages_time
                                        
                                        	Time spent processing inbound update messages (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: maximum_read_size
                                        
                                        	Size of largest socket (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: actives
                                        
                                        	Number of retried Active opens for this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: failed_post_actives
                                        
                                        	Number of Active Opens that failed in the Post Active State for this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passives
                                        
                                        	Number of retried Passive opens for this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rejected_passives
                                        
                                        	Number of rejected Passive opens for this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: active_collision
                                        
                                        	Number of Closed Active connections for this neighbor due to collision 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passive_collision
                                        
                                        	Number of Closed Remote opens for this neighborneighbor due to collision 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_read_thread_trigger
                                        
                                        	Number of times io\-control thread trigger read thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_write_thread_trigger
                                        
                                        	Number of times io\-control thread trigger write thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network_status
                                        
                                        	Socket status, TRUE if socket closed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_flags
                                        
                                        	Reset flags, per thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nbr_flags
                                        
                                        	Nbr flags, per thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nbr_fd
                                        
                                        	Primary FD, per nbr
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: reset_retries
                                        
                                        	Reset Retries, per nbr
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: sync_flags
                                        
                                        	Sync flags, per nbr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_oper_down_count
                                        
                                        	Number of times NSR scoped sync has been done
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_nsr_scoped_sync
                                        
                                        	Last time NSR scoped syncwas done for the neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('read_throttles', (YLeaf(YType.uint32, 'read-throttles'), ['int'])),
                                                ('low_throttled_read', (YLeaf(YType.uint32, 'low-throttled-read'), ['int'])),
                                                ('high_throttled_read', (YLeaf(YType.uint32, 'high-throttled-read'), ['int'])),
                                                ('time_since_last_throttled_read', (YLeaf(YType.uint32, 'time-since-last-throttled-read'), ['int'])),
                                                ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                                ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                                ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                                ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                                ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                                ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                                ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                                ('last_sent_seq_no', (YLeaf(YType.uint32, 'last-sent-seq-no'), ['int'])),
                                                ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                                ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                                ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                                ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                                ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                                ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                                ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                                ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                                ('maximum_read_size', (YLeaf(YType.uint32, 'maximum-read-size'), ['int'])),
                                                ('actives', (YLeaf(YType.uint32, 'actives'), ['int'])),
                                                ('failed_post_actives', (YLeaf(YType.uint32, 'failed-post-actives'), ['int'])),
                                                ('passives', (YLeaf(YType.uint32, 'passives'), ['int'])),
                                                ('rejected_passives', (YLeaf(YType.uint32, 'rejected-passives'), ['int'])),
                                                ('active_collision', (YLeaf(YType.uint32, 'active-collision'), ['int'])),
                                                ('passive_collision', (YLeaf(YType.uint32, 'passive-collision'), ['int'])),
                                                ('control_to_read_thread_trigger', (YLeaf(YType.uint32, 'control-to-read-thread-trigger'), ['int'])),
                                                ('control_to_write_thread_trigger', (YLeaf(YType.uint32, 'control-to-write-thread-trigger'), ['int'])),
                                                ('network_status', (YLeaf(YType.uint32, 'network-status'), ['int'])),
                                                ('reset_flags', (YLeaf(YType.uint32, 'reset-flags'), ['int'])),
                                                ('nbr_flags', (YLeaf(YType.uint32, 'nbr-flags'), ['int'])),
                                                ('nbr_fd', (YLeaf(YType.int32, 'nbr-fd'), ['int'])),
                                                ('reset_retries', (YLeaf(YType.uint8, 'reset-retries'), ['int'])),
                                                ('sync_flags', (YLeaf(YType.uint32, 'sync-flags'), ['int'])),
                                                ('nsr_oper_down_count', (YLeaf(YType.uint32, 'nsr-oper-down-count'), ['int'])),
                                                ('last_nsr_scoped_sync', (YLeaf(YType.uint32, 'last-nsr-scoped-sync'), ['int'])),
                                            ])
                                            self.read_throttles = None
                                            self.low_throttled_read = None
                                            self.high_throttled_read = None
                                            self.time_since_last_throttled_read = None
                                            self.read_calls_count = None
                                            self.read_messages_count = None
                                            self.data_bytes_read = None
                                            self.io_read_time = None
                                            self.write_calls_count = None
                                            self.data_bytes_written = None
                                            self.io_write_time = None
                                            self.last_sent_seq_no = None
                                            self.write_subgroup_calls_count = None
                                            self.write_subgroup_messages_count = None
                                            self.subgroup_list_time = None
                                            self.write_queue_calls_count = None
                                            self.write_queue_messages_count = None
                                            self.write_queue_time = None
                                            self.inbound_update_messages = None
                                            self.inbound_update_messages_time = None
                                            self.maximum_read_size = None
                                            self.actives = None
                                            self.failed_post_actives = None
                                            self.passives = None
                                            self.rejected_passives = None
                                            self.active_collision = None
                                            self.passive_collision = None
                                            self.control_to_read_thread_trigger = None
                                            self.control_to_write_thread_trigger = None
                                            self.network_status = None
                                            self.reset_flags = None
                                            self.nbr_flags = None
                                            self.nbr_fd = None
                                            self.reset_retries = None
                                            self.sync_flags = None
                                            self.nsr_oper_down_count = None
                                            self.last_nsr_scoped_sync = None
                                            self._segment_path = lambda: "performance-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, [u'read_throttles', u'low_throttled_read', u'high_throttled_read', u'time_since_last_throttled_read', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'last_sent_seq_no', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time', u'maximum_read_size', u'actives', u'failed_post_actives', u'passives', u'rejected_passives', u'active_collision', u'passive_collision', u'control_to_read_thread_trigger', u'control_to_write_thread_trigger', u'network_status', u'reset_flags', u'nbr_flags', u'nbr_fd', u'reset_retries', u'sync_flags', u'nsr_oper_down_count', u'last_nsr_scoped_sync'], name, value)


                                    class MessageStatistics(Entity):
                                        """
                                        Message statistics
                                        
                                        .. attribute:: open
                                        
                                        	Open
                                        	**type**\:  :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                        
                                        .. attribute:: notification
                                        
                                        	Notification
                                        	**type**\:  :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                        
                                        .. attribute:: update
                                        
                                        	Update
                                        	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                        
                                        .. attribute:: keepalive
                                        
                                        	Keepalive
                                        	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                        
                                        .. attribute:: route_refresh
                                        
                                        	Route refresh
                                        	**type**\:  :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                        
                                        .. attribute:: total
                                        
                                        	Total
                                        	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, self).__init__()

                                            self.yang_name = "message-statistics"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("open", ("open", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open)), ("notification", ("notification", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification)), ("update", ("update", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update)), ("keepalive", ("keepalive", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive)), ("route-refresh", ("route_refresh", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh)), ("total", ("total", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total))])
                                            self._leafs = OrderedDict()

                                            self.open = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                            self.open.parent = self
                                            self._children_name_map["open"] = "open"

                                            self.notification = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                            self.notification.parent = self
                                            self._children_name_map["notification"] = "notification"

                                            self.update = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                            self.update.parent = self
                                            self._children_name_map["update"] = "update"

                                            self.keepalive = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                            self.keepalive.parent = self
                                            self._children_name_map["keepalive"] = "keepalive"

                                            self.route_refresh = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                            self.route_refresh.parent = self
                                            self._children_name_map["route_refresh"] = "route-refresh"

                                            self.total = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                            self.total.parent = self
                                            self._children_name_map["total"] = "total"
                                            self._segment_path = lambda: "message-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, [], name, value)


                                        class Open(Entity):
                                            """
                                            Open
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, self).__init__()

                                                self.yang_name = "open"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "open"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "open"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "open"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Notification(Entity):
                                            """
                                            Notification
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, self).__init__()

                                                self.yang_name = "notification"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "notification"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "notification"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "notification"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Update(Entity):
                                            """
                                            Update
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, self).__init__()

                                                self.yang_name = "update"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "update"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Keepalive(Entity):
                                            """
                                            Keepalive
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                                self.yang_name = "keepalive"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "keepalive"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "keepalive"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "keepalive"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class RouteRefresh(Entity):
                                            """
                                            Route refresh
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                                self.yang_name = "route-refresh"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "route-refresh"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "route-refresh"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "route-refresh"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Total(Entity):
                                            """
                                            Total
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, self).__init__()

                                                self.yang_name = "total"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "total"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "total"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "total"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TcpInitSyncTimeSpec(Entity):
                                        """
                                        Time When neighbor entered TCP Init Sync
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "tcp-init-sync-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                        """
                                        Time when neighbor entered TCP Init Sync Phase
                                        Two
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TcpInitSyncDoneTimeSpec(Entity):
                                        """
                                        Time when neighbor entered TCP Init Sync Done
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-done-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "tcp-init-sync-done-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class GracefulMaintenance(Entity):
                                        """
                                        Graceful Maintenance
                                        
                                        .. attribute:: gshut_exists
                                        
                                        	Graceful Maintenance enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_local_active
                                        
                                        	Graceful Maintenance locally activated
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_active
                                        
                                        	Graceful Maintenance activated
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	Graceful Maintenance Local Preference set
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	Graceful Maintenance Local Preference
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	Graceful Maintenance number of AS prepends
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, self).__init__()

                                            self.yang_name = "graceful-maintenance"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                                ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                                ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                                ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                                ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                                ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                            ])
                                            self.gshut_exists = None
                                            self.gshut_local_active = None
                                            self.gshut_active = None
                                            self.gshut_locpref_set = None
                                            self.gshut_locpref = None
                                            self.gshut_prepends = None
                                            self._segment_path = lambda: "graceful-maintenance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                                    class AfData(Entity):
                                        """
                                        Address family specific neighbor data
                                        
                                        .. attribute:: neighbor_af_performance_statistics
                                        
                                        	Neighbor AF statistics
                                        	**type**\:  :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: is_neighbor_route_reflector_client
                                        
                                        	Nbr is a route reflector client
                                        	**type**\: bool
                                        
                                        .. attribute:: is_legacy_pe_rt
                                        
                                        	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_af_capable
                                        
                                        	Address family capability received from neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: is_soft_reconfiguration_inbound_allowed
                                        
                                        	Inbound soft reconfiguration allowed
                                        	**type**\: bool
                                        
                                        .. attribute:: is_use_soft_reconfiguration_always_on
                                        
                                        	Soft reconf overrides route refresh
                                        	**type**\: bool
                                        
                                        .. attribute:: remove_private_as_from_updates
                                        
                                        	Private AS numbers removed from updates to this nbr
                                        	**type**\: bool
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_updates
                                        
                                        	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                        	**type**\: bool
                                        
                                        .. attribute:: remove_private_as_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr
                                        	**type**\: bool
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                        	**type**\: bool
                                        
                                        .. attribute:: flowspec_validation_d_isable
                                        
                                        	Flowspec Validation Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: flowspec_redirect_validation_d_isable
                                        
                                        	Flowspec Redirect Validation Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\: str
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_afi
                                        
                                        	Encode in Advertise AFI
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_afi_reorg
                                        
                                        	Encode in Advertise AFI
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_afi_disable
                                        
                                        	Encode in Advertise AFI
                                        	**type**\: bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: advertise_afi_def_vrf_imp_disable
                                        
                                        	Advertise of default VRF import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                        
                                        	Advertise of v4 default VRF import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                        
                                        	Advertise of v6 default VRF import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_afi_vrf_re_imp_disable
                                        
                                        	Advertise of VRF re\-import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                        
                                        	Advertise of v4 VRF re\-import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                        
                                        	Advertise of v6 VRF re\-import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_afi_eo_r_ready
                                        
                                        	EoR Can be sent for Advertise AFI
                                        	**type**\: bool
                                        
                                        .. attribute:: always_use_next_hop_local
                                        
                                        	Local router always used for next\-hop
                                        	**type**\: bool
                                        
                                        .. attribute:: sent_community_to_neighbor
                                        
                                        	Community attribute sent to neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: sent_gshut_community_to_neighbor
                                        
                                        	GSHUT Community attribute sent to neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: sent_extended_community_to_neighbor
                                        
                                        	Extended community attribute sent to neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor_default_originate
                                        
                                        	Neighbor originates default
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orf_sent
                                        
                                        	Outbound route filter sent to neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: is_update_deferred
                                        
                                        	Update deferred until ORF/route refresh received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orf_send_scheduled
                                        
                                        	Scheduled to send prefix based ORF
                                        	**type**\: bool
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_update_throttled
                                        
                                        	Updates Throttled becausewrite limit is reached
                                        	**type**\: bool
                                        
                                        .. attribute:: is_update_leaving
                                        
                                        	Nbr leaving update\-groupto another
                                        	**type**\: bool
                                        
                                        .. attribute:: vpn_update_gen_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\: bool
                                        
                                        .. attribute:: vpn_update_gen_trigger_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\: bool
                                        
                                        .. attribute:: is_addpath_send_operational
                                        
                                        	Addpath is operational on send\-side
                                        	**type**\: bool
                                        
                                        .. attribute:: is_addpath_receive_operational
                                        
                                        	Addpath is operational on receive\-side
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor_version
                                        
                                        	Neighbor version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: weight
                                        
                                        	Weight for this AF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_prefix_limit
                                        
                                        	Max limit for # of prefixes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: use_max_prefix_warning_only
                                        
                                        	Warning only when maximum prefix limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: max_prefix_discard_extra_paths
                                        
                                        	Discard extra paths when prefix limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: max_prefix_exceed_discard_paths
                                        
                                        	Did we discard extra paths when prefix limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: max_prefix_threshold_percent
                                        
                                        	Percentage of maximum no. of prefixes at which to generate warning
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: max_prefix_restart_time
                                        
                                        	Time interval (in minutes) after which peering session will be reestablished
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: prefixes_accepted
                                        
                                        	No. of prefixes accepted
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_synced
                                        
                                        	Number of prefixes synced to standby
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn_not_found
                                        
                                        	No. of prefixes withdrawn but not found
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied
                                        
                                        	No. of prefixes denied
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_no_policy
                                        
                                        	No. of prefixes denied because there was no inbound policy
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_rt_permit
                                        
                                        	No. of prefixes denied because RT extended community is not imported
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_orf_policy
                                        
                                        	No. of prefixes denied by prefix based ORF policy
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_policy
                                        
                                        	No. of prefixes denied by inbound policy
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_bestpaths
                                        
                                        	No. of bestpaths from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_best_externalpaths
                                        
                                        	No. of best\-external paths from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_advertised
                                        
                                        	No. of prefixes advertised
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_be_advertised
                                        
                                        	No BE prefixes advertised
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_suppressed
                                        
                                        	No. of prefixes suppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn
                                        
                                        	No. of prefixes withdrawn
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_peer_orf_capable
                                        
                                        	Peer has outbound route filter capability
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertised_orf_send
                                        
                                        	Prefix based ORF send mode capability advertised
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_orf_send_capable
                                        
                                        	Prefix based ORF send mode capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertised_orf_receive
                                        
                                        	Prefix based ORF receive mode capability advertised
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_orf_receive_capable
                                        
                                        	Prefix based ORF receive mode capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertised_graceful_restart
                                        
                                        	Graceful Restart Capability advertised
                                        	**type**\: bool
                                        
                                        .. attribute:: is_graceful_restart_state_flag
                                        
                                        	Restart state flag enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_graceful_restart_capable
                                        
                                        	Graceful Restart Capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_add_path_send_capability_advertised
                                        
                                        	Addpath Send capability advertised
                                        	**type**\: bool
                                        
                                        .. attribute:: is_add_path_send_capability_received
                                        
                                        	Addpath Send capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_add_path_receive_capability_advertised
                                        
                                        	Addpath Receive capability advertised
                                        	**type**\: bool
                                        
                                        .. attribute:: is_add_path_receive_capability_received
                                        
                                        	Addpath Receive capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_received
                                        
                                        	Extended nexthop encoding capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_sent
                                        
                                        	Extended nexhop encoding capability Sent
                                        	**type**\: bool
                                        
                                        .. attribute:: restart_time
                                        
                                        	Restart time advertised (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: local_restart_time
                                        
                                        	Local Restart time (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: stale_path_timeout
                                        
                                        	Stale path timeout time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_purge_timeout_value
                                        
                                        	RIB purge timeout time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_preserved_forwarding_state
                                        
                                        	Neighbor preserved forwarding state
                                        	**type**\: bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_configured
                                        
                                        	Long\-lived graceful\-restart stale time is configured
                                        	**type**\: bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_sent
                                        
                                        	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_accept
                                        
                                        	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_capability_received
                                        
                                        	Long\-lived graceful\-restart capability received from the neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_received
                                        
                                        	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                        
                                        	Neighbor preserved long\-lived forwarding state
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_capable
                                        
                                        	Treat neighbor as long\-lived graceful\-restart capable
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                        
                                        	Remaining long\-lived graceful\-restart time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_refreshes_received
                                        
                                        	Number of route refresh requests received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_refreshes_sent
                                        
                                        	Number of route refresh requests sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_target_version
                                        
                                        	Target version for refresh update generation
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_version
                                        
                                        	Version till which refresh updates have been generated
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_acked_version
                                        
                                        	Version acked by the peer for refresh updates sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_prefix_orf_present
                                        
                                        	Outbound route filter prefix ORF present
                                        	**type**\: bool
                                        
                                        .. attribute:: orf_entries_received
                                        
                                        	Number of outbound route filter entries received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_default_originate_sent
                                        
                                        	Default origination update sent
                                        	**type**\: bool
                                        
                                        .. attribute:: route_policy_prefix_orf
                                        
                                        	Prefix based ORF for incoming updates
                                        	**type**\: str
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Incoming route policy name
                                        	**type**\: str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outgoing route policy name
                                        	**type**\: str
                                        
                                        .. attribute:: route_policy_default_originate
                                        
                                        	Default\-originate route policy name
                                        	**type**\: str
                                        
                                        .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                        
                                        	eBGP neighbor with no configured inbound policy
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                        
                                        	eBGP neighbor with no configured outbound policy
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_override_set
                                        
                                        	As override set 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_allow_as_in_set
                                        
                                        	Allowas\-in set 
                                        	**type**\: bool
                                        
                                        .. attribute:: allow_as_in_count
                                        
                                        	Allowas\-in count config
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: address_family_long_lived_time
                                        
                                        	AF specific Long\-lived\-time config
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_received_in_read_only
                                        
                                        	An EoR was received while in read\-only mode
                                        	**type**\: bool
                                        
                                        .. attribute:: acked_version
                                        
                                        	Version mapped from acked seqNo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: synced_acked_version
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version
                                        
                                        	No. of all outstanding version objects waiting for ack from the peer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_refresh_version
                                        
                                        	No. of only refresh version objects waiting for ack from the peer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_max
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aigp_set
                                        
                                        	AIGP set 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rt_present
                                        
                                        	RT attribute list present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rt_present_standby
                                        
                                        	RT attribute list present
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_enabled
                                        
                                        	Accept\-Own enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: selective_multipath_eligible
                                        
                                        	Selective multipath eligible
                                        	**type**\: bool
                                        
                                        .. attribute:: afrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: afrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\: bool
                                        
                                        .. attribute:: afrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: afrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertise_permanent_network
                                        
                                        	Advertise Permanent Network
                                        	**type**\: bool
                                        
                                        .. attribute:: is_send_mcast_attr
                                        
                                        	Send Mcast Attr
                                        	**type**\: bool
                                        
                                        .. attribute:: import_stitching
                                        
                                        	Import Stitching enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: import_reoriginate
                                        
                                        	Import Reoriginate enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: import_reoriginate_stitching
                                        
                                        	Import Reoriginate Stitching enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_v4_flags
                                        
                                        	Advertise options for VPNV4
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_v6_flags
                                        
                                        	Advertise options for VPNV6
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with 
                                        	**type**\: bool
                                        
                                        .. attribute:: prefixes_denied_non_cumulative
                                        
                                        	No. of prefixes exactly denied (non cumulative)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: enable_label_stack
                                        
                                        	Enable label stack
                                        	**type**\: bool
                                        
                                        .. attribute:: extended_community
                                        
                                        	Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                        
                                        .. attribute:: extended_community_standby
                                        
                                        	Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData, self).__init__()

                                            self.yang_name = "af-data"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-af-performance-statistics", ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby))])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                                ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                                ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                                ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                                ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                                ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                                ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                                ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                                ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                                ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                                ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                                ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                                ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                                ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                                ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                                ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                                ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                                ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                                ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                                ('advertise_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-def-vrf-imp-disable'), ['bool'])),
                                                ('advertise_evpnv4_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-def-vrf-imp-disable'), ['bool'])),
                                                ('advertise_evpnv6_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-def-vrf-imp-disable'), ['bool'])),
                                                ('advertise_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-vrf-re-imp-disable'), ['bool'])),
                                                ('advertise_evpnv4_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-vrf-re-imp-disable'), ['bool'])),
                                                ('advertise_evpnv6_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-vrf-re-imp-disable'), ['bool'])),
                                                ('advertise_afi_eo_r_ready', (YLeaf(YType.boolean, 'advertise-afi-eo-r-ready'), ['bool'])),
                                                ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                                ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                                ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                                ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                                ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                                ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                                ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                                ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                                ('is_update_throttled', (YLeaf(YType.boolean, 'is-update-throttled'), ['bool'])),
                                                ('is_update_leaving', (YLeaf(YType.boolean, 'is-update-leaving'), ['bool'])),
                                                ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                                ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                                ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                                ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                                ('neighbor_version', (YLeaf(YType.uint32, 'neighbor-version'), ['int'])),
                                                ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                                ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                                ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                                ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                                ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                                ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                                ('prefixes_accepted', (YLeaf(YType.uint32, 'prefixes-accepted'), ['int'])),
                                                ('prefixes_synced', (YLeaf(YType.uint32, 'prefixes-synced'), ['int'])),
                                                ('prefixes_withdrawn_not_found', (YLeaf(YType.uint32, 'prefixes-withdrawn-not-found'), ['int'])),
                                                ('prefixes_denied', (YLeaf(YType.uint32, 'prefixes-denied'), ['int'])),
                                                ('prefixes_denied_no_policy', (YLeaf(YType.uint32, 'prefixes-denied-no-policy'), ['int'])),
                                                ('prefixes_denied_rt_permit', (YLeaf(YType.uint32, 'prefixes-denied-rt-permit'), ['int'])),
                                                ('prefixes_denied_orf_policy', (YLeaf(YType.uint32, 'prefixes-denied-orf-policy'), ['int'])),
                                                ('prefixes_denied_policy', (YLeaf(YType.uint32, 'prefixes-denied-policy'), ['int'])),
                                                ('number_of_bestpaths', (YLeaf(YType.uint32, 'number-of-bestpaths'), ['int'])),
                                                ('number_of_best_externalpaths', (YLeaf(YType.uint32, 'number-of-best-externalpaths'), ['int'])),
                                                ('prefixes_advertised', (YLeaf(YType.uint32, 'prefixes-advertised'), ['int'])),
                                                ('prefixes_be_advertised', (YLeaf(YType.uint32, 'prefixes-be-advertised'), ['int'])),
                                                ('prefixes_suppressed', (YLeaf(YType.uint32, 'prefixes-suppressed'), ['int'])),
                                                ('prefixes_withdrawn', (YLeaf(YType.uint32, 'prefixes-withdrawn'), ['int'])),
                                                ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                                ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                                ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                                ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                                ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                                ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                                ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                                ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                                ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                                ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                                ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                                ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                                ('is_ext_nh_encoding_capability_received', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-received'), ['bool'])),
                                                ('is_ext_nh_encoding_capability_sent', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-sent'), ['bool'])),
                                                ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                                ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                                ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                                ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                                ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                                ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                                ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                                ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                                ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                                ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                                ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                                ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                                ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                                ('route_refreshes_received', (YLeaf(YType.uint32, 'route-refreshes-received'), ['int'])),
                                                ('route_refreshes_sent', (YLeaf(YType.uint32, 'route-refreshes-sent'), ['int'])),
                                                ('refresh_target_version', (YLeaf(YType.uint32, 'refresh-target-version'), ['int'])),
                                                ('refresh_version', (YLeaf(YType.uint32, 'refresh-version'), ['int'])),
                                                ('refresh_acked_version', (YLeaf(YType.uint32, 'refresh-acked-version'), ['int'])),
                                                ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                                ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                                ('is_default_originate_sent', (YLeaf(YType.boolean, 'is-default-originate-sent'), ['bool'])),
                                                ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                                ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                                ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                                ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                                ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                                ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                                ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                                ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                                ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                                ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                                ('eo_r_received_in_read_only', (YLeaf(YType.boolean, 'eo-r-received-in-read-only'), ['bool'])),
                                                ('acked_version', (YLeaf(YType.uint32, 'acked-version'), ['int'])),
                                                ('synced_acked_version', (YLeaf(YType.uint32, 'synced-acked-version'), ['int'])),
                                                ('outstanding_version', (YLeaf(YType.uint32, 'outstanding-version'), ['int'])),
                                                ('outstanding_refresh_version', (YLeaf(YType.uint32, 'outstanding-refresh-version'), ['int'])),
                                                ('outstanding_version_max', (YLeaf(YType.uint32, 'outstanding-version-max'), ['int'])),
                                                ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                                ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                                ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                                ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                                ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                                ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                                ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                                ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                                ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                                ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                                ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                                ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                                ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                                ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                                ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                                ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                                ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                                ('prefixes_denied_non_cumulative', (YLeaf(YType.uint32, 'prefixes-denied-non-cumulative'), ['int'])),
                                                ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                            ])
                                            self.af_name = None
                                            self.is_neighbor_route_reflector_client = None
                                            self.is_legacy_pe_rt = None
                                            self.is_neighbor_af_capable = None
                                            self.is_soft_reconfiguration_inbound_allowed = None
                                            self.is_use_soft_reconfiguration_always_on = None
                                            self.remove_private_as_from_updates = None
                                            self.remove_private_as_entire_aspath_from_updates = None
                                            self.remove_private_as_from_inbound_updates = None
                                            self.remove_private_as_entire_aspath_from_inbound_updates = None
                                            self.flowspec_validation_d_isable = None
                                            self.flowspec_redirect_validation_d_isable = None
                                            self.orr_group_name = None
                                            self.orr_group_index = None
                                            self.is_orr_root_address_configured = None
                                            self.advertise_afi = None
                                            self.advertise_afi_reorg = None
                                            self.advertise_afi_disable = None
                                            self.encapsulation_type = None
                                            self.advertise_rt_type = None
                                            self.advertise_afi_def_vrf_imp_disable = None
                                            self.advertise_evpnv4_afi_def_vrf_imp_disable = None
                                            self.advertise_evpnv6_afi_def_vrf_imp_disable = None
                                            self.advertise_afi_vrf_re_imp_disable = None
                                            self.advertise_evpnv4_afi_vrf_re_imp_disable = None
                                            self.advertise_evpnv6_afi_vrf_re_imp_disable = None
                                            self.advertise_afi_eo_r_ready = None
                                            self.always_use_next_hop_local = None
                                            self.sent_community_to_neighbor = None
                                            self.sent_gshut_community_to_neighbor = None
                                            self.sent_extended_community_to_neighbor = None
                                            self.neighbor_default_originate = None
                                            self.is_orf_sent = None
                                            self.is_update_deferred = None
                                            self.is_orf_send_scheduled = None
                                            self.update_group_number = None
                                            self.filter_group_index = None
                                            self.is_update_throttled = None
                                            self.is_update_leaving = None
                                            self.vpn_update_gen_enabled = None
                                            self.vpn_update_gen_trigger_enabled = None
                                            self.is_addpath_send_operational = None
                                            self.is_addpath_receive_operational = None
                                            self.neighbor_version = None
                                            self.weight = None
                                            self.max_prefix_limit = None
                                            self.use_max_prefix_warning_only = None
                                            self.max_prefix_discard_extra_paths = None
                                            self.max_prefix_exceed_discard_paths = None
                                            self.max_prefix_threshold_percent = None
                                            self.max_prefix_restart_time = None
                                            self.prefixes_accepted = None
                                            self.prefixes_synced = None
                                            self.prefixes_withdrawn_not_found = None
                                            self.prefixes_denied = None
                                            self.prefixes_denied_no_policy = None
                                            self.prefixes_denied_rt_permit = None
                                            self.prefixes_denied_orf_policy = None
                                            self.prefixes_denied_policy = None
                                            self.number_of_bestpaths = None
                                            self.number_of_best_externalpaths = None
                                            self.prefixes_advertised = None
                                            self.prefixes_be_advertised = None
                                            self.prefixes_suppressed = None
                                            self.prefixes_withdrawn = None
                                            self.is_peer_orf_capable = None
                                            self.is_advertised_orf_send = None
                                            self.is_received_orf_send_capable = None
                                            self.is_advertised_orf_receive = None
                                            self.is_received_orf_receive_capable = None
                                            self.is_advertised_graceful_restart = None
                                            self.is_graceful_restart_state_flag = None
                                            self.is_received_graceful_restart_capable = None
                                            self.is_add_path_send_capability_advertised = None
                                            self.is_add_path_send_capability_received = None
                                            self.is_add_path_receive_capability_advertised = None
                                            self.is_add_path_receive_capability_received = None
                                            self.is_ext_nh_encoding_capability_received = None
                                            self.is_ext_nh_encoding_capability_sent = None
                                            self.restart_time = None
                                            self.local_restart_time = None
                                            self.stale_path_timeout = None
                                            self.rib_purge_timeout_value = None
                                            self.neighbor_preserved_forwarding_state = None
                                            self.long_lived_graceful_restart_stale_time_configured = None
                                            self.long_lived_graceful_restart_stale_time_sent = None
                                            self.long_lived_graceful_restart_stale_time_accept = None
                                            self.long_lived_graceful_restart_capability_received = None
                                            self.long_lived_graceful_restart_stale_time_received = None
                                            self.neighbor_preserved_long_lived_forwarding_state = None
                                            self.neighbor_long_lived_graceful_restart_capable = None
                                            self.neighbor_long_lived_graceful_restart_time_remaining = None
                                            self.route_refreshes_received = None
                                            self.route_refreshes_sent = None
                                            self.refresh_target_version = None
                                            self.refresh_version = None
                                            self.refresh_acked_version = None
                                            self.is_prefix_orf_present = None
                                            self.orf_entries_received = None
                                            self.is_default_originate_sent = None
                                            self.route_policy_prefix_orf = None
                                            self.route_policy_in = None
                                            self.route_policy_out = None
                                            self.route_policy_default_originate = None
                                            self.is_neighbor_ebgp_without_inbound_policy = None
                                            self.is_neighbor_ebgp_without_outbound_policy = None
                                            self.is_as_override_set = None
                                            self.is_allow_as_in_set = None
                                            self.allow_as_in_count = None
                                            self.address_family_long_lived_time = None
                                            self.eo_r_received_in_read_only = None
                                            self.acked_version = None
                                            self.synced_acked_version = None
                                            self.outstanding_version = None
                                            self.outstanding_refresh_version = None
                                            self.outstanding_version_max = None
                                            self.is_aigp_set = None
                                            self.is_rt_present = None
                                            self.is_rt_present_standby = None
                                            self.accept_own_enabled = None
                                            self.selective_multipath_eligible = None
                                            self.afrpki_disable = None
                                            self.afrpki_use_validity = None
                                            self.afrpki_allow_invalid = None
                                            self.afrpki_signal_ibgp = None
                                            self.is_advertise_permanent_network = None
                                            self.is_send_mcast_attr = None
                                            self.import_stitching = None
                                            self.import_reoriginate = None
                                            self.import_reoriginate_stitching = None
                                            self.advertise_v4_flags = None
                                            self.advertise_v6_flags = None
                                            self.advertise_local_labeled_route_unicast = None
                                            self.prefixes_denied_non_cumulative = None
                                            self.enable_label_stack = None

                                            self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                            self.neighbor_af_performance_statistics.parent = self
                                            self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"

                                            self.extended_community = YList(self)
                                            self.extended_community_standby = YList(self)
                                            self._segment_path = lambda: "af-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_disable', u'encapsulation_type', u'advertise_rt_type', u'advertise_afi_def_vrf_imp_disable', u'advertise_evpnv4_afi_def_vrf_imp_disable', u'advertise_evpnv6_afi_def_vrf_imp_disable', u'advertise_afi_vrf_re_imp_disable', u'advertise_evpnv4_afi_vrf_re_imp_disable', u'advertise_evpnv6_afi_vrf_re_imp_disable', u'advertise_afi_eo_r_ready', u'always_use_next_hop_local', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'update_group_number', u'filter_group_index', u'is_update_throttled', u'is_update_leaving', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'neighbor_version', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'prefixes_accepted', u'prefixes_synced', u'prefixes_withdrawn_not_found', u'prefixes_denied', u'prefixes_denied_no_policy', u'prefixes_denied_rt_permit', u'prefixes_denied_orf_policy', u'prefixes_denied_policy', u'number_of_bestpaths', u'number_of_best_externalpaths', u'prefixes_advertised', u'prefixes_be_advertised', u'prefixes_suppressed', u'prefixes_withdrawn', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'is_ext_nh_encoding_capability_received', u'is_ext_nh_encoding_capability_sent', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'route_refreshes_received', u'route_refreshes_sent', u'refresh_target_version', u'refresh_version', u'refresh_acked_version', u'is_prefix_orf_present', u'orf_entries_received', u'is_default_originate_sent', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'eo_r_received_in_read_only', u'acked_version', u'synced_acked_version', u'outstanding_version', u'outstanding_refresh_version', u'outstanding_version_max', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'advertise_local_labeled_route_unicast', u'prefixes_denied_non_cumulative', u'enable_label_stack'], name, value)


                                        class NeighborAfPerformanceStatistics(Entity):
                                            """
                                            Neighbor AF statistics
                                            
                                            .. attribute:: sub_group_pending_message_count
                                            
                                            	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: processed_messages
                                            
                                            	Number of messages processed from the neighbor's write queue
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sent_messages
                                            
                                            	Number of messages sent from the neighbor's write queue
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_transmit
                                            
                                            	No. of update messages with split\-horizon flag that were sent out
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_blocked
                                            
                                            	No. of update messages with split\-horizon flag that were blocked
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_transmit
                                            
                                            	No. of withdraw messages with split\-horizon flag that were sent out
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_blocked
                                            
                                            	No. of withdraw messages with split\-horizon flag that were blocked
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                                self.yang_name = "neighbor-af-performance-statistics"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('sub_group_pending_message_count', (YLeaf(YType.uint32, 'sub-group-pending-message-count'), ['int'])),
                                                    ('processed_messages', (YLeaf(YType.uint32, 'processed-messages'), ['int'])),
                                                    ('sent_messages', (YLeaf(YType.uint32, 'sent-messages'), ['int'])),
                                                    ('split_horizon_update_transmit', (YLeaf(YType.uint32, 'split-horizon-update-transmit'), ['int'])),
                                                    ('split_horizon_update_blocked', (YLeaf(YType.uint32, 'split-horizon-update-blocked'), ['int'])),
                                                    ('split_horizon_withdraw_transmit', (YLeaf(YType.uint32, 'split-horizon-withdraw-transmit'), ['int'])),
                                                    ('split_horizon_withdraw_blocked', (YLeaf(YType.uint32, 'split-horizon-withdraw-blocked'), ['int'])),
                                                ])
                                                self.sub_group_pending_message_count = None
                                                self.processed_messages = None
                                                self.sent_messages = None
                                                self.split_horizon_update_transmit = None
                                                self.split_horizon_update_blocked = None
                                                self.split_horizon_withdraw_transmit = None
                                                self.split_horizon_withdraw_blocked = None
                                                self._segment_path = lambda: "neighbor-af-performance-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, [u'sub_group_pending_message_count', u'processed_messages', u'sent_messages', u'split_horizon_update_transmit', u'split_horizon_update_blocked', u'split_horizon_withdraw_transmit', u'split_horizon_withdraw_blocked'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, [u'entry'], name, value)


                                        class ExtendedCommunityStandby(Entity):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                                self.yang_name = "extended-community-standby"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community-standby"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                            class UpdateGenerationNeighbors(Entity):
                                """
                                Update generation for all neighbors
                                
                                .. attribute:: update_generation_neighbor
                                
                                	Update generation for neighbor
                                	**type**\: list of  		 :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors, self).__init__()

                                    self.yang_name = "update-generation-neighbors"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-generation-neighbor", ("update_generation_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.update_generation_neighbor = YList(self)
                                    self._segment_path = lambda: "update-generation-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors, [], name, value)


                                class UpdateGenerationNeighbor(Entity):
                                    """
                                    Update generation for neighbor
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: update_neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                    
                                    .. attribute:: last_sub_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:  :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                    
                                    .. attribute:: last_sub_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:  :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                    
                                    .. attribute:: last_filter_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:  :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                    
                                    .. attribute:: last_filter_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:  :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                    
                                    .. attribute:: first_default_originate_timestamp
                                    
                                    	First default\-origination time
                                    	**type**\:  :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: last_default_originate_timestamp
                                    
                                    	Last default\-origination time
                                    	**type**\:  :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: last_update_group_start_timestamp
                                    
                                    	Last update\-group timer start
                                    	**type**\:  :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                    
                                    .. attribute:: last_update_group_expiry_timestamp
                                    
                                    	Last update\-group timer expiry
                                    	**type**\:  :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                    
                                    .. attribute:: first_update_queued_timestamp
                                    
                                    	First update queued time
                                    	**type**\:  :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:  :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_queued_timestamp
                                    
                                    	Last refresh update queued time
                                    	**type**\:  :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: first_update_write_timestamp
                                    
                                    	First update write time
                                    	**type**\:  :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                    
                                    .. attribute:: last_update_write_timestamp
                                    
                                    	Last update write time
                                    	**type**\:  :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_write_timestamp
                                    
                                    	Last refresh update write time
                                    	**type**\:  :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_filter_group_index
                                    
                                    	Refresh Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_index
                                    
                                    	Refresh Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_id
                                    
                                    	Refresh sub\-group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_messages
                                    
                                    	Refresh OutQueue messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_size
                                    
                                    	Refresh OutQueue size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_messages
                                    
                                    	Filter\-group messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_resume_version
                                    
                                    	Resume version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ack_version
                                    
                                    	Ack version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: synced_ack_version
                                    
                                    	Synced ack version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_count
                                    
                                    	Outstanding version count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_version
                                    
                                    	Refresh version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_requested_target_version
                                    
                                    	Requested refresh target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_pending_target_version
                                    
                                    	Pending refresh target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_next_resume_version
                                    
                                    	Refresh resume version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_ack_version
                                    
                                    	Refresh Ack version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_default_originate_age
                                    
                                    	Time since last default\-origination event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: default_originate_state
                                    
                                    	Default\-origination state
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: default_originate_internal_context
                                    
                                    	Default\-origination context
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: is_eor_outstanding
                                    
                                    	Number of EORs outstanding
                                    	**type**\: bool
                                    
                                    .. attribute:: outbound_refresh_count
                                    
                                    	Refresh Outbound count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_refresh_count
                                    
                                    	Refresh Inbound count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_update_group_timer_running
                                    
                                    	Is update\-group timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: current_update_group_af_name
                                    
                                    	Current Update\-group address\-family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: last_update_group_af_name
                                    
                                    	Last Update\-group address\-family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_queued_age
                                    
                                    	Time since last refresh update queued event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_write_age
                                    
                                    	Time since last update write event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_write_age
                                    
                                    	Time since last refresh update write event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, self).__init__()

                                        self.yang_name = "update-generation-neighbor"
                                        self.yang_parent_name = "update-generation-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress)), ("last-sub-group-add-timestamp", ("last_sub_group_add_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp)), ("last-sub-group-remove-timestamp", ("last_sub_group_remove_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp)), ("last-filter-group-add-timestamp", ("last_filter_group_add_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp)), ("last-filter-group-remove-timestamp", ("last_filter_group_remove_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp)), ("first-default-originate-timestamp", ("first_default_originate_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp)), ("last-default-originate-timestamp", ("last_default_originate_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp)), ("last-update-group-start-timestamp", ("last_update_group_start_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp)), ("last-update-group-expiry-timestamp", ("last_update_group_expiry_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp)), ("first-update-queued-timestamp", ("first_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp)), ("last-update-queued-timestamp", ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp)), ("last-refresh-update-queued-timestamp", ("last_refresh_update_queued_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp)), ("first-update-write-timestamp", ("first_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp)), ("last-update-write-timestamp", ("last_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp)), ("last-refresh-update-write-timestamp", ("last_refresh_update_write_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics))])
                                        self._leafs = OrderedDict([
                                            ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                            ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                            ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                            ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                            ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('update_filter_group_index', (YLeaf(YType.uint32, 'update-filter-group-index'), ['int'])),
                                            ('refresh_filter_group_index', (YLeaf(YType.uint32, 'refresh-filter-group-index'), ['int'])),
                                            ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                            ('refresh_sub_group_index', (YLeaf(YType.uint32, 'refresh-sub-group-index'), ['int'])),
                                            ('refresh_sub_group_id', (YLeaf(YType.uint32, 'refresh-sub-group-id'), ['int'])),
                                            ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                            ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                            ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                            ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                            ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                            ('refresh_update_out_queue_messages', (YLeaf(YType.uint32, 'refresh-update-out-queue-messages'), ['int'])),
                                            ('refresh_update_out_queue_size', (YLeaf(YType.uint32, 'refresh-update-out-queue-size'), ['int'])),
                                            ('update_filter_group_messages', (YLeaf(YType.uint32, 'update-filter-group-messages'), ['int'])),
                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                            ('pending_target_version', (YLeaf(YType.uint32, 'pending-target-version'), ['int'])),
                                            ('next_resume_version', (YLeaf(YType.uint32, 'next-resume-version'), ['int'])),
                                            ('ack_version', (YLeaf(YType.uint32, 'ack-version'), ['int'])),
                                            ('synced_ack_version', (YLeaf(YType.uint32, 'synced-ack-version'), ['int'])),
                                            ('outstanding_version_count', (YLeaf(YType.uint32, 'outstanding-version-count'), ['int'])),
                                            ('update_refresh_version', (YLeaf(YType.uint32, 'update-refresh-version'), ['int'])),
                                            ('refresh_requested_target_version', (YLeaf(YType.uint32, 'refresh-requested-target-version'), ['int'])),
                                            ('update_refresh_target_version', (YLeaf(YType.uint32, 'update-refresh-target-version'), ['int'])),
                                            ('refresh_pending_target_version', (YLeaf(YType.uint32, 'refresh-pending-target-version'), ['int'])),
                                            ('refresh_next_resume_version', (YLeaf(YType.uint32, 'refresh-next-resume-version'), ['int'])),
                                            ('refresh_ack_version', (YLeaf(YType.uint32, 'refresh-ack-version'), ['int'])),
                                            ('last_default_originate_age', (YLeaf(YType.uint32, 'last-default-originate-age'), ['int'])),
                                            ('default_originate_state', (YLeaf(YType.int32, 'default-originate-state'), ['int'])),
                                            ('default_originate_internal_context', (YLeaf(YType.int32, 'default-originate-internal-context'), ['int'])),
                                            ('is_eor_outstanding', (YLeaf(YType.boolean, 'is-eor-outstanding'), ['bool'])),
                                            ('outbound_refresh_count', (YLeaf(YType.uint32, 'outbound-refresh-count'), ['int'])),
                                            ('inbound_refresh_count', (YLeaf(YType.uint32, 'inbound-refresh-count'), ['int'])),
                                            ('is_update_group_timer_running', (YLeaf(YType.boolean, 'is-update-group-timer-running'), ['bool'])),
                                            ('current_update_group_af_name', (YLeaf(YType.enumeration, 'current-update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('last_update_group_af_name', (YLeaf(YType.enumeration, 'last-update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('last_update_queued_age', (YLeaf(YType.uint32, 'last-update-queued-age'), ['int'])),
                                            ('last_refresh_update_queued_age', (YLeaf(YType.uint32, 'last-refresh-update-queued-age'), ['int'])),
                                            ('last_update_write_age', (YLeaf(YType.uint32, 'last-update-write-age'), ['int'])),
                                            ('last_refresh_update_write_age', (YLeaf(YType.uint32, 'last-refresh-update-write-age'), ['int'])),
                                        ])
                                        self.update_group_index = None
                                        self.sub_group_index = None
                                        self.sub_group_id = None
                                        self.filter_group_index = None
                                        self.neighbor_address = None
                                        self.process_id = None
                                        self.update_vrf_name = None
                                        self.update_group_af_name = None
                                        self.update_filter_group_index = None
                                        self.refresh_filter_group_index = None
                                        self.sub_group_index_xr = None
                                        self.refresh_sub_group_index = None
                                        self.refresh_sub_group_id = None
                                        self.update_group_index_xr = None
                                        self.update_main_table_version = None
                                        self.update_vrf_table_rib_version = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.refresh_update_out_queue_messages = None
                                        self.refresh_update_out_queue_size = None
                                        self.update_filter_group_messages = None
                                        self.version = None
                                        self.pending_target_version = None
                                        self.next_resume_version = None
                                        self.ack_version = None
                                        self.synced_ack_version = None
                                        self.outstanding_version_count = None
                                        self.update_refresh_version = None
                                        self.refresh_requested_target_version = None
                                        self.update_refresh_target_version = None
                                        self.refresh_pending_target_version = None
                                        self.refresh_next_resume_version = None
                                        self.refresh_ack_version = None
                                        self.last_default_originate_age = None
                                        self.default_originate_state = None
                                        self.default_originate_internal_context = None
                                        self.is_eor_outstanding = None
                                        self.outbound_refresh_count = None
                                        self.inbound_refresh_count = None
                                        self.is_update_group_timer_running = None
                                        self.current_update_group_af_name = None
                                        self.last_update_group_af_name = None
                                        self.last_update_queued_age = None
                                        self.last_refresh_update_queued_age = None
                                        self.last_update_write_age = None
                                        self.last_refresh_update_write_age = None

                                        self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                        self.update_neighbor_address.parent = self
                                        self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                        self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                        self.last_sub_group_add_timestamp.parent = self
                                        self._children_name_map["last_sub_group_add_timestamp"] = "last-sub-group-add-timestamp"

                                        self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                        self.last_sub_group_remove_timestamp.parent = self
                                        self._children_name_map["last_sub_group_remove_timestamp"] = "last-sub-group-remove-timestamp"

                                        self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                        self.last_filter_group_add_timestamp.parent = self
                                        self._children_name_map["last_filter_group_add_timestamp"] = "last-filter-group-add-timestamp"

                                        self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                        self.last_filter_group_remove_timestamp.parent = self
                                        self._children_name_map["last_filter_group_remove_timestamp"] = "last-filter-group-remove-timestamp"

                                        self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                        self.first_default_originate_timestamp.parent = self
                                        self._children_name_map["first_default_originate_timestamp"] = "first-default-originate-timestamp"

                                        self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                        self.last_default_originate_timestamp.parent = self
                                        self._children_name_map["last_default_originate_timestamp"] = "last-default-originate-timestamp"

                                        self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                        self.last_update_group_start_timestamp.parent = self
                                        self._children_name_map["last_update_group_start_timestamp"] = "last-update-group-start-timestamp"

                                        self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                        self.last_update_group_expiry_timestamp.parent = self
                                        self._children_name_map["last_update_group_expiry_timestamp"] = "last-update-group-expiry-timestamp"

                                        self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                        self.first_update_queued_timestamp.parent = self
                                        self._children_name_map["first_update_queued_timestamp"] = "first-update-queued-timestamp"

                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"

                                        self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                        self.last_refresh_update_queued_timestamp.parent = self
                                        self._children_name_map["last_refresh_update_queued_timestamp"] = "last-refresh-update-queued-timestamp"

                                        self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                        self.first_update_write_timestamp.parent = self
                                        self._children_name_map["first_update_write_timestamp"] = "first-update-write-timestamp"

                                        self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                        self.last_update_write_timestamp.parent = self
                                        self._children_name_map["last_update_write_timestamp"] = "last-update-write-timestamp"

                                        self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                        self.last_refresh_update_write_timestamp.parent = self
                                        self._children_name_map["last_refresh_update_write_timestamp"] = "last-refresh-update-write-timestamp"

                                        self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._segment_path = lambda: "update-generation-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, ['update_group_index', 'sub_group_index', 'sub_group_id', 'filter_group_index', 'neighbor_address', u'process_id', u'update_vrf_name', u'update_group_af_name', u'update_filter_group_index', u'refresh_filter_group_index', u'sub_group_index_xr', u'refresh_sub_group_index', u'refresh_sub_group_id', u'update_group_index_xr', u'update_main_table_version', u'update_vrf_table_rib_version', u'update_out_queue_messages', u'update_out_queue_size', u'refresh_update_out_queue_messages', u'refresh_update_out_queue_size', u'update_filter_group_messages', u'version', u'pending_target_version', u'next_resume_version', u'ack_version', u'synced_ack_version', u'outstanding_version_count', u'update_refresh_version', u'refresh_requested_target_version', u'update_refresh_target_version', u'refresh_pending_target_version', u'refresh_next_resume_version', u'refresh_ack_version', u'last_default_originate_age', u'default_originate_state', u'default_originate_internal_context', u'is_eor_outstanding', u'outbound_refresh_count', u'inbound_refresh_count', u'is_update_group_timer_running', u'current_update_group_af_name', u'last_update_group_af_name', u'last_update_queued_age', u'last_refresh_update_queued_age', u'last_update_write_age', u'last_refresh_update_write_age'], name, value)


                                    class UpdateNeighborAddress(Entity):
                                        """
                                        Neighbor address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, self).__init__()

                                            self.yang_name = "update-neighbor-address"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "update-neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class LastSubGroupAddTimestamp(Entity):
                                        """
                                        Last added time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, self).__init__()

                                            self.yang_name = "last-sub-group-add-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-sub-group-add-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastSubGroupRemoveTimestamp(Entity):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, self).__init__()

                                            self.yang_name = "last-sub-group-remove-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-sub-group-remove-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastFilterGroupAddTimestamp(Entity):
                                        """
                                        Last added time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, self).__init__()

                                            self.yang_name = "last-filter-group-add-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-filter-group-add-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastFilterGroupRemoveTimestamp(Entity):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, self).__init__()

                                            self.yang_name = "last-filter-group-remove-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-filter-group-remove-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstDefaultOriginateTimestamp(Entity):
                                        """
                                        First default\-origination time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, self).__init__()

                                            self.yang_name = "first-default-originate-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-default-originate-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastDefaultOriginateTimestamp(Entity):
                                        """
                                        Last default\-origination time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, self).__init__()

                                            self.yang_name = "last-default-originate-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-default-originate-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateGroupStartTimestamp(Entity):
                                        """
                                        Last update\-group timer start
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-group-start-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-group-start-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateGroupExpiryTimestamp(Entity):
                                        """
                                        Last update\-group timer expiry
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, self).__init__()

                                            self.yang_name = "last-update-group-expiry-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-group-expiry-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstUpdateQueuedTimestamp(Entity):
                                        """
                                        First update queued time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "first-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-update-queued-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateQueuedTimestamp(Entity):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-queued-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRefreshUpdateQueuedTimestamp(Entity):
                                        """
                                        Last refresh update queued time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-refresh-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-refresh-update-queued-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstUpdateWriteTimestamp(Entity):
                                        """
                                        First update write time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "first-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-update-write-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateWriteTimestamp(Entity):
                                        """
                                        Last update write time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "last-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-write-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRefreshUpdateWriteTimestamp(Entity):
                                        """
                                        Last refresh update write time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "last-refresh-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-refresh-update-write-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                            ])
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_size_high = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_cleared = None
                                            self.last_update_discard_age = None
                                            self.last_update_cleard_age = None
                                            self.update_throttle_count = None
                                            self.last_update_throttle_age = None
                                            self.update_recovery_count = None
                                            self.last_update_recovery_age = None
                                            self.update_memory_allocation_fail_count = None
                                            self.last_update_memory_allocation_fail_age = None

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._segment_path = lambda: "update-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-discard-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-cleared-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-throttle-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-recovery-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class UpdateGenerationAddressFamily(Entity):
                                """
                                Update generation for address\-family
                                
                                .. attribute:: update_statistics
                                
                                	Upate statistics
                                	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                
                                .. attribute:: update_group_af_name
                                
                                	Address family identifier
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_main_table_version
                                
                                	Main table version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_rib_version
                                
                                	RIB version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_min_neighbor_version
                                
                                	Minimum Neighbor version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_af
                                
                                	Current AF update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_af
                                
                                	Configured AF update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_subgrp_ebgp
                                
                                	Current EBGP sub\-group update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_subgrp_ebgp
                                
                                	Configured EBGP sub\-group update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_sub_group_ibgp
                                
                                	Current IBGP sub\-group update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_sub_group_ibgp
                                
                                	Configured IBGP sub\-group update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_messages
                                
                                	OutQueue messsages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_size
                                
                                	OutQueue size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_throttled
                                
                                	Is Update throttled
                                	**type**\: bool
                                
                                .. attribute:: update_update_group_count
                                
                                	Update\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_sub_group_count
                                
                                	Sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sub_group_throttled_count
                                
                                	Throttled sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_count
                                
                                	Refresh sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_throttled_count
                                
                                	Throttled refresh sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: filter_group_count
                                
                                	Filter\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_count
                                
                                	Neighbor count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_vrf_name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: update_vrfaf_name
                                
                                	Address family identifier
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_rd_version
                                
                                	RD Version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_table_rib_version
                                
                                	VRF Table RIB version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_update_group_count
                                
                                	VRF Table update\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_sub_group_count
                                
                                	VRF Table sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_sub_group_throttled_count
                                
                                	VRF Table throttled sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_count
                                
                                	VRF Table refresh sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_throttled_count
                                
                                	VRF Table throttled refresh sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_filter_group_count
                                
                                	VRF Table filter\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_neighbor_count
                                
                                	VRF Table neighbor count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily, self).__init__()

                                    self.yang_name = "update-generation-address-family"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics))])
                                    self._leafs = OrderedDict([
                                        ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                        ('update_rib_version', (YLeaf(YType.uint32, 'update-rib-version'), ['int'])),
                                        ('update_min_neighbor_version', (YLeaf(YType.uint32, 'update-min-neighbor-version'), ['int'])),
                                        ('current_update_limit_af', (YLeaf(YType.uint32, 'current-update-limit-af'), ['int'])),
                                        ('configured_update_limit_af', (YLeaf(YType.uint32, 'configured-update-limit-af'), ['int'])),
                                        ('current_update_limit_subgrp_ebgp', (YLeaf(YType.uint32, 'current-update-limit-subgrp-ebgp'), ['int'])),
                                        ('configured_update_limit_subgrp_ebgp', (YLeaf(YType.uint32, 'configured-update-limit-subgrp-ebgp'), ['int'])),
                                        ('current_update_limit_sub_group_ibgp', (YLeaf(YType.uint32, 'current-update-limit-sub-group-ibgp'), ['int'])),
                                        ('configured_update_limit_sub_group_ibgp', (YLeaf(YType.uint32, 'configured-update-limit-sub-group-ibgp'), ['int'])),
                                        ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                        ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                        ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                                        ('update_update_group_count', (YLeaf(YType.uint32, 'update-update-group-count'), ['int'])),
                                        ('update_sub_group_count', (YLeaf(YType.uint32, 'update-sub-group-count'), ['int'])),
                                        ('sub_group_throttled_count', (YLeaf(YType.uint32, 'sub-group-throttled-count'), ['int'])),
                                        ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                        ('refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'refresh-sub-group-throttled-count'), ['int'])),
                                        ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                        ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                        ('update_table_vrf_name', (YLeaf(YType.str, 'update-table-vrf-name'), ['str'])),
                                        ('update_vrfaf_name', (YLeaf(YType.uint32, 'update-vrfaf-name'), ['int'])),
                                        ('update_vrf_rd_version', (YLeaf(YType.uint32, 'update-vrf-rd-version'), ['int'])),
                                        ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                        ('table_update_group_count', (YLeaf(YType.uint32, 'table-update-group-count'), ['int'])),
                                        ('update_table_sub_group_count', (YLeaf(YType.uint32, 'update-table-sub-group-count'), ['int'])),
                                        ('table_sub_group_throttled_count', (YLeaf(YType.uint32, 'table-sub-group-throttled-count'), ['int'])),
                                        ('table_refresh_sub_group_count', (YLeaf(YType.uint32, 'table-refresh-sub-group-count'), ['int'])),
                                        ('table_refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'table-refresh-sub-group-throttled-count'), ['int'])),
                                        ('update_table_filter_group_count', (YLeaf(YType.uint32, 'update-table-filter-group-count'), ['int'])),
                                        ('table_neighbor_count', (YLeaf(YType.uint32, 'table-neighbor-count'), ['int'])),
                                    ])
                                    self.update_group_af_name = None
                                    self.update_main_table_version = None
                                    self.update_rib_version = None
                                    self.update_min_neighbor_version = None
                                    self.current_update_limit_af = None
                                    self.configured_update_limit_af = None
                                    self.current_update_limit_subgrp_ebgp = None
                                    self.configured_update_limit_subgrp_ebgp = None
                                    self.current_update_limit_sub_group_ibgp = None
                                    self.configured_update_limit_sub_group_ibgp = None
                                    self.update_out_queue_messages = None
                                    self.update_out_queue_size = None
                                    self.update_throttled = None
                                    self.update_update_group_count = None
                                    self.update_sub_group_count = None
                                    self.sub_group_throttled_count = None
                                    self.refresh_sub_group_count = None
                                    self.refresh_sub_group_throttled_count = None
                                    self.filter_group_count = None
                                    self.neighbor_count = None
                                    self.update_table_vrf_name = None
                                    self.update_vrfaf_name = None
                                    self.update_vrf_rd_version = None
                                    self.update_vrf_table_rib_version = None
                                    self.table_update_group_count = None
                                    self.update_table_sub_group_count = None
                                    self.table_sub_group_throttled_count = None
                                    self.table_refresh_sub_group_count = None
                                    self.table_refresh_sub_group_throttled_count = None
                                    self.update_table_filter_group_count = None
                                    self.table_neighbor_count = None

                                    self.update_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                    self.update_statistics.parent = self
                                    self._children_name_map["update_statistics"] = "update-statistics"
                                    self._segment_path = lambda: "update-generation-address-family"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily, [u'update_group_af_name', u'update_main_table_version', u'update_rib_version', u'update_min_neighbor_version', u'current_update_limit_af', u'configured_update_limit_af', u'current_update_limit_subgrp_ebgp', u'configured_update_limit_subgrp_ebgp', u'current_update_limit_sub_group_ibgp', u'configured_update_limit_sub_group_ibgp', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled', u'update_update_group_count', u'update_sub_group_count', u'sub_group_throttled_count', u'refresh_sub_group_count', u'refresh_sub_group_throttled_count', u'filter_group_count', u'neighbor_count', u'update_table_vrf_name', u'update_vrfaf_name', u'update_vrf_rd_version', u'update_vrf_table_rib_version', u'table_update_group_count', u'update_table_sub_group_count', u'table_sub_group_throttled_count', u'table_refresh_sub_group_count', u'table_refresh_sub_group_throttled_count', u'update_table_filter_group_count', u'table_neighbor_count'], name, value)


                                class UpdateStatistics(Entity):
                                    """
                                    Upate statistics
                                    
                                    .. attribute:: last_update_discard_timestamp
                                    
                                    	Last Discarded time
                                    	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                    
                                    .. attribute:: last_update_cleared_timestamp
                                    
                                    	Last Cleared time
                                    	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                    
                                    .. attribute:: last_update_throttle_timestamp
                                    
                                    	Last Throttled time
                                    	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                    
                                    .. attribute:: last_update_recovery_timestamp
                                    
                                    	Last Recovery time
                                    	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                    
                                    .. attribute:: last_update_memory_allocation_fail_timestamp
                                    
                                    	Memory allocation failure time
                                    	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                    
                                    .. attribute:: update_out_queue_messages_high
                                    
                                    	OutQueue High Messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cumulative
                                    
                                    	OutQueue Cumulative Messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_discarded
                                    
                                    	OutQueue Discarded Messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cleared
                                    
                                    	OutQueue Cleared Messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size_high
                                    
                                    	OutQueue Hi Size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size_cumulative
                                    
                                    	OutQueue Cumulative Size
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_discarded
                                    
                                    	OutQueue Discarded Size
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_cleared
                                    
                                    	OutQueue Cleared Size
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_update_discard_age
                                    
                                    	Time since last Discard event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_cleard_age
                                    
                                    	Time since last Clear event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: update_throttle_count
                                    
                                    	Throttle Count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_throttle_age
                                    
                                    	Time since last Throttle event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: update_recovery_count
                                    
                                    	Recovery Count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_recovery_age
                                    
                                    	Time since last Recovery event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: update_memory_allocation_fail_count
                                    
                                    	Memory allocation failure count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_memory_allocation_fail_age
                                    
                                    	Time since last memory allocation failure event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, self).__init__()

                                        self.yang_name = "update-statistics"
                                        self.yang_parent_name = "update-generation-address-family"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                            ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                            ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                            ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                            ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                            ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                            ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                            ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                            ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                            ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                            ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                            ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                            ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                            ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                            ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                            ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                        ])
                                        self.update_out_queue_messages_high = None
                                        self.update_out_queue_messages_cumulative = None
                                        self.update_out_queue_messages_discarded = None
                                        self.update_out_queue_messages_cleared = None
                                        self.update_out_queue_size_high = None
                                        self.update_out_queue_size_cumulative = None
                                        self.update_out_queue_size_discarded = None
                                        self.update_out_queue_size_cleared = None
                                        self.last_update_discard_age = None
                                        self.last_update_cleard_age = None
                                        self.update_throttle_count = None
                                        self.last_update_throttle_age = None
                                        self.update_recovery_count = None
                                        self.last_update_recovery_age = None
                                        self.update_memory_allocation_fail_count = None
                                        self.last_update_memory_allocation_fail_age = None

                                        self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                        self.last_update_discard_timestamp.parent = self
                                        self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                        self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                        self.last_update_cleared_timestamp.parent = self
                                        self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                        self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                        self.last_update_throttle_timestamp.parent = self
                                        self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                        self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                        self.last_update_recovery_timestamp.parent = self
                                        self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                        self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                        self.last_update_memory_allocation_fail_timestamp.parent = self
                                        self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                        self._segment_path = lambda: "update-statistics"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                    class LastUpdateDiscardTimestamp(Entity):
                                        """
                                        Last Discarded time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                            self.yang_name = "last-update-discard-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-discard-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateClearedTimestamp(Entity):
                                        """
                                        Last Cleared time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                            self.yang_name = "last-update-cleared-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-cleared-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateThrottleTimestamp(Entity):
                                        """
                                        Last Throttled time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                            self.yang_name = "last-update-throttle-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-throttle-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateRecoveryTimestamp(Entity):
                                        """
                                        Last Recovery time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                            self.yang_name = "last-update-recovery-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-recovery-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                        """
                                        Memory allocation failure time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                            self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class Dampenings(Entity):
                                """
                                The BGP Dampening table
                                
                                .. attribute:: dampening
                                
                                	A BGP Dampening table entry
                                	**type**\: list of  		 :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings, self).__init__()

                                    self.yang_name = "dampenings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dampening", ("dampening", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening))])
                                    self._leafs = OrderedDict()

                                    self.dampening = YList(self)
                                    self._segment_path = lambda: "dampenings"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings, [], name, value)


                                class Dampening(Entity):
                                    """
                                    A BGP Dampening table entry
                                    
                                    .. attribute:: reuse
                                    
                                    	Reuse array index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: length
                                    
                                    	Prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: orig_source_rd
                                    
                                    	Original Source Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertised_neighbor
                                    
                                    	Advertised Neighbor Address. Valid in the case of Advertised table
                                    	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor>`
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: original_source_route_distinguisher
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\: str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "dampenings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn))])
                                        self._leafs = OrderedDict([
                                            ('reuse', (YLeaf(YType.uint32, 'reuse'), ['int'])),
                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('length', (YLeaf(YType.uint32, 'length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                            ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                            ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                            ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                            ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                            ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.reuse = None
                                        self.version = None
                                        self.rd = None
                                        self.network = None
                                        self.length = None
                                        self.neighbor_address = None
                                        self.source_rd = None
                                        self.orig_source_rd = None
                                        self.path_id = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.label_oor = None
                                        self.label_oor_version = None
                                        self.label_fail = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.original_source_route_distinguisher = None
                                        self.prefix_version = None
                                        self.vrf_name = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None

                                        self.advertised_neighbor = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor()
                                        self.advertised_neighbor.parent = self
                                        self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                        self.path_information = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening, ['reuse', 'version', 'rd', 'network', 'length', 'neighbor_address', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                    class AdvertisedNeighbor(Entity):
                                        """
                                        Advertised Neighbor Address. Valid in the case
                                        of Advertised table
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor, self).__init__()

                                            self.yang_name = "advertised-neighbor"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "advertised-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied. In the
                                        case of path type received\-only this will be
                                        attributes before inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class PrefixFilters(Entity):
                                """
                                The BGP Prefix Filter table
                                
                                .. attribute:: prefix_filter
                                
                                	A BGP prefix filter table entry
                                	**type**\: list of  		 :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters, self).__init__()

                                    self.yang_name = "prefix-filters"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("prefix-filter", ("prefix_filter", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter))])
                                    self._leafs = OrderedDict()

                                    self.prefix_filter = YList(self)
                                    self._segment_path = lambda: "prefix-filters"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters, [], name, value)


                                class PrefixFilter(Entity):
                                    """
                                    A BGP prefix filter table entry
                                    
                                    .. attribute:: neighbor_address  (key)
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                    
                                    .. attribute:: prefix_list_info
                                    
                                    	Prefix list
                                    	**type**\:  :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identfier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter, self).__init__()

                                        self.yang_name = "prefix-filter"
                                        self.yang_parent_name = "prefix-filters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['neighbor_address']
                                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr)), ("prefix-list-info", ("prefix_list_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo))])
                                        self._leafs = OrderedDict([
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.neighbor_address = None
                                        self.af_name = None

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                        self.prefix_list_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                        self.prefix_list_info.parent = self
                                        self._children_name_map["prefix_list_info"] = "prefix-list-info"
                                        self._segment_path = lambda: "prefix-filter" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter, ['neighbor_address', u'af_name'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "prefix-filter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address-xr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PrefixListInfo(Entity):
                                        """
                                        Prefix list
                                        
                                        .. attribute:: bgp_pfxlst
                                        
                                        	bgp pfxlst
                                        	**type**\: list of  		 :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, self).__init__()

                                            self.yang_name = "prefix-list-info"
                                            self.yang_parent_name = "prefix-filter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-pfxlst", ("bgp_pfxlst", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst))])
                                            self._leafs = OrderedDict()

                                            self.bgp_pfxlst = YList(self)
                                            self._segment_path = lambda: "prefix-list-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, [], name, value)


                                        class BgpPfxlst(Entity):
                                            """
                                            bgp pfxlst
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_prefix_grant
                                            
                                            	TRUE = permit, FALSE = deny
                                            	**type**\: bool
                                            
                                            .. attribute:: min_prefix_length
                                            
                                            	Minimum prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: max_prefix_length
                                            
                                            	Maximum prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, self).__init__()

                                                self.yang_name = "bgp-pfxlst"
                                                self.yang_parent_name = "prefix-list-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix))])
                                                self._leafs = OrderedDict([
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('is_prefix_grant', (YLeaf(YType.boolean, 'is-prefix-grant'), ['bool'])),
                                                    ('min_prefix_length', (YLeaf(YType.uint8, 'min-prefix-length'), ['int'])),
                                                    ('max_prefix_length', (YLeaf(YType.uint8, 'max-prefix-length'), ['int'])),
                                                ])
                                                self.sequence_number = None
                                                self.is_prefix_grant = None
                                                self.min_prefix_length = None
                                                self.max_prefix_length = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._segment_path = lambda: "bgp-pfxlst"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, [u'sequence_number', u'is_prefix_grant', u'min_prefix_length', u'max_prefix_length'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "bgp-pfxlst"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class Attributes(Entity):
                                """
                                The BGP Attribute table
                                
                                .. attribute:: attribute
                                
                                	A BGP Attribute table entry
                                	**type**\: list of  		 :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes, self).__init__()

                                    self.yang_name = "attributes"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("attribute", ("attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute))])
                                    self._leafs = OrderedDict()

                                    self.attribute = YList(self)
                                    self._segment_path = lambda: "attributes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes, [], name, value)


                                class Attribute(Entity):
                                    """
                                    A BGP Attribute table entry
                                    
                                    .. attribute:: attribute_iid
                                    
                                    	Attribute IID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_cache_bucket
                                    
                                    	Attribute cache bucket
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_cache_id
                                    
                                    	Attribute cache ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_info
                                    
                                    	Attributes
                                    	**type**\:  :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: attribute_instance_id
                                    
                                    	Attribute Instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: attribute_structure_id
                                    
                                    	ID of attribute structure
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_structure_hash_value
                                    
                                    	Hash value for attribute structure
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_count
                                    
                                    	Number of paths which use this attribute structure
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute, self).__init__()

                                        self.yang_name = "attribute"
                                        self.yang_parent_name = "attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("attribute-info", ("attribute_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo))])
                                        self._leafs = OrderedDict([
                                            ('attribute_iid', (YLeaf(YType.uint32, 'attribute-iid'), ['int'])),
                                            ('attribute_cache_bucket', (YLeaf(YType.uint32, 'attribute-cache-bucket'), ['int'])),
                                            ('attribute_cache_id', (YLeaf(YType.uint32, 'attribute-cache-id'), ['int'])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('attribute_instance_id', (YLeaf(YType.uint8, 'attribute-instance-id'), ['int'])),
                                            ('attribute_structure_id', (YLeaf(YType.uint32, 'attribute-structure-id'), ['int'])),
                                            ('attribute_structure_hash_value', (YLeaf(YType.uint32, 'attribute-structure-hash-value'), ['int'])),
                                            ('reference_count', (YLeaf(YType.uint32, 'reference-count'), ['int'])),
                                        ])
                                        self.attribute_iid = None
                                        self.attribute_cache_bucket = None
                                        self.attribute_cache_id = None
                                        self.process_instance_id = None
                                        self.attribute_instance_id = None
                                        self.attribute_structure_id = None
                                        self.attribute_structure_hash_value = None
                                        self.reference_count = None

                                        self.attribute_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                        self.attribute_info.parent = self
                                        self._children_name_map["attribute_info"] = "attribute-info"
                                        self._segment_path = lambda: "attribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute, ['attribute_iid', 'attribute_cache_bucket', 'attribute_cache_id', u'process_instance_id', u'attribute_instance_id', u'attribute_structure_id', u'attribute_structure_hash_value', u'reference_count'], name, value)


                                    class AttributeInfo(Entity):
                                        """
                                        Attributes
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo, self).__init__()

                                            self.yang_name = "attribute-info"
                                            self.yang_parent_name = "attribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attribute-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                    class Information(Entity):
                        """
                        Meta data for VRF
                        
                        .. attribute:: route_distinguisher
                        
                        	Route Distinguisher
                        	**type**\: str
                        
                        	**pattern:** [a\-fA\-F0\-9]{16}
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information, self).__init__()

                            self.yang_name = "information"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                            ])
                            self.route_distinguisher = None
                            self._segment_path = lambda: "information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Information, [u'route_distinguisher'], name, value)


                    class UpdateInboundFilterVrf(Entity):
                        """
                        Update inbound filtering information for the VRF
                        
                        .. attribute:: last_update_filtered_timestamp
                        
                        	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:  :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: update_filtered_message_count
                        
                        	Filtered messages count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_filtered_neighbor_count
                        
                        	Count of neighbors that received filtered messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_update_filtered_age
                        
                        	Time since last filtered messages received event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf, self).__init__()

                            self.yang_name = "update-inbound-filter-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("last-update-filtered-timestamp", ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp))])
                            self._leafs = OrderedDict([
                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                ('update_filtered_message_count', (YLeaf(YType.uint32, 'update-filtered-message-count'), ['int'])),
                                ('update_filtered_neighbor_count', (YLeaf(YType.uint32, 'update-filtered-neighbor-count'), ['int'])),
                                ('last_update_filtered_age', (YLeaf(YType.uint32, 'last-update-filtered-age'), ['int'])),
                            ])
                            self.update_vrf_name = None
                            self.update_filtered_message_count = None
                            self.update_filtered_neighbor_count = None
                            self.last_update_filtered_age = None

                            self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                            self.last_update_filtered_timestamp.parent = self
                            self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                            self._segment_path = lambda: "update-inbound-filter-vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf, [u'update_vrf_name', u'update_filtered_message_count', u'update_filtered_neighbor_count', u'last_update_filtered_age'], name, value)


                        class LastUpdateFilteredTimestamp(Entity):
                            """
                            Last Filtered messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, self).__init__()

                                self.yang_name = "last-update-filtered-timestamp"
                                self.yang_parent_name = "update-inbound-filter-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-filtered-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                    class Postits(Entity):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: postit
                        
                        	A BGP Postit table entry
                        	**type**\: list of  		 :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits, self).__init__()

                            self.yang_name = "postits"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("postit", ("postit", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit))])
                            self._leafs = OrderedDict()

                            self.postit = YList(self)
                            self._segment_path = lambda: "postits"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits, [], name, value)


                        class Postit(Entity):
                            """
                            A BGP Postit table entry
                            
                            .. attribute:: neighbor_address  (key)
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbors_address
                            
                            	Neighbor Addr
                            	**type**\:  :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress>`
                            
                            .. attribute:: vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: connect_state
                            
                            	State
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: start_time
                            
                            	StartTime
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: neighbor_af
                            
                            	Neighbor Afi
                            	**type**\: list of  		 :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborAf>`
                            
                            .. attribute:: postit_info
                            
                            	Postit Info
                            	**type**\: list of  		 :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit, self).__init__()

                                self.yang_name = "postit"
                                self.yang_parent_name = "postits"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_classes = OrderedDict([("neighbors-address", ("neighbors_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress)), ("neighbor-af", ("neighbor_af", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborAf)), ("postit-info", ("postit_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('connect_state', (YLeaf(YType.uint32, 'connect-state'), ['int'])),
                                    ('start_time', (YLeaf(YType.uint32, 'start-time'), ['int'])),
                                    ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                ])
                                self.neighbor_address = None
                                self.vrf_name = None
                                self.connect_state = None
                                self.start_time = None
                                self.nsr_state = None

                                self.neighbors_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress()
                                self.neighbors_address.parent = self
                                self._children_name_map["neighbors_address"] = "neighbors-address"

                                self.neighbor_af = YList(self)
                                self.postit_info = YList(self)
                                self._segment_path = lambda: "postit" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit, ['neighbor_address', u'vrf_name', u'connect_state', u'start_time', u'nsr_state'], name, value)


                            class NeighborsAddress(Entity):
                                """
                                Neighbor Addr
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress, self).__init__()

                                    self.yang_name = "neighbors-address"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "neighbors-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NeighborAf(Entity):
                                """
                                Neighbor Afi
                                
                                .. attribute:: entry
                                
                                	Array entry
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborAf, self).__init__()

                                    self.yang_name = "neighbor-af"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "neighbor-af"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.NeighborAf, [u'entry'], name, value)


                            class PostitInfo(Entity):
                                """
                                Postit Info
                                
                                .. attribute:: postit_notification
                                
                                	Postit notification
                                	**type**\:  :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification>`
                                
                                .. attribute:: postit_type
                                
                                	Postit Type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_subtype
                                
                                	Postit Subtype
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_flags
                                
                                	Postit Flags
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_af_name
                                
                                	Postit Afi
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: postit_ts
                                
                                	Postit TS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: postit_direction
                                
                                	Postit Direction
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_id
                                
                                	Postit ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peer_id
                                
                                	Peer ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_policy
                                
                                	Policy
                                	**type**\: str
                                
                                .. attribute:: postit_reset
                                
                                	Reset
                                	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo, self).__init__()

                                    self.yang_name = "postit-info"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("postit-notification", ("postit_notification", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification))])
                                    self._leafs = OrderedDict([
                                        ('postit_type', (YLeaf(YType.uint32, 'postit-type'), ['int'])),
                                        ('postit_subtype', (YLeaf(YType.uint32, 'postit-subtype'), ['int'])),
                                        ('postit_flags', (YLeaf(YType.uint8, 'postit-flags'), ['int'])),
                                        ('postit_af_name', (YLeaf(YType.enumeration, 'postit-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('postit_ts', (YLeaf(YType.uint64, 'postit-ts'), ['int'])),
                                        ('postit_direction', (YLeaf(YType.uint8, 'postit-direction'), ['int'])),
                                        ('postit_id', (YLeaf(YType.uint32, 'postit-id'), ['int'])),
                                        ('peer_id', (YLeaf(YType.uint32, 'peer-id'), ['int'])),
                                        ('postit_policy', (YLeaf(YType.str, 'postit-policy'), ['str'])),
                                        ('postit_reset', (YLeaf(YType.enumeration, 'postit-reset'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                    ])
                                    self.postit_type = None
                                    self.postit_subtype = None
                                    self.postit_flags = None
                                    self.postit_af_name = None
                                    self.postit_ts = None
                                    self.postit_direction = None
                                    self.postit_id = None
                                    self.peer_id = None
                                    self.postit_policy = None
                                    self.postit_reset = None

                                    self.postit_notification = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification()
                                    self.postit_notification.parent = self
                                    self._children_name_map["postit_notification"] = "postit-notification"
                                    self._segment_path = lambda: "postit-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo, [u'postit_type', u'postit_subtype', u'postit_flags', u'postit_af_name', u'postit_ts', u'postit_direction', u'postit_id', u'peer_id', u'postit_policy', u'postit_reset'], name, value)


                                class PostitNotification(Entity):
                                    """
                                    Postit notification
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification, self).__init__()

                                        self.yang_name = "postit-notification"
                                        self.yang_parent_name = "postit-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData))])
                                        self._leafs = OrderedDict([
                                            ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                            ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                            ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                        ])
                                        self.time_since_last_notification = None
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "postit-notification"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "postit-notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "last-notification-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, [u'entry'], name, value)


                    class GlobalProcessInfo(Entity):
                        """
                        The Global Process information table
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf>`
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\: str
                        
                        .. attribute:: vrfid
                        
                        	VRF ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo, self).__init__()

                            self.yang_name = "global-process-info"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf))])
                            self._leafs = OrderedDict([
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('vrfid', (YLeaf(YType.uint32, 'vrfid'), ['int'])),
                            ])
                            self.vrf_name = None
                            self.vrfid = None

                            self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"

                            self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._segment_path = lambda: "global-process-info"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo, [u'vrf_name', u'vrfid'], name, value)


                        class Global(Entity):
                            """
                            Global information
                            
                            .. attribute:: in_standalone_mode
                            
                            	Standalone or Distributed mode
                            	**type**\: bool
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_name
                            
                            	Name of BGP instance
                            	**type**\: str
                            
                            .. attribute:: restart_count
                            
                            	No of times BGP has started
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_delay
                            
                            	Update delay timeout time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: generic_scan_period
                            
                            	Period (in seconds) of generic scanner runs
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: confederation_id
                            
                            	Confederation ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: cluster_id
                            
                            	Cluster ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_cluster_id
                            
                            	Configured cluster ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_cluster_id_specified_as_ip
                            
                            	Cluster ID specified as an IP address
                            	**type**\: bool
                            
                            .. attribute:: asn_format
                            
                            	BGP AS Number Format
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start_configured
                            
                            	Configured segment\-routing Global Block start value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end_configured
                            
                            	Configured segment\-routing Global Block end value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start
                            
                            	In use segment\-routing Global Block start value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end
                            
                            	In use Segment\-routing Global Block end value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\: bool
                            
                            .. attribute:: graceful_maint_all_nbrs
                            
                            	Graceful Maintenance also for neighbors without GM configuration
                            	**type**\: bool
                            
                            .. attribute:: graceful_maint_retain_routes
                            
                            	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                            	**type**\: bool
                            
                            .. attribute:: process_rlimit
                            
                            	Platform RLIMIT max for the process
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_maximum_buffer_size
                            
                            	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_default_buffer_size
                            
                            	Default value for BMP buffer limit when a value is not configured
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_current_buffer_size
                            
                            	Current value for BMP buffer 
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_cur_maximum_buffer_size
                            
                            	Maximum limit user has configure using max\-buffer\-size command under bmp\-server
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: cluster_id_entry
                            
                            	All configured Cluster IDs
                            	**type**\: list of  		 :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global.ClusterIdEntry>`
                            
                            .. attribute:: color_id
                            
                            	All configured Color IDs
                            	**type**\: list of  		 :py:class:`ColorId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global.ColorId>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "global-process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cluster-id-entry", ("cluster_id_entry", Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global.ClusterIdEntry)), ("color-id", ("color_id", Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global.ColorId))])
                                self._leafs = OrderedDict([
                                    ('in_standalone_mode', (YLeaf(YType.boolean, 'in-standalone-mode'), ['bool'])),
                                    ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                    ('instance_name', (YLeaf(YType.str, 'instance-name'), ['str'])),
                                    ('restart_count', (YLeaf(YType.uint32, 'restart-count'), ['int'])),
                                    ('update_delay', (YLeaf(YType.uint32, 'update-delay'), ['int'])),
                                    ('generic_scan_period', (YLeaf(YType.uint16, 'generic-scan-period'), ['int'])),
                                    ('confederation_id', (YLeaf(YType.uint32, 'confederation-id'), ['int'])),
                                    ('cluster_id', (YLeaf(YType.uint32, 'cluster-id'), ['int'])),
                                    ('configured_cluster_id', (YLeaf(YType.uint32, 'configured-cluster-id'), ['int'])),
                                    ('is_cluster_id_specified_as_ip', (YLeaf(YType.boolean, 'is-cluster-id-specified-as-ip'), ['bool'])),
                                    ('asn_format', (YLeaf(YType.uint32, 'asn-format'), ['int'])),
                                    ('srgb_start_configured', (YLeaf(YType.uint32, 'srgb-start-configured'), ['int'])),
                                    ('srgb_end_configured', (YLeaf(YType.uint32, 'srgb-end-configured'), ['int'])),
                                    ('srgb_start', (YLeaf(YType.uint32, 'srgb-start'), ['int'])),
                                    ('srgb_end', (YLeaf(YType.uint32, 'srgb-end'), ['int'])),
                                    ('graceful_maintenance', (YLeaf(YType.boolean, 'graceful-maintenance'), ['bool'])),
                                    ('graceful_maint_all_nbrs', (YLeaf(YType.boolean, 'graceful-maint-all-nbrs'), ['bool'])),
                                    ('graceful_maint_retain_routes', (YLeaf(YType.boolean, 'graceful-maint-retain-routes'), ['bool'])),
                                    ('process_rlimit', (YLeaf(YType.uint64, 'process-rlimit'), ['int'])),
                                    ('bmp_maximum_buffer_size', (YLeaf(YType.uint64, 'bmp-maximum-buffer-size'), ['int'])),
                                    ('bmp_default_buffer_size', (YLeaf(YType.uint64, 'bmp-default-buffer-size'), ['int'])),
                                    ('bmp_current_buffer_size', (YLeaf(YType.uint64, 'bmp-current-buffer-size'), ['int'])),
                                    ('bmp_cur_maximum_buffer_size', (YLeaf(YType.uint64, 'bmp-cur-maximum-buffer-size'), ['int'])),
                                ])
                                self.in_standalone_mode = None
                                self.local_as = None
                                self.instance_name = None
                                self.restart_count = None
                                self.update_delay = None
                                self.generic_scan_period = None
                                self.confederation_id = None
                                self.cluster_id = None
                                self.configured_cluster_id = None
                                self.is_cluster_id_specified_as_ip = None
                                self.asn_format = None
                                self.srgb_start_configured = None
                                self.srgb_end_configured = None
                                self.srgb_start = None
                                self.srgb_end = None
                                self.graceful_maintenance = None
                                self.graceful_maint_all_nbrs = None
                                self.graceful_maint_retain_routes = None
                                self.process_rlimit = None
                                self.bmp_maximum_buffer_size = None
                                self.bmp_default_buffer_size = None
                                self.bmp_current_buffer_size = None
                                self.bmp_cur_maximum_buffer_size = None

                                self.cluster_id_entry = YList(self)
                                self.color_id = YList(self)
                                self._segment_path = lambda: "global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global, [u'in_standalone_mode', u'local_as', u'instance_name', u'restart_count', u'update_delay', u'generic_scan_period', u'confederation_id', u'cluster_id', u'configured_cluster_id', u'is_cluster_id_specified_as_ip', u'asn_format', u'srgb_start_configured', u'srgb_end_configured', u'srgb_start', u'srgb_end', u'graceful_maintenance', u'graceful_maint_all_nbrs', u'graceful_maint_retain_routes', u'process_rlimit', u'bmp_maximum_buffer_size', u'bmp_default_buffer_size', u'bmp_current_buffer_size', u'bmp_cur_maximum_buffer_size'], name, value)


                            class ClusterIdEntry(Entity):
                                """
                                All configured Cluster IDs
                                
                                .. attribute:: cluster_id_val
                                
                                	Cluster ID 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: cluster_id_type
                                
                                	Cluster ID type\: number or IPv4 address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global.ClusterIdEntry, self).__init__()

                                    self.yang_name = "cluster-id-entry"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cluster_id_val', (YLeaf(YType.uint32, 'cluster-id-val'), ['int'])),
                                        ('cluster_id_type', (YLeaf(YType.uint8, 'cluster-id-type'), ['int'])),
                                    ])
                                    self.cluster_id_val = None
                                    self.cluster_id_type = None
                                    self._segment_path = lambda: "cluster-id-entry"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global.ClusterIdEntry, [u'cluster_id_val', u'cluster_id_type'], name, value)


                            class ColorId(Entity):
                                """
                                All configured Color IDs
                                
                                .. attribute:: color_id_val
                                
                                	Color ID 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global.ColorId, self).__init__()

                                    self.yang_name = "color-id"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('color_id_val', (YLeaf(YType.uint32, 'color-id-val'), ['int'])),
                                    ])
                                    self.color_id_val = None
                                    self._segment_path = lambda: "color-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Global.ColorId, [u'color_id_val'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: vrf_is_active
                            
                            	VRF state
                            	**type**\: bool
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: router_id
                            
                            	Router ID for the VRF
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: configured_router_id
                            
                            	Configured router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                            
                            	Redistribute iBGP into IGPs enabled
                            	**type**\: bool
                            
                            .. attribute:: is_fast_external_fallover_enabled
                            
                            	Fast external fallover enabled
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_missing_med_is_worst_enabled
                            
                            	Bestpath\: Treat missing MED as worst
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_always_compare_med_enabled
                            
                            	Bestpath\: Always compare MED
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_ignore_as_path_enabled
                            
                            	Bestpath\: Ignore AS path
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                            
                            	Bestpath\: Relax AS path for mpath
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                            
                            	Bestpath\: Compare MED from confed peer
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                            
                            	Bestpath\: Compare routerID for eBGP peers
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_aigp_ignore_enabled
                            
                            	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_igp_metric_ignore_enabled
                            
                            	Bestpath\: Ignore IGP metric
                            	**type**\: bool
                            
                            .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                            
                            	Multipath\: Ignore everything AS path onwards for mpath
                            	**type**\: bool
                            
                            .. attribute:: is_enforce_first_as_enabled
                            
                            	Enforce first AS
                            	**type**\: bool
                            
                            .. attribute:: default_local_preference
                            
                            	Default local preference
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_time
                            
                            	Default keepalive timer (seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: hold_time
                            
                            	Default hold timer (seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: min_acceptable_hold_time
                            
                            	Default min acceptable hold time from neighbor(seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: is_neighbor_logging
                            
                            	Neighbor logging enabled
                            	**type**\: bool
                            
                            .. attribute:: is_default_metric_configured
                            
                            	Default metric configured
                            	**type**\: bool
                            
                            .. attribute:: default_metric
                            
                            	Default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_default_originate_configured
                            
                            	Default route originate configured
                            	**type**\: bool
                            
                            .. attribute:: is_graceful_restart
                            
                            	Graceful restart enabled
                            	**type**\: bool
                            
                            .. attribute:: is_nsr
                            
                            	Non\-stop routing enabled
                            	**type**\: bool
                            
                            .. attribute:: restart_time
                            
                            	Restart time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: stale_path_time
                            
                            	Stale path timeout time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: rib_purge_timeout
                            
                            	RIB purge timeout time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: rpki_use_validity
                            
                            	Use RPKI validity for bestpath calculation
                            	**type**\: bool
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Allow invalid paths
                            	**type**\: bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Signal RPKI validity to iBGP peers
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "global-process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vrf_is_active', (YLeaf(YType.boolean, 'vrf-is-active'), ['bool'])),
                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                    ('configured_router_id', (YLeaf(YType.str, 'configured-router-id'), ['str'])),
                                    ('is_redistribute_ibgp_to_ig_ps_enabled', (YLeaf(YType.boolean, 'is-redistribute-ibgp-to-ig-ps-enabled'), ['bool'])),
                                    ('is_fast_external_fallover_enabled', (YLeaf(YType.boolean, 'is-fast-external-fallover-enabled'), ['bool'])),
                                    ('is_bestpath_missing_med_is_worst_enabled', (YLeaf(YType.boolean, 'is-bestpath-missing-med-is-worst-enabled'), ['bool'])),
                                    ('is_bestpath_always_compare_med_enabled', (YLeaf(YType.boolean, 'is-bestpath-always-compare-med-enabled'), ['bool'])),
                                    ('is_bestpath_ignore_as_path_enabled', (YLeaf(YType.boolean, 'is-bestpath-ignore-as-path-enabled'), ['bool'])),
                                    ('is_bestpath_as_path_mpath_relax_enabled', (YLeaf(YType.boolean, 'is-bestpath-as-path-mpath-relax-enabled'), ['bool'])),
                                    ('is_bestpath_compare_med_from_confed_peer_enabled', (YLeaf(YType.boolean, 'is-bestpath-compare-med-from-confed-peer-enabled'), ['bool'])),
                                    ('is_bestpath_compare_router_id_for_ebgp_peers_enabled', (YLeaf(YType.boolean, 'is-bestpath-compare-router-id-for-ebgp-peers-enabled'), ['bool'])),
                                    ('is_bestpath_aigp_ignore_enabled', (YLeaf(YType.boolean, 'is-bestpath-aigp-ignore-enabled'), ['bool'])),
                                    ('is_bestpath_igp_metric_ignore_enabled', (YLeaf(YType.boolean, 'is-bestpath-igp-metric-ignore-enabled'), ['bool'])),
                                    ('is_multipath_as_path_ignore_onwards_enabled', (YLeaf(YType.boolean, 'is-multipath-as-path-ignore-onwards-enabled'), ['bool'])),
                                    ('is_enforce_first_as_enabled', (YLeaf(YType.boolean, 'is-enforce-first-as-enabled'), ['bool'])),
                                    ('default_local_preference', (YLeaf(YType.uint32, 'default-local-preference'), ['int'])),
                                    ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                    ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                    ('min_acceptable_hold_time', (YLeaf(YType.uint16, 'min-acceptable-hold-time'), ['int'])),
                                    ('is_neighbor_logging', (YLeaf(YType.boolean, 'is-neighbor-logging'), ['bool'])),
                                    ('is_default_metric_configured', (YLeaf(YType.boolean, 'is-default-metric-configured'), ['bool'])),
                                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                    ('is_default_originate_configured', (YLeaf(YType.boolean, 'is-default-originate-configured'), ['bool'])),
                                    ('is_graceful_restart', (YLeaf(YType.boolean, 'is-graceful-restart'), ['bool'])),
                                    ('is_nsr', (YLeaf(YType.boolean, 'is-nsr'), ['bool'])),
                                    ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                    ('stale_path_time', (YLeaf(YType.uint32, 'stale-path-time'), ['int'])),
                                    ('rib_purge_timeout', (YLeaf(YType.uint32, 'rib-purge-timeout'), ['int'])),
                                    ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                    ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                    ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                ])
                                self.vrf_is_active = None
                                self.route_distinguisher = None
                                self.router_id = None
                                self.configured_router_id = None
                                self.is_redistribute_ibgp_to_ig_ps_enabled = None
                                self.is_fast_external_fallover_enabled = None
                                self.is_bestpath_missing_med_is_worst_enabled = None
                                self.is_bestpath_always_compare_med_enabled = None
                                self.is_bestpath_ignore_as_path_enabled = None
                                self.is_bestpath_as_path_mpath_relax_enabled = None
                                self.is_bestpath_compare_med_from_confed_peer_enabled = None
                                self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = None
                                self.is_bestpath_aigp_ignore_enabled = None
                                self.is_bestpath_igp_metric_ignore_enabled = None
                                self.is_multipath_as_path_ignore_onwards_enabled = None
                                self.is_enforce_first_as_enabled = None
                                self.default_local_preference = None
                                self.keep_alive_time = None
                                self.hold_time = None
                                self.min_acceptable_hold_time = None
                                self.is_neighbor_logging = None
                                self.is_default_metric_configured = None
                                self.default_metric = None
                                self.is_default_originate_configured = None
                                self.is_graceful_restart = None
                                self.is_nsr = None
                                self.restart_time = None
                                self.stale_path_time = None
                                self.rib_purge_timeout = None
                                self.rpki_use_validity = None
                                self.rpki_allow_invalid = None
                                self.rpki_signal_ibgp = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.GlobalProcessInfo.Vrf, [u'vrf_is_active', u'route_distinguisher', u'router_id', u'configured_router_id', u'is_redistribute_ibgp_to_ig_ps_enabled', u'is_fast_external_fallover_enabled', u'is_bestpath_missing_med_is_worst_enabled', u'is_bestpath_always_compare_med_enabled', u'is_bestpath_ignore_as_path_enabled', u'is_bestpath_as_path_mpath_relax_enabled', u'is_bestpath_compare_med_from_confed_peer_enabled', u'is_bestpath_compare_router_id_for_ebgp_peers_enabled', u'is_bestpath_aigp_ignore_enabled', u'is_bestpath_igp_metric_ignore_enabled', u'is_multipath_as_path_ignore_onwards_enabled', u'is_enforce_first_as_enabled', u'default_local_preference', u'keep_alive_time', u'hold_time', u'min_acceptable_hold_time', u'is_neighbor_logging', u'is_default_metric_configured', u'default_metric', u'is_default_originate_configured', u'is_graceful_restart', u'is_nsr', u'restart_time', u'stale_path_time', u'rib_purge_timeout', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp'], name, value)


                    class UpdateInboundErrorNeighbors(Entity):
                        """
                        Update inbound error information for all
                        neighbors
                        
                        .. attribute:: update_inbound_error_neighbor
                        
                        	Update inbound error information for neighbor
                        	**type**\: list of  		 :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors, self).__init__()

                            self.yang_name = "update-inbound-error-neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("update-inbound-error-neighbor", ("update_inbound_error_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor))])
                            self._leafs = OrderedDict()

                            self.update_inbound_error_neighbor = YList(self)
                            self._segment_path = lambda: "update-inbound-error-neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors, [], name, value)


                        class UpdateInboundErrorNeighbor(Entity):
                            """
                            Update inbound error information for neighbor
                            
                            .. attribute:: neighbor_address  (key)
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: first_update_malformed_timestamp
                            
                            	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: first_update_memory_allocation_fail_timestamp
                            
                            	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: last_update_memory_allocation_fail_timestamp
                            
                            	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: first_update_error_handling_reset_timestamp
                            
                            	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                            
                            .. attribute:: last_error_handling_reset_timestamp
                            
                            	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: update_error_handling_avoid_reset
                            
                            	Configure error\-handling to avoid resets
                            	**type**\: bool
                            
                            .. attribute:: total_update_message_count
                            
                            	Total update messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed message received event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: update_memory_allocation_fail_count
                            
                            	Memory allocation failure count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_update_memory_allocation_fail_age
                            
                            	Time since last memory allocation failure event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: update_error_handling_reset_count
                            
                            	Error\-handling reset count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_error_handling_reset_age
                            
                            	Time since last error\-handling reset event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: update_error_message_list_count
                            
                            	Malformed messages list count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_discard_count
                            
                            	Discarded attribute count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_total_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_action_count
                            
                            	Number of occurence of each action type since  session establishment
                            	**type**\: list of  		 :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                            
                            .. attribute:: update_error_message
                            
                            	List of malformed messages
                            	**type**\: list of  		 :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, self).__init__()

                                self.yang_name = "update-inbound-error-neighbor"
                                self.yang_parent_name = "update-inbound-error-neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress)), ("first-update-malformed-timestamp", ("first_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp)), ("last-update-malformed-timestamp", ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp)), ("first-update-memory-allocation-fail-timestamp", ("first_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp)), ("first-update-error-handling-reset-timestamp", ("first_update_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp)), ("last-error-handling-reset-timestamp", ("last_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp)), ("establishment-action-count", ("establishment_action_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount)), ("update-error-message", ("update_error_message", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                    ('update_error_handling_avoid_reset', (YLeaf(YType.boolean, 'update-error-handling-avoid-reset'), ['bool'])),
                                    ('total_update_message_count', (YLeaf(YType.uint32, 'total-update-message-count'), ['int'])),
                                    ('update_malformed_message_count', (YLeaf(YType.uint32, 'update-malformed-message-count'), ['int'])),
                                    ('last_update_malformed_age', (YLeaf(YType.uint32, 'last-update-malformed-age'), ['int'])),
                                    ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                    ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                    ('update_error_handling_reset_count', (YLeaf(YType.uint32, 'update-error-handling-reset-count'), ['int'])),
                                    ('last_error_handling_reset_age', (YLeaf(YType.uint32, 'last-error-handling-reset-age'), ['int'])),
                                    ('update_error_message_list_count', (YLeaf(YType.uint32, 'update-error-message-list-count'), ['int'])),
                                    ('update_attribute_discard_count', (YLeaf(YType.uint32, 'update-attribute-discard-count'), ['int'])),
                                    ('establishment_total_update_message_count', (YLeaf(YType.uint32, 'establishment-total-update-message-count'), ['int'])),
                                ])
                                self.neighbor_address = None
                                self.update_vrf_name = None
                                self.update_error_handling_avoid_reset = None
                                self.total_update_message_count = None
                                self.update_malformed_message_count = None
                                self.last_update_malformed_age = None
                                self.update_memory_allocation_fail_count = None
                                self.last_update_memory_allocation_fail_age = None
                                self.update_error_handling_reset_count = None
                                self.last_error_handling_reset_age = None
                                self.update_error_message_list_count = None
                                self.update_attribute_discard_count = None
                                self.establishment_total_update_message_count = None

                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                self.first_update_malformed_timestamp.parent = self
                                self._children_name_map["first_update_malformed_timestamp"] = "first-update-malformed-timestamp"

                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"

                                self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                self.first_update_memory_allocation_fail_timestamp.parent = self
                                self._children_name_map["first_update_memory_allocation_fail_timestamp"] = "first-update-memory-allocation-fail-timestamp"

                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"

                                self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                self.first_update_error_handling_reset_timestamp.parent = self
                                self._children_name_map["first_update_error_handling_reset_timestamp"] = "first-update-error-handling-reset-timestamp"

                                self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                self.last_error_handling_reset_timestamp.parent = self
                                self._children_name_map["last_error_handling_reset_timestamp"] = "last-error-handling-reset-timestamp"

                                self.establishment_action_count = YList(self)
                                self.update_error_message = YList(self)
                                self._segment_path = lambda: "update-inbound-error-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, ['neighbor_address', u'update_vrf_name', u'update_error_handling_avoid_reset', u'total_update_message_count', u'update_malformed_message_count', u'last_update_malformed_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age', u'update_error_handling_reset_count', u'last_error_handling_reset_age', u'update_error_message_list_count', u'update_attribute_discard_count', u'establishment_total_update_message_count'], name, value)


                            class UpdateNeighborAddress(Entity):
                                """
                                Neighbor address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, self).__init__()

                                    self.yang_name = "update-neighbor-address"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "update-neighbor-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class FirstUpdateMalformedTimestamp(Entity):
                                """
                                First malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "first-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "first-update-malformed-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class LastUpdateMalformedTimestamp(Entity):
                                """
                                Last malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "last-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-update-malformed-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class FirstUpdateMemoryAllocationFailTimestamp(Entity):
                                """
                                First memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, self).__init__()

                                    self.yang_name = "first-update-memory-allocation-fail-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "first-update-memory-allocation-fail-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                """
                                Last memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class FirstUpdateErrorHandlingResetTimestamp(Entity):
                                """
                                First error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, self).__init__()

                                    self.yang_name = "first-update-error-handling-reset-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "first-update-error-handling-reset-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class LastErrorHandlingResetTimestamp(Entity):
                                """
                                Last error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, self).__init__()

                                    self.yang_name = "last-error-handling-reset-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-error-handling-reset-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class EstablishmentActionCount(Entity):
                                """
                                Number of occurence of each action type since
                                
                                session establishment
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, self).__init__()

                                    self.yang_name = "establishment-action-count"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "establishment-action-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, [u'entry'], name, value)


                            class UpdateErrorMessage(Entity):
                                """
                                List of malformed messages
                                
                                .. attribute:: update_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                
                                .. attribute:: update_message_reset_data
                                
                                	Reset data
                                	**type**\:  :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                
                                .. attribute:: update_error_final_action
                                
                                	Error final action
                                	**type**\:  :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_error_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\: str
                                
                                .. attribute:: update_error_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\: bool
                                
                                .. attribute:: update_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of  		 :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                
                                .. attribute:: update_error_element
                                
                                	Error element list
                                	**type**\: list of  		 :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, self).__init__()

                                    self.yang_name = "update-error-message"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-message-timestamp", ("update_message_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp)), ("update-message-reset-data", ("update_message_reset_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData)), ("update-message-data", ("update_message_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData)), ("update-error-element", ("update_error_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement))])
                                    self._leafs = OrderedDict([
                                        ('update_error_final_action', (YLeaf(YType.enumeration, 'update-error-final-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdErrAction', '')])),
                                        ('update_attribute_discard_count', (YLeaf(YType.uint32, 'update-attribute-discard-count'), ['int'])),
                                        ('update_error_nlri_address_family', (YLeaf(YType.enumeration, 'update-error-nlri-address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('update_error_nlri_string', (YLeaf(YType.str, 'update-error-nlri-string'), ['str'])),
                                        ('update_error_nlri_string_truncated', (YLeaf(YType.boolean, 'update-error-nlri-string-truncated'), ['bool'])),
                                    ])
                                    self.update_error_final_action = None
                                    self.update_attribute_discard_count = None
                                    self.update_error_nlri_address_family = None
                                    self.update_error_nlri_string = None
                                    self.update_error_nlri_string_truncated = None

                                    self.update_message_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                    self.update_message_timestamp.parent = self
                                    self._children_name_map["update_message_timestamp"] = "update-message-timestamp"

                                    self.update_message_reset_data = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                    self.update_message_reset_data.parent = self
                                    self._children_name_map["update_message_reset_data"] = "update-message-reset-data"

                                    self.update_message_data = YList(self)
                                    self.update_error_element = YList(self)
                                    self._segment_path = lambda: "update-error-message"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, [u'update_error_final_action', u'update_attribute_discard_count', u'update_error_nlri_address_family', u'update_error_nlri_string', u'update_error_nlri_string_truncated'], name, value)


                                class UpdateMessageTimestamp(Entity):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, self).__init__()

                                        self.yang_name = "update-message-timestamp"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "update-message-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateMessageResetData(Entity):
                                    """
                                    Reset data
                                    
                                    .. attribute:: update_error_reset_reason
                                    
                                    	Reset Reason
                                    	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    .. attribute:: update_error_reset_notification_code
                                    
                                    	Notification code
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_error_reset_notification_sub_code
                                    
                                    	Notification sub code
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_reset_notification_data
                                    
                                    	Notification data
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_reset_notification_data_length
                                    
                                    	Notification data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, self).__init__()

                                        self.yang_name = "update-message-reset-data"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('update_error_reset_reason', (YLeaf(YType.enumeration, 'update-error-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                            ('update_error_reset_notification_code', (YLeaf(YType.uint8, 'update-error-reset-notification-code'), ['int'])),
                                            ('update_error_reset_notification_sub_code', (YLeaf(YType.uint16, 'update-error-reset-notification-sub-code'), ['int'])),
                                            ('update_error_reset_notification_data', (YLeaf(YType.str, 'update-error-reset-notification-data'), ['str'])),
                                            ('update_error_reset_notification_data_length', (YLeaf(YType.uint16, 'update-error-reset-notification-data-length'), ['int'])),
                                        ])
                                        self.update_error_reset_reason = None
                                        self.update_error_reset_notification_code = None
                                        self.update_error_reset_notification_sub_code = None
                                        self.update_error_reset_notification_data = None
                                        self.update_error_reset_notification_data_length = None
                                        self._segment_path = lambda: "update-message-reset-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, [u'update_error_reset_reason', u'update_error_reset_notification_code', u'update_error_reset_notification_sub_code', u'update_error_reset_notification_data', u'update_error_reset_notification_data_length'], name, value)


                                class UpdateMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, self).__init__()

                                        self.yang_name = "update-message-data"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "update-message-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, [u'entry'], name, value)


                                class UpdateErrorElement(Entity):
                                    """
                                    Error element list
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_length
                                    
                                    	Attribute Length [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_data
                                    
                                    	Error data
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_data_length
                                    
                                    	Error data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_action
                                    
                                    	Error action
                                    	**type**\:  :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, self).__init__()

                                        self.yang_name = "update-error-element"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('update_attribute_flags', (YLeaf(YType.uint8, 'update-attribute-flags'), ['int'])),
                                            ('update_attribute_code', (YLeaf(YType.uint8, 'update-attribute-code'), ['int'])),
                                            ('update_attribute_length', (YLeaf(YType.uint16, 'update-attribute-length'), ['int'])),
                                            ('update_error_data', (YLeaf(YType.str, 'update-error-data'), ['str'])),
                                            ('update_error_data_length', (YLeaf(YType.uint16, 'update-error-data-length'), ['int'])),
                                            ('update_error_action', (YLeaf(YType.enumeration, 'update-error-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdErrAction', '')])),
                                        ])
                                        self.update_attribute_flags = None
                                        self.update_attribute_code = None
                                        self.update_attribute_length = None
                                        self.update_error_data = None
                                        self.update_error_data_length = None
                                        self.update_error_action = None
                                        self._segment_path = lambda: "update-error-element"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, [u'update_attribute_flags', u'update_attribute_code', u'update_attribute_length', u'update_error_data', u'update_error_data_length', u'update_error_action'], name, value)


                    class UpdateInboundFilterNeighbors(Entity):
                        """
                        Update inbound filtering information for all
                        neighbors
                        
                        .. attribute:: update_inbound_filter_neighbor
                        
                        	Update inbound filtering information for neighbor
                        	**type**\: list of  		 :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors, self).__init__()

                            self.yang_name = "update-inbound-filter-neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("update-inbound-filter-neighbor", ("update_inbound_filter_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor))])
                            self._leafs = OrderedDict()

                            self.update_inbound_filter_neighbor = YList(self)
                            self._segment_path = lambda: "update-inbound-filter-neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors, [], name, value)


                        class UpdateInboundFilterNeighbor(Entity):
                            """
                            Update inbound filtering information for
                            neighbor
                            
                            .. attribute:: neighbor_address  (key)
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: first_update_filtered_timestamp
                            
                            	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: update_filter_logging_enabled
                            
                            	Logging is enabled
                            	**type**\: bool
                            
                            .. attribute:: configured_update_filter_message_buffer_count
                            
                            	Configured Filtered message buffer count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: operational_update_filter_message_buffer_count
                            
                            	Operational Filtered messages buffer count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filter_message_buffer_circular
                            
                            	Indicates if the message buffers are circular
                            	**type**\: bool
                            
                            .. attribute:: update_attribute_filter_group_name
                            
                            	Update attribute\-filter group name
                            	**type**\: str
                            
                            .. attribute:: operational_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled
                            	**type**\: bool
                            
                            .. attribute:: message_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled for the current message being parsed
                            	**type**\: bool
                            
                            .. attribute:: total_filter_update_message_count
                            
                            	Total update messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_total_filter_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_update_filtered_message_count
                            
                            	Filtered messages count since session establishment
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered message received event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: update_filter_message_list_count
                            
                            	Filtered messages list count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_filter_attributes
                            
                            	List of attributes that can be filtered
                            	**type**\: list of  		 :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                            
                            .. attribute:: update_filter_message
                            
                            	List of filtered messages
                            	**type**\: list of  		 :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, self).__init__()

                                self.yang_name = "update-inbound-filter-neighbor"
                                self.yang_parent_name = "update-inbound-filter-neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress)), ("first-update-filtered-timestamp", ("first_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp)), ("last-update-filtered-timestamp", ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp)), ("update-attribute-filter-attributes", ("update_attribute_filter_attributes", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes)), ("update-filter-message", ("update_filter_message", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                    ('update_filter_logging_enabled', (YLeaf(YType.boolean, 'update-filter-logging-enabled'), ['bool'])),
                                    ('configured_update_filter_message_buffer_count', (YLeaf(YType.uint32, 'configured-update-filter-message-buffer-count'), ['int'])),
                                    ('operational_update_filter_message_buffer_count', (YLeaf(YType.uint32, 'operational-update-filter-message-buffer-count'), ['int'])),
                                    ('update_filter_message_buffer_circular', (YLeaf(YType.boolean, 'update-filter-message-buffer-circular'), ['bool'])),
                                    ('update_attribute_filter_group_name', (YLeaf(YType.str, 'update-attribute-filter-group-name'), ['str'])),
                                    ('operational_update_attribute_filtering_enabled', (YLeaf(YType.boolean, 'operational-update-attribute-filtering-enabled'), ['bool'])),
                                    ('message_update_attribute_filtering_enabled', (YLeaf(YType.boolean, 'message-update-attribute-filtering-enabled'), ['bool'])),
                                    ('total_filter_update_message_count', (YLeaf(YType.uint32, 'total-filter-update-message-count'), ['int'])),
                                    ('establishment_total_filter_update_message_count', (YLeaf(YType.uint32, 'establishment-total-filter-update-message-count'), ['int'])),
                                    ('update_filtered_message_count', (YLeaf(YType.uint32, 'update-filtered-message-count'), ['int'])),
                                    ('establishment_update_filtered_message_count', (YLeaf(YType.uint32, 'establishment-update-filtered-message-count'), ['int'])),
                                    ('last_update_filtered_age', (YLeaf(YType.uint32, 'last-update-filtered-age'), ['int'])),
                                    ('update_filter_message_list_count', (YLeaf(YType.uint32, 'update-filter-message-list-count'), ['int'])),
                                ])
                                self.neighbor_address = None
                                self.update_vrf_name = None
                                self.update_filter_logging_enabled = None
                                self.configured_update_filter_message_buffer_count = None
                                self.operational_update_filter_message_buffer_count = None
                                self.update_filter_message_buffer_circular = None
                                self.update_attribute_filter_group_name = None
                                self.operational_update_attribute_filtering_enabled = None
                                self.message_update_attribute_filtering_enabled = None
                                self.total_filter_update_message_count = None
                                self.establishment_total_filter_update_message_count = None
                                self.update_filtered_message_count = None
                                self.establishment_update_filtered_message_count = None
                                self.last_update_filtered_age = None
                                self.update_filter_message_list_count = None

                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                self.first_update_filtered_timestamp.parent = self
                                self._children_name_map["first_update_filtered_timestamp"] = "first-update-filtered-timestamp"

                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"

                                self.update_attribute_filter_attributes = YList(self)
                                self.update_filter_message = YList(self)
                                self._segment_path = lambda: "update-inbound-filter-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, ['neighbor_address', u'update_vrf_name', u'update_filter_logging_enabled', u'configured_update_filter_message_buffer_count', u'operational_update_filter_message_buffer_count', u'update_filter_message_buffer_circular', u'update_attribute_filter_group_name', u'operational_update_attribute_filtering_enabled', u'message_update_attribute_filtering_enabled', u'total_filter_update_message_count', u'establishment_total_filter_update_message_count', u'update_filtered_message_count', u'establishment_update_filtered_message_count', u'last_update_filtered_age', u'update_filter_message_list_count'], name, value)


                            class UpdateNeighborAddress(Entity):
                                """
                                Neighbor address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, self).__init__()

                                    self.yang_name = "update-neighbor-address"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "update-neighbor-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class FirstUpdateFilteredTimestamp(Entity):
                                """
                                First filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "first-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "first-update-filtered-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class LastUpdateFilteredTimestamp(Entity):
                                """
                                Last filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "last-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-update-filtered-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class UpdateAttributeFilterAttributes(Entity):
                                """
                                List of attributes that can be filtered
                                
                                .. attribute:: last_update_filter_match_timestamp
                                
                                	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                
                                .. attribute:: update_internal_attribute_code
                                
                                	Internal attribute code [RFC4271\: BGP4]
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filter_action
                                
                                	Filtering action
                                	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                
                                .. attribute:: update_filter_match_count
                                
                                	Filter match counter
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_update_filter_match_count
                                
                                	Filter match counter since last session establishment
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_filter_match_age
                                
                                	Time since this attribute was last filtered (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, self).__init__()

                                    self.yang_name = "update-attribute-filter-attributes"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("last-update-filter-match-timestamp", ("last_update_filter_match_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp))])
                                    self._leafs = OrderedDict([
                                        ('update_internal_attribute_code', (YLeaf(YType.uint32, 'update-internal-attribute-code'), ['int'])),
                                        ('update_filter_action', (YLeaf(YType.enumeration, 'update-filter-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                        ('update_filter_match_count', (YLeaf(YType.uint32, 'update-filter-match-count'), ['int'])),
                                        ('establishment_update_filter_match_count', (YLeaf(YType.uint32, 'establishment-update-filter-match-count'), ['int'])),
                                        ('last_update_filter_match_age', (YLeaf(YType.uint32, 'last-update-filter-match-age'), ['int'])),
                                    ])
                                    self.update_internal_attribute_code = None
                                    self.update_filter_action = None
                                    self.update_filter_match_count = None
                                    self.establishment_update_filter_match_count = None
                                    self.last_update_filter_match_age = None

                                    self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                    self.last_update_filter_match_timestamp.parent = self
                                    self._children_name_map["last_update_filter_match_timestamp"] = "last-update-filter-match-timestamp"
                                    self._segment_path = lambda: "update-attribute-filter-attributes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, [u'update_internal_attribute_code', u'update_filter_action', u'update_filter_match_count', u'establishment_update_filter_match_count', u'last_update_filter_match_age'], name, value)


                                class LastUpdateFilterMatchTimestamp(Entity):
                                    """
                                    Last attribute filtered time\: time elapsed since
                                    00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, self).__init__()

                                        self.yang_name = "last-update-filter-match-timestamp"
                                        self.yang_parent_name = "update-attribute-filter-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "last-update-filter-match-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class UpdateFilterMessage(Entity):
                                """
                                List of filtered messages
                                
                                .. attribute:: update_filter_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                
                                .. attribute:: update_filtered_attribute_count
                                
                                	Filtered attributes count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filter_final_action
                                
                                	Filtering final action
                                	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                
                                .. attribute:: update_filter_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_filter_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\: str
                                
                                .. attribute:: update_filter_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\: bool
                                
                                .. attribute:: update_filter_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of  		 :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                
                                .. attribute:: update_filter_element
                                
                                	Filtering element list
                                	**type**\: list of  		 :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, self).__init__()

                                    self.yang_name = "update-filter-message"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-filter-message-timestamp", ("update_filter_message_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp)), ("update-filter-message-data", ("update_filter_message_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData)), ("update-filter-element", ("update_filter_element", Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement))])
                                    self._leafs = OrderedDict([
                                        ('update_filtered_attribute_count', (YLeaf(YType.uint32, 'update-filtered-attribute-count'), ['int'])),
                                        ('update_filter_final_action', (YLeaf(YType.enumeration, 'update-filter-final-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                        ('update_filter_nlri_address_family', (YLeaf(YType.enumeration, 'update-filter-nlri-address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('update_filter_nlri_string', (YLeaf(YType.str, 'update-filter-nlri-string'), ['str'])),
                                        ('update_filter_nlri_string_truncated', (YLeaf(YType.boolean, 'update-filter-nlri-string-truncated'), ['bool'])),
                                    ])
                                    self.update_filtered_attribute_count = None
                                    self.update_filter_final_action = None
                                    self.update_filter_nlri_address_family = None
                                    self.update_filter_nlri_string = None
                                    self.update_filter_nlri_string_truncated = None

                                    self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                    self.update_filter_message_timestamp.parent = self
                                    self._children_name_map["update_filter_message_timestamp"] = "update-filter-message-timestamp"

                                    self.update_filter_message_data = YList(self)
                                    self.update_filter_element = YList(self)
                                    self._segment_path = lambda: "update-filter-message"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, [u'update_filtered_attribute_count', u'update_filter_final_action', u'update_filter_nlri_address_family', u'update_filter_nlri_string', u'update_filter_nlri_string_truncated'], name, value)


                                class UpdateFilterMessageTimestamp(Entity):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, self).__init__()

                                        self.yang_name = "update-filter-message-timestamp"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "update-filter-message-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateFilterMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, self).__init__()

                                        self.yang_name = "update-filter-message-data"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "update-filter-message-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, [u'entry'], name, value)


                                class UpdateFilterElement(Entity):
                                    """
                                    Filtering element list
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, self).__init__()

                                        self.yang_name = "update-filter-element"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('update_attribute_flags', (YLeaf(YType.uint8, 'update-attribute-flags'), ['int'])),
                                            ('update_attribute_code', (YLeaf(YType.uint8, 'update-attribute-code'), ['int'])),
                                            ('update_filter_action', (YLeaf(YType.enumeration, 'update-filter-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                        ])
                                        self.update_attribute_flags = None
                                        self.update_attribute_code = None
                                        self.update_filter_action = None
                                        self._segment_path = lambda: "update-filter-element"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, [u'update_attribute_flags', u'update_attribute_code', u'update_filter_action'], name, value)


                    class Bmp(Entity):
                        """
                        BMP related Operational Data
                        
                        .. attribute:: server_summaries
                        
                        	Table of BMP Servers
                        	**type**\:  :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries>`
                        
                        .. attribute:: server_neighbors
                        
                        	Table of Neighbors for a BMP Server
                        	**type**\:  :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp, self).__init__()

                            self.yang_name = "bmp"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("server-summaries", ("server_summaries", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries)), ("server-neighbors", ("server_neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors))])
                            self._leafs = OrderedDict()

                            self.server_summaries = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries()
                            self.server_summaries.parent = self
                            self._children_name_map["server_summaries"] = "server-summaries"

                            self.server_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors()
                            self.server_neighbors.parent = self
                            self._children_name_map["server_neighbors"] = "server-neighbors"
                            self._segment_path = lambda: "bmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp, [], name, value)


                        class ServerSummaries(Entity):
                            """
                            Table of BMP Servers
                            
                            .. attribute:: server_summary
                            
                            	Summary Information about BMP server
                            	**type**\: list of  		 :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries, self).__init__()

                                self.yang_name = "server-summaries"
                                self.yang_parent_name = "bmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("server-summary", ("server_summary", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary))])
                                self._leafs = OrderedDict()

                                self.server_summary = YList(self)
                                self._segment_path = lambda: "server-summaries"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries, [], name, value)


                            class ServerSummary(Entity):
                                """
                                Summary Information about BMP server
                                
                                .. attribute:: server_id  (key)
                                
                                	BMP Server ID
                                	**type**\: int
                                
                                	**range:** 1..8
                                
                                .. attribute:: bmp_server_state_age
                                
                                	Age of current state of BMP Server
                                	**type**\:  :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                
                                .. attribute:: bmp_server_state_time_spec
                                
                                	Timespec of current state of BMP Server
                                	**type**\:  :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                
                                .. attribute:: bmp_server_last_discon_time
                                
                                	Timespec of Last Disconnect event received from BMP server
                                	**type**\:  :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                
                                .. attribute:: update_source_address
                                
                                	Address of Interface configured as Update Source
                                	**type**\:  :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                
                                .. attribute:: bmp_server_id
                                
                                	BMP Server ID
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: bmp_server_host_name
                                
                                	BMP Server Hostname
                                	**type**\: str
                                
                                .. attribute:: bmp_server_port
                                
                                	BMP Server Port Number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_server_state
                                
                                	Connection state of the BMP server
                                	**type**\:  :py:class:`BgpBmpState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpState>`
                                
                                .. attribute:: bmp_server_is_flapping
                                
                                	Connection to the BMP server Flapping
                                	**type**\: bool
                                
                                .. attribute:: bmp_server_nbr_count
                                
                                	Neighbor count for the BMP Server
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_init_msg_count
                                
                                	Number of Initiation Msgs sent by this BMP Server
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_termination_msg_count
                                
                                	Number of Termination Messages sent by this BMP Server
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_status_report_count
                                
                                	Number of Status ReportMessages sent by this BMP Server
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_count
                                
                                	Total number of per peer messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_drop_count
                                
                                	Total number of messages dropped
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count
                                
                                	Total number of bmpQ msgs pending
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos_type
                                
                                	Precedence (0) or DSCP (1) type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: update_source_interface_name
                                
                                	Interface configured as Update Source
                                	**type**\: str
                                
                                .. attribute:: update_source_vrf_id
                                
                                	VRF ID of interface configured as Update Source
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_vrf_name
                                
                                	VRF Name configured
                                	**type**\: str
                                
                                .. attribute:: bmp_vrf_id
                                
                                	VRF ID for the vrf name configured
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_update_mode
                                
                                	Update sending mode configured for this BMP server
                                	**type**\:  :py:class:`BgpBmpUpdMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdMode>`
                                
                                .. attribute:: tcp_keep_alive_interval
                                
                                	TCP Keep alive interval configured
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_maximum_segment_size
                                
                                	TCP Maximum Segments size configured
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_write_cb_pending
                                
                                	Are we waiting for TCP write callback ?
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_result
                                
                                	Last TCP Socket write status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_cb_time
                                
                                	Last TCP Write CB time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: tcp_last_write_time
                                
                                	Last TCP Write time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_all_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent for all BMP servers 
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_cb_time
                                
                                	Last BMPQ write pulse callback time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: path_update_count
                                
                                	Number of path update sent 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_count
                                
                                	Number of path wdraw sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_update_drop
                                
                                	Number of path update drop 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_drop
                                
                                	Number of path wdraw drop 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count_max
                                
                                	Total bmpQ msgs pending max
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count_hwts
                                
                                	Total bmpQ msgs pending max time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_bytes_written_tcp
                                
                                	Total bytes sent to TCP
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: tcp_write_time
                                
                                	Time spent processing sending msg to TCP(milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bmpr_mon_upd_messages
                                
                                	Total bmpQ update msgs 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmpr_mon_wdraw_messages
                                
                                	Total bmpQ withdraw msgs 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_messages_wdraw_discarded
                                
                                	Total bmpQ wdraw msgs discarded because of peer down
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_pfx_wdraw_discarded
                                
                                	Total bmpQ wdraw pfxes discarded because of peer down
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_route_mon_count
                                
                                	Total number of per peer route mon messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmpr_mon_update_gen_time
                                
                                	Time spent in update generation(milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bmpr_mon_eo_rmessages
                                
                                	Total bmpQ EOR update msgs 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_rmon_cur_buffer_size
                                
                                	Current Buffer usage per BMP Route Mon
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_maximum_buffer_size_route_mon
                                
                                	Buffer limit used for route mon
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_server_up_count
                                
                                	Number of BMP server that are UP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_upd_gen_in_progress
                                
                                	Update generation in progress
                                	**type**\: bool
                                
                                .. attribute:: bmp_reset_walk_in_progress
                                
                                	Reset walk in progress
                                	**type**\: bool
                                
                                .. attribute:: bmpafi_info
                                
                                	AFI specific info for BMP server
                                	**type**\: list of  		 :py:class:`BmpafiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary, self).__init__()

                                    self.yang_name = "server-summary"
                                    self.yang_parent_name = "server-summaries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['server_id']
                                    self._child_classes = OrderedDict([("bmp-server-state-age", ("bmp_server_state_age", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge)), ("bmp-server-state-time-spec", ("bmp_server_state_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec)), ("bmp-server-last-discon-time", ("bmp_server_last_discon_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime)), ("update-source-address", ("update_source_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress)), ("bmpafi-info", ("bmpafi_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo))])
                                    self._leafs = OrderedDict([
                                        ('server_id', (YLeaf(YType.uint32, 'server-id'), ['int'])),
                                        ('bmp_server_id', (YLeaf(YType.uint8, 'bmp-server-id'), ['int'])),
                                        ('bmp_server_host_name', (YLeaf(YType.str, 'bmp-server-host-name'), ['str'])),
                                        ('bmp_server_port', (YLeaf(YType.uint32, 'bmp-server-port'), ['int'])),
                                        ('bmp_server_state', (YLeaf(YType.enumeration, 'bmp-server-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBmpState', '')])),
                                        ('bmp_server_is_flapping', (YLeaf(YType.boolean, 'bmp-server-is-flapping'), ['bool'])),
                                        ('bmp_server_nbr_count', (YLeaf(YType.uint32, 'bmp-server-nbr-count'), ['int'])),
                                        ('bmp_init_msg_count', (YLeaf(YType.uint32, 'bmp-init-msg-count'), ['int'])),
                                        ('bmp_termination_msg_count', (YLeaf(YType.uint32, 'bmp-termination-msg-count'), ['int'])),
                                        ('bmp_status_report_count', (YLeaf(YType.uint32, 'bmp-status-report-count'), ['int'])),
                                        ('bmp_per_peer_msg_count', (YLeaf(YType.uint32, 'bmp-per-peer-msg-count'), ['int'])),
                                        ('bmp_peer_msg_drop_count', (YLeaf(YType.uint32, 'bmp-peer-msg-drop-count'), ['int'])),
                                        ('bmp_peer_msg_pending_count', (YLeaf(YType.uint32, 'bmp-peer-msg-pending-count'), ['int'])),
                                        ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                        ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                        ('update_source_interface_name', (YLeaf(YType.str, 'update-source-interface-name'), ['str'])),
                                        ('update_source_vrf_id', (YLeaf(YType.uint32, 'update-source-vrf-id'), ['int'])),
                                        ('bmp_vrf_name', (YLeaf(YType.str, 'bmp-vrf-name'), ['str'])),
                                        ('bmp_vrf_id', (YLeaf(YType.uint32, 'bmp-vrf-id'), ['int'])),
                                        ('bmp_update_mode', (YLeaf(YType.enumeration, 'bmp-update-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBmpUpdMode', '')])),
                                        ('tcp_keep_alive_interval', (YLeaf(YType.uint32, 'tcp-keep-alive-interval'), ['int'])),
                                        ('tcp_maximum_segment_size', (YLeaf(YType.uint32, 'tcp-maximum-segment-size'), ['int'])),
                                        ('tcp_write_cb_pending', (YLeaf(YType.uint32, 'tcp-write-cb-pending'), ['int'])),
                                        ('tcp_last_write_result', (YLeaf(YType.uint32, 'tcp-last-write-result'), ['int'])),
                                        ('tcp_last_write_cb_time', (YLeaf(YType.uint64, 'tcp-last-write-cb-time'), ['int'])),
                                        ('tcp_last_write_time', (YLeaf(YType.uint64, 'tcp-last-write-time'), ['int'])),
                                        ('bmpq_last_write_pulse_sent_time', (YLeaf(YType.uint64, 'bmpq-last-write-pulse-sent-time'), ['int'])),
                                        ('bmpq_last_all_write_pulse_sent_time', (YLeaf(YType.uint64, 'bmpq-last-all-write-pulse-sent-time'), ['int'])),
                                        ('bmpq_last_write_pulse_cb_time', (YLeaf(YType.uint64, 'bmpq-last-write-pulse-cb-time'), ['int'])),
                                        ('path_update_count', (YLeaf(YType.uint32, 'path-update-count'), ['int'])),
                                        ('path_withdraw_count', (YLeaf(YType.uint32, 'path-withdraw-count'), ['int'])),
                                        ('path_update_drop', (YLeaf(YType.uint32, 'path-update-drop'), ['int'])),
                                        ('path_withdraw_drop', (YLeaf(YType.uint32, 'path-withdraw-drop'), ['int'])),
                                        ('bmp_peer_msg_pending_count_max', (YLeaf(YType.uint32, 'bmp-peer-msg-pending-count-max'), ['int'])),
                                        ('bmp_peer_msg_pending_count_hwts', (YLeaf(YType.uint64, 'bmp-peer-msg-pending-count-hwts'), ['int'])),
                                        ('bmp_bytes_written_tcp', (YLeaf(YType.uint64, 'bmp-bytes-written-tcp'), ['int'])),
                                        ('tcp_write_time', (YLeaf(YType.uint32, 'tcp-write-time'), ['int'])),
                                        ('bmpr_mon_upd_messages', (YLeaf(YType.uint32, 'bmpr-mon-upd-messages'), ['int'])),
                                        ('bmpr_mon_wdraw_messages', (YLeaf(YType.uint32, 'bmpr-mon-wdraw-messages'), ['int'])),
                                        ('bmp_messages_wdraw_discarded', (YLeaf(YType.uint32, 'bmp-messages-wdraw-discarded'), ['int'])),
                                        ('bmp_pfx_wdraw_discarded', (YLeaf(YType.uint32, 'bmp-pfx-wdraw-discarded'), ['int'])),
                                        ('bmp_per_peer_msg_route_mon_count', (YLeaf(YType.uint32, 'bmp-per-peer-msg-route-mon-count'), ['int'])),
                                        ('bmpr_mon_update_gen_time', (YLeaf(YType.uint32, 'bmpr-mon-update-gen-time'), ['int'])),
                                        ('bmpr_mon_eo_rmessages', (YLeaf(YType.uint32, 'bmpr-mon-eo-rmessages'), ['int'])),
                                        ('bmp_rmon_cur_buffer_size', (YLeaf(YType.uint64, 'bmp-rmon-cur-buffer-size'), ['int'])),
                                        ('bmp_maximum_buffer_size_route_mon', (YLeaf(YType.uint64, 'bmp-maximum-buffer-size-route-mon'), ['int'])),
                                        ('bmp_server_up_count', (YLeaf(YType.uint32, 'bmp-server-up-count'), ['int'])),
                                        ('bmp_upd_gen_in_progress', (YLeaf(YType.boolean, 'bmp-upd-gen-in-progress'), ['bool'])),
                                        ('bmp_reset_walk_in_progress', (YLeaf(YType.boolean, 'bmp-reset-walk-in-progress'), ['bool'])),
                                    ])
                                    self.server_id = None
                                    self.bmp_server_id = None
                                    self.bmp_server_host_name = None
                                    self.bmp_server_port = None
                                    self.bmp_server_state = None
                                    self.bmp_server_is_flapping = None
                                    self.bmp_server_nbr_count = None
                                    self.bmp_init_msg_count = None
                                    self.bmp_termination_msg_count = None
                                    self.bmp_status_report_count = None
                                    self.bmp_per_peer_msg_count = None
                                    self.bmp_peer_msg_drop_count = None
                                    self.bmp_peer_msg_pending_count = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.update_source_interface_name = None
                                    self.update_source_vrf_id = None
                                    self.bmp_vrf_name = None
                                    self.bmp_vrf_id = None
                                    self.bmp_update_mode = None
                                    self.tcp_keep_alive_interval = None
                                    self.tcp_maximum_segment_size = None
                                    self.tcp_write_cb_pending = None
                                    self.tcp_last_write_result = None
                                    self.tcp_last_write_cb_time = None
                                    self.tcp_last_write_time = None
                                    self.bmpq_last_write_pulse_sent_time = None
                                    self.bmpq_last_all_write_pulse_sent_time = None
                                    self.bmpq_last_write_pulse_cb_time = None
                                    self.path_update_count = None
                                    self.path_withdraw_count = None
                                    self.path_update_drop = None
                                    self.path_withdraw_drop = None
                                    self.bmp_peer_msg_pending_count_max = None
                                    self.bmp_peer_msg_pending_count_hwts = None
                                    self.bmp_bytes_written_tcp = None
                                    self.tcp_write_time = None
                                    self.bmpr_mon_upd_messages = None
                                    self.bmpr_mon_wdraw_messages = None
                                    self.bmp_messages_wdraw_discarded = None
                                    self.bmp_pfx_wdraw_discarded = None
                                    self.bmp_per_peer_msg_route_mon_count = None
                                    self.bmpr_mon_update_gen_time = None
                                    self.bmpr_mon_eo_rmessages = None
                                    self.bmp_rmon_cur_buffer_size = None
                                    self.bmp_maximum_buffer_size_route_mon = None
                                    self.bmp_server_up_count = None
                                    self.bmp_upd_gen_in_progress = None
                                    self.bmp_reset_walk_in_progress = None

                                    self.bmp_server_state_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                    self.bmp_server_state_age.parent = self
                                    self._children_name_map["bmp_server_state_age"] = "bmp-server-state-age"

                                    self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                    self.bmp_server_state_time_spec.parent = self
                                    self._children_name_map["bmp_server_state_time_spec"] = "bmp-server-state-time-spec"

                                    self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                    self.bmp_server_last_discon_time.parent = self
                                    self._children_name_map["bmp_server_last_discon_time"] = "bmp-server-last-discon-time"

                                    self.update_source_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                    self.update_source_address.parent = self
                                    self._children_name_map["update_source_address"] = "update-source-address"

                                    self.bmpafi_info = YList(self)
                                    self._segment_path = lambda: "server-summary" + "[server-id='" + str(self.server_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary, ['server_id', u'bmp_server_id', u'bmp_server_host_name', u'bmp_server_port', u'bmp_server_state', u'bmp_server_is_flapping', u'bmp_server_nbr_count', u'bmp_init_msg_count', u'bmp_termination_msg_count', u'bmp_status_report_count', u'bmp_per_peer_msg_count', u'bmp_peer_msg_drop_count', u'bmp_peer_msg_pending_count', u'tos_type', u'tos_value', u'update_source_interface_name', u'update_source_vrf_id', u'bmp_vrf_name', u'bmp_vrf_id', u'bmp_update_mode', u'tcp_keep_alive_interval', u'tcp_maximum_segment_size', u'tcp_write_cb_pending', u'tcp_last_write_result', u'tcp_last_write_cb_time', u'tcp_last_write_time', u'bmpq_last_write_pulse_sent_time', u'bmpq_last_all_write_pulse_sent_time', u'bmpq_last_write_pulse_cb_time', u'path_update_count', u'path_withdraw_count', u'path_update_drop', u'path_withdraw_drop', u'bmp_peer_msg_pending_count_max', u'bmp_peer_msg_pending_count_hwts', u'bmp_bytes_written_tcp', u'tcp_write_time', u'bmpr_mon_upd_messages', u'bmpr_mon_wdraw_messages', u'bmp_messages_wdraw_discarded', u'bmp_pfx_wdraw_discarded', u'bmp_per_peer_msg_route_mon_count', u'bmpr_mon_update_gen_time', u'bmpr_mon_eo_rmessages', u'bmp_rmon_cur_buffer_size', u'bmp_maximum_buffer_size_route_mon', u'bmp_server_up_count', u'bmp_upd_gen_in_progress', u'bmp_reset_walk_in_progress'], name, value)


                                class BmpServerStateAge(Entity):
                                    """
                                    Age of current state of BMP Server
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, self).__init__()

                                        self.yang_name = "bmp-server-state-age"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-server-state-age"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, [u'seconds', u'nanoseconds'], name, value)


                                class BmpServerStateTimeSpec(Entity):
                                    """
                                    Timespec of current state of BMP Server
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, self).__init__()

                                        self.yang_name = "bmp-server-state-time-spec"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-server-state-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class BmpServerLastDisconTime(Entity):
                                    """
                                    Timespec of Last Disconnect event received from
                                    BMP server
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, self).__init__()

                                        self.yang_name = "bmp-server-last-discon-time"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-server-last-discon-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateSourceAddress(Entity):
                                    """
                                    Address of Interface configured as Update Source
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, self).__init__()

                                        self.yang_name = "update-source-address"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "update-source-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class BmpafiInfo(Entity):
                                    """
                                    AFI specific info for BMP server
                                    
                                    .. attribute:: bmp_resume_prefix
                                    
                                    	BMP Resume prefix
                                    	**type**\:  :py:class:`BmpResumePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix>`
                                    
                                    .. attribute:: bmp_filter_neighbor_address
                                    
                                    	Filter Neighbor Address
                                    	**type**\:  :py:class:`BmpFilterNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress>`
                                    
                                    .. attribute:: bmpaf_name
                                    
                                    	BMP Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: bmp_resume_prefix_len
                                    
                                    	BMP Resume prefix Len
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_resume_start_version
                                    
                                    	Update Gen ResumeWalk start version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_resume_end_version
                                    
                                    	Update Gen ResumeWalk end version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_walk_stopped
                                    
                                    	Update Gen WalkStopped
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_upd_gen_resume_net_version
                                    
                                    	Update Gen ResumeWalk Net version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_walk_run_time_stamp
                                    
                                    	Last Update Gen Run time stamp
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_run_count
                                    
                                    	Number of times Update Gen ran
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_stop_time_stamp
                                    
                                    	Last Update Gen Stop time stamp
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_stop_count
                                    
                                    	Number of times Update Gen Stopped
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_init_eor_end_version
                                    
                                    	Version to reach to send EOR
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_init_eor_pending_cnt
                                    
                                    	Count for pending EOR
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_filter_neighbor_address_set
                                    
                                    	Filter Neighbor Address Set ?
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_filter_nbr_cnt
                                    
                                    	Filter nbr Count for this AFI
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_send_version
                                    
                                    	Table Version that this BMP server has caught upto
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, self).__init__()

                                        self.yang_name = "bmpafi-info"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bmp-resume-prefix", ("bmp_resume_prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix)), ("bmp-filter-neighbor-address", ("bmp_filter_neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress))])
                                        self._leafs = OrderedDict([
                                            ('bmpaf_name', (YLeaf(YType.enumeration, 'bmpaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('bmp_resume_prefix_len', (YLeaf(YType.uint32, 'bmp-resume-prefix-len'), ['int'])),
                                            ('bmp_upd_gen_resume_start_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-start-version'), ['int'])),
                                            ('bmp_upd_gen_resume_end_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-end-version'), ['int'])),
                                            ('bmp_upd_gen_walk_stopped', (YLeaf(YType.boolean, 'bmp-upd-gen-walk-stopped'), ['bool'])),
                                            ('bmp_upd_gen_resume_net_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-net-version'), ['int'])),
                                            ('bmp_upd_gen_walk_run_time_stamp', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-run-time-stamp'), ['int'])),
                                            ('bmp_upd_gen_walk_run_count', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-run-count'), ['int'])),
                                            ('bmp_upd_gen_walk_stop_time_stamp', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-stop-time-stamp'), ['int'])),
                                            ('bmp_upd_gen_walk_stop_count', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-stop-count'), ['int'])),
                                            ('bmp_init_eor_end_version', (YLeaf(YType.uint32, 'bmp-init-eor-end-version'), ['int'])),
                                            ('bmp_init_eor_pending_cnt', (YLeaf(YType.uint32, 'bmp-init-eor-pending-cnt'), ['int'])),
                                            ('bmp_filter_neighbor_address_set', (YLeaf(YType.boolean, 'bmp-filter-neighbor-address-set'), ['bool'])),
                                            ('bmp_filter_nbr_cnt', (YLeaf(YType.uint32, 'bmp-filter-nbr-cnt'), ['int'])),
                                            ('bmp_send_version', (YLeaf(YType.uint32, 'bmp-send-version'), ['int'])),
                                        ])
                                        self.bmpaf_name = None
                                        self.bmp_resume_prefix_len = None
                                        self.bmp_upd_gen_resume_start_version = None
                                        self.bmp_upd_gen_resume_end_version = None
                                        self.bmp_upd_gen_walk_stopped = None
                                        self.bmp_upd_gen_resume_net_version = None
                                        self.bmp_upd_gen_walk_run_time_stamp = None
                                        self.bmp_upd_gen_walk_run_count = None
                                        self.bmp_upd_gen_walk_stop_time_stamp = None
                                        self.bmp_upd_gen_walk_stop_count = None
                                        self.bmp_init_eor_end_version = None
                                        self.bmp_init_eor_pending_cnt = None
                                        self.bmp_filter_neighbor_address_set = None
                                        self.bmp_filter_nbr_cnt = None
                                        self.bmp_send_version = None

                                        self.bmp_resume_prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix()
                                        self.bmp_resume_prefix.parent = self
                                        self._children_name_map["bmp_resume_prefix"] = "bmp-resume-prefix"

                                        self.bmp_filter_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress()
                                        self.bmp_filter_neighbor_address.parent = self
                                        self._children_name_map["bmp_filter_neighbor_address"] = "bmp-filter-neighbor-address"
                                        self._segment_path = lambda: "bmpafi-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, [u'bmpaf_name', u'bmp_resume_prefix_len', u'bmp_upd_gen_resume_start_version', u'bmp_upd_gen_resume_end_version', u'bmp_upd_gen_walk_stopped', u'bmp_upd_gen_resume_net_version', u'bmp_upd_gen_walk_run_time_stamp', u'bmp_upd_gen_walk_run_count', u'bmp_upd_gen_walk_stop_time_stamp', u'bmp_upd_gen_walk_stop_count', u'bmp_init_eor_end_version', u'bmp_init_eor_pending_cnt', u'bmp_filter_neighbor_address_set', u'bmp_filter_nbr_cnt', u'bmp_send_version'], name, value)


                                    class BmpResumePrefix(Entity):
                                        """
                                        BMP Resume prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, self).__init__()

                                            self.yang_name = "bmp-resume-prefix"
                                            self.yang_parent_name = "bmpafi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix_length = None

                                            self.prefix = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._segment_path = lambda: "bmp-resume-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, [u'prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bmp-resume-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class BmpFilterNeighborAddress(Entity):
                                        """
                                        Filter Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, self).__init__()

                                            self.yang_name = "bmp-filter-neighbor-address"
                                            self.yang_parent_name = "bmpafi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "bmp-filter-neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class ServerNeighbors(Entity):
                            """
                            Table of Neighbors for a BMP Server
                            
                            .. attribute:: server_neighbor
                            
                            	BMP Server under which neighbor info are needed
                            	**type**\: list of  		 :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors, self).__init__()

                                self.yang_name = "server-neighbors"
                                self.yang_parent_name = "bmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("server-neighbor", ("server_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor))])
                                self._leafs = OrderedDict()

                                self.server_neighbor = YList(self)
                                self._segment_path = lambda: "server-neighbors"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors, [], name, value)


                            class ServerNeighbor(Entity):
                                """
                                BMP Server under which neighbor info are
                                needed
                                
                                .. attribute:: server_id  (key)
                                
                                	BMP Server ID
                                	**type**\: int
                                
                                	**range:** 1..8
                                
                                .. attribute:: monitored_neighbors
                                
                                	List of Neighbors under which BMP Server is confgiured
                                	**type**\:  :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor, self).__init__()

                                    self.yang_name = "server-neighbor"
                                    self.yang_parent_name = "server-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['server_id']
                                    self._child_classes = OrderedDict([("monitored-neighbors", ("monitored_neighbors", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors))])
                                    self._leafs = OrderedDict([
                                        ('server_id', (YLeaf(YType.uint32, 'server-id'), ['int'])),
                                    ])
                                    self.server_id = None

                                    self.monitored_neighbors = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                    self.monitored_neighbors.parent = self
                                    self._children_name_map["monitored_neighbors"] = "monitored-neighbors"
                                    self._segment_path = lambda: "server-neighbor" + "[server-id='" + str(self.server_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor, ['server_id'], name, value)


                                class MonitoredNeighbors(Entity):
                                    """
                                    List of Neighbors under which BMP Server is
                                    confgiured
                                    
                                    .. attribute:: monitored_neighbor
                                    
                                    	Information about a neighbor monitored by BMP server
                                    	**type**\: list of  		 :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, self).__init__()

                                        self.yang_name = "monitored-neighbors"
                                        self.yang_parent_name = "server-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("monitored-neighbor", ("monitored_neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor))])
                                        self._leafs = OrderedDict()

                                        self.monitored_neighbor = YList(self)
                                        self._segment_path = lambda: "monitored-neighbors"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, [], name, value)


                                    class MonitoredNeighbor(Entity):
                                        """
                                        Information about a neighbor monitored by
                                        BMP server
                                        
                                        .. attribute:: neighbor_address  (key)
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bmp_neighbor_address
                                        
                                        	Address of Nbr that logs to BMP server
                                        	**type**\:  :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                        
                                        .. attribute:: bmp_neighbor_msg_pending
                                        
                                        	Number of messages pending to be sent to BMP Server from this Neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_msg_dropped
                                        
                                        	Number of messages dropped sent from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_up_sent
                                        
                                        	Number of Peer UP Messages sent from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_down_sent
                                        
                                        	Number of Peer DOWN Messages sent from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_route_monitor_sent
                                        
                                        	Number of Route Monitor Messages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_route_monitor_eor_sent
                                        
                                        	Number of Route Monitor EOR Messages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_sent
                                        
                                        	Number of Path UpdateMessages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_sent
                                        
                                        	Number of Path WithdrawMessages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_drop
                                        
                                        	Number of path update drop 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_drop
                                        
                                        	Number of path wdraw drop 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_upd_msg_sent
                                        
                                        	Number of update message sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_wdraw_msg_sent
                                        
                                        	Number of withdraw message sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, self).__init__()

                                            self.yang_name = "monitored-neighbor"
                                            self.yang_parent_name = "monitored-neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['neighbor_address']
                                            self._child_classes = OrderedDict([("bmp-neighbor-address", ("bmp_neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('bmp_neighbor_msg_pending', (YLeaf(YType.uint32, 'bmp-neighbor-msg-pending'), ['int'])),
                                                ('bmp_neighbor_msg_dropped', (YLeaf(YType.uint32, 'bmp-neighbor-msg-dropped'), ['int'])),
                                                ('bmp_neighbor_peer_up_sent', (YLeaf(YType.uint32, 'bmp-neighbor-peer-up-sent'), ['int'])),
                                                ('bmp_neighbor_peer_down_sent', (YLeaf(YType.uint32, 'bmp-neighbor-peer-down-sent'), ['int'])),
                                                ('bmp_neighbor_route_monitor_sent', (YLeaf(YType.uint32, 'bmp-neighbor-route-monitor-sent'), ['int'])),
                                                ('bmp_neighbor_route_monitor_eor_sent', (YLeaf(YType.uint32, 'bmp-neighbor-route-monitor-eor-sent'), ['int'])),
                                                ('bmp_neighbor_path_update_sent', (YLeaf(YType.uint32, 'bmp-neighbor-path-update-sent'), ['int'])),
                                                ('bmp_neighbor_path_withdraw_sent', (YLeaf(YType.uint32, 'bmp-neighbor-path-withdraw-sent'), ['int'])),
                                                ('bmp_neighbor_path_update_drop', (YLeaf(YType.uint32, 'bmp-neighbor-path-update-drop'), ['int'])),
                                                ('bmp_neighbor_path_withdraw_drop', (YLeaf(YType.uint32, 'bmp-neighbor-path-withdraw-drop'), ['int'])),
                                                ('bmp_neighbor_upd_msg_sent', (YLeaf(YType.uint32, 'bmp-neighbor-upd-msg-sent'), ['int'])),
                                                ('bmp_neighbor_wdraw_msg_sent', (YLeaf(YType.uint32, 'bmp-neighbor-wdraw-msg-sent'), ['int'])),
                                            ])
                                            self.neighbor_address = None
                                            self.bmp_neighbor_msg_pending = None
                                            self.bmp_neighbor_msg_dropped = None
                                            self.bmp_neighbor_peer_up_sent = None
                                            self.bmp_neighbor_peer_down_sent = None
                                            self.bmp_neighbor_route_monitor_sent = None
                                            self.bmp_neighbor_route_monitor_eor_sent = None
                                            self.bmp_neighbor_path_update_sent = None
                                            self.bmp_neighbor_path_withdraw_sent = None
                                            self.bmp_neighbor_path_update_drop = None
                                            self.bmp_neighbor_path_withdraw_drop = None
                                            self.bmp_neighbor_upd_msg_sent = None
                                            self.bmp_neighbor_wdraw_msg_sent = None

                                            self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                            self.bmp_neighbor_address.parent = self
                                            self._children_name_map["bmp_neighbor_address"] = "bmp-neighbor-address"
                                            self._segment_path = lambda: "monitored-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, ['neighbor_address', u'bmp_neighbor_msg_pending', u'bmp_neighbor_msg_dropped', u'bmp_neighbor_peer_up_sent', u'bmp_neighbor_peer_down_sent', u'bmp_neighbor_route_monitor_sent', u'bmp_neighbor_route_monitor_eor_sent', u'bmp_neighbor_path_update_sent', u'bmp_neighbor_path_withdraw_sent', u'bmp_neighbor_path_update_drop', u'bmp_neighbor_path_withdraw_drop', u'bmp_neighbor_upd_msg_sent', u'bmp_neighbor_wdraw_msg_sent'], name, value)


                                        class BmpNeighborAddress(Entity):
                                            """
                                            Address of Nbr that logs to BMP server
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, self).__init__()

                                                self.yang_name = "bmp-neighbor-address"
                                                self.yang_parent_name = "monitored-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "bmp-neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                    class ProcessInfo(Entity):
                        """
                        A Process instance table entry
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf>`
                        
                        .. attribute:: performance_statistics
                        
                        	Performance statistics
                        	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics>`
                        
                        .. attribute:: process_instance
                        
                        	ID for the BGP process instance
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\: str
                        
                        .. attribute:: vrf_totals
                        
                        	per VRF counts aggregated across all VRFs
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo, self).__init__()

                            self.yang_name = "process-info"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics))])
                            self._leafs = OrderedDict([
                                ('process_instance', (YLeaf(YType.uint8, 'process-instance'), ['int'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('vrf_totals', (YLeaf(YType.boolean, 'vrf-totals'), ['bool'])),
                            ])
                            self.process_instance = None
                            self.vrf_name = None
                            self.vrf_totals = None

                            self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"

                            self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics()
                            self.performance_statistics.parent = self
                            self._children_name_map["performance_statistics"] = "performance-statistics"
                            self._segment_path = lambda: "process-info"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo, [u'process_instance', u'vrf_name', u'vrf_totals'], name, value)


                        class Global(Entity):
                            """
                            Global information
                            
                            .. attribute:: process_instance_node
                            
                            	Node the process instance is on
                            	**type**\: str
                            
                            .. attribute:: restart_count
                            
                            	No. of times BGP has started
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_attributes_entry_count
                            
                            	No. of path attribute entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_attribute_memory
                            
                            	Memory (bytes) used by path attribute entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: as_path_entry_count
                            
                            	Number of AS\-path entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_path_entries_memory
                            
                            	Memory (in bytes) used by AS\-path entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: community_entry_count
                            
                            	Number of community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: community_memory
                            
                            	Memory (in bytes) used by community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: extended_community_entry_count
                            
                            	Number of extended community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_memory
                            
                            	Memory (in bytes) used by extended community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: pe_distinguisher_label_entry_count
                            
                            	Number of PE distinguisher label entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_distinguisher_label_memory
                            
                            	Memory (in bytes) used by PE distinguisher labels entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: pta_entry_count
                            
                            	Number of PTA entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pta_memory
                            
                            	Memory (in bytes) used by PTA entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: tunnel_encap_entry_count
                            
                            	Number of Tunnel encap entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_encap_memory
                            
                            	Memory (in bytes) used by tunnel encap entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: ribrnh_entry_count
                            
                            	Number of RIBRNH entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_memory
                            
                            	Memory (in bytes) used by RIBRNH entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: ppmp_entry_count
                            
                            	Number of PPMP entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ppmp_memory
                            
                            	Memory (in bytes) used by PPMP entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: route_reflectors
                            
                            	Number of route reflector info entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_reflector_memory
                            
                            	Memory (in bytes) used by route reflector info entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: nexthop_count
                            
                            	Number of nexthop attribute info entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nexthop_memory
                            
                            	Memory (in bytes) used by nexthop attribute info entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: lsattr_entry_count
                            
                            	Number of LASATTR entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsattr_memory
                            
                            	Memory (in bytes) used by LSATTR entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: attr_set_entry_count
                            
                            	Number of ATTRSET entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attr_set_memory
                            
                            	Memory (in bytes) used by ATTRSET entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: lindex_entry_count
                            
                            	Number of LINDEX entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lindex_memory
                            
                            	Memory (in bytes) used by LINDEX entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_vrf_count
                            
                            	total vrf count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbors_count_total
                            
                            	Total number of neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: established_neighbors_count_total
                            
                            	Total umber of established neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs
                            
                            	sn num non dflt vrf nbrs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                            
                            	sn num non dflt vrf nbrs estab
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: large_community_entry_count
                            
                            	Number of large community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: large_community_memory
                            
                            	Memory (in bytes) used by large community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: pool_size
                            
                            	pool size
                            	**type**\: list of  		 :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolSize>`
                            
                            .. attribute:: pool_alloc_count
                            
                            	pool alloc count
                            	**type**\: list of  		 :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolAllocCount>`
                            
                            .. attribute:: pool_free_count
                            
                            	pool free count
                            	**type**\: list of  		 :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolFreeCount>`
                            
                            .. attribute:: msg_log_pool_size
                            
                            	msg log pool size
                            	**type**\: list of  		 :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolSize>`
                            
                            .. attribute:: msg_log_pool_alloc_count
                            
                            	msg log pool alloc count
                            	**type**\: list of  		 :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolAllocCount>`
                            
                            .. attribute:: msg_log_pool_free_count
                            
                            	msg log pool free count
                            	**type**\: list of  		 :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolFreeCount>`
                            
                            .. attribute:: bmp_pool_size
                            
                            	bmp pool size
                            	**type**\: list of  		 :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolSize>`
                            
                            .. attribute:: bmp_pool_alloc_count
                            
                            	bmp pool alloc count
                            	**type**\: list of  		 :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolAllocCount>`
                            
                            .. attribute:: bmp_pool_free_count
                            
                            	bmp pool free count
                            	**type**\: list of  		 :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolFreeCount>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pool-size", ("pool_size", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolSize)), ("pool-alloc-count", ("pool_alloc_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolAllocCount)), ("pool-free-count", ("pool_free_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolFreeCount)), ("msg-log-pool-size", ("msg_log_pool_size", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolSize)), ("msg-log-pool-alloc-count", ("msg_log_pool_alloc_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolAllocCount)), ("msg-log-pool-free-count", ("msg_log_pool_free_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolFreeCount)), ("bmp-pool-size", ("bmp_pool_size", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolSize)), ("bmp-pool-alloc-count", ("bmp_pool_alloc_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolAllocCount)), ("bmp-pool-free-count", ("bmp_pool_free_count", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolFreeCount))])
                                self._leafs = OrderedDict([
                                    ('process_instance_node', (YLeaf(YType.str, 'process-instance-node'), ['str'])),
                                    ('restart_count', (YLeaf(YType.uint32, 'restart-count'), ['int'])),
                                    ('path_attributes_entry_count', (YLeaf(YType.uint32, 'path-attributes-entry-count'), ['int'])),
                                    ('path_attribute_memory', (YLeaf(YType.uint32, 'path-attribute-memory'), ['int'])),
                                    ('as_path_entry_count', (YLeaf(YType.uint32, 'as-path-entry-count'), ['int'])),
                                    ('as_path_entries_memory', (YLeaf(YType.uint32, 'as-path-entries-memory'), ['int'])),
                                    ('community_entry_count', (YLeaf(YType.uint32, 'community-entry-count'), ['int'])),
                                    ('community_memory', (YLeaf(YType.uint32, 'community-memory'), ['int'])),
                                    ('extended_community_entry_count', (YLeaf(YType.uint32, 'extended-community-entry-count'), ['int'])),
                                    ('extended_community_memory', (YLeaf(YType.uint32, 'extended-community-memory'), ['int'])),
                                    ('pe_distinguisher_label_entry_count', (YLeaf(YType.uint32, 'pe-distinguisher-label-entry-count'), ['int'])),
                                    ('pe_distinguisher_label_memory', (YLeaf(YType.uint32, 'pe-distinguisher-label-memory'), ['int'])),
                                    ('pta_entry_count', (YLeaf(YType.uint32, 'pta-entry-count'), ['int'])),
                                    ('pta_memory', (YLeaf(YType.uint32, 'pta-memory'), ['int'])),
                                    ('tunnel_encap_entry_count', (YLeaf(YType.uint32, 'tunnel-encap-entry-count'), ['int'])),
                                    ('tunnel_encap_memory', (YLeaf(YType.uint32, 'tunnel-encap-memory'), ['int'])),
                                    ('ribrnh_entry_count', (YLeaf(YType.uint32, 'ribrnh-entry-count'), ['int'])),
                                    ('ribrnh_memory', (YLeaf(YType.uint32, 'ribrnh-memory'), ['int'])),
                                    ('ppmp_entry_count', (YLeaf(YType.uint32, 'ppmp-entry-count'), ['int'])),
                                    ('ppmp_memory', (YLeaf(YType.uint32, 'ppmp-memory'), ['int'])),
                                    ('route_reflectors', (YLeaf(YType.uint32, 'route-reflectors'), ['int'])),
                                    ('route_reflector_memory', (YLeaf(YType.uint32, 'route-reflector-memory'), ['int'])),
                                    ('nexthop_count', (YLeaf(YType.uint32, 'nexthop-count'), ['int'])),
                                    ('nexthop_memory', (YLeaf(YType.uint32, 'nexthop-memory'), ['int'])),
                                    ('lsattr_entry_count', (YLeaf(YType.uint32, 'lsattr-entry-count'), ['int'])),
                                    ('lsattr_memory', (YLeaf(YType.uint32, 'lsattr-memory'), ['int'])),
                                    ('attr_set_entry_count', (YLeaf(YType.uint32, 'attr-set-entry-count'), ['int'])),
                                    ('attr_set_memory', (YLeaf(YType.uint32, 'attr-set-memory'), ['int'])),
                                    ('lindex_entry_count', (YLeaf(YType.uint32, 'lindex-entry-count'), ['int'])),
                                    ('lindex_memory', (YLeaf(YType.uint32, 'lindex-memory'), ['int'])),
                                    ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                    ('total_vrf_count', (YLeaf(YType.uint32, 'total-vrf-count'), ['int'])),
                                    ('neighbors_count_total', (YLeaf(YType.uint32, 'neighbors-count-total'), ['int'])),
                                    ('established_neighbors_count_total', (YLeaf(YType.uint32, 'established-neighbors-count-total'), ['int'])),
                                    ('sn_num_non_dflt_vrf_nbrs', (YLeaf(YType.uint32, 'sn-num-non-dflt-vrf-nbrs'), ['int'])),
                                    ('sn_num_non_dflt_vrf_nbrs_estab', (YLeaf(YType.uint32, 'sn-num-non-dflt-vrf-nbrs-estab'), ['int'])),
                                    ('large_community_entry_count', (YLeaf(YType.uint32, 'large-community-entry-count'), ['int'])),
                                    ('large_community_memory', (YLeaf(YType.uint32, 'large-community-memory'), ['int'])),
                                ])
                                self.process_instance_node = None
                                self.restart_count = None
                                self.path_attributes_entry_count = None
                                self.path_attribute_memory = None
                                self.as_path_entry_count = None
                                self.as_path_entries_memory = None
                                self.community_entry_count = None
                                self.community_memory = None
                                self.extended_community_entry_count = None
                                self.extended_community_memory = None
                                self.pe_distinguisher_label_entry_count = None
                                self.pe_distinguisher_label_memory = None
                                self.pta_entry_count = None
                                self.pta_memory = None
                                self.tunnel_encap_entry_count = None
                                self.tunnel_encap_memory = None
                                self.ribrnh_entry_count = None
                                self.ribrnh_memory = None
                                self.ppmp_entry_count = None
                                self.ppmp_memory = None
                                self.route_reflectors = None
                                self.route_reflector_memory = None
                                self.nexthop_count = None
                                self.nexthop_memory = None
                                self.lsattr_entry_count = None
                                self.lsattr_memory = None
                                self.attr_set_entry_count = None
                                self.attr_set_memory = None
                                self.lindex_entry_count = None
                                self.lindex_memory = None
                                self.local_as = None
                                self.total_vrf_count = None
                                self.neighbors_count_total = None
                                self.established_neighbors_count_total = None
                                self.sn_num_non_dflt_vrf_nbrs = None
                                self.sn_num_non_dflt_vrf_nbrs_estab = None
                                self.large_community_entry_count = None
                                self.large_community_memory = None

                                self.pool_size = YList(self)
                                self.pool_alloc_count = YList(self)
                                self.pool_free_count = YList(self)
                                self.msg_log_pool_size = YList(self)
                                self.msg_log_pool_alloc_count = YList(self)
                                self.msg_log_pool_free_count = YList(self)
                                self.bmp_pool_size = YList(self)
                                self.bmp_pool_alloc_count = YList(self)
                                self.bmp_pool_free_count = YList(self)
                                self._segment_path = lambda: "global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global, [u'process_instance_node', u'restart_count', u'path_attributes_entry_count', u'path_attribute_memory', u'as_path_entry_count', u'as_path_entries_memory', u'community_entry_count', u'community_memory', u'extended_community_entry_count', u'extended_community_memory', u'pe_distinguisher_label_entry_count', u'pe_distinguisher_label_memory', u'pta_entry_count', u'pta_memory', u'tunnel_encap_entry_count', u'tunnel_encap_memory', u'ribrnh_entry_count', u'ribrnh_memory', u'ppmp_entry_count', u'ppmp_memory', u'route_reflectors', u'route_reflector_memory', u'nexthop_count', u'nexthop_memory', u'lsattr_entry_count', u'lsattr_memory', u'attr_set_entry_count', u'attr_set_memory', u'lindex_entry_count', u'lindex_memory', u'local_as', u'total_vrf_count', u'neighbors_count_total', u'established_neighbors_count_total', u'sn_num_non_dflt_vrf_nbrs', u'sn_num_non_dflt_vrf_nbrs_estab', u'large_community_entry_count', u'large_community_memory'], name, value)


                            class PoolSize(Entity):
                                """
                                pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolSize, self).__init__()

                                    self.yang_name = "pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "pool-size"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolSize, [u'entry'], name, value)


                            class PoolAllocCount(Entity):
                                """
                                pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolAllocCount, self).__init__()

                                    self.yang_name = "pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "pool-alloc-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolAllocCount, [u'entry'], name, value)


                            class PoolFreeCount(Entity):
                                """
                                pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolFreeCount, self).__init__()

                                    self.yang_name = "pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "pool-free-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.PoolFreeCount, [u'entry'], name, value)


                            class MsgLogPoolSize(Entity):
                                """
                                msg log pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolSize, self).__init__()

                                    self.yang_name = "msg-log-pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "msg-log-pool-size"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolSize, [u'entry'], name, value)


                            class MsgLogPoolAllocCount(Entity):
                                """
                                msg log pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolAllocCount, self).__init__()

                                    self.yang_name = "msg-log-pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "msg-log-pool-alloc-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolAllocCount, [u'entry'], name, value)


                            class MsgLogPoolFreeCount(Entity):
                                """
                                msg log pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolFreeCount, self).__init__()

                                    self.yang_name = "msg-log-pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "msg-log-pool-free-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.MsgLogPoolFreeCount, [u'entry'], name, value)


                            class BmpPoolSize(Entity):
                                """
                                bmp pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolSize, self).__init__()

                                    self.yang_name = "bmp-pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "bmp-pool-size"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolSize, [u'entry'], name, value)


                            class BmpPoolAllocCount(Entity):
                                """
                                bmp pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolAllocCount, self).__init__()

                                    self.yang_name = "bmp-pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "bmp-pool-alloc-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolAllocCount, [u'entry'], name, value)


                            class BmpPoolFreeCount(Entity):
                                """
                                bmp pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolFreeCount, self).__init__()

                                    self.yang_name = "bmp-pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "bmp-pool-free-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Global.BmpPoolFreeCount, [u'entry'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: neighbors_count
                            
                            	Number of neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: established_neighbors_count
                            
                            	Number of established neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_received
                            
                            	Number of update messages received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_sent
                            
                            	No. of update messages sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_received
                            
                            	No. of notifications received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_sent
                            
                            	No. of notifications sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: network_count
                            
                            	Number of networks
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_count
                            
                            	Number of paths
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('neighbors_count', (YLeaf(YType.uint32, 'neighbors-count'), ['int'])),
                                    ('established_neighbors_count', (YLeaf(YType.uint32, 'established-neighbors-count'), ['int'])),
                                    ('update_messages_received', (YLeaf(YType.uint32, 'update-messages-received'), ['int'])),
                                    ('update_messages_sent', (YLeaf(YType.uint32, 'update-messages-sent'), ['int'])),
                                    ('notifications_received', (YLeaf(YType.uint32, 'notifications-received'), ['int'])),
                                    ('notifications_sent', (YLeaf(YType.uint32, 'notifications-sent'), ['int'])),
                                    ('network_count', (YLeaf(YType.uint32, 'network-count'), ['int'])),
                                    ('path_count', (YLeaf(YType.uint32, 'path-count'), ['int'])),
                                ])
                                self.neighbors_count = None
                                self.established_neighbors_count = None
                                self.update_messages_received = None
                                self.update_messages_sent = None
                                self.notifications_received = None
                                self.notifications_sent = None
                                self.network_count = None
                                self.path_count = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.Vrf, [u'neighbors_count', u'established_neighbors_count', u'update_messages_received', u'update_messages_sent', u'notifications_received', u'notifications_sent', u'network_count', u'path_count'], name, value)


                        class PerformanceStatistics(Entity):
                            """
                            Performance statistics
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics, self).__init__()

                                self.yang_name = "performance-statistics"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf))])
                                self._leafs = OrderedDict()

                                self.global_ = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"

                                self.vrf = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._segment_path = lambda: "performance-statistics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics, [], name, value)


                            class Global(Entity):
                                """
                                Global information
                                
                                .. attribute:: ipv4rib_server
                                
                                	IPv4 RIB server global info
                                	**type**\:  :py:class:`Ipv4ribServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer>`
                                
                                .. attribute:: ipv6rib_server
                                
                                	IPv6 RIB server global info
                                	**type**\:  :py:class:`Ipv6ribServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer>`
                                
                                .. attribute:: te_connection
                                
                                	MPLS TE server connection info
                                	**type**\:  :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection>`
                                
                                .. attribute:: lsd_connection
                                
                                	MPLS LSD server connection info
                                	**type**\:  :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection>`
                                
                                .. attribute:: ds_npl
                                
                                	NSR related DS and NPL information
                                	**type**\:  :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl>`
                                
                                .. attribute:: configuration_items_processed
                                
                                	Number of config items processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configuration_processing_time
                                
                                	Time spent processing config (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: edm_requests_count
                                
                                	Number of EDM requests processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: edm_processing_time
                                
                                	Time spent processing EDM requests (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_messages_sent
                                
                                	bRIB API output messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_bytes_sent
                                
                                	bRIB API output bytes sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_bytes_generated
                                
                                	bRIB API output bytes generated
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_prefixes_advertised
                                
                                	bRIB API output prefixes advertised
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_prefixes_withdrawn
                                
                                	bRIB API output prefixes withdrawn
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_sending_time
                                
                                	Time spent sending output to bRIB API (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_generation_time
                                
                                	Time spent generating output for bRIB API (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: brib_api_output_calls
                                
                                	bRIB API calls to generate output
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_messages
                                
                                	bRIB API input messages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_bytes
                                
                                	bRIB API input bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_input_prefixes_received
                                
                                	bRIB API input advertised prefixes received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_withdrawn_prefixes
                                
                                	bRIB API input withdrawn prefixes received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_processing_time
                                
                                	Time spent processing input from bRIB API (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: instance_node_role
                                
                                	Node role \- active/passive
                                	**type**\: bool
                                
                                .. attribute:: active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: proc_scoped_sync_state
                                
                                	BGP scoped sync state
                                	**type**\:  :py:class:`BgpScopedSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncState>`
                                
                                .. attribute:: initial_sync_sessions_added
                                
                                	If true, BGP has at least one established session when NSR initial synchronization is started
                                	**type**\: bool
                                
                                .. attribute:: in_event_attach_calls
                                
                                	event\_file\_attach  calls for input
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_event_attach_calls
                                
                                	event\_file\_attach  calls for output
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_out_event_attach_calls
                                
                                	event\_file\_attach calls for input
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_timer_id
                                
                                	Updgen master timer ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: current_clock_time
                                
                                	Current time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_handler_tm
                                
                                	Timestamp when updgen timer handler got called
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_timer_id
                                
                                	IO master timer ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: io_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_handler_tm
                                
                                	Timestamp when IO timer handler got called
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: qad_messages_sent
                                
                                	Messages sent on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadack_sent
                                
                                	Acks sent on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_failure
                                
                                	Send failure on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_ac_ks_failure
                                
                                	Ack failure on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_suspends
                                
                                	QAD send suspend
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_resumes
                                
                                	QAD send resume 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_drops
                                
                                	Send packets dropped due to null peer 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_messages_received
                                
                                	Messages received on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_processed
                                
                                	Messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_ac_ks_received
                                
                                	Acks received on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_received
                                
                                	Timeouts received on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_init_drops
                                
                                	Packets dropped on standby during initialization
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadoos_drops
                                
                                	Packets dropped due to  out of sequence packetreceived
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_recv_drops
                                
                                	Received packet dropped due to null peer 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_recvd
                                
                                	Number of packet send timeouts 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_last_reset_reason
                                
                                	Reason for last nsr state  machine reset
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: redcon_nsr_ready
                                
                                	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                	**type**\: bool
                                
                                .. attribute:: redcon_state_time
                                
                                	Time when nsr state wasconveyed to Redcon last
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: active_nsr_state
                                
                                	Current Active BGP nsrstate
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sec_active_nsr_state
                                
                                	Current Sec Active BGP nsrstate
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_outstanding_postits
                                
                                	Total outstanding postits across all neighbors
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_neighbors_with_pending_postits
                                
                                	Total nbrs with pending postits
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tep2p_auto_tunnel_enabled
                                
                                	TE support for P2P auto tunnel
                                	**type**\: bool
                                
                                .. attribute:: active_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of  		 :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime>`
                                
                                .. attribute:: standby_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of  		 :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime>`
                                
                                .. attribute:: active_nsrfo_time
                                
                                	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                	**type**\: list of  		 :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime>`
                                
                                .. attribute:: postit_count_info
                                
                                	List of neighbors and their postit counts
                                	**type**\: list of  		 :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo>`
                                
                                .. attribute:: issu_milestone
                                
                                	ISSU Milestones
                                	**type**\: list of  		 :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "performance-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4rib-server", ("ipv4rib_server", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer)), ("ipv6rib-server", ("ipv6rib_server", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer)), ("te-connection", ("te_connection", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection)), ("lsd-connection", ("lsd_connection", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection)), ("ds-npl", ("ds_npl", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl)), ("active-nsr-mode-enter-time", ("active_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime)), ("standby-nsr-mode-enter-time", ("standby_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime)), ("active-nsrfo-time", ("active_nsrfo_time", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime)), ("postit-count-info", ("postit_count_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo)), ("issu-milestone", ("issu_milestone", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone))])
                                    self._leafs = OrderedDict([
                                        ('configuration_items_processed', (YLeaf(YType.uint32, 'configuration-items-processed'), ['int'])),
                                        ('configuration_processing_time', (YLeaf(YType.uint32, 'configuration-processing-time'), ['int'])),
                                        ('edm_requests_count', (YLeaf(YType.uint32, 'edm-requests-count'), ['int'])),
                                        ('edm_processing_time', (YLeaf(YType.uint32, 'edm-processing-time'), ['int'])),
                                        ('brib_api_output_messages_sent', (YLeaf(YType.uint32, 'brib-api-output-messages-sent'), ['int'])),
                                        ('brib_api_output_bytes_sent', (YLeaf(YType.uint32, 'brib-api-output-bytes-sent'), ['int'])),
                                        ('brib_api_output_bytes_generated', (YLeaf(YType.uint32, 'brib-api-output-bytes-generated'), ['int'])),
                                        ('brib_api_output_prefixes_advertised', (YLeaf(YType.uint32, 'brib-api-output-prefixes-advertised'), ['int'])),
                                        ('brib_api_output_prefixes_withdrawn', (YLeaf(YType.uint32, 'brib-api-output-prefixes-withdrawn'), ['int'])),
                                        ('brib_api_output_sending_time', (YLeaf(YType.uint32, 'brib-api-output-sending-time'), ['int'])),
                                        ('brib_api_output_generation_time', (YLeaf(YType.uint32, 'brib-api-output-generation-time'), ['int'])),
                                        ('brib_api_output_calls', (YLeaf(YType.uint32, 'brib-api-output-calls'), ['int'])),
                                        ('brib_api_input_messages', (YLeaf(YType.uint32, 'brib-api-input-messages'), ['int'])),
                                        ('brib_api_input_bytes', (YLeaf(YType.uint32, 'brib-api-input-bytes'), ['int'])),
                                        ('brib_api_input_prefixes_received', (YLeaf(YType.uint32, 'brib-api-input-prefixes-received'), ['int'])),
                                        ('brib_api_input_withdrawn_prefixes', (YLeaf(YType.uint32, 'brib-api-input-withdrawn-prefixes'), ['int'])),
                                        ('brib_api_input_processing_time', (YLeaf(YType.uint32, 'brib-api-input-processing-time'), ['int'])),
                                        ('instance_node_role', (YLeaf(YType.boolean, 'instance-node-role'), ['bool'])),
                                        ('active_nsrtcp_phase_two_enter_time', (YLeaf(YType.uint32, 'active-nsrtcp-phase-two-enter-time'), ['int'])),
                                        ('sec_active_nsrtcp_phase_two_enter_time', (YLeaf(YType.uint32, 'sec-active-nsrtcp-phase-two-enter-time'), ['int'])),
                                        ('proc_scoped_sync_state', (YLeaf(YType.enumeration, 'proc-scoped-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpScopedSyncState', '')])),
                                        ('initial_sync_sessions_added', (YLeaf(YType.boolean, 'initial-sync-sessions-added'), ['bool'])),
                                        ('in_event_attach_calls', (YLeaf(YType.uint32, 'in-event-attach-calls'), ['int'])),
                                        ('out_event_attach_calls', (YLeaf(YType.uint32, 'out-event-attach-calls'), ['int'])),
                                        ('in_out_event_attach_calls', (YLeaf(YType.uint32, 'in-out-event-attach-calls'), ['int'])),
                                        ('updgen_timer_id', (YLeaf(YType.uint32, 'updgen-timer-id'), ['int'])),
                                        ('updgen_tree_timer_left', (YLeaf(YType.uint64, 'updgen-tree-timer-left'), ['int'])),
                                        ('updgen_tree_timer_expiry', (YLeaf(YType.uint64, 'updgen-tree-timer-expiry'), ['int'])),
                                        ('current_clock_time', (YLeaf(YType.uint64, 'current-clock-time'), ['int'])),
                                        ('updgen_handler_tm', (YLeaf(YType.uint64, 'updgen-handler-tm'), ['int'])),
                                        ('io_timer_id', (YLeaf(YType.uint32, 'io-timer-id'), ['int'])),
                                        ('io_tree_timer_left', (YLeaf(YType.uint64, 'io-tree-timer-left'), ['int'])),
                                        ('io_tree_timer_expiry', (YLeaf(YType.uint64, 'io-tree-timer-expiry'), ['int'])),
                                        ('io_handler_tm', (YLeaf(YType.uint64, 'io-handler-tm'), ['int'])),
                                        ('qad_messages_sent', (YLeaf(YType.uint32, 'qad-messages-sent'), ['int'])),
                                        ('qadack_sent', (YLeaf(YType.uint32, 'qadack-sent'), ['int'])),
                                        ('qad_send_failure', (YLeaf(YType.uint32, 'qad-send-failure'), ['int'])),
                                        ('qad_ac_ks_failure', (YLeaf(YType.uint32, 'qad-ac-ks-failure'), ['int'])),
                                        ('qad_suspends', (YLeaf(YType.uint32, 'qad-suspends'), ['int'])),
                                        ('qad_resumes', (YLeaf(YType.uint32, 'qad-resumes'), ['int'])),
                                        ('qad_send_drops', (YLeaf(YType.uint32, 'qad-send-drops'), ['int'])),
                                        ('qad_messages_received', (YLeaf(YType.uint32, 'qad-messages-received'), ['int'])),
                                        ('qad_processed', (YLeaf(YType.uint32, 'qad-processed'), ['int'])),
                                        ('qad_ac_ks_received', (YLeaf(YType.uint32, 'qad-ac-ks-received'), ['int'])),
                                        ('qad_timeout_received', (YLeaf(YType.uint32, 'qad-timeout-received'), ['int'])),
                                        ('qad_init_drops', (YLeaf(YType.uint32, 'qad-init-drops'), ['int'])),
                                        ('qadoos_drops', (YLeaf(YType.uint32, 'qadoos-drops'), ['int'])),
                                        ('qad_recv_drops', (YLeaf(YType.uint32, 'qad-recv-drops'), ['int'])),
                                        ('qad_timeout_recvd', (YLeaf(YType.uint32, 'qad-timeout-recvd'), ['int'])),
                                        ('nsr_last_reset_reason', (YLeaf(YType.uint8, 'nsr-last-reset-reason'), ['int'])),
                                        ('redcon_nsr_ready', (YLeaf(YType.boolean, 'redcon-nsr-ready'), ['bool'])),
                                        ('redcon_state_time', (YLeaf(YType.uint32, 'redcon-state-time'), ['int'])),
                                        ('active_nsr_state', (YLeaf(YType.uint32, 'active-nsr-state'), ['int'])),
                                        ('sec_active_nsr_state', (YLeaf(YType.uint32, 'sec-active-nsr-state'), ['int'])),
                                        ('total_outstanding_postits', (YLeaf(YType.uint32, 'total-outstanding-postits'), ['int'])),
                                        ('total_neighbors_with_pending_postits', (YLeaf(YType.uint32, 'total-neighbors-with-pending-postits'), ['int'])),
                                        ('tep2p_auto_tunnel_enabled', (YLeaf(YType.boolean, 'tep2p-auto-tunnel-enabled'), ['bool'])),
                                    ])
                                    self.configuration_items_processed = None
                                    self.configuration_processing_time = None
                                    self.edm_requests_count = None
                                    self.edm_processing_time = None
                                    self.brib_api_output_messages_sent = None
                                    self.brib_api_output_bytes_sent = None
                                    self.brib_api_output_bytes_generated = None
                                    self.brib_api_output_prefixes_advertised = None
                                    self.brib_api_output_prefixes_withdrawn = None
                                    self.brib_api_output_sending_time = None
                                    self.brib_api_output_generation_time = None
                                    self.brib_api_output_calls = None
                                    self.brib_api_input_messages = None
                                    self.brib_api_input_bytes = None
                                    self.brib_api_input_prefixes_received = None
                                    self.brib_api_input_withdrawn_prefixes = None
                                    self.brib_api_input_processing_time = None
                                    self.instance_node_role = None
                                    self.active_nsrtcp_phase_two_enter_time = None
                                    self.sec_active_nsrtcp_phase_two_enter_time = None
                                    self.proc_scoped_sync_state = None
                                    self.initial_sync_sessions_added = None
                                    self.in_event_attach_calls = None
                                    self.out_event_attach_calls = None
                                    self.in_out_event_attach_calls = None
                                    self.updgen_timer_id = None
                                    self.updgen_tree_timer_left = None
                                    self.updgen_tree_timer_expiry = None
                                    self.current_clock_time = None
                                    self.updgen_handler_tm = None
                                    self.io_timer_id = None
                                    self.io_tree_timer_left = None
                                    self.io_tree_timer_expiry = None
                                    self.io_handler_tm = None
                                    self.qad_messages_sent = None
                                    self.qadack_sent = None
                                    self.qad_send_failure = None
                                    self.qad_ac_ks_failure = None
                                    self.qad_suspends = None
                                    self.qad_resumes = None
                                    self.qad_send_drops = None
                                    self.qad_messages_received = None
                                    self.qad_processed = None
                                    self.qad_ac_ks_received = None
                                    self.qad_timeout_received = None
                                    self.qad_init_drops = None
                                    self.qadoos_drops = None
                                    self.qad_recv_drops = None
                                    self.qad_timeout_recvd = None
                                    self.nsr_last_reset_reason = None
                                    self.redcon_nsr_ready = None
                                    self.redcon_state_time = None
                                    self.active_nsr_state = None
                                    self.sec_active_nsr_state = None
                                    self.total_outstanding_postits = None
                                    self.total_neighbors_with_pending_postits = None
                                    self.tep2p_auto_tunnel_enabled = None

                                    self.ipv4rib_server = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer()
                                    self.ipv4rib_server.parent = self
                                    self._children_name_map["ipv4rib_server"] = "ipv4rib-server"

                                    self.ipv6rib_server = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer()
                                    self.ipv6rib_server.parent = self
                                    self._children_name_map["ipv6rib_server"] = "ipv6rib-server"

                                    self.te_connection = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection()
                                    self.te_connection.parent = self
                                    self._children_name_map["te_connection"] = "te-connection"

                                    self.lsd_connection = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection()
                                    self.lsd_connection.parent = self
                                    self._children_name_map["lsd_connection"] = "lsd-connection"

                                    self.ds_npl = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl()
                                    self.ds_npl.parent = self
                                    self._children_name_map["ds_npl"] = "ds-npl"

                                    self.active_nsr_mode_enter_time = YList(self)
                                    self.standby_nsr_mode_enter_time = YList(self)
                                    self.active_nsrfo_time = YList(self)
                                    self.postit_count_info = YList(self)
                                    self.issu_milestone = YList(self)
                                    self._segment_path = lambda: "global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global, [u'configuration_items_processed', u'configuration_processing_time', u'edm_requests_count', u'edm_processing_time', u'brib_api_output_messages_sent', u'brib_api_output_bytes_sent', u'brib_api_output_bytes_generated', u'brib_api_output_prefixes_advertised', u'brib_api_output_prefixes_withdrawn', u'brib_api_output_sending_time', u'brib_api_output_generation_time', u'brib_api_output_calls', u'brib_api_input_messages', u'brib_api_input_bytes', u'brib_api_input_prefixes_received', u'brib_api_input_withdrawn_prefixes', u'brib_api_input_processing_time', u'instance_node_role', u'active_nsrtcp_phase_two_enter_time', u'sec_active_nsrtcp_phase_two_enter_time', u'proc_scoped_sync_state', u'initial_sync_sessions_added', u'in_event_attach_calls', u'out_event_attach_calls', u'in_out_event_attach_calls', u'updgen_timer_id', u'updgen_tree_timer_left', u'updgen_tree_timer_expiry', u'current_clock_time', u'updgen_handler_tm', u'io_timer_id', u'io_tree_timer_left', u'io_tree_timer_expiry', u'io_handler_tm', u'qad_messages_sent', u'qadack_sent', u'qad_send_failure', u'qad_ac_ks_failure', u'qad_suspends', u'qad_resumes', u'qad_send_drops', u'qad_messages_received', u'qad_processed', u'qad_ac_ks_received', u'qad_timeout_received', u'qad_init_drops', u'qadoos_drops', u'qad_recv_drops', u'qad_timeout_recvd', u'nsr_last_reset_reason', u'redcon_nsr_ready', u'redcon_state_time', u'active_nsr_state', u'sec_active_nsr_state', u'total_outstanding_postits', u'total_neighbors_with_pending_postits', u'tep2p_auto_tunnel_enabled'], name, value)


                                class Ipv4ribServer(Entity):
                                    """
                                    IPv4 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:  :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:  :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:  :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:  :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer, self).__init__()

                                        self.yang_name = "ipv4rib-server"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("first-rib-connection-up-timestamp", ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp)), ("last-rib-connection-up-timestamp", ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp)), ("first-rib-connection-down-timestamp", ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp)), ("last-rib-connection-down-timestamp", ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('is_rib_connection_up', (YLeaf(YType.boolean, 'is-rib-connection-up'), ['bool'])),
                                            ('rib_connection_up_count', (YLeaf(YType.uint32, 'rib-connection-up-count'), ['int'])),
                                            ('last_rib_connection_up_age', (YLeaf(YType.uint32, 'last-rib-connection-up-age'), ['int'])),
                                            ('rib_connection_down_count', (YLeaf(YType.uint32, 'rib-connection-down-count'), ['int'])),
                                            ('last_rib_connection_down_age', (YLeaf(YType.uint32, 'last-rib-connection-down-age'), ['int'])),
                                        ])
                                        self.is_rib_connection_up = None
                                        self.rib_connection_up_count = None
                                        self.last_rib_connection_up_age = None
                                        self.rib_connection_down_count = None
                                        self.last_rib_connection_down_age = None

                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"

                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"

                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"

                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                        self._segment_path = lambda: "ipv4rib-server"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer, [u'is_rib_connection_up', u'rib_connection_up_count', u'last_rib_connection_up_age', u'rib_connection_down_count', u'last_rib_connection_down_age'], name, value)


                                    class FirstRibConnectionUpTimestamp(Entity):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-rib-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRibConnectionUpTimestamp(Entity):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-rib-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstRibConnectionDownTimestamp(Entity):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-rib-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRibConnectionDownTimestamp(Entity):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-rib-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class Ipv6ribServer(Entity):
                                    """
                                    IPv6 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:  :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:  :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:  :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:  :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer, self).__init__()

                                        self.yang_name = "ipv6rib-server"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("first-rib-connection-up-timestamp", ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp)), ("last-rib-connection-up-timestamp", ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp)), ("first-rib-connection-down-timestamp", ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp)), ("last-rib-connection-down-timestamp", ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('is_rib_connection_up', (YLeaf(YType.boolean, 'is-rib-connection-up'), ['bool'])),
                                            ('rib_connection_up_count', (YLeaf(YType.uint32, 'rib-connection-up-count'), ['int'])),
                                            ('last_rib_connection_up_age', (YLeaf(YType.uint32, 'last-rib-connection-up-age'), ['int'])),
                                            ('rib_connection_down_count', (YLeaf(YType.uint32, 'rib-connection-down-count'), ['int'])),
                                            ('last_rib_connection_down_age', (YLeaf(YType.uint32, 'last-rib-connection-down-age'), ['int'])),
                                        ])
                                        self.is_rib_connection_up = None
                                        self.rib_connection_up_count = None
                                        self.last_rib_connection_up_age = None
                                        self.rib_connection_down_count = None
                                        self.last_rib_connection_down_age = None

                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"

                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"

                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"

                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                        self._segment_path = lambda: "ipv6rib-server"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer, [u'is_rib_connection_up', u'rib_connection_up_count', u'last_rib_connection_up_age', u'rib_connection_down_count', u'last_rib_connection_down_age'], name, value)


                                    class FirstRibConnectionUpTimestamp(Entity):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-rib-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRibConnectionUpTimestamp(Entity):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-rib-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstRibConnectionDownTimestamp(Entity):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-rib-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRibConnectionDownTimestamp(Entity):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-rib-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class TeConnection(Entity):
                                    """
                                    MPLS TE server connection info
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:  :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:  :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp>`
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:  :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:  :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\: bool
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection, self).__init__()

                                        self.yang_name = "te-connection"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("first-connection-up-timestamp", ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp)), ("last-connection-up-timestamp", ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp)), ("first-connection-down-timestamp", ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp)), ("last-connection-down-timestamp", ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('is_connection_up', (YLeaf(YType.boolean, 'is-connection-up'), ['bool'])),
                                            ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                            ('last_connection_up_age', (YLeaf(YType.uint32, 'last-connection-up-age'), ['int'])),
                                            ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                            ('last_connection_down_age', (YLeaf(YType.uint32, 'last-connection-down-age'), ['int'])),
                                        ])
                                        self.is_connection_up = None
                                        self.connection_up_count = None
                                        self.last_connection_up_age = None
                                        self.connection_down_count = None
                                        self.last_connection_down_age = None

                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"

                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self
                                        self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"

                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"

                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                        self._segment_path = lambda: "te-connection"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection, [u'is_connection_up', u'connection_up_count', u'last_connection_up_age', u'connection_down_count', u'last_connection_down_age'], name, value)


                                    class FirstConnectionUpTimestamp(Entity):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-connection-up-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastConnectionUpTimestamp(Entity):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-connection-up-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstConnectionDownTimestamp(Entity):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-connection-down-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastConnectionDownTimestamp(Entity):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-connection-down-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LsdConnection(Entity):
                                    """
                                    MPLS LSD server connection info
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:  :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:  :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp>`
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:  :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:  :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\: bool
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection, self).__init__()

                                        self.yang_name = "lsd-connection"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("first-connection-up-timestamp", ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp)), ("last-connection-up-timestamp", ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp)), ("first-connection-down-timestamp", ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp)), ("last-connection-down-timestamp", ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('is_connection_up', (YLeaf(YType.boolean, 'is-connection-up'), ['bool'])),
                                            ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                            ('last_connection_up_age', (YLeaf(YType.uint32, 'last-connection-up-age'), ['int'])),
                                            ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                            ('last_connection_down_age', (YLeaf(YType.uint32, 'last-connection-down-age'), ['int'])),
                                        ])
                                        self.is_connection_up = None
                                        self.connection_up_count = None
                                        self.last_connection_up_age = None
                                        self.connection_down_count = None
                                        self.last_connection_down_age = None

                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"

                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self
                                        self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"

                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"

                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                        self._segment_path = lambda: "lsd-connection"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection, [u'is_connection_up', u'connection_up_count', u'last_connection_up_age', u'connection_down_count', u'last_connection_down_age'], name, value)


                                    class FirstConnectionUpTimestamp(Entity):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-connection-up-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastConnectionUpTimestamp(Entity):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-connection-up-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstConnectionDownTimestamp(Entity):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-connection-down-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastConnectionDownTimestamp(Entity):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-connection-down-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class DsNpl(Entity):
                                    """
                                    NSR related DS and NPL information
                                    
                                    .. attribute:: dir_service_conn_state
                                    
                                    	Current Directory Service connectionstate
                                    	**type**\:  :py:class:`BgpDsConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnState>`
                                    
                                    .. attribute:: issu_mgr_conn_state
                                    
                                    	Current ISSU Mgr connection state
                                    	**type**\:  :py:class:`BgpIsmConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnState>`
                                    
                                    .. attribute:: issu_phase
                                    
                                    	Current ISSU Phase
                                    	**type**\: str
                                    
                                    .. attribute:: issu_type_ng
                                    
                                    	ISSU type is Next Gen
                                    	**type**\: bool
                                    
                                    .. attribute:: issuha_option
                                    
                                    	Current ISSU HA option
                                    	**type**\: str
                                    
                                    .. attribute:: local_ds_handle
                                    
                                    	Local Directory Service handle
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: service_name
                                    
                                    	Local DS service name
                                    	**type**\: str
                                    
                                    .. attribute:: dsissu_status_flag
                                    
                                    	DS ISSU status flag
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: npl_priority_statistic
                                    
                                    	NPL priority statistics
                                    	**type**\: list of  		 :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic>`
                                    
                                    .. attribute:: npl_endpoint
                                    
                                    	NPL endpoint information
                                    	**type**\: list of  		 :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl, self).__init__()

                                        self.yang_name = "ds-npl"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("npl-priority-statistic", ("npl_priority_statistic", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic)), ("npl-endpoint", ("npl_endpoint", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint))])
                                        self._leafs = OrderedDict([
                                            ('dir_service_conn_state', (YLeaf(YType.enumeration, 'dir-service-conn-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpDsConnState', '')])),
                                            ('issu_mgr_conn_state', (YLeaf(YType.enumeration, 'issu-mgr-conn-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpIsmConnState', '')])),
                                            ('issu_phase', (YLeaf(YType.str, 'issu-phase'), ['str'])),
                                            ('issu_type_ng', (YLeaf(YType.boolean, 'issu-type-ng'), ['bool'])),
                                            ('issuha_option', (YLeaf(YType.str, 'issuha-option'), ['str'])),
                                            ('local_ds_handle', (YLeaf(YType.uint64, 'local-ds-handle'), ['int'])),
                                            ('service_name', (YLeaf(YType.str, 'service-name'), ['str'])),
                                            ('dsissu_status_flag', (YLeaf(YType.uint32, 'dsissu-status-flag'), ['int'])),
                                        ])
                                        self.dir_service_conn_state = None
                                        self.issu_mgr_conn_state = None
                                        self.issu_phase = None
                                        self.issu_type_ng = None
                                        self.issuha_option = None
                                        self.local_ds_handle = None
                                        self.service_name = None
                                        self.dsissu_status_flag = None

                                        self.npl_priority_statistic = YList(self)
                                        self.npl_endpoint = YList(self)
                                        self._segment_path = lambda: "ds-npl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl, [u'dir_service_conn_state', u'issu_mgr_conn_state', u'issu_phase', u'issu_type_ng', u'issuha_option', u'local_ds_handle', u'service_name', u'dsissu_status_flag'], name, value)


                                    class NplPriorityStatistic(Entity):
                                        """
                                        NPL priority statistics
                                        
                                        .. attribute:: num_sent
                                        
                                        	Total sent
                                        	**type**\: list of  		 :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent>`
                                        
                                        .. attribute:: num_recv
                                        
                                        	Total recvd
                                        	**type**\: list of  		 :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv>`
                                        
                                        .. attribute:: num_sent_drop
                                        
                                        	Sent Error/drops
                                        	**type**\: list of  		 :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                        
                                        .. attribute:: num_recv_drop
                                        
                                        	Recv Errors/drops
                                        	**type**\: list of  		 :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic, self).__init__()

                                            self.yang_name = "npl-priority-statistic"
                                            self.yang_parent_name = "ds-npl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("num-sent", ("num_sent", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent)), ("num-recv", ("num_recv", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv)), ("num-sent-drop", ("num_sent_drop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop)), ("num-recv-drop", ("num_recv_drop", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop))])
                                            self._leafs = OrderedDict()

                                            self.num_sent = YList(self)
                                            self.num_recv = YList(self)
                                            self.num_sent_drop = YList(self)
                                            self.num_recv_drop = YList(self)
                                            self._segment_path = lambda: "npl-priority-statistic"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic, [], name, value)


                                        class NumSent(Entity):
                                            """
                                            Total sent
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent, self).__init__()

                                                self.yang_name = "num-sent"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint64, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "num-sent"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent, [u'entry'], name, value)


                                        class NumRecv(Entity):
                                            """
                                            Total recvd
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv, self).__init__()

                                                self.yang_name = "num-recv"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint64, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "num-recv"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv, [u'entry'], name, value)


                                        class NumSentDrop(Entity):
                                            """
                                            Sent Error/drops
                                            
                                            .. attribute:: nsr_pl_send_drop_array
                                            
                                            	nsr pl send drop array
                                            	**type**\: list of  		 :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop, self).__init__()

                                                self.yang_name = "num-sent-drop"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nsr-pl-send-drop-array", ("nsr_pl_send_drop_array", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray))])
                                                self._leafs = OrderedDict()

                                                self.nsr_pl_send_drop_array = YList(self)
                                                self._segment_path = lambda: "num-sent-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop, [], name, value)


                                            class NsrPlSendDropArray(Entity):
                                                """
                                                nsr pl send drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                                    self.yang_name = "nsr-pl-send-drop-array"
                                                    self.yang_parent_name = "num-sent-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "nsr-pl-send-drop-array"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, [u'entry'], name, value)


                                        class NumRecvDrop(Entity):
                                            """
                                            Recv Errors/drops
                                            
                                            .. attribute:: nsr_pl_recv_drop_array
                                            
                                            	nsr pl recv drop array
                                            	**type**\: list of  		 :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop, self).__init__()

                                                self.yang_name = "num-recv-drop"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nsr-pl-recv-drop-array", ("nsr_pl_recv_drop_array", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray))])
                                                self._leafs = OrderedDict()

                                                self.nsr_pl_recv_drop_array = YList(self)
                                                self._segment_path = lambda: "num-recv-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop, [], name, value)


                                            class NsrPlRecvDropArray(Entity):
                                                """
                                                nsr pl recv drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                                    self.yang_name = "nsr-pl-recv-drop-array"
                                                    self.yang_parent_name = "num-recv-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "nsr-pl-recv-drop-array"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, [u'entry'], name, value)


                                    class NplEndpoint(Entity):
                                        """
                                        NPL endpoint information
                                        
                                        .. attribute:: endpoint_name
                                        
                                        	Endpoint name
                                        	**type**\: str
                                        
                                        .. attribute:: sync_group_name
                                        
                                        	Syncgroup associated with this endpoint
                                        	**type**\: str
                                        
                                        .. attribute:: node_id
                                        
                                        	Node ID
                                        	**type**\: str
                                        
                                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                        
                                        .. attribute:: endpoint_handle
                                        
                                        	NCD endpoint handle
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: endpoint_stale_flag
                                        
                                        	Endpoint stale flag
                                        	**type**\: bool
                                        
                                        .. attribute:: endpoint_issu_role
                                        
                                        	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                        	**type**\: str
                                        
                                        .. attribute:: endpoint_active_flag
                                        
                                        	Endpoint active flag
                                        	**type**\: bool
                                        
                                        .. attribute:: msg_size
                                        
                                        	Message size for this entity
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: wheel_id
                                        
                                        	Wheel ID for this endpoint
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: expected_sequence_num
                                        
                                        	Expected sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: endpoint
                                        
                                        	NCD endpoint bytestream
                                        	**type**\: list of  		 :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint, self).__init__()

                                            self.yang_name = "npl-endpoint"
                                            self.yang_parent_name = "ds-npl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("endpoint", ("endpoint", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint))])
                                            self._leafs = OrderedDict([
                                                ('endpoint_name', (YLeaf(YType.str, 'endpoint-name'), ['str'])),
                                                ('sync_group_name', (YLeaf(YType.str, 'sync-group-name'), ['str'])),
                                                ('node_id', (YLeaf(YType.str, 'node-id'), ['str'])),
                                                ('endpoint_handle', (YLeaf(YType.uint64, 'endpoint-handle'), ['int'])),
                                                ('endpoint_stale_flag', (YLeaf(YType.boolean, 'endpoint-stale-flag'), ['bool'])),
                                                ('endpoint_issu_role', (YLeaf(YType.str, 'endpoint-issu-role'), ['str'])),
                                                ('endpoint_active_flag', (YLeaf(YType.boolean, 'endpoint-active-flag'), ['bool'])),
                                                ('msg_size', (YLeaf(YType.uint32, 'msg-size'), ['int'])),
                                                ('wheel_id', (YLeaf(YType.uint32, 'wheel-id'), ['int'])),
                                                ('expected_sequence_num', (YLeaf(YType.uint32, 'expected-sequence-num'), ['int'])),
                                            ])
                                            self.endpoint_name = None
                                            self.sync_group_name = None
                                            self.node_id = None
                                            self.endpoint_handle = None
                                            self.endpoint_stale_flag = None
                                            self.endpoint_issu_role = None
                                            self.endpoint_active_flag = None
                                            self.msg_size = None
                                            self.wheel_id = None
                                            self.expected_sequence_num = None

                                            self.endpoint = YList(self)
                                            self._segment_path = lambda: "npl-endpoint"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint, [u'endpoint_name', u'sync_group_name', u'node_id', u'endpoint_handle', u'endpoint_stale_flag', u'endpoint_issu_role', u'endpoint_active_flag', u'msg_size', u'wheel_id', u'expected_sequence_num'], name, value)


                                        class Endpoint(Entity):
                                            """
                                            NCD endpoint bytestream
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint, self).__init__()

                                                self.yang_name = "endpoint"
                                                self.yang_parent_name = "npl-endpoint"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "endpoint"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint, [u'entry'], name, value)


                                class ActiveNsrModeEnterTime(Entity):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime, self).__init__()

                                        self.yang_name = "active-nsr-mode-enter-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "active-nsr-mode-enter-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime, [u'entry'], name, value)


                                class StandbyNsrModeEnterTime(Entity):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime, self).__init__()

                                        self.yang_name = "standby-nsr-mode-enter-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "standby-nsr-mode-enter-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime, [u'entry'], name, value)


                                class ActiveNsrfoTime(Entity):
                                    """
                                    Time that each thread isdone with its
                                    
                                    go\-activeprocessing (seconds since Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime, self).__init__()

                                        self.yang_name = "active-nsrfo-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "active-nsrfo-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime, [u'entry'], name, value)


                                class PostitCountInfo(Entity):
                                    """
                                    List of neighbors and their postit counts
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress>`
                                    
                                    .. attribute:: postit_count
                                    
                                    	Count of the number of postits for this nbr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo, self).__init__()

                                        self.yang_name = "postit-count-info"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress))])
                                        self._leafs = OrderedDict([
                                            ('postit_count', (YLeaf(YType.uint32, 'postit-count'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ])
                                        self.postit_count = None
                                        self.vrf_name = None

                                        self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._segment_path = lambda: "postit-count-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo, [u'postit_count', u'vrf_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "postit-count-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class IssuMilestone(Entity):
                                    """
                                    ISSU Milestones
                                    
                                    .. attribute:: milestone_name
                                    
                                    	Milestone name
                                    	**type**\: str
                                    
                                    .. attribute:: milestone_start_timestamp
                                    
                                    	Milestone start timestamp
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: milestone_met_timestamp
                                    
                                    	Milestone met timestamp
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone, self).__init__()

                                        self.yang_name = "issu-milestone"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('milestone_name', (YLeaf(YType.str, 'milestone-name'), ['str'])),
                                            ('milestone_start_timestamp', (YLeaf(YType.uint32, 'milestone-start-timestamp'), ['int'])),
                                            ('milestone_met_timestamp', (YLeaf(YType.uint32, 'milestone-met-timestamp'), ['int'])),
                                        ])
                                        self.milestone_name = None
                                        self.milestone_start_timestamp = None
                                        self.milestone_met_timestamp = None
                                        self._segment_path = lambda: "issu-milestone"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone, [u'milestone_name', u'milestone_start_timestamp', u'milestone_met_timestamp'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: lpts_set_up_time
                                
                                	Time spent setting up LPTS socket opt (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lpts_calls
                                
                                	Number of times LPTS socket opt set up
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_throttles_count
                                
                                	Number of partial read throttles
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read_count
                                
                                	Number of socket reads for nbrs above low threshold
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high_throttled_read_count
                                
                                	Number of socket reads for nbrs above high threshold
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_written
                                
                                	Number of bytes of data written
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to to funvction to process sub\-group message list
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of Calls to function to process write queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing imbound update messages (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "performance-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lpts_set_up_time', (YLeaf(YType.uint32, 'lpts-set-up-time'), ['int'])),
                                        ('lpts_calls', (YLeaf(YType.uint32, 'lpts-calls'), ['int'])),
                                        ('read_throttles_count', (YLeaf(YType.uint32, 'read-throttles-count'), ['int'])),
                                        ('low_throttled_read_count', (YLeaf(YType.uint32, 'low-throttled-read-count'), ['int'])),
                                        ('high_throttled_read_count', (YLeaf(YType.uint32, 'high-throttled-read-count'), ['int'])),
                                        ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                        ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                        ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                        ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                        ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                        ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                        ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                        ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                        ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                        ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                        ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                        ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                        ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                        ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                        ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                    ])
                                    self.lpts_set_up_time = None
                                    self.lpts_calls = None
                                    self.read_throttles_count = None
                                    self.low_throttled_read_count = None
                                    self.high_throttled_read_count = None
                                    self.read_calls_count = None
                                    self.read_messages_count = None
                                    self.data_bytes_read = None
                                    self.io_read_time = None
                                    self.write_calls_count = None
                                    self.data_bytes_written = None
                                    self.io_write_time = None
                                    self.write_subgroup_calls_count = None
                                    self.write_subgroup_messages_count = None
                                    self.subgroup_list_time = None
                                    self.write_queue_calls_count = None
                                    self.write_queue_messages_count = None
                                    self.write_queue_time = None
                                    self.inbound_update_messages = None
                                    self.inbound_update_messages_time = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf, [u'lpts_set_up_time', u'lpts_calls', u'read_throttles_count', u'low_throttled_read_count', u'high_throttled_read_count', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time'], name, value)


                    class Sessions(Entity):
                        """
                        The BGP session table
                        
                        .. attribute:: session
                        
                        	A BGP session table entry
                        	**type**\: list of  		 :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions, self).__init__()

                            self.yang_name = "sessions"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("session", ("session", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session))])
                            self._leafs = OrderedDict()

                            self.session = YList(self)
                            self._segment_path = lambda: "sessions"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions, [], name, value)


                        class Session(Entity):
                            """
                            A BGP session table entry
                            
                            .. attribute:: neighbor_address  (key)
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress>`
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\: str
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\: bool
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\: str
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\: bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: postit_pending
                            
                            	Nbr has postits pending
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session, self).__init__()

                                self.yang_name = "session"
                                self.yang_parent_name = "sessions"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                    ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                    ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                    ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                    ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                    ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                    ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                    ('postit_pending', (YLeaf(YType.boolean, 'postit-pending'), ['bool'])),
                                ])
                                self.neighbor_address = None
                                self.speaker_id = None
                                self.description = None
                                self.local_as = None
                                self.remote_as = None
                                self.messages_queued_in = None
                                self.messages_queued_out = None
                                self.connection_state = None
                                self.is_local_address_configured = None
                                self.vrf_name = None
                                self.nsr_enabled = None
                                self.nsr_state = None
                                self.postit_pending = None

                                self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                self._segment_path = lambda: "session" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'messages_queued_in', u'messages_queued_out', u'connection_state', u'is_local_address_configured', u'vrf_name', u'nsr_enabled', u'nsr_state', u'postit_pending'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-local-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-remote-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                    class Neighbors(Entity):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: neighbor
                        
                        	A BGP Neighbor table entry
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor))])
                            self._leafs = OrderedDict()

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            A BGP Neighbor table entry
                            
                            .. attribute:: neighbor_address  (key)
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                            
                            .. attribute:: send_notification_info
                            
                            	Information on the last notification sent
                            	**type**\:  :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo>`
                            
                            .. attribute:: received_notification_info
                            
                            	Information on the last notification received
                            	**type**\:  :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics>`
                            
                            .. attribute:: message_statistics
                            
                            	Message statistics
                            	**type**\:  :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics>`
                            
                            .. attribute:: tcp_init_sync_time_spec
                            
                            	Time When neighbor entered TCP Init Sync
                            	**type**\:  :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_phase_two_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Phase Two
                            	**type**\:  :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_done_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Done
                            	**type**\:  :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance>`
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\: str
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\: bool
                            
                            .. attribute:: is_external_neighbor_not_directly_connected
                            
                            	External neighbor not directly connected
                            	**type**\: bool
                            
                            .. attribute:: messages_received
                            
                            	Number of messages received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_sent
                            
                            	Number of messages sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_in
                            
                            	No. of update msgs received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_out
                            
                            	No. of update messages sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_established_time
                            
                            	Time (in secs) that the connection has been established
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                            
                            .. attribute:: previous_connection_state
                            
                            	Previous state of connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_admin_status
                            
                            	Administrative status of connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: open_check_error_code
                            
                            	Open check error code
                            	**type**\:  :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\: bool
                            
                            .. attribute:: connection_local_port
                            
                            	Local port for the connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_remote_port
                            
                            	Remote port for the connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_interface_handle
                            
                            	Interface Handle of Neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reset_notification_sent
                            
                            	Notification was sent during last reset
                            	**type**\: bool
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\: bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\: bool
                            
                            .. attribute:: is_out_of_memory_shutdown
                            
                            	Neighbor shut down during a SEVERE low memory condition
                            	**type**\: bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\: bool
                            
                            .. attribute:: is_ebgp_peer_as_league
                            
                            	EBGP peer belongs to AS League
                            	**type**\: bool
                            
                            .. attribute:: is_ebgp_peer_common_admin
                            
                            	EBGP peer with common administation
                            	**type**\: bool
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\: bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\: bool
                            
                            .. attribute:: bfd_session_state
                            
                            	BFD state for this peer
                            	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                            
                            .. attribute:: bfd_session_created_state
                            
                            	BFD state for this peer
                            	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_state_ts
                            
                            	Timestamp since when nbr is in this bfd state
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: router_id
                            
                            	Router ID for the neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: negotiated_protocol_version
                            
                            	Negotiated protocol version
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\: bool
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\: bool
                            
                            .. attribute:: is_capability_negotiation_suppressed
                            
                            	Capability negotiation suppressed
                            	**type**\: bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\: bool
                            
                            .. attribute:: is_route_refresh_capability_received
                            
                            	Route refresh capability received
                            	**type**\: bool
                            
                            .. attribute:: is_route_refresh_old_capability_received
                            
                            	Route refresh old capability received
                            	**type**\: bool
                            
                            .. attribute:: is_gr_aware
                            
                            	GR awareness received
                            	**type**\: bool
                            
                            .. attribute:: is4_byte_as_capability_received
                            
                            	4\-byte AScapability received
                            	**type**\: bool
                            
                            .. attribute:: is4_byte_as_capability_sent
                            
                            	4\-byte AScapability Snt
                            	**type**\: bool
                            
                            .. attribute:: multi_protocol_capability_received
                            
                            	Multi\-protocol capability has been received
                            	**type**\: bool
                            
                            .. attribute:: hold_time
                            
                            	Hold time (in secs) negotiated for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: keep_alive_time
                            
                            	Keepalive time (in secs) negotiated for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connect_retry_interval
                            
                            	Time (in secs) for connect retry timer
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_update
                            
                            	Time (in secs) since last update message was received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read
                            
                            	Time (in secs) since last read
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read_reset
                            
                            	Time (in secs) since last read before last reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_last_cb
                            
                            	CB
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: time_last_cb_reset
                            
                            	Last CB before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_last_fb
                            
                            	FB
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: count_last_write
                            
                            	Count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_write
                            
                            	Time (in secs) since last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: attempted_last_write_bytes
                            
                            	Attempted size of last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_last_write_bytes
                            
                            	Actual size of last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_second_last_write
                            
                            	Time (in secs) since second  last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: attempted_second_last_write_bytes
                            
                            	Attempted size of second last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_bytes
                            
                            	Actual size of second last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: attempted_last_write_reset_bytes
                            
                            	Attempted size of last write before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_last_write_reset_bytes
                            
                            	Actual size of last write before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_second_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: attempted_second_last_write_reset_bytes
                            
                            	Attempted size of second last write before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_reset_bytes
                            
                            	Actual size of second last write before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_write_event
                            
                            	Time (in secs) since last write thread event
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_write_event
                            
                            	Time (in secs) since second last write thread event
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_aexpiry_reset
                            
                            	Time (in secs) since last KA timer expiry before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_k_aexpiry_reset
                            
                            	Time (in secs) since second last KA timer expiry before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_anotsent_reset
                            
                            	Duration (in secs) since last time that KA was not sent before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_aerror_reset
                            
                            	Duration (in secs) since last time that an error was encountered after KA expiry
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_astart_reset
                            
                            	Time (in secs) since the last KA timer start before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_k_astart_reset
                            
                            	Time (in secs) since the second last KA timer start before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: connection_up_count
                            
                            	Number of times the connection was established
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_down_count
                            
                            	Number of times connection was dropped
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_connection_last_dropped
                            
                            	Time since the connection last went down (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: reset_reason
                            
                            	Reason for last connection reset
                            	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                            
                            .. attribute:: peer_reset_reason
                            
                            	Reason for last peer close event
                            	**type**\:  :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                            
                            .. attribute:: peer_error_code
                            
                            	If peer closed, error received from transport
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_notify_error_code
                            
                            	Code for the last error notification seen on the connection
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: last_notify_error_subcode
                            
                            	Error subcode of the last error notification seen on the connection
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: error_notifies_received
                            
                            	Number of error notifications received on the connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: error_notifies_sent
                            
                            	Number of error notifications sent on the connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\: bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\: str
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\: bool
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\: bool
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\: bool
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: fssn_offset
                            
                            	First standby SeqNo offset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpbsn_offset
                            
                            	First standby PDU boundary SeqNo offset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_ackd_seq_no
                            
                            	SeqNo of the last Ackd byte
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bytes_written
                            
                            	Total bytes written by write thread
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: bytes_read
                            
                            	Total bytes read
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: socket_read_bytes
                            
                            	Total read bytes value insocket\-lib
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: is_read_disabled
                            
                            	If true, socket read isdisabled
                            	**type**\: bool
                            
                            .. attribute:: update_bytes_read
                            
                            	Total update bytes read
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\: bool
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\: bool
                            
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\: bool
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\: bool
                            
                            .. attribute:: io_armed
                            
                            	If true, socket has beenauto\-armed for io control
                            	**type**\: bool
                            
                            .. attribute:: read_armed
                            
                            	If true, socket has beenauto\-armed for read
                            	**type**\: bool
                            
                            .. attribute:: write_armed
                            
                            	If true, socket has beenauto\-armed for write
                            	**type**\: bool
                            
                            .. attribute:: discard_data_bytes
                            
                            	Remaining discard data (bytes) on Standby
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\: bool
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\: bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\: bool
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\: bool
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\: bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\: bool
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\: bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\: bool
                            
                            .. attribute:: dynamic_neighbor
                            
                            	Dynamic neighbor
                            	**type**\: bool
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress)), ("send-notification-info", ("send_notification_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo)), ("received-notification-info", ("received_notification_info", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics)), ("message-statistics", ("message_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics)), ("tcp-init-sync-time-spec", ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec)), ("tcp-init-sync-phase-two-time-spec", ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec)), ("tcp-init-sync-done-time-spec", ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                    ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                    ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                    ('is_external_neighbor_not_directly_connected', (YLeaf(YType.boolean, 'is-external-neighbor-not-directly-connected'), ['bool'])),
                                    ('messages_received', (YLeaf(YType.uint32, 'messages-received'), ['int'])),
                                    ('messages_sent', (YLeaf(YType.uint32, 'messages-sent'), ['int'])),
                                    ('update_messages_in', (YLeaf(YType.uint32, 'update-messages-in'), ['int'])),
                                    ('update_messages_out', (YLeaf(YType.uint32, 'update-messages-out'), ['int'])),
                                    ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                    ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                    ('connection_established_time', (YLeaf(YType.uint32, 'connection-established-time'), ['int'])),
                                    ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                    ('previous_connection_state', (YLeaf(YType.uint32, 'previous-connection-state'), ['int'])),
                                    ('connection_admin_status', (YLeaf(YType.uint32, 'connection-admin-status'), ['int'])),
                                    ('open_check_error_code', (YLeaf(YType.enumeration, 'open-check-error-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpOpenCheckErr', '')])),
                                    ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                    ('connection_local_port', (YLeaf(YType.uint32, 'connection-local-port'), ['int'])),
                                    ('connection_remote_port', (YLeaf(YType.uint32, 'connection-remote-port'), ['int'])),
                                    ('neighbor_interface_handle', (YLeaf(YType.uint32, 'neighbor-interface-handle'), ['int'])),
                                    ('reset_notification_sent', (YLeaf(YType.boolean, 'reset-notification-sent'), ['bool'])),
                                    ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                    ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                    ('is_out_of_memory_shutdown', (YLeaf(YType.boolean, 'is-out-of-memory-shutdown'), ['bool'])),
                                    ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                    ('is_ebgp_peer_as_league', (YLeaf(YType.boolean, 'is-ebgp-peer-as-league'), ['bool'])),
                                    ('is_ebgp_peer_common_admin', (YLeaf(YType.boolean, 'is-ebgp-peer-common-admin'), ['bool'])),
                                    ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                    ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                    ('bfd_session_state', (YLeaf(YType.enumeration, 'bfd-session-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                    ('bfd_session_created_state', (YLeaf(YType.enumeration, 'bfd-session-created-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                    ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                    ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                    ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                    ('bfd_state_ts', (YLeaf(YType.uint64, 'bfd-state-ts'), ['int'])),
                                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                    ('negotiated_protocol_version', (YLeaf(YType.uint16, 'negotiated-protocol-version'), ['int'])),
                                    ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                    ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                    ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                    ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                    ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                    ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                    ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                    ('is_capability_negotiation_suppressed', (YLeaf(YType.boolean, 'is-capability-negotiation-suppressed'), ['bool'])),
                                    ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                    ('is_route_refresh_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-capability-received'), ['bool'])),
                                    ('is_route_refresh_old_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-old-capability-received'), ['bool'])),
                                    ('is_gr_aware', (YLeaf(YType.boolean, 'is-gr-aware'), ['bool'])),
                                    ('is4_byte_as_capability_received', (YLeaf(YType.boolean, 'is4-byte-as-capability-received'), ['bool'])),
                                    ('is4_byte_as_capability_sent', (YLeaf(YType.boolean, 'is4-byte-as-capability-sent'), ['bool'])),
                                    ('multi_protocol_capability_received', (YLeaf(YType.boolean, 'multi-protocol-capability-received'), ['bool'])),
                                    ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                    ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                    ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                    ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                    ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                    ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                    ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                    ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                    ('connect_retry_interval', (YLeaf(YType.uint16, 'connect-retry-interval'), ['int'])),
                                    ('time_since_last_update', (YLeaf(YType.uint32, 'time-since-last-update'), ['int'])),
                                    ('time_since_last_read', (YLeaf(YType.uint32, 'time-since-last-read'), ['int'])),
                                    ('time_since_last_read_reset', (YLeaf(YType.uint32, 'time-since-last-read-reset'), ['int'])),
                                    ('time_last_cb', (YLeaf(YType.uint64, 'time-last-cb'), ['int'])),
                                    ('time_last_cb_reset', (YLeaf(YType.uint32, 'time-last-cb-reset'), ['int'])),
                                    ('time_last_fb', (YLeaf(YType.uint64, 'time-last-fb'), ['int'])),
                                    ('count_last_write', (YLeaf(YType.uint32, 'count-last-write'), ['int'])),
                                    ('time_since_last_write', (YLeaf(YType.uint32, 'time-since-last-write'), ['int'])),
                                    ('attempted_last_write_bytes', (YLeaf(YType.uint32, 'attempted-last-write-bytes'), ['int'])),
                                    ('actual_last_write_bytes', (YLeaf(YType.uint32, 'actual-last-write-bytes'), ['int'])),
                                    ('time_since_second_last_write', (YLeaf(YType.uint32, 'time-since-second-last-write'), ['int'])),
                                    ('attempted_second_last_write_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-bytes'), ['int'])),
                                    ('actual_second_last_write_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-bytes'), ['int'])),
                                    ('time_since_last_write_reset', (YLeaf(YType.uint32, 'time-since-last-write-reset'), ['int'])),
                                    ('attempted_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-last-write-reset-bytes'), ['int'])),
                                    ('actual_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-last-write-reset-bytes'), ['int'])),
                                    ('time_since_second_last_write_reset', (YLeaf(YType.uint32, 'time-since-second-last-write-reset'), ['int'])),
                                    ('attempted_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-reset-bytes'), ['int'])),
                                    ('actual_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-reset-bytes'), ['int'])),
                                    ('last_write_event', (YLeaf(YType.uint32, 'last-write-event'), ['int'])),
                                    ('second_last_write_event', (YLeaf(YType.uint32, 'second-last-write-event'), ['int'])),
                                    ('last_k_aexpiry_reset', (YLeaf(YType.uint32, 'last-k-aexpiry-reset'), ['int'])),
                                    ('second_last_k_aexpiry_reset', (YLeaf(YType.uint32, 'second-last-k-aexpiry-reset'), ['int'])),
                                    ('last_k_anotsent_reset', (YLeaf(YType.uint32, 'last-k-anotsent-reset'), ['int'])),
                                    ('last_k_aerror_reset', (YLeaf(YType.uint32, 'last-k-aerror-reset'), ['int'])),
                                    ('last_k_astart_reset', (YLeaf(YType.uint32, 'last-k-astart-reset'), ['int'])),
                                    ('second_last_k_astart_reset', (YLeaf(YType.uint32, 'second-last-k-astart-reset'), ['int'])),
                                    ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                    ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                    ('time_since_connection_last_dropped', (YLeaf(YType.uint32, 'time-since-connection-last-dropped'), ['int'])),
                                    ('reset_reason', (YLeaf(YType.enumeration, 'reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                    ('peer_reset_reason', (YLeaf(YType.enumeration, 'peer-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPeerResetReasonIndex', '')])),
                                    ('peer_error_code', (YLeaf(YType.uint32, 'peer-error-code'), ['int'])),
                                    ('last_notify_error_code', (YLeaf(YType.uint8, 'last-notify-error-code'), ['int'])),
                                    ('last_notify_error_subcode', (YLeaf(YType.uint8, 'last-notify-error-subcode'), ['int'])),
                                    ('error_notifies_received', (YLeaf(YType.uint32, 'error-notifies-received'), ['int'])),
                                    ('error_notifies_sent', (YLeaf(YType.uint32, 'error-notifies-sent'), ['int'])),
                                    ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                    ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                    ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                    ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                    ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                    ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                    ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                    ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                    ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                    ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                    ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                    ('fssn_offset', (YLeaf(YType.uint32, 'fssn-offset'), ['int'])),
                                    ('fpbsn_offset', (YLeaf(YType.uint32, 'fpbsn-offset'), ['int'])),
                                    ('last_ackd_seq_no', (YLeaf(YType.uint32, 'last-ackd-seq-no'), ['int'])),
                                    ('bytes_written', (YLeaf(YType.uint32, 'bytes-written'), ['int'])),
                                    ('bytes_read', (YLeaf(YType.uint32, 'bytes-read'), ['int'])),
                                    ('socket_read_bytes', (YLeaf(YType.uint32, 'socket-read-bytes'), ['int'])),
                                    ('is_read_disabled', (YLeaf(YType.boolean, 'is-read-disabled'), ['bool'])),
                                    ('update_bytes_read', (YLeaf(YType.uint32, 'update-bytes-read'), ['int'])),
                                    ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                    ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                    ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                    ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                    ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                    ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                    ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                    ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                    ('io_armed', (YLeaf(YType.boolean, 'io-armed'), ['bool'])),
                                    ('read_armed', (YLeaf(YType.boolean, 'read-armed'), ['bool'])),
                                    ('write_armed', (YLeaf(YType.boolean, 'write-armed'), ['bool'])),
                                    ('discard_data_bytes', (YLeaf(YType.uint32, 'discard-data-bytes'), ['int'])),
                                    ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                    ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                    ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                    ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                    ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                    ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                    ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                    ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                    ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                    ('dynamic_neighbor', (YLeaf(YType.boolean, 'dynamic-neighbor'), ['bool'])),
                                ])
                                self.neighbor_address = None
                                self.speaker_id = None
                                self.description = None
                                self.local_as = None
                                self.remote_as = None
                                self.has_internal_link = None
                                self.is_external_neighbor_not_directly_connected = None
                                self.messages_received = None
                                self.messages_sent = None
                                self.update_messages_in = None
                                self.update_messages_out = None
                                self.messages_queued_in = None
                                self.messages_queued_out = None
                                self.connection_established_time = None
                                self.connection_state = None
                                self.previous_connection_state = None
                                self.connection_admin_status = None
                                self.open_check_error_code = None
                                self.is_local_address_configured = None
                                self.connection_local_port = None
                                self.connection_remote_port = None
                                self.neighbor_interface_handle = None
                                self.reset_notification_sent = None
                                self.is_administratively_shut_down = None
                                self.is_neighbor_max_prefix_shutdown = None
                                self.is_out_of_memory_shutdown = None
                                self.is_out_of_memory_forced_up = None
                                self.is_ebgp_peer_as_league = None
                                self.is_ebgp_peer_common_admin = None
                                self.ttl_security_enabled = None
                                self.suppress4_byte_as = None
                                self.bfd_session_state = None
                                self.bfd_session_created_state = None
                                self.bfd_session_enable_mode = None
                                self.bfd_minintervalval = None
                                self.bfd_multiplierval = None
                                self.bfd_state_ts = None
                                self.router_id = None
                                self.negotiated_protocol_version = None
                                self.ebgp_time_to_live = None
                                self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                self.tcpmss = None
                                self.msg_log_in = None
                                self.msg_log_out = None
                                self.neighbor_local_as = None
                                self.local_as_no_prepend = None
                                self.is_capability_negotiation_suppressed = None
                                self.is_capability_negotiation_performed = None
                                self.is_route_refresh_capability_received = None
                                self.is_route_refresh_old_capability_received = None
                                self.is_gr_aware = None
                                self.is4_byte_as_capability_received = None
                                self.is4_byte_as_capability_sent = None
                                self.multi_protocol_capability_received = None
                                self.hold_time = None
                                self.keep_alive_time = None
                                self.configured_hold_time = None
                                self.configured_keepalive = None
                                self.configured_min_acc_hold_time = None
                                self.min_advertise_interval = None
                                self.min_advertise_interval_msecs = None
                                self.min_origination_interval = None
                                self.connect_retry_interval = None
                                self.time_since_last_update = None
                                self.time_since_last_read = None
                                self.time_since_last_read_reset = None
                                self.time_last_cb = None
                                self.time_last_cb_reset = None
                                self.time_last_fb = None
                                self.count_last_write = None
                                self.time_since_last_write = None
                                self.attempted_last_write_bytes = None
                                self.actual_last_write_bytes = None
                                self.time_since_second_last_write = None
                                self.attempted_second_last_write_bytes = None
                                self.actual_second_last_write_bytes = None
                                self.time_since_last_write_reset = None
                                self.attempted_last_write_reset_bytes = None
                                self.actual_last_write_reset_bytes = None
                                self.time_since_second_last_write_reset = None
                                self.attempted_second_last_write_reset_bytes = None
                                self.actual_second_last_write_reset_bytes = None
                                self.last_write_event = None
                                self.second_last_write_event = None
                                self.last_k_aexpiry_reset = None
                                self.second_last_k_aexpiry_reset = None
                                self.last_k_anotsent_reset = None
                                self.last_k_aerror_reset = None
                                self.last_k_astart_reset = None
                                self.second_last_k_astart_reset = None
                                self.connection_up_count = None
                                self.connection_down_count = None
                                self.time_since_connection_last_dropped = None
                                self.reset_reason = None
                                self.peer_reset_reason = None
                                self.peer_error_code = None
                                self.last_notify_error_code = None
                                self.last_notify_error_subcode = None
                                self.error_notifies_received = None
                                self.error_notifies_sent = None
                                self.remote_as_number = None
                                self.dmz_link_bandwidth = None
                                self.ebgp_recv_dmz = None
                                self.ebgp_send_dmz_mode = None
                                self.tos_type = None
                                self.tos_value = None
                                self.tcp_session_open_mode = None
                                self.vrf_name = None
                                self.standby_rp = None
                                self.nsr_enabled = None
                                self.graceful_restart_enabled_nbr = None
                                self.gr_restart_time = None
                                self.gr_stale_path_time = None
                                self.fssn_offset = None
                                self.fpbsn_offset = None
                                self.last_ackd_seq_no = None
                                self.bytes_written = None
                                self.bytes_read = None
                                self.socket_read_bytes = None
                                self.is_read_disabled = None
                                self.update_bytes_read = None
                                self.nsr_state = None
                                self.is_passive_close = None
                                self.nbr_enforce_first_as = None
                                self.active_bmp_servers = None
                                self.nbr_cluster_id = None
                                self.nbr_in_cluster = None
                                self.ignore_connected = None
                                self.internal_vpn_client = None
                                self.io_armed = None
                                self.read_armed = None
                                self.write_armed = None
                                self.discard_data_bytes = None
                                self.local_as_replace_as = None
                                self.local_as_dual_as = None
                                self.local_as_dual_as_mode_native = None
                                self.egress_peer_engineering_enabled = None
                                self.discard_as4_path = None
                                self.rpki_disable = None
                                self.rpki_use_validity = None
                                self.rpki_allow_invalid = None
                                self.rpki_signal_ibgp = None
                                self.dynamic_neighbor = None

                                self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                self.send_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo()
                                self.send_notification_info.parent = self
                                self._children_name_map["send_notification_info"] = "send-notification-info"

                                self.received_notification_info = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                self.received_notification_info.parent = self
                                self._children_name_map["received_notification_info"] = "received-notification-info"

                                self.performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self._children_name_map["performance_statistics"] = "performance-statistics"

                                self.message_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics()
                                self.message_statistics.parent = self
                                self._children_name_map["message_statistics"] = "message-statistics"

                                self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                self.tcp_init_sync_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"

                                self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                self.tcp_init_sync_phase_two_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"

                                self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                self.tcp_init_sync_done_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"

                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                self.af_data = YList(self)
                                self._segment_path = lambda: "neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_external_neighbor_not_directly_connected', u'messages_received', u'messages_sent', u'update_messages_in', u'update_messages_out', u'messages_queued_in', u'messages_queued_out', u'connection_established_time', u'connection_state', u'previous_connection_state', u'connection_admin_status', u'open_check_error_code', u'is_local_address_configured', u'connection_local_port', u'connection_remote_port', u'neighbor_interface_handle', u'reset_notification_sent', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_shutdown', u'is_out_of_memory_forced_up', u'is_ebgp_peer_as_league', u'is_ebgp_peer_common_admin', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_state', u'bfd_session_created_state', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'bfd_state_ts', u'router_id', u'negotiated_protocol_version', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_suppressed', u'is_capability_negotiation_performed', u'is_route_refresh_capability_received', u'is_route_refresh_old_capability_received', u'is_gr_aware', u'is4_byte_as_capability_received', u'is4_byte_as_capability_sent', u'multi_protocol_capability_received', u'hold_time', u'keep_alive_time', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'connect_retry_interval', u'time_since_last_update', u'time_since_last_read', u'time_since_last_read_reset', u'time_last_cb', u'time_last_cb_reset', u'time_last_fb', u'count_last_write', u'time_since_last_write', u'attempted_last_write_bytes', u'actual_last_write_bytes', u'time_since_second_last_write', u'attempted_second_last_write_bytes', u'actual_second_last_write_bytes', u'time_since_last_write_reset', u'attempted_last_write_reset_bytes', u'actual_last_write_reset_bytes', u'time_since_second_last_write_reset', u'attempted_second_last_write_reset_bytes', u'actual_second_last_write_reset_bytes', u'last_write_event', u'second_last_write_event', u'last_k_aexpiry_reset', u'second_last_k_aexpiry_reset', u'last_k_anotsent_reset', u'last_k_aerror_reset', u'last_k_astart_reset', u'second_last_k_astart_reset', u'connection_up_count', u'connection_down_count', u'time_since_connection_last_dropped', u'reset_reason', u'peer_reset_reason', u'peer_error_code', u'last_notify_error_code', u'last_notify_error_subcode', u'error_notifies_received', u'error_notifies_sent', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'fssn_offset', u'fpbsn_offset', u'last_ackd_seq_no', u'bytes_written', u'bytes_read', u'socket_read_bytes', u'is_read_disabled', u'update_bytes_read', u'nsr_state', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'io_armed', u'read_armed', u'write_armed', u'discard_data_bytes', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'dynamic_neighbor'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-local-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-remote-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SendNotificationInfo(Entity):
                                """
                                Information on the last notification sent
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo, self).__init__()

                                    self.yang_name = "send-notification-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData))])
                                    self._leafs = OrderedDict([
                                        ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                        ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                        ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                    ])
                                    self.time_since_last_notification = None
                                    self.notification_error_code = None
                                    self.notification_error_subcode = None

                                    self.last_notification_data = YList(self)
                                    self._segment_path = lambda: "send-notification-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                class LastNotificationData(Entity):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                        self.yang_name = "last-notification-data"
                                        self.yang_parent_name = "send-notification-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "last-notification-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, [u'entry'], name, value)


                            class ReceivedNotificationInfo(Entity):
                                """
                                Information on the last notification received
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo, self).__init__()

                                    self.yang_name = "received-notification-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData))])
                                    self._leafs = OrderedDict([
                                        ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                        ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                        ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                    ])
                                    self.time_since_last_notification = None
                                    self.notification_error_code = None
                                    self.notification_error_subcode = None

                                    self.last_notification_data = YList(self)
                                    self._segment_path = lambda: "received-notification-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                class LastNotificationData(Entity):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                        self.yang_name = "last-notification-data"
                                        self.yang_parent_name = "received-notification-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "last-notification-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, [u'entry'], name, value)


                            class PerformanceStatistics(Entity):
                                """
                                Performance statistics
                                
                                .. attribute:: read_throttles
                                
                                	Number of partial read throttles
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read
                                
                                	Num socket reads after nbrs crossed low threshold
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high_throttled_read
                                
                                	Num of socket reads after nbr crossed high threshold
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_last_throttled_read
                                
                                	Time (in secs) since last read after being throttled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_written
                                
                                	No. of data bytes written
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: last_sent_seq_no
                                
                                	Seq No of the last sent byte
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to function to process sub\-group message list
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group msgs processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list  (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of calls to function to process write queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing inbound update messages (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: maximum_read_size
                                
                                	Size of largest socket (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: actives
                                
                                	Number of retried Active opens for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: failed_post_actives
                                
                                	Number of Active Opens that failed in the Post Active State for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passives
                                
                                	Number of retried Passive opens for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rejected_passives
                                
                                	Number of rejected Passive opens for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: active_collision
                                
                                	Number of Closed Active connections for this neighbor due to collision 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passive_collision
                                
                                	Number of Closed Remote opens for this neighborneighbor due to collision 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_read_thread_trigger
                                
                                	Number of times io\-control thread trigger read thread
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_write_thread_trigger
                                
                                	Number of times io\-control thread trigger write thread
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_status
                                
                                	Socket status, TRUE if socket closed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_flags
                                
                                	Reset flags, per thread
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_flags
                                
                                	Nbr flags, per thread
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_fd
                                
                                	Primary FD, per nbr
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: reset_retries
                                
                                	Reset Retries, per nbr
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: sync_flags
                                
                                	Sync flags, per nbr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_oper_down_count
                                
                                	Number of times NSR scoped sync has been done
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_nsr_scoped_sync
                                
                                	Last time NSR scoped syncwas done for the neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics, self).__init__()

                                    self.yang_name = "performance-statistics"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('read_throttles', (YLeaf(YType.uint32, 'read-throttles'), ['int'])),
                                        ('low_throttled_read', (YLeaf(YType.uint32, 'low-throttled-read'), ['int'])),
                                        ('high_throttled_read', (YLeaf(YType.uint32, 'high-throttled-read'), ['int'])),
                                        ('time_since_last_throttled_read', (YLeaf(YType.uint32, 'time-since-last-throttled-read'), ['int'])),
                                        ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                        ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                        ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                        ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                        ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                        ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                        ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                        ('last_sent_seq_no', (YLeaf(YType.uint32, 'last-sent-seq-no'), ['int'])),
                                        ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                        ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                        ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                        ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                        ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                        ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                        ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                        ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                        ('maximum_read_size', (YLeaf(YType.uint32, 'maximum-read-size'), ['int'])),
                                        ('actives', (YLeaf(YType.uint32, 'actives'), ['int'])),
                                        ('failed_post_actives', (YLeaf(YType.uint32, 'failed-post-actives'), ['int'])),
                                        ('passives', (YLeaf(YType.uint32, 'passives'), ['int'])),
                                        ('rejected_passives', (YLeaf(YType.uint32, 'rejected-passives'), ['int'])),
                                        ('active_collision', (YLeaf(YType.uint32, 'active-collision'), ['int'])),
                                        ('passive_collision', (YLeaf(YType.uint32, 'passive-collision'), ['int'])),
                                        ('control_to_read_thread_trigger', (YLeaf(YType.uint32, 'control-to-read-thread-trigger'), ['int'])),
                                        ('control_to_write_thread_trigger', (YLeaf(YType.uint32, 'control-to-write-thread-trigger'), ['int'])),
                                        ('network_status', (YLeaf(YType.uint32, 'network-status'), ['int'])),
                                        ('reset_flags', (YLeaf(YType.uint32, 'reset-flags'), ['int'])),
                                        ('nbr_flags', (YLeaf(YType.uint32, 'nbr-flags'), ['int'])),
                                        ('nbr_fd', (YLeaf(YType.int32, 'nbr-fd'), ['int'])),
                                        ('reset_retries', (YLeaf(YType.uint8, 'reset-retries'), ['int'])),
                                        ('sync_flags', (YLeaf(YType.uint32, 'sync-flags'), ['int'])),
                                        ('nsr_oper_down_count', (YLeaf(YType.uint32, 'nsr-oper-down-count'), ['int'])),
                                        ('last_nsr_scoped_sync', (YLeaf(YType.uint32, 'last-nsr-scoped-sync'), ['int'])),
                                    ])
                                    self.read_throttles = None
                                    self.low_throttled_read = None
                                    self.high_throttled_read = None
                                    self.time_since_last_throttled_read = None
                                    self.read_calls_count = None
                                    self.read_messages_count = None
                                    self.data_bytes_read = None
                                    self.io_read_time = None
                                    self.write_calls_count = None
                                    self.data_bytes_written = None
                                    self.io_write_time = None
                                    self.last_sent_seq_no = None
                                    self.write_subgroup_calls_count = None
                                    self.write_subgroup_messages_count = None
                                    self.subgroup_list_time = None
                                    self.write_queue_calls_count = None
                                    self.write_queue_messages_count = None
                                    self.write_queue_time = None
                                    self.inbound_update_messages = None
                                    self.inbound_update_messages_time = None
                                    self.maximum_read_size = None
                                    self.actives = None
                                    self.failed_post_actives = None
                                    self.passives = None
                                    self.rejected_passives = None
                                    self.active_collision = None
                                    self.passive_collision = None
                                    self.control_to_read_thread_trigger = None
                                    self.control_to_write_thread_trigger = None
                                    self.network_status = None
                                    self.reset_flags = None
                                    self.nbr_flags = None
                                    self.nbr_fd = None
                                    self.reset_retries = None
                                    self.sync_flags = None
                                    self.nsr_oper_down_count = None
                                    self.last_nsr_scoped_sync = None
                                    self._segment_path = lambda: "performance-statistics"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics, [u'read_throttles', u'low_throttled_read', u'high_throttled_read', u'time_since_last_throttled_read', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'last_sent_seq_no', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time', u'maximum_read_size', u'actives', u'failed_post_actives', u'passives', u'rejected_passives', u'active_collision', u'passive_collision', u'control_to_read_thread_trigger', u'control_to_write_thread_trigger', u'network_status', u'reset_flags', u'nbr_flags', u'nbr_fd', u'reset_retries', u'sync_flags', u'nsr_oper_down_count', u'last_nsr_scoped_sync'], name, value)


                            class MessageStatistics(Entity):
                                """
                                Message statistics
                                
                                .. attribute:: open
                                
                                	Open
                                	**type**\:  :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                
                                .. attribute:: notification
                                
                                	Notification
                                	**type**\:  :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                
                                .. attribute:: update
                                
                                	Update
                                	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                
                                .. attribute:: keepalive
                                
                                	Keepalive
                                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                
                                .. attribute:: route_refresh
                                
                                	Route refresh
                                	**type**\:  :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                
                                .. attribute:: total
                                
                                	Total
                                	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics, self).__init__()

                                    self.yang_name = "message-statistics"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("open", ("open", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open)), ("notification", ("notification", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification)), ("update", ("update", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update)), ("keepalive", ("keepalive", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive)), ("route-refresh", ("route_refresh", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh)), ("total", ("total", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total))])
                                    self._leafs = OrderedDict()

                                    self.open = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open()
                                    self.open.parent = self
                                    self._children_name_map["open"] = "open"

                                    self.notification = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                    self.notification.parent = self
                                    self._children_name_map["notification"] = "notification"

                                    self.update = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update()
                                    self.update.parent = self
                                    self._children_name_map["update"] = "update"

                                    self.keepalive = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                    self.keepalive.parent = self
                                    self._children_name_map["keepalive"] = "keepalive"

                                    self.route_refresh = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                    self.route_refresh.parent = self
                                    self._children_name_map["route_refresh"] = "route-refresh"

                                    self.total = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total()
                                    self.total.parent = self
                                    self._children_name_map["total"] = "total"
                                    self._segment_path = lambda: "message-statistics"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics, [], name, value)


                                class Open(Entity):
                                    """
                                    Open
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open, self).__init__()

                                        self.yang_name = "open"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "open"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "open"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "open"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class Notification(Entity):
                                    """
                                    Notification
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification, self).__init__()

                                        self.yang_name = "notification"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "notification"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class Update(Entity):
                                    """
                                    Update
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update, self).__init__()

                                        self.yang_name = "update"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "update"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "update"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "update"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class Keepalive(Entity):
                                    """
                                    Keepalive
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                        self.yang_name = "keepalive"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "keepalive"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "keepalive"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "keepalive"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class RouteRefresh(Entity):
                                    """
                                    Route refresh
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                        self.yang_name = "route-refresh"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "route-refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "route-refresh"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "route-refresh"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class Total(Entity):
                                    """
                                    Total
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total, self).__init__()

                                        self.yang_name = "total"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "total"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "total"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "total"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                            class TcpInitSyncTimeSpec(Entity):
                                """
                                Time When neighbor entered TCP Init Sync
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "tcp-init-sync-time-spec"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                            class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                """
                                Time when neighbor entered TCP Init Sync Phase
                                Two
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                            class TcpInitSyncDoneTimeSpec(Entity):
                                """
                                Time when neighbor entered TCP Init Sync Done
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-done-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "tcp-init-sync-done-time-spec"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                            class GracefulMaintenance(Entity):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\: bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\: bool
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\: bool
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\: bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance, self).__init__()

                                    self.yang_name = "graceful-maintenance"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                        ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                        ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                        ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                        ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                        ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                    ])
                                    self.gshut_exists = None
                                    self.gshut_local_active = None
                                    self.gshut_active = None
                                    self.gshut_locpref_set = None
                                    self.gshut_locpref = None
                                    self.gshut_prepends = None
                                    self._segment_path = lambda: "graceful-maintenance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                            class AfData(Entity):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: neighbor_af_performance_statistics
                                
                                	Neighbor AF statistics
                                	**type**\:  :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\: bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\: bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\: bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\: bool
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\: bool
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\: str
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_rt_type
                                
                                	Advertise RT type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_afi_def_vrf_imp_disable
                                
                                	Advertise of default VRF import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                
                                	Advertise of v4 default VRF import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                
                                	Advertise of v6 default VRF import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_vrf_re_imp_disable
                                
                                	Advertise of VRF re\-import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                
                                	Advertise of v4 VRF re\-import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                
                                	Advertise of v6 VRF re\-import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_eo_r_ready
                                
                                	EoR Can be sent for Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\: bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\: bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\: bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\: bool
                                
                                .. attribute:: update_group_number
                                
                                	Update group index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: filter_group_index
                                
                                	Filter group index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_update_throttled
                                
                                	Updates Throttled becausewrite limit is reached
                                	**type**\: bool
                                
                                .. attribute:: is_update_leaving
                                
                                	Nbr leaving update\-groupto another
                                	**type**\: bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\: bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\: bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\: bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\: bool
                                
                                .. attribute:: neighbor_version
                                
                                	Neighbor version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: prefixes_accepted
                                
                                	No. of prefixes accepted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_synced
                                
                                	Number of prefixes synced to standby
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn_not_found
                                
                                	No. of prefixes withdrawn but not found
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied
                                
                                	No. of prefixes denied
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_no_policy
                                
                                	No. of prefixes denied because there was no inbound policy
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_rt_permit
                                
                                	No. of prefixes denied because RT extended community is not imported
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_orf_policy
                                
                                	No. of prefixes denied by prefix based ORF policy
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_policy
                                
                                	No. of prefixes denied by inbound policy
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_bestpaths
                                
                                	No. of bestpaths from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_best_externalpaths
                                
                                	No. of best\-external paths from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_advertised
                                
                                	No. of prefixes advertised
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_be_advertised
                                
                                	No BE prefixes advertised
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_suppressed
                                
                                	No. of prefixes suppressed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn
                                
                                	No. of prefixes withdrawn
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\: bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\: bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_received
                                
                                	Extended nexthop encoding capability received
                                	**type**\: bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_sent
                                
                                	Extended nexhop encoding capability Sent
                                	**type**\: bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\: bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\: bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_refreshes_received
                                
                                	Number of route refresh requests received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_refreshes_sent
                                
                                	Number of route refresh requests sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_target_version
                                
                                	Target version for refresh update generation
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_version
                                
                                	Version till which refresh updates have been generated
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_acked_version
                                
                                	Version acked by the peer for refresh updates sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\: bool
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_default_originate_sent
                                
                                	Default origination update sent
                                	**type**\: bool
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\: str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\: str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\: str
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\: str
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\: bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\: bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\: bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: eo_r_received_in_read_only
                                
                                	An EoR was received while in read\-only mode
                                	**type**\: bool
                                
                                .. attribute:: acked_version
                                
                                	Version mapped from acked seqNo
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: synced_acked_version
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outstanding_version
                                
                                	No. of all outstanding version objects waiting for ack from the peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outstanding_refresh_version
                                
                                	No. of only refresh version objects waiting for ack from the peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outstanding_version_max
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\: bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\: bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\: bool
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\: bool
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\: bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\: bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\: bool
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\: bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\: bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\: bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\: bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\: bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\: bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\: bool
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_local_labeled_route_unicast
                                
                                	Advertise routes with 
                                	**type**\: bool
                                
                                .. attribute:: prefixes_denied_non_cumulative
                                
                                	No. of prefixes exactly denied (non cumulative)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: enable_label_stack
                                
                                	Enable label stack
                                	**type**\: bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData, self).__init__()

                                    self.yang_name = "af-data"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-af-performance-statistics", ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                        ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                        ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                        ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                        ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                        ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                        ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                        ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                        ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                        ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                        ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                        ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                        ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                        ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                        ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                        ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                        ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                        ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                        ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                        ('advertise_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-def-vrf-imp-disable'), ['bool'])),
                                        ('advertise_evpnv4_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-def-vrf-imp-disable'), ['bool'])),
                                        ('advertise_evpnv6_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-def-vrf-imp-disable'), ['bool'])),
                                        ('advertise_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-vrf-re-imp-disable'), ['bool'])),
                                        ('advertise_evpnv4_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-vrf-re-imp-disable'), ['bool'])),
                                        ('advertise_evpnv6_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-vrf-re-imp-disable'), ['bool'])),
                                        ('advertise_afi_eo_r_ready', (YLeaf(YType.boolean, 'advertise-afi-eo-r-ready'), ['bool'])),
                                        ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                        ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                        ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                        ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                        ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                        ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                        ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                        ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                        ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                        ('is_update_throttled', (YLeaf(YType.boolean, 'is-update-throttled'), ['bool'])),
                                        ('is_update_leaving', (YLeaf(YType.boolean, 'is-update-leaving'), ['bool'])),
                                        ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                        ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                        ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                        ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                        ('neighbor_version', (YLeaf(YType.uint32, 'neighbor-version'), ['int'])),
                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                        ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                        ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                        ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                        ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                        ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                        ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                        ('prefixes_accepted', (YLeaf(YType.uint32, 'prefixes-accepted'), ['int'])),
                                        ('prefixes_synced', (YLeaf(YType.uint32, 'prefixes-synced'), ['int'])),
                                        ('prefixes_withdrawn_not_found', (YLeaf(YType.uint32, 'prefixes-withdrawn-not-found'), ['int'])),
                                        ('prefixes_denied', (YLeaf(YType.uint32, 'prefixes-denied'), ['int'])),
                                        ('prefixes_denied_no_policy', (YLeaf(YType.uint32, 'prefixes-denied-no-policy'), ['int'])),
                                        ('prefixes_denied_rt_permit', (YLeaf(YType.uint32, 'prefixes-denied-rt-permit'), ['int'])),
                                        ('prefixes_denied_orf_policy', (YLeaf(YType.uint32, 'prefixes-denied-orf-policy'), ['int'])),
                                        ('prefixes_denied_policy', (YLeaf(YType.uint32, 'prefixes-denied-policy'), ['int'])),
                                        ('number_of_bestpaths', (YLeaf(YType.uint32, 'number-of-bestpaths'), ['int'])),
                                        ('number_of_best_externalpaths', (YLeaf(YType.uint32, 'number-of-best-externalpaths'), ['int'])),
                                        ('prefixes_advertised', (YLeaf(YType.uint32, 'prefixes-advertised'), ['int'])),
                                        ('prefixes_be_advertised', (YLeaf(YType.uint32, 'prefixes-be-advertised'), ['int'])),
                                        ('prefixes_suppressed', (YLeaf(YType.uint32, 'prefixes-suppressed'), ['int'])),
                                        ('prefixes_withdrawn', (YLeaf(YType.uint32, 'prefixes-withdrawn'), ['int'])),
                                        ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                        ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                        ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                        ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                        ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                        ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                        ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                        ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                        ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                        ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                        ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                        ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                        ('is_ext_nh_encoding_capability_received', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-received'), ['bool'])),
                                        ('is_ext_nh_encoding_capability_sent', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-sent'), ['bool'])),
                                        ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                        ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                        ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                        ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                        ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                        ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                        ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                        ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                        ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                        ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                        ('route_refreshes_received', (YLeaf(YType.uint32, 'route-refreshes-received'), ['int'])),
                                        ('route_refreshes_sent', (YLeaf(YType.uint32, 'route-refreshes-sent'), ['int'])),
                                        ('refresh_target_version', (YLeaf(YType.uint32, 'refresh-target-version'), ['int'])),
                                        ('refresh_version', (YLeaf(YType.uint32, 'refresh-version'), ['int'])),
                                        ('refresh_acked_version', (YLeaf(YType.uint32, 'refresh-acked-version'), ['int'])),
                                        ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                        ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                        ('is_default_originate_sent', (YLeaf(YType.boolean, 'is-default-originate-sent'), ['bool'])),
                                        ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                        ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                        ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                        ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                        ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                        ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                        ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                        ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                        ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                        ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                        ('eo_r_received_in_read_only', (YLeaf(YType.boolean, 'eo-r-received-in-read-only'), ['bool'])),
                                        ('acked_version', (YLeaf(YType.uint32, 'acked-version'), ['int'])),
                                        ('synced_acked_version', (YLeaf(YType.uint32, 'synced-acked-version'), ['int'])),
                                        ('outstanding_version', (YLeaf(YType.uint32, 'outstanding-version'), ['int'])),
                                        ('outstanding_refresh_version', (YLeaf(YType.uint32, 'outstanding-refresh-version'), ['int'])),
                                        ('outstanding_version_max', (YLeaf(YType.uint32, 'outstanding-version-max'), ['int'])),
                                        ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                        ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                        ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                        ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                        ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                        ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                        ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                        ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                        ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                        ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                        ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                        ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                        ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                        ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                        ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                        ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                        ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                        ('prefixes_denied_non_cumulative', (YLeaf(YType.uint32, 'prefixes-denied-non-cumulative'), ['int'])),
                                        ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                    ])
                                    self.af_name = None
                                    self.is_neighbor_route_reflector_client = None
                                    self.is_legacy_pe_rt = None
                                    self.is_neighbor_af_capable = None
                                    self.is_soft_reconfiguration_inbound_allowed = None
                                    self.is_use_soft_reconfiguration_always_on = None
                                    self.remove_private_as_from_updates = None
                                    self.remove_private_as_entire_aspath_from_updates = None
                                    self.remove_private_as_from_inbound_updates = None
                                    self.remove_private_as_entire_aspath_from_inbound_updates = None
                                    self.flowspec_validation_d_isable = None
                                    self.flowspec_redirect_validation_d_isable = None
                                    self.orr_group_name = None
                                    self.orr_group_index = None
                                    self.is_orr_root_address_configured = None
                                    self.advertise_afi = None
                                    self.advertise_afi_reorg = None
                                    self.advertise_afi_disable = None
                                    self.encapsulation_type = None
                                    self.advertise_rt_type = None
                                    self.advertise_afi_def_vrf_imp_disable = None
                                    self.advertise_evpnv4_afi_def_vrf_imp_disable = None
                                    self.advertise_evpnv6_afi_def_vrf_imp_disable = None
                                    self.advertise_afi_vrf_re_imp_disable = None
                                    self.advertise_evpnv4_afi_vrf_re_imp_disable = None
                                    self.advertise_evpnv6_afi_vrf_re_imp_disable = None
                                    self.advertise_afi_eo_r_ready = None
                                    self.always_use_next_hop_local = None
                                    self.sent_community_to_neighbor = None
                                    self.sent_gshut_community_to_neighbor = None
                                    self.sent_extended_community_to_neighbor = None
                                    self.neighbor_default_originate = None
                                    self.is_orf_sent = None
                                    self.is_update_deferred = None
                                    self.is_orf_send_scheduled = None
                                    self.update_group_number = None
                                    self.filter_group_index = None
                                    self.is_update_throttled = None
                                    self.is_update_leaving = None
                                    self.vpn_update_gen_enabled = None
                                    self.vpn_update_gen_trigger_enabled = None
                                    self.is_addpath_send_operational = None
                                    self.is_addpath_receive_operational = None
                                    self.neighbor_version = None
                                    self.weight = None
                                    self.max_prefix_limit = None
                                    self.use_max_prefix_warning_only = None
                                    self.max_prefix_discard_extra_paths = None
                                    self.max_prefix_exceed_discard_paths = None
                                    self.max_prefix_threshold_percent = None
                                    self.max_prefix_restart_time = None
                                    self.prefixes_accepted = None
                                    self.prefixes_synced = None
                                    self.prefixes_withdrawn_not_found = None
                                    self.prefixes_denied = None
                                    self.prefixes_denied_no_policy = None
                                    self.prefixes_denied_rt_permit = None
                                    self.prefixes_denied_orf_policy = None
                                    self.prefixes_denied_policy = None
                                    self.number_of_bestpaths = None
                                    self.number_of_best_externalpaths = None
                                    self.prefixes_advertised = None
                                    self.prefixes_be_advertised = None
                                    self.prefixes_suppressed = None
                                    self.prefixes_withdrawn = None
                                    self.is_peer_orf_capable = None
                                    self.is_advertised_orf_send = None
                                    self.is_received_orf_send_capable = None
                                    self.is_advertised_orf_receive = None
                                    self.is_received_orf_receive_capable = None
                                    self.is_advertised_graceful_restart = None
                                    self.is_graceful_restart_state_flag = None
                                    self.is_received_graceful_restart_capable = None
                                    self.is_add_path_send_capability_advertised = None
                                    self.is_add_path_send_capability_received = None
                                    self.is_add_path_receive_capability_advertised = None
                                    self.is_add_path_receive_capability_received = None
                                    self.is_ext_nh_encoding_capability_received = None
                                    self.is_ext_nh_encoding_capability_sent = None
                                    self.restart_time = None
                                    self.local_restart_time = None
                                    self.stale_path_timeout = None
                                    self.rib_purge_timeout_value = None
                                    self.neighbor_preserved_forwarding_state = None
                                    self.long_lived_graceful_restart_stale_time_configured = None
                                    self.long_lived_graceful_restart_stale_time_sent = None
                                    self.long_lived_graceful_restart_stale_time_accept = None
                                    self.long_lived_graceful_restart_capability_received = None
                                    self.long_lived_graceful_restart_stale_time_received = None
                                    self.neighbor_preserved_long_lived_forwarding_state = None
                                    self.neighbor_long_lived_graceful_restart_capable = None
                                    self.neighbor_long_lived_graceful_restart_time_remaining = None
                                    self.route_refreshes_received = None
                                    self.route_refreshes_sent = None
                                    self.refresh_target_version = None
                                    self.refresh_version = None
                                    self.refresh_acked_version = None
                                    self.is_prefix_orf_present = None
                                    self.orf_entries_received = None
                                    self.is_default_originate_sent = None
                                    self.route_policy_prefix_orf = None
                                    self.route_policy_in = None
                                    self.route_policy_out = None
                                    self.route_policy_default_originate = None
                                    self.is_neighbor_ebgp_without_inbound_policy = None
                                    self.is_neighbor_ebgp_without_outbound_policy = None
                                    self.is_as_override_set = None
                                    self.is_allow_as_in_set = None
                                    self.allow_as_in_count = None
                                    self.address_family_long_lived_time = None
                                    self.eo_r_received_in_read_only = None
                                    self.acked_version = None
                                    self.synced_acked_version = None
                                    self.outstanding_version = None
                                    self.outstanding_refresh_version = None
                                    self.outstanding_version_max = None
                                    self.is_aigp_set = None
                                    self.is_rt_present = None
                                    self.is_rt_present_standby = None
                                    self.accept_own_enabled = None
                                    self.selective_multipath_eligible = None
                                    self.afrpki_disable = None
                                    self.afrpki_use_validity = None
                                    self.afrpki_allow_invalid = None
                                    self.afrpki_signal_ibgp = None
                                    self.is_advertise_permanent_network = None
                                    self.is_send_mcast_attr = None
                                    self.import_stitching = None
                                    self.import_reoriginate = None
                                    self.import_reoriginate_stitching = None
                                    self.advertise_v4_flags = None
                                    self.advertise_v6_flags = None
                                    self.advertise_local_labeled_route_unicast = None
                                    self.prefixes_denied_non_cumulative = None
                                    self.enable_label_stack = None

                                    self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                    self.neighbor_af_performance_statistics.parent = self
                                    self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"

                                    self.extended_community = YList(self)
                                    self.extended_community_standby = YList(self)
                                    self._segment_path = lambda: "af-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_disable', u'encapsulation_type', u'advertise_rt_type', u'advertise_afi_def_vrf_imp_disable', u'advertise_evpnv4_afi_def_vrf_imp_disable', u'advertise_evpnv6_afi_def_vrf_imp_disable', u'advertise_afi_vrf_re_imp_disable', u'advertise_evpnv4_afi_vrf_re_imp_disable', u'advertise_evpnv6_afi_vrf_re_imp_disable', u'advertise_afi_eo_r_ready', u'always_use_next_hop_local', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'update_group_number', u'filter_group_index', u'is_update_throttled', u'is_update_leaving', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'neighbor_version', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'prefixes_accepted', u'prefixes_synced', u'prefixes_withdrawn_not_found', u'prefixes_denied', u'prefixes_denied_no_policy', u'prefixes_denied_rt_permit', u'prefixes_denied_orf_policy', u'prefixes_denied_policy', u'number_of_bestpaths', u'number_of_best_externalpaths', u'prefixes_advertised', u'prefixes_be_advertised', u'prefixes_suppressed', u'prefixes_withdrawn', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'is_ext_nh_encoding_capability_received', u'is_ext_nh_encoding_capability_sent', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'route_refreshes_received', u'route_refreshes_sent', u'refresh_target_version', u'refresh_version', u'refresh_acked_version', u'is_prefix_orf_present', u'orf_entries_received', u'is_default_originate_sent', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'eo_r_received_in_read_only', u'acked_version', u'synced_acked_version', u'outstanding_version', u'outstanding_refresh_version', u'outstanding_version_max', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'advertise_local_labeled_route_unicast', u'prefixes_denied_non_cumulative', u'enable_label_stack'], name, value)


                                class NeighborAfPerformanceStatistics(Entity):
                                    """
                                    Neighbor AF statistics
                                    
                                    .. attribute:: sub_group_pending_message_count
                                    
                                    	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: processed_messages
                                    
                                    	Number of messages processed from the neighbor's write queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_messages
                                    
                                    	Number of messages sent from the neighbor's write queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_transmit
                                    
                                    	No. of update messages with split\-horizon flag that were sent out
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_blocked
                                    
                                    	No. of update messages with split\-horizon flag that were blocked
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_transmit
                                    
                                    	No. of withdraw messages with split\-horizon flag that were sent out
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_blocked
                                    
                                    	No. of withdraw messages with split\-horizon flag that were blocked
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                        self.yang_name = "neighbor-af-performance-statistics"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sub_group_pending_message_count', (YLeaf(YType.uint32, 'sub-group-pending-message-count'), ['int'])),
                                            ('processed_messages', (YLeaf(YType.uint32, 'processed-messages'), ['int'])),
                                            ('sent_messages', (YLeaf(YType.uint32, 'sent-messages'), ['int'])),
                                            ('split_horizon_update_transmit', (YLeaf(YType.uint32, 'split-horizon-update-transmit'), ['int'])),
                                            ('split_horizon_update_blocked', (YLeaf(YType.uint32, 'split-horizon-update-blocked'), ['int'])),
                                            ('split_horizon_withdraw_transmit', (YLeaf(YType.uint32, 'split-horizon-withdraw-transmit'), ['int'])),
                                            ('split_horizon_withdraw_blocked', (YLeaf(YType.uint32, 'split-horizon-withdraw-blocked'), ['int'])),
                                        ])
                                        self.sub_group_pending_message_count = None
                                        self.processed_messages = None
                                        self.sent_messages = None
                                        self.split_horizon_update_transmit = None
                                        self.split_horizon_update_blocked = None
                                        self.split_horizon_withdraw_transmit = None
                                        self.split_horizon_withdraw_blocked = None
                                        self._segment_path = lambda: "neighbor-af-performance-statistics"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, [u'sub_group_pending_message_count', u'processed_messages', u'sent_messages', u'split_horizon_update_transmit', u'split_horizon_update_blocked', u'split_horizon_withdraw_transmit', u'split_horizon_withdraw_blocked'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity, [u'entry'], name, value)


                                class ExtendedCommunityStandby(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                        self.yang_name = "extended-community-standby"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community-standby"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                    class NextHopVrf(Entity):
                        """
                        A BGP Next\-hop VRF table entry
                        
                        .. attribute:: total_processing_time
                        
                        	Total time spent in processing
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_proc_notification_time
                        
                        	How long since the maximum processing time notifcation was received
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_deletes
                        
                        	Number of bestpath deletes caused by notification which resulted in maximum processing
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_changes
                        
                        	Number of bestpath changes caused by notification which resulted in maximum processing
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_processing_time
                        
                        	Maximum time spent procesing a single batch notification
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_notificationication_time
                        
                        	Time since the last notification was received
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_notification_processing_time
                        
                        	Processing time for the last notification
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf, self).__init__()

                            self.yang_name = "next-hop-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('total_processing_time', (YLeaf(YType.uint32, 'total-processing-time'), ['int'])),
                                ('max_proc_notification_time', (YLeaf(YType.uint32, 'max-proc-notification-time'), ['int'])),
                                ('max_notification_bestpath_deletes', (YLeaf(YType.uint32, 'max-notification-bestpath-deletes'), ['int'])),
                                ('max_notification_bestpath_changes', (YLeaf(YType.uint32, 'max-notification-bestpath-changes'), ['int'])),
                                ('maximum_processing_time', (YLeaf(YType.uint32, 'maximum-processing-time'), ['int'])),
                                ('last_notificationication_time', (YLeaf(YType.uint32, 'last-notificationication-time'), ['int'])),
                                ('last_notification_processing_time', (YLeaf(YType.uint32, 'last-notification-processing-time'), ['int'])),
                            ])
                            self.total_processing_time = None
                            self.max_proc_notification_time = None
                            self.max_notification_bestpath_deletes = None
                            self.max_notification_bestpath_changes = None
                            self.maximum_processing_time = None
                            self.last_notificationication_time = None
                            self.last_notification_processing_time = None
                            self._segment_path = lambda: "next-hop-vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NextHopVrf, [u'total_processing_time', u'max_proc_notification_time', u'max_notification_bestpath_deletes', u'max_notification_bestpath_changes', u'maximum_processing_time', u'last_notificationication_time', u'last_notification_processing_time'], name, value)


                    class NeighborRanges(Entity):
                        """
                        The BGP Dynamic Neighbor Range table
                        
                        .. attribute:: neighbor_range
                        
                        	A BGP Neighbor Range table entry
                        	**type**\: list of  		 :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges, self).__init__()

                            self.yang_name = "neighbor-ranges"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-range", ("neighbor_range", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange))])
                            self._leafs = OrderedDict()

                            self.neighbor_range = YList(self)
                            self._segment_path = lambda: "neighbor-ranges"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges, [], name, value)


                        class NeighborRange(Entity):
                            """
                            A BGP Neighbor Range table entry
                            
                            .. attribute:: neighbor_range_address  (key)
                            
                            	Neighbor Range prefix
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                            
                            .. attribute:: cfg_local_address
                            
                            	Configured local address
                            	**type**\:  :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\: str
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\: bool
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\: bool
                            
                            .. attribute:: neighbor_range_prefix_length
                            
                            	Neighbor Range Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\: bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\: bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\: bool
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\: bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\: bool
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\: bool
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\: bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\: bool
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\: bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\: str
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\: bool
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\: bool
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\: bool
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\: bool
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\: bool
                            
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\: bool
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\: bool
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\: bool
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\: bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\: bool
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\: bool
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\: bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\: bool
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\: bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\: bool
                            
                            .. attribute:: remote_as_list_name
                            
                            	Remote AS List Name
                            	**type**\: str
                            
                            .. attribute:: nbr_rcv_size
                            
                            	Nbr Receive Size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_send_size
                            
                            	Nbr Send Size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: islocal_address_cfg
                            
                            	Local address configured
                            	**type**\: bool
                            
                            .. attribute:: update_source
                            
                            	Update Source
                            	**type**\: str
                            
                            .. attribute:: addpath_send_enable
                            
                            	Addpath Send enabled
                            	**type**\: bool
                            
                            .. attribute:: addpath_receive_enable
                            
                            	Addpath Receive enable
                            	**type**\: bool
                            
                            .. attribute:: addpath_send_disable
                            
                            	Addpath Send Disabled
                            	**type**\: bool
                            
                            .. attribute:: addpath_receive_disable
                            
                            	Addpath Receive Disabled
                            	**type**\: bool
                            
                            .. attribute:: upd_errh_noreset
                            
                            	Update errh noreset
                            	**type**\: bool
                            
                            .. attribute:: msg_buf_count
                            
                            	Message Buf Count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_bug_circular
                            
                            	Message Buf Circular
                            	**type**\: bool
                            
                            .. attribute:: syslog_enable
                            
                            	syslog enable
                            	**type**\: bool
                            
                            .. attribute:: oper_attrf_enable
                            
                            	Oper attrf Enable
                            	**type**\: bool
                            
                            .. attribute:: attrf_group_name
                            
                            	Attrf Group Name
                            	**type**\: str
                            
                            .. attribute:: max_peers
                            
                            	Max Dynamic nbrs in range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: idle_watch_time
                            
                            	Dynamic Neighbor idle\-watch time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: current_peers
                            
                            	Current Dynamic nbrs in range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_match
                            
                            	Passive open matching range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_accepted
                            
                            	open accepted
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_max_drop
                            
                            	open drop due to max peers
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_inst_error
                            
                            	Error during instance creation
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData>`
                            
                            .. attribute:: instance
                            
                            	Dynamic Neighbor Instance List
                            	**type**\: list of  		 :py:class:`Instance_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange, self).__init__()

                                self.yang_name = "neighbor-range"
                                self.yang_parent_name = "neighbor-ranges"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_range_address']
                                self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance)), ("cfg-local-address", ("cfg_local_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData)), ("instance", ("instance", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_))])
                                self._leafs = OrderedDict([
                                    ('neighbor_range_address', (YLeaf(YType.str, 'neighbor-range-address'), ['str','str'])),
                                    ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                    ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                    ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                    ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                    ('neighbor_range_prefix_length', (YLeaf(YType.uint8, 'neighbor-range-prefix-length'), ['int'])),
                                    ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                    ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                    ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                    ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                    ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                    ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                    ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                    ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                    ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                    ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                    ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                    ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                    ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                    ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                    ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                    ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                    ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                    ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                    ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                    ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                    ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                    ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                    ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                    ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                    ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                    ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                    ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                    ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                    ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                    ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                    ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                    ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                    ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                    ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                    ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                    ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                    ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                    ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                    ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                    ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                    ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                    ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                    ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                    ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                    ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                    ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                    ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                    ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                    ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                    ('remote_as_list_name', (YLeaf(YType.str, 'remote-as-list-name'), ['str'])),
                                    ('nbr_rcv_size', (YLeaf(YType.uint32, 'nbr-rcv-size'), ['int'])),
                                    ('nbr_send_size', (YLeaf(YType.uint32, 'nbr-send-size'), ['int'])),
                                    ('islocal_address_cfg', (YLeaf(YType.boolean, 'islocal-address-cfg'), ['bool'])),
                                    ('update_source', (YLeaf(YType.str, 'update-source'), ['str'])),
                                    ('addpath_send_enable', (YLeaf(YType.boolean, 'addpath-send-enable'), ['bool'])),
                                    ('addpath_receive_enable', (YLeaf(YType.boolean, 'addpath-receive-enable'), ['bool'])),
                                    ('addpath_send_disable', (YLeaf(YType.boolean, 'addpath-send-disable'), ['bool'])),
                                    ('addpath_receive_disable', (YLeaf(YType.boolean, 'addpath-receive-disable'), ['bool'])),
                                    ('upd_errh_noreset', (YLeaf(YType.boolean, 'upd-errh-noreset'), ['bool'])),
                                    ('msg_buf_count', (YLeaf(YType.uint32, 'msg-buf-count'), ['int'])),
                                    ('msg_bug_circular', (YLeaf(YType.boolean, 'msg-bug-circular'), ['bool'])),
                                    ('syslog_enable', (YLeaf(YType.boolean, 'syslog-enable'), ['bool'])),
                                    ('oper_attrf_enable', (YLeaf(YType.boolean, 'oper-attrf-enable'), ['bool'])),
                                    ('attrf_group_name', (YLeaf(YType.str, 'attrf-group-name'), ['str'])),
                                    ('max_peers', (YLeaf(YType.uint32, 'max-peers'), ['int'])),
                                    ('idle_watch_time', (YLeaf(YType.uint32, 'idle-watch-time'), ['int'])),
                                    ('current_peers', (YLeaf(YType.uint32, 'current-peers'), ['int'])),
                                    ('range_open_match', (YLeaf(YType.uint32, 'range-open-match'), ['int'])),
                                    ('range_open_accepted', (YLeaf(YType.uint32, 'range-open-accepted'), ['int'])),
                                    ('range_max_drop', (YLeaf(YType.uint32, 'range-max-drop'), ['int'])),
                                    ('range_inst_error', (YLeaf(YType.uint32, 'range-inst-error'), ['int'])),
                                ])
                                self.neighbor_range_address = None
                                self.speaker_id = None
                                self.description = None
                                self.local_as = None
                                self.remote_as = None
                                self.has_internal_link = None
                                self.is_local_address_configured = None
                                self.neighbor_range_prefix_length = None
                                self.is_administratively_shut_down = None
                                self.is_neighbor_max_prefix_shutdown = None
                                self.is_out_of_memory_forced_up = None
                                self.ttl_security_enabled = None
                                self.suppress4_byte_as = None
                                self.bfd_session_enable_mode = None
                                self.bfd_minintervalval = None
                                self.bfd_multiplierval = None
                                self.ebgp_time_to_live = None
                                self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                self.tcpmss = None
                                self.msg_log_in = None
                                self.msg_log_out = None
                                self.neighbor_local_as = None
                                self.local_as_no_prepend = None
                                self.is_capability_negotiation_performed = None
                                self.configured_hold_time = None
                                self.configured_keepalive = None
                                self.configured_min_acc_hold_time = None
                                self.min_advertise_interval = None
                                self.min_advertise_interval_msecs = None
                                self.min_origination_interval = None
                                self.remote_as_number = None
                                self.dmz_link_bandwidth = None
                                self.ebgp_recv_dmz = None
                                self.ebgp_send_dmz_mode = None
                                self.tos_type = None
                                self.tos_value = None
                                self.tcp_session_open_mode = None
                                self.vrf_name = None
                                self.standby_rp = None
                                self.nsr_enabled = None
                                self.graceful_restart_enabled_nbr = None
                                self.gr_restart_time = None
                                self.gr_stale_path_time = None
                                self.is_passive_close = None
                                self.nbr_enforce_first_as = None
                                self.active_bmp_servers = None
                                self.nbr_cluster_id = None
                                self.nbr_in_cluster = None
                                self.ignore_connected = None
                                self.internal_vpn_client = None
                                self.local_as_replace_as = None
                                self.local_as_dual_as = None
                                self.local_as_dual_as_mode_native = None
                                self.egress_peer_engineering_enabled = None
                                self.discard_as4_path = None
                                self.rpki_disable = None
                                self.rpki_use_validity = None
                                self.rpki_allow_invalid = None
                                self.rpki_signal_ibgp = None
                                self.remote_as_list_name = None
                                self.nbr_rcv_size = None
                                self.nbr_send_size = None
                                self.islocal_address_cfg = None
                                self.update_source = None
                                self.addpath_send_enable = None
                                self.addpath_receive_enable = None
                                self.addpath_send_disable = None
                                self.addpath_receive_disable = None
                                self.upd_errh_noreset = None
                                self.msg_buf_count = None
                                self.msg_bug_circular = None
                                self.syslog_enable = None
                                self.oper_attrf_enable = None
                                self.attrf_group_name = None
                                self.max_peers = None
                                self.idle_watch_time = None
                                self.current_peers = None
                                self.range_open_match = None
                                self.range_open_accepted = None
                                self.range_max_drop = None
                                self.range_inst_error = None

                                self.connection_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                self.cfg_local_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                self.cfg_local_address.parent = self
                                self._children_name_map["cfg_local_address"] = "cfg-local-address"

                                self.af_data = YList(self)
                                self.instance = YList(self)
                                self._segment_path = lambda: "neighbor-range" + "[neighbor-range-address='" + str(self.neighbor_range_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange, ['neighbor_range_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_local_address_configured', u'neighbor_range_prefix_length', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_forced_up', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_performed', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'remote_as_list_name', u'nbr_rcv_size', u'nbr_send_size', u'islocal_address_cfg', u'update_source', u'addpath_send_enable', u'addpath_receive_enable', u'addpath_send_disable', u'addpath_receive_disable', u'upd_errh_noreset', u'msg_buf_count', u'msg_bug_circular', u'syslog_enable', u'oper_attrf_enable', u'attrf_group_name', u'max_peers', u'idle_watch_time', u'current_peers', u'range_open_match', u'range_open_accepted', u'range_max_drop', u'range_inst_error'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-local-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-remote-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class GracefulMaintenance(Entity):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\: bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\: bool
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\: bool
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\: bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance, self).__init__()

                                    self.yang_name = "graceful-maintenance"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                        ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                        ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                        ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                        ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                        ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                    ])
                                    self.gshut_exists = None
                                    self.gshut_local_active = None
                                    self.gshut_active = None
                                    self.gshut_locpref_set = None
                                    self.gshut_locpref = None
                                    self.gshut_prepends = None
                                    self._segment_path = lambda: "graceful-maintenance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                            class CfgLocalAddress(Entity):
                                """
                                Configured local address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress, self).__init__()

                                    self.yang_name = "cfg-local-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "cfg-local-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfData(Entity):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\: bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\: bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\: bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\: bool
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\: bool
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\: str
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_local
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\: bool
                                
                                .. attribute:: next_hop_unchanged
                                
                                	router does not change next\-hop
                                	**type**\: bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\: bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\: bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\: bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\: bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\: bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\: bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\: bool
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\: bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\: bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\: bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\: bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\: bool
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\: str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\: str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\: str
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\: str
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\: bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\: bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\: bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\: bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\: bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\: bool
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\: bool
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\: bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\: bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\: bool
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\: bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\: bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\: bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\: bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\: bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\: bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\: bool
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: enable_label_stack
                                
                                	Enable label stack
                                	**type**\: bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData, self).__init__()

                                    self.yang_name = "af-data"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                        ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                        ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                        ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                        ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                        ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                        ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                        ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                        ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                        ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                        ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                        ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                        ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                        ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                        ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                        ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                        ('advertise_afi_local', (YLeaf(YType.boolean, 'advertise-afi-local'), ['bool'])),
                                        ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                        ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                        ('next_hop_unchanged', (YLeaf(YType.boolean, 'next-hop-unchanged'), ['bool'])),
                                        ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                        ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                        ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                        ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                        ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                        ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                        ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                        ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                        ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                        ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                        ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                        ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                        ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                        ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                        ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                        ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                        ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                        ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                        ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                        ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                        ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                        ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                        ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                        ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                        ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                        ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                        ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                        ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                        ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                        ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                        ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                        ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                        ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                        ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                        ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                        ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                        ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                        ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                        ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                        ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                        ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                        ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                        ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                        ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                        ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                        ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                        ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                        ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                        ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                        ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                        ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                        ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                        ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                        ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                        ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                        ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                        ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                        ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                        ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                        ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                        ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                        ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                        ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                        ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                        ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                        ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                        ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                        ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                    ])
                                    self.af_name = None
                                    self.is_neighbor_route_reflector_client = None
                                    self.is_legacy_pe_rt = None
                                    self.is_neighbor_af_capable = None
                                    self.is_soft_reconfiguration_inbound_allowed = None
                                    self.is_use_soft_reconfiguration_always_on = None
                                    self.remove_private_as_from_updates = None
                                    self.remove_private_as_entire_aspath_from_updates = None
                                    self.remove_private_as_from_inbound_updates = None
                                    self.remove_private_as_entire_aspath_from_inbound_updates = None
                                    self.flowspec_validation_d_isable = None
                                    self.flowspec_redirect_validation_d_isable = None
                                    self.orr_group_name = None
                                    self.orr_group_index = None
                                    self.is_orr_root_address_configured = None
                                    self.advertise_afi = None
                                    self.advertise_afi_reorg = None
                                    self.advertise_afi_local = None
                                    self.advertise_afi_disable = None
                                    self.always_use_next_hop_local = None
                                    self.next_hop_unchanged = None
                                    self.sent_community_to_neighbor = None
                                    self.sent_gshut_community_to_neighbor = None
                                    self.sent_extended_community_to_neighbor = None
                                    self.neighbor_default_originate = None
                                    self.is_orf_sent = None
                                    self.is_update_deferred = None
                                    self.is_orf_send_scheduled = None
                                    self.vpn_update_gen_enabled = None
                                    self.vpn_update_gen_trigger_enabled = None
                                    self.is_addpath_send_operational = None
                                    self.is_addpath_receive_operational = None
                                    self.weight = None
                                    self.max_prefix_limit = None
                                    self.use_max_prefix_warning_only = None
                                    self.max_prefix_discard_extra_paths = None
                                    self.max_prefix_exceed_discard_paths = None
                                    self.max_prefix_threshold_percent = None
                                    self.max_prefix_restart_time = None
                                    self.is_peer_orf_capable = None
                                    self.is_advertised_orf_send = None
                                    self.is_received_orf_send_capable = None
                                    self.is_advertised_orf_receive = None
                                    self.is_received_orf_receive_capable = None
                                    self.is_advertised_graceful_restart = None
                                    self.is_graceful_restart_state_flag = None
                                    self.is_received_graceful_restart_capable = None
                                    self.is_add_path_send_capability_advertised = None
                                    self.is_add_path_send_capability_received = None
                                    self.is_add_path_receive_capability_advertised = None
                                    self.is_add_path_receive_capability_received = None
                                    self.restart_time = None
                                    self.local_restart_time = None
                                    self.stale_path_timeout = None
                                    self.rib_purge_timeout_value = None
                                    self.neighbor_preserved_forwarding_state = None
                                    self.long_lived_graceful_restart_stale_time_configured = None
                                    self.long_lived_graceful_restart_stale_time_sent = None
                                    self.long_lived_graceful_restart_stale_time_accept = None
                                    self.long_lived_graceful_restart_capability_received = None
                                    self.long_lived_graceful_restart_stale_time_received = None
                                    self.neighbor_preserved_long_lived_forwarding_state = None
                                    self.neighbor_long_lived_graceful_restart_capable = None
                                    self.neighbor_long_lived_graceful_restart_time_remaining = None
                                    self.is_prefix_orf_present = None
                                    self.orf_entries_received = None
                                    self.route_policy_prefix_orf = None
                                    self.route_policy_in = None
                                    self.route_policy_out = None
                                    self.route_policy_default_originate = None
                                    self.is_neighbor_ebgp_without_inbound_policy = None
                                    self.is_neighbor_ebgp_without_outbound_policy = None
                                    self.is_as_override_set = None
                                    self.is_allow_as_in_set = None
                                    self.allow_as_in_count = None
                                    self.address_family_long_lived_time = None
                                    self.is_aigp_set = None
                                    self.is_rt_present = None
                                    self.is_rt_present_standby = None
                                    self.accept_own_enabled = None
                                    self.selective_multipath_eligible = None
                                    self.afrpki_disable = None
                                    self.afrpki_use_validity = None
                                    self.afrpki_allow_invalid = None
                                    self.afrpki_signal_ibgp = None
                                    self.is_advertise_permanent_network = None
                                    self.is_send_mcast_attr = None
                                    self.import_stitching = None
                                    self.import_reoriginate = None
                                    self.import_reoriginate_stitching = None
                                    self.advertise_v4_flags = None
                                    self.advertise_v6_flags = None
                                    self.enable_label_stack = None

                                    self.extended_community = YList(self)
                                    self.extended_community_standby = YList(self)
                                    self._segment_path = lambda: "af-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_local', u'advertise_afi_disable', u'always_use_next_hop_local', u'next_hop_unchanged', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'is_prefix_orf_present', u'orf_entries_received', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'enable_label_stack'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, [u'entry'], name, value)


                                class ExtendedCommunityStandby(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, self).__init__()

                                        self.yang_name = "extended-community-standby"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community-standby"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                            class Instance_(Entity):
                                """
                                Dynamic Neighbor Instance List
                                
                                .. attribute:: neighbor_address
                                
                                	Dynamic Neighbor address
                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress>`
                                
                                .. attribute:: neighbor_age
                                
                                	Neighbor age
                                	**type**\:  :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge>`
                                
                                .. attribute:: idle_watch_timer_remaining_value
                                
                                	Idle watch timer remaining time
                                	**type**\:  :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue>`
                                
                                .. attribute:: is_idle_watch_timer_running
                                
                                	Is idle watch timer running
                                	**type**\: bool
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_, self).__init__()

                                    self.yang_name = "instance"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress)), ("neighbor-age", ("neighbor_age", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge)), ("idle-watch-timer-remaining-value", ("idle_watch_timer_remaining_value", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue))])
                                    self._leafs = OrderedDict([
                                        ('is_idle_watch_timer_running', (YLeaf(YType.boolean, 'is-idle-watch-timer-running'), ['bool'])),
                                        ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                    ])
                                    self.is_idle_watch_timer_running = None
                                    self.connection_state = None

                                    self.neighbor_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                    self.neighbor_age = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge()
                                    self.neighbor_age.parent = self
                                    self._children_name_map["neighbor_age"] = "neighbor-age"

                                    self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue()
                                    self.idle_watch_timer_remaining_value.parent = self
                                    self._children_name_map["idle_watch_timer_remaining_value"] = "idle-watch-timer-remaining-value"
                                    self._segment_path = lambda: "instance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_, [u'is_idle_watch_timer_running', u'connection_state'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Dynamic Neighbor address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "neighbor-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NeighborAge(Entity):
                                    """
                                    Neighbor age
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge, self).__init__()

                                        self.yang_name = "neighbor-age"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "neighbor-age"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge, [u'seconds', u'nanoseconds'], name, value)


                                class IdleWatchTimerRemainingValue(Entity):
                                    """
                                    Idle watch timer remaining time
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue, self).__init__()

                                        self.yang_name = "idle-watch-timer-remaining-value"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "idle-watch-timer-remaining-value"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue, [u'seconds', u'nanoseconds'], name, value)


                    class MessageLogs(Entity):
                        """
                        The BGP Neighbor Message table
                        
                        .. attribute:: message_log
                        
                        	A BGP Message log entry
                        	**type**\: list of  		 :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs, self).__init__()

                            self.yang_name = "message-logs"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("message-log", ("message_log", Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog))])
                            self._leafs = OrderedDict()

                            self.message_log = YList(self)
                            self._segment_path = lambda: "message-logs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs, [], name, value)


                        class MessageLog(Entity):
                            """
                            A BGP Message log entry
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: direction
                            
                            	Direction
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_message
                            
                            	Array of Neighbor Messages in one direction
                            	**type**\: list of  		 :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog, self).__init__()

                                self.yang_name = "message-log"
                                self.yang_parent_name = "message-logs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-message", ("neighbor_message", Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('direction', (YLeaf(YType.uint32, 'direction'), ['int'])),
                                ])
                                self.neighbor_address = None
                                self.direction = None

                                self.neighbor_message = YList(self)
                                self._segment_path = lambda: "message-log"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog, ['neighbor_address', 'direction'], name, value)


                            class NeighborMessage(Entity):
                                """
                                Array of Neighbor Messages in one direction
                                
                                .. attribute:: message_timestamp
                                
                                	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                
                                .. attribute:: message_type_received
                                
                                	Type of messages Received
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: total_logged_message_count
                                
                                	Total logged messages count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: message_data_length
                                
                                	Message data length
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: logged_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of  		 :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage, self).__init__()

                                    self.yang_name = "neighbor-message"
                                    self.yang_parent_name = "message-log"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("message-timestamp", ("message_timestamp", Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp)), ("logged-message-data", ("logged_message_data", Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData))])
                                    self._leafs = OrderedDict([
                                        ('message_type_received', (YLeaf(YType.uint8, 'message-type-received'), ['int'])),
                                        ('total_logged_message_count', (YLeaf(YType.uint32, 'total-logged-message-count'), ['int'])),
                                        ('message_data_length', (YLeaf(YType.uint16, 'message-data-length'), ['int'])),
                                    ])
                                    self.message_type_received = None
                                    self.total_logged_message_count = None
                                    self.message_data_length = None

                                    self.message_timestamp = Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                    self.message_timestamp.parent = self
                                    self._children_name_map["message_timestamp"] = "message-timestamp"

                                    self.logged_message_data = YList(self)
                                    self._segment_path = lambda: "neighbor-message"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage, [u'message_type_received', u'total_logged_message_count', u'message_data_length'], name, value)


                                class MessageTimestamp(Entity):
                                    """
                                    message received time\: time elapsed since 00\:00
                                    \:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, self).__init__()

                                        self.yang_name = "message-timestamp"
                                        self.yang_parent_name = "neighbor-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "message-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LoggedMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, self).__init__()

                                        self.yang_name = "logged-message-data"
                                        self.yang_parent_name = "neighbor-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "logged-message-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, [u'entry'], name, value)


                class UpdateInboundFilterProcess(Entity):
                    """
                    Update inbound filtering information for the
                    process
                    
                    .. attribute:: last_update_filtered_timestamp
                    
                    	Last filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:  :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp>`
                    
                    .. attribute:: update_filtered_message_count
                    
                    	Filtered messages count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_filtered_neighbor_count
                    
                    	Count of neighbors that received filtered messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_update_filtered_age
                    
                    	Time since last filtered messages received event (in seconds)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess, self).__init__()

                        self.yang_name = "update-inbound-filter-process"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("last-update-filtered-timestamp", ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp))])
                        self._leafs = OrderedDict([
                            ('update_filtered_message_count', (YLeaf(YType.uint32, 'update-filtered-message-count'), ['int'])),
                            ('update_filtered_neighbor_count', (YLeaf(YType.uint32, 'update-filtered-neighbor-count'), ['int'])),
                            ('last_update_filtered_age', (YLeaf(YType.uint32, 'last-update-filtered-age'), ['int'])),
                        ])
                        self.update_filtered_message_count = None
                        self.update_filtered_neighbor_count = None
                        self.last_update_filtered_age = None

                        self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp()
                        self.last_update_filtered_timestamp.parent = self
                        self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                        self._segment_path = lambda: "update-inbound-filter-process"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess, [u'update_filtered_message_count', u'update_filtered_neighbor_count', u'last_update_filtered_age'], name, value)


                    class LastUpdateFilteredTimestamp(Entity):
                        """
                        Last filtered messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp, self).__init__()

                            self.yang_name = "last-update-filtered-timestamp"
                            self.yang_parent_name = "update-inbound-filter-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nanoseconds = None
                            self._segment_path = lambda: "last-update-filtered-timestamp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                class Attributes(Entity):
                    """
                    The BGP Attribute table
                    
                    .. attribute:: attribute
                    
                    	A BGP Attribute table entry
                    	**type**\: list of  		 :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.Attributes, self).__init__()

                        self.yang_name = "attributes"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attribute", ("attribute", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute))])
                        self._leafs = OrderedDict()

                        self.attribute = YList(self)
                        self._segment_path = lambda: "attributes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes, [], name, value)


                    class Attribute(Entity):
                        """
                        A BGP Attribute table entry
                        
                        .. attribute:: attribute_iid
                        
                        	Attribute IID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_cache_bucket
                        
                        	Attribute cache bucket
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_cache_id
                        
                        	Attribute cache ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_info
                        
                        	Attributes
                        	**type**\:  :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo>`
                        
                        .. attribute:: process_instance_id
                        
                        	Process instance ID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: attribute_instance_id
                        
                        	Attribute Instance ID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: attribute_structure_id
                        
                        	ID of attribute structure
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_structure_hash_value
                        
                        	Hash value for attribute structure
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reference_count
                        
                        	Number of paths which use this attribute structure
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute, self).__init__()

                            self.yang_name = "attribute"
                            self.yang_parent_name = "attributes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("attribute-info", ("attribute_info", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo))])
                            self._leafs = OrderedDict([
                                ('attribute_iid', (YLeaf(YType.uint32, 'attribute-iid'), ['int'])),
                                ('attribute_cache_bucket', (YLeaf(YType.uint32, 'attribute-cache-bucket'), ['int'])),
                                ('attribute_cache_id', (YLeaf(YType.uint32, 'attribute-cache-id'), ['int'])),
                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                ('attribute_instance_id', (YLeaf(YType.uint8, 'attribute-instance-id'), ['int'])),
                                ('attribute_structure_id', (YLeaf(YType.uint32, 'attribute-structure-id'), ['int'])),
                                ('attribute_structure_hash_value', (YLeaf(YType.uint32, 'attribute-structure-hash-value'), ['int'])),
                                ('reference_count', (YLeaf(YType.uint32, 'reference-count'), ['int'])),
                            ])
                            self.attribute_iid = None
                            self.attribute_cache_bucket = None
                            self.attribute_cache_id = None
                            self.process_instance_id = None
                            self.attribute_instance_id = None
                            self.attribute_structure_id = None
                            self.attribute_structure_hash_value = None
                            self.reference_count = None

                            self.attribute_info = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo()
                            self.attribute_info.parent = self
                            self._children_name_map["attribute_info"] = "attribute-info"
                            self._segment_path = lambda: "attribute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute, ['attribute_iid', 'attribute_cache_bucket', 'attribute_cache_id', u'process_instance_id', u'attribute_instance_id', u'attribute_structure_id', u'attribute_structure_hash_value', u'reference_count'], name, value)


                        class AttributeInfo(Entity):
                            """
                            Attributes
                            
                            .. attribute:: common_attributes
                            
                            	Common attributes
                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                            
                            .. attribute:: attr_set
                            
                            	ATTR\_SET attribute
                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet>`
                            
                            .. attribute:: rnh_addr
                            
                            	RNH Address
                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr>`
                            
                            .. attribute:: ribrnh_ip
                            
                            	RIB RNH IP Address
                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                            
                            .. attribute:: is_as_path2_byte
                            
                            	AS path encoded as 2\-byte
                            	**type**\: bool
                            
                            .. attribute:: is_application_gateway_present
                            
                            	Application gateway present
                            	**type**\: bool
                            
                            .. attribute:: is_attr_set_present
                            
                            	BGP ATTR\_SET attribute present
                            	**type**\: bool
                            
                            .. attribute:: set_aigp_inbound_igp
                            
                            	AIGP set by policy inbound IGP 
                            	**type**\: bool
                            
                            .. attribute:: set_aigp_inbound_metric
                            
                            	AIGP set by policy inbound metric
                            	**type**\: bool
                            
                            .. attribute:: is_rnh_present
                            
                            	RNH Attribute  present
                            	**type**\: bool
                            
                            .. attribute:: is_ribrnh_present
                            
                            	RIB RNH Attribute  present
                            	**type**\: bool
                            
                            .. attribute:: attribute_key_number
                            
                            	Attribute key number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_config
                            
                            	Attribute reuse ID Configured
                            	**type**\: bool
                            
                            .. attribute:: attribute_reuse_id_max_id
                            
                            	Attribute reuse ID maximum ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_node
                            
                            	Attribute reuse ID nodes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_current
                            
                            	Attribute reuse ID current ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_keys
                            
                            	Attribute reuse ID allocated keys
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_recover_sec
                            
                            	Attribute reuse ID timer in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: vpn_distinguisher
                            
                            	VPN Distinguisher
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rnh_type
                            
                            	RNH Type
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: rnh_len
                            
                            	RNH Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: rnh_addr_len
                            
                            	RNH Address Length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_table
                            
                            	RIB RNH Table
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_mac
                            
                            	RIB RNH MAC Address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: ribrnhip_table
                            
                            	RIB RNH IP Table
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_vni
                            
                            	RIB RNH Vni
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_encap
                            
                            	RIB RNH Encapsulation Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo, self).__init__()

                                self.yang_name = "attribute-info"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp))])
                                self._leafs = OrderedDict([
                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                ])
                                self.is_as_path2_byte = None
                                self.is_application_gateway_present = None
                                self.is_attr_set_present = None
                                self.set_aigp_inbound_igp = None
                                self.set_aigp_inbound_metric = None
                                self.is_rnh_present = None
                                self.is_ribrnh_present = None
                                self.attribute_key_number = None
                                self.attribute_reuse_id_config = None
                                self.attribute_reuse_id_max_id = None
                                self.attribute_reuse_id_node = None
                                self.attribute_reuse_id_current = None
                                self.attribute_reuse_id_keys = None
                                self.attribute_reuse_id_recover_sec = None
                                self.vpn_distinguisher = None
                                self.rnh_type = None
                                self.rnh_len = None
                                self.rnh_addr_len = None
                                self.ribrnh_table = None
                                self.ribrnh_mac = None
                                self.ribrnhip_table = None
                                self.ribrnh_vni = None
                                self.ribrnh_encap = None

                                self.common_attributes = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                self.common_attributes.parent = self
                                self._children_name_map["common_attributes"] = "common-attributes"

                                self.attr_set = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet()
                                self.attr_set.parent = self
                                self._children_name_map["attr_set"] = "attr-set"

                                self.rnh_addr = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr()
                                self.rnh_addr.parent = self
                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                self.ribrnh_ip.parent = self
                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                self._segment_path = lambda: "attribute-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                            class CommonAttributes(Entity):
                                """
                                Common attributes
                                
                                .. attribute:: prefix_sid_attr
                                
                                	Prefix SID attribute
                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr>`
                                
                                .. attribute:: tunnel_encap
                                
                                	Tunnel Encapsulation attribute
                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\: bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\: bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\: bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\: bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\: bool
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\: str
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_large_community_present
                                
                                	Large Community attribute present
                                	**type**\: bool
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie>`
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                
                                .. attribute:: large_community
                                
                                	Large Community attribute
                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                    self.yang_name = "common-attributes"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity))])
                                    self._leafs = OrderedDict([
                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                    ])
                                    self.is_metric_present = None
                                    self.is_local_pref_present = None
                                    self.is_atomic_aggregate_present = None
                                    self.is_aggregator_present = None
                                    self.is_origin_present = None
                                    self.is_as_path_present = None
                                    self.is_community_present = None
                                    self.is_extended_community_present = None
                                    self.is_ssa_present = None
                                    self.is_connector_present = None
                                    self.is_pmsi_present = None
                                    self.is_pppmp_present = None
                                    self.is_aigp_present = None
                                    self.is_pe_distinguisher_label_present = None
                                    self.is_ls_attribute_present = None
                                    self.is_label_index_present = None
                                    self.neighbor_as = None
                                    self.aggregator_as = None
                                    self.aggregator_address = None
                                    self.metric = None
                                    self.local_preference = None
                                    self.origin = None
                                    self.as_path = None
                                    self.extended_community_flags = None
                                    self.originator = None
                                    self.l2tpv3_session_id = None
                                    self.connector_type = None
                                    self.aigp_metric_value = None
                                    self.pmsi_type = None
                                    self.pmsi_flags = None
                                    self.pmsi_label = None
                                    self.ppm_pvalue = None
                                    self.is_large_community_present = None

                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr()
                                    self.prefix_sid_attr.parent = self
                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                    self.tunnel_encap.parent = self
                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                    self.community = YList(self)
                                    self.extended_community = YList(self)
                                    self.unknown_attribute = YList(self)
                                    self.cluster = YList(self)
                                    self.l2tpv3_cookie = YList(self)
                                    self.connector_value = YList(self)
                                    self.pmsi_value = YList(self)
                                    self.ls_attr = YList(self)
                                    self.pe_distinguisher_label = YList(self)
                                    self.large_community = YList(self)
                                    self._segment_path = lambda: "common-attributes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                class PrefixSidAttr(Entity):
                                    """
                                    Prefix SID attribute
                                    
                                    .. attribute:: prefix_sid_tlv
                                    
                                    	Prefix SID TLV array
                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, self).__init__()

                                        self.yang_name = "prefix-sid-attr"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                        self._leafs = OrderedDict()

                                        self.prefix_sid_tlv = YList(self)
                                        self._segment_path = lambda: "prefix-sid-attr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, [], name, value)


                                    class PrefixSidTlv(Entity):
                                        """
                                        Prefix SID TLV array
                                        
                                        .. attribute:: type
                                        
                                        	Prefix SID TLV type field
                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                        
                                        .. attribute:: len
                                        
                                        	Prefix SID TLV Length in bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: val
                                        
                                        	Prefix SID TLV value string
                                        	**type**\: str
                                        
                                        	**length:** 0..46
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                            self.yang_name = "prefix-sid-tlv"
                                            self.yang_parent_name = "prefix-sid-attr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                            ])
                                            self.type = None
                                            self.len = None
                                            self.val = None
                                            self._segment_path = lambda: "prefix-sid-tlv"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                class TunnelEncap(Entity):
                                    """
                                    Tunnel Encapsulation attribute
                                    
                                    .. attribute:: sr_policy
                                    
                                    	Tunnel encap type SR policy
                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                        self.yang_name = "tunnel-encap"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy))])
                                        self._leafs = OrderedDict()

                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                        self.sr_policy.parent = self
                                        self._children_name_map["sr_policy"] = "sr-policy"
                                        self._segment_path = lambda: "tunnel-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, [], name, value)


                                    class SrPolicy(Entity):
                                        """
                                        Tunnel encap type SR policy
                                        
                                        .. attribute:: binding_sid
                                        
                                        	SR Policy incoming Binding sid
                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                        
                                        .. attribute:: allocated_binding_sid
                                        
                                        	SR Policy allocated Binding sid by the router
                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                        
                                        .. attribute:: tunnel_encap_type
                                        
                                        	Tunnel Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: preference
                                        
                                        	SR Policy Preference
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state
                                        
                                        	SR Policy active state in forwarding
                                        	**type**\: bool
                                        
                                        .. attribute:: request_state
                                        
                                        	SR Policy programming Status
                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                        
                                        .. attribute:: usable
                                        
                                        	SR Policy is usable on this node
                                        	**type**\: bool
                                        
                                        .. attribute:: segment_list
                                        
                                        	SR Policy Segment Lists
                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                            self.yang_name = "sr-policy"
                                            self.yang_parent_name = "tunnel-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                            self._leafs = OrderedDict([
                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                            ])
                                            self.tunnel_encap_type = None
                                            self.preference = None
                                            self.state = None
                                            self.request_state = None
                                            self.usable = None

                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                            self.binding_sid.parent = self
                                            self._children_name_map["binding_sid"] = "binding-sid"

                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                            self.allocated_binding_sid.parent = self
                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                            self.segment_list = YList(self)
                                            self._segment_path = lambda: "sr-policy"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                        class BindingSid(Entity):
                                            """
                                            SR Policy incoming Binding sid
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                self.yang_name = "binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.type = None
                                                self.label = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "binding-sid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                        class AllocatedBindingSid(Entity):
                                            """
                                            SR Policy allocated Binding sid by the router
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                self.yang_name = "allocated-binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.type = None
                                                self.label = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "allocated-binding-sid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                        class SegmentList(Entity):
                                            """
                                            SR Policy Segment Lists
                                            
                                            .. attribute:: weight
                                            
                                            	Weight of segment list
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: segment
                                            
                                            	Segments in segment list
                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                self.yang_name = "segment-list"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                self._leafs = OrderedDict([
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.weight = None

                                                self.segment = YList(self)
                                                self._segment_path = lambda: "segment-list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                            class Segment(Entity):
                                                """
                                                Segments in segment list
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address value
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address value
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                    self.yang_name = "segment"
                                                    self.yang_parent_name = "segment-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.type = None
                                                    self.label = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "segment"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                class Community(Entity):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, [u'entry'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                class UnknownAttribute(Entity):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                        self.yang_name = "unknown-attribute"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "unknown-attribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                class Cluster(Entity):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                        self.yang_name = "cluster"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "cluster"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, [u'entry'], name, value)


                                class L2tpv3Cookie(Entity):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, self).__init__()

                                        self.yang_name = "l2tpv3-cookie"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "l2tpv3-cookie"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                class ConnectorValue(Entity):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                        self.yang_name = "connector-value"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "connector-value"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                class PmsiValue(Entity):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                        self.yang_name = "pmsi-value"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "pmsi-value"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                class LsAttr(Entity):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                        self.yang_name = "ls-attr"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "ls-attr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, [u'entry'], name, value)


                                class PeDistinguisherLabel(Entity):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                        self.yang_name = "pe-distinguisher-label"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                        ])
                                        self.pe_address = None
                                        self.label = None
                                        self._segment_path = lambda: "pe-distinguisher-label"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                class LargeCommunity(Entity):
                                    """
                                    Large Community attribute
                                    
                                    .. attribute:: global_admin
                                    
                                    	Global Administrator
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data1
                                    
                                    	Local Data 1
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data2
                                    
                                    	Local Data 2
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                        self.yang_name = "large-community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                        ])
                                        self.global_admin = None
                                        self.local_data1 = None
                                        self.local_data2 = None
                                        self._segment_path = lambda: "large-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                            class AttrSet(Entity):
                                """
                                ATTR\_SET attribute
                                
                                .. attribute:: prefix_sid_attr
                                
                                	Prefix SID attribute
                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr>`
                                
                                .. attribute:: tunnel_encap
                                
                                	Tunnel Encapsulation attribute
                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\: bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\: bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\: bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\: bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\: bool
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\: str
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_large_community_present
                                
                                	Large Community attribute present
                                	**type**\: bool
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie>`
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                
                                .. attribute:: large_community
                                
                                	Large Community attribute
                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                    self.yang_name = "attr-set"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity))])
                                    self._leafs = OrderedDict([
                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                    ])
                                    self.is_metric_present = None
                                    self.is_local_pref_present = None
                                    self.is_atomic_aggregate_present = None
                                    self.is_aggregator_present = None
                                    self.is_origin_present = None
                                    self.is_as_path_present = None
                                    self.is_community_present = None
                                    self.is_extended_community_present = None
                                    self.is_ssa_present = None
                                    self.is_connector_present = None
                                    self.is_pmsi_present = None
                                    self.is_pppmp_present = None
                                    self.is_aigp_present = None
                                    self.is_pe_distinguisher_label_present = None
                                    self.is_ls_attribute_present = None
                                    self.is_label_index_present = None
                                    self.neighbor_as = None
                                    self.aggregator_as = None
                                    self.aggregator_address = None
                                    self.metric = None
                                    self.local_preference = None
                                    self.origin = None
                                    self.as_path = None
                                    self.extended_community_flags = None
                                    self.originator = None
                                    self.l2tpv3_session_id = None
                                    self.connector_type = None
                                    self.aigp_metric_value = None
                                    self.pmsi_type = None
                                    self.pmsi_flags = None
                                    self.pmsi_label = None
                                    self.ppm_pvalue = None
                                    self.is_large_community_present = None

                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr()
                                    self.prefix_sid_attr.parent = self
                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                    self.tunnel_encap.parent = self
                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                    self.community = YList(self)
                                    self.extended_community = YList(self)
                                    self.unknown_attribute = YList(self)
                                    self.cluster = YList(self)
                                    self.l2tpv3_cookie = YList(self)
                                    self.connector_value = YList(self)
                                    self.pmsi_value = YList(self)
                                    self.ls_attr = YList(self)
                                    self.pe_distinguisher_label = YList(self)
                                    self.large_community = YList(self)
                                    self._segment_path = lambda: "attr-set"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                class PrefixSidAttr(Entity):
                                    """
                                    Prefix SID attribute
                                    
                                    .. attribute:: prefix_sid_tlv
                                    
                                    	Prefix SID TLV array
                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, self).__init__()

                                        self.yang_name = "prefix-sid-attr"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                        self._leafs = OrderedDict()

                                        self.prefix_sid_tlv = YList(self)
                                        self._segment_path = lambda: "prefix-sid-attr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, [], name, value)


                                    class PrefixSidTlv(Entity):
                                        """
                                        Prefix SID TLV array
                                        
                                        .. attribute:: type
                                        
                                        	Prefix SID TLV type field
                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                        
                                        .. attribute:: len
                                        
                                        	Prefix SID TLV Length in bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: val
                                        
                                        	Prefix SID TLV value string
                                        	**type**\: str
                                        
                                        	**length:** 0..46
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                            self.yang_name = "prefix-sid-tlv"
                                            self.yang_parent_name = "prefix-sid-attr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                            ])
                                            self.type = None
                                            self.len = None
                                            self.val = None
                                            self._segment_path = lambda: "prefix-sid-tlv"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                class TunnelEncap(Entity):
                                    """
                                    Tunnel Encapsulation attribute
                                    
                                    .. attribute:: sr_policy
                                    
                                    	Tunnel encap type SR policy
                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                        self.yang_name = "tunnel-encap"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy))])
                                        self._leafs = OrderedDict()

                                        self.sr_policy = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                        self.sr_policy.parent = self
                                        self._children_name_map["sr_policy"] = "sr-policy"
                                        self._segment_path = lambda: "tunnel-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, [], name, value)


                                    class SrPolicy(Entity):
                                        """
                                        Tunnel encap type SR policy
                                        
                                        .. attribute:: binding_sid
                                        
                                        	SR Policy incoming Binding sid
                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                        
                                        .. attribute:: allocated_binding_sid
                                        
                                        	SR Policy allocated Binding sid by the router
                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                        
                                        .. attribute:: tunnel_encap_type
                                        
                                        	Tunnel Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: preference
                                        
                                        	SR Policy Preference
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state
                                        
                                        	SR Policy active state in forwarding
                                        	**type**\: bool
                                        
                                        .. attribute:: request_state
                                        
                                        	SR Policy programming Status
                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                        
                                        .. attribute:: usable
                                        
                                        	SR Policy is usable on this node
                                        	**type**\: bool
                                        
                                        .. attribute:: segment_list
                                        
                                        	SR Policy Segment Lists
                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                            self.yang_name = "sr-policy"
                                            self.yang_parent_name = "tunnel-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                            self._leafs = OrderedDict([
                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                            ])
                                            self.tunnel_encap_type = None
                                            self.preference = None
                                            self.state = None
                                            self.request_state = None
                                            self.usable = None

                                            self.binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                            self.binding_sid.parent = self
                                            self._children_name_map["binding_sid"] = "binding-sid"

                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                            self.allocated_binding_sid.parent = self
                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                            self.segment_list = YList(self)
                                            self._segment_path = lambda: "sr-policy"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                        class BindingSid(Entity):
                                            """
                                            SR Policy incoming Binding sid
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                self.yang_name = "binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.type = None
                                                self.label = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "binding-sid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                        class AllocatedBindingSid(Entity):
                                            """
                                            SR Policy allocated Binding sid by the router
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                self.yang_name = "allocated-binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.type = None
                                                self.label = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "allocated-binding-sid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                        class SegmentList(Entity):
                                            """
                                            SR Policy Segment Lists
                                            
                                            .. attribute:: weight
                                            
                                            	Weight of segment list
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: segment
                                            
                                            	Segments in segment list
                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                self.yang_name = "segment-list"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                self._leafs = OrderedDict([
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.weight = None

                                                self.segment = YList(self)
                                                self._segment_path = lambda: "segment-list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                            class Segment(Entity):
                                                """
                                                Segments in segment list
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address value
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address value
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                    self.yang_name = "segment"
                                                    self.yang_parent_name = "segment-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.type = None
                                                    self.label = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "segment"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                class Community(Entity):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Community, [u'entry'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                class UnknownAttribute(Entity):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                        self.yang_name = "unknown-attribute"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "unknown-attribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                class Cluster(Entity):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                        self.yang_name = "cluster"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "cluster"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, [u'entry'], name, value)


                                class L2tpv3Cookie(Entity):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, self).__init__()

                                        self.yang_name = "l2tpv3-cookie"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "l2tpv3-cookie"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                class ConnectorValue(Entity):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                        self.yang_name = "connector-value"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "connector-value"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, [u'entry'], name, value)


                                class PmsiValue(Entity):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                        self.yang_name = "pmsi-value"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "pmsi-value"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, [u'entry'], name, value)


                                class LsAttr(Entity):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                        self.yang_name = "ls-attr"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "ls-attr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, [u'entry'], name, value)


                                class PeDistinguisherLabel(Entity):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                        self.yang_name = "pe-distinguisher-label"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                        ])
                                        self.pe_address = None
                                        self.label = None
                                        self._segment_path = lambda: "pe-distinguisher-label"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                class LargeCommunity(Entity):
                                    """
                                    Large Community attribute
                                    
                                    .. attribute:: global_admin
                                    
                                    	Global Administrator
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data1
                                    
                                    	Local Data 1
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data2
                                    
                                    	Local Data 2
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                        self.yang_name = "large-community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                        ])
                                        self.global_admin = None
                                        self.local_data1 = None
                                        self.local_data2 = None
                                        self._segment_path = lambda: "large-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                            class RnhAddr(Entity):
                                """
                                RNH Address
                                
                                .. attribute:: len
                                
                                	len
                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPv6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_address
                                
                                	MAC Addr
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                    self.yang_name = "rnh-addr"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                    ])
                                    self.len = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self.mac_address = None
                                    self._segment_path = lambda: "rnh-addr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                            class RibrnhIp(Entity):
                                """
                                RIB RNH IP Address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                    self.yang_name = "ribrnh-ip"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "ribrnh-ip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                class RtEntries(Entity):
                    """
                    BGP Route Target Sets Table
                    
                    .. attribute:: rt_entry
                    
                    	BGP Route Target Set Entry
                    	**type**\: list of  		 :py:class:`RtEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.RtEntries, self).__init__()

                        self.yang_name = "rt-entries"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rt-entry", ("rt_entry", Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry))])
                        self._leafs = OrderedDict()

                        self.rt_entry = YList(self)
                        self._segment_path = lambda: "rt-entries"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RtEntries, [], name, value)


                    class RtEntry(Entity):
                        """
                        BGP Route Target Set Entry
                        
                        .. attribute:: route_target_lower_bytes
                        
                        	Lower 4 bytes of RT
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_target_upper_bytes
                        
                        	Upper 4 bytes of RT
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:  :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                        
                        .. attribute:: request_id
                        
                        	Random Request ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rt
                        
                        	rt
                        	**type**\:  :py:class:`Rt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt>`
                        
                        .. attribute:: afs
                        
                        	afs
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry, self).__init__()

                            self.yang_name = "rt-entry"
                            self.yang_parent_name = "rt-entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rt", ("rt", Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt))])
                            self._leafs = OrderedDict([
                                ('route_target_lower_bytes', (YLeaf(YType.uint32, 'route-target-lower-bytes'), ['int'])),
                                ('route_target_upper_bytes', (YLeaf(YType.uint32, 'route-target-upper-bytes'), ['int'])),
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes', 'BgpAddressFamily', '')])),
                                ('request_id', (YLeaf(YType.uint32, 'request-id'), ['int'])),
                                ('afs', (YLeaf(YType.str, 'afs'), ['str'])),
                            ])
                            self.route_target_lower_bytes = None
                            self.route_target_upper_bytes = None
                            self.af_name = None
                            self.request_id = None
                            self.afs = None

                            self.rt = Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt()
                            self.rt.parent = self
                            self._children_name_map["rt"] = "rt"
                            self._segment_path = lambda: "rt-entry"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry, ['route_target_lower_bytes', 'route_target_upper_bytes', 'af_name', 'request_id', u'afs'], name, value)


                        class Rt(Entity):
                            """
                            rt
                            
                            .. attribute:: route_target
                            
                            	route target
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt, self).__init__()

                                self.yang_name = "rt"
                                self.yang_parent_name = "rt-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                                ])
                                self.route_target = None
                                self._segment_path = lambda: "rt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RtEntries.RtEntry.Rt, [u'route_target'], name, value)


                class AttributeFilterGroups(Entity):
                    """
                    All attribute\-filter groups in this instance
                    
                    .. attribute:: attribute_filter_group
                    
                    	Attribute\-filter group
                    	**type**\: list of  		 :py:class:`AttributeFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups, self).__init__()

                        self.yang_name = "attribute-filter-groups"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attribute-filter-group", ("attribute_filter_group", Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup))])
                        self._leafs = OrderedDict()

                        self.attribute_filter_group = YList(self)
                        self._segment_path = lambda: "attribute-filter-groups"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups, [], name, value)


                    class AttributeFilterGroup(Entity):
                        """
                        Attribute\-filter group
                        
                        .. attribute:: group_name  (key)
                        
                        	Attribute\-filter group name
                        	**type**\: str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: attribute_filter_group_name
                        
                        	Attribute\-filter group name
                        	**type**\: str
                        
                        .. attribute:: attribute_filter_total_group_count
                        
                        	Total number of attriute\-filter groups
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_filter_entry
                        
                        	List of attriute\-filter entries
                        	**type**\: list of  		 :py:class:`AttributeFilterEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup, self).__init__()

                            self.yang_name = "attribute-filter-group"
                            self.yang_parent_name = "attribute-filter-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['group_name']
                            self._child_classes = OrderedDict([("attribute-filter-entry", ("attribute_filter_entry", Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry))])
                            self._leafs = OrderedDict([
                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                ('attribute_filter_group_name', (YLeaf(YType.str, 'attribute-filter-group-name'), ['str'])),
                                ('attribute_filter_total_group_count', (YLeaf(YType.uint32, 'attribute-filter-total-group-count'), ['int'])),
                            ])
                            self.group_name = None
                            self.attribute_filter_group_name = None
                            self.attribute_filter_total_group_count = None

                            self.attribute_filter_entry = YList(self)
                            self._segment_path = lambda: "attribute-filter-group" + "[group-name='" + str(self.group_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup, ['group_name', u'attribute_filter_group_name', u'attribute_filter_total_group_count'], name, value)


                        class AttributeFilterEntry(Entity):
                            """
                            List of attriute\-filter entries
                            
                            .. attribute:: attribute_filter_entry_requested_action
                            
                            	Requested filtering action
                            	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                            
                            .. attribute:: attribute_filter_entry_range_start
                            
                            	Start of attribute range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_filter_entry_range_end
                            
                            	End of attribute range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry, self).__init__()

                                self.yang_name = "attribute-filter-entry"
                                self.yang_parent_name = "attribute-filter-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('attribute_filter_entry_requested_action', (YLeaf(YType.enumeration, 'attribute-filter-entry-requested-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                    ('attribute_filter_entry_range_start', (YLeaf(YType.uint32, 'attribute-filter-entry-range-start'), ['int'])),
                                    ('attribute_filter_entry_range_end', (YLeaf(YType.uint32, 'attribute-filter-entry-range-end'), ['int'])),
                                ])
                                self.attribute_filter_entry_requested_action = None
                                self.attribute_filter_entry_range_start = None
                                self.attribute_filter_entry_range_end = None
                                self._segment_path = lambda: "attribute-filter-entry"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry, [u'attribute_filter_entry_requested_action', u'attribute_filter_entry_range_start', u'attribute_filter_entry_range_end'], name, value)


                class RpkiServerList(Entity):
                    """
                    RPKI Server Table
                    
                    .. attribute:: rpki_server
                    
                    	Array of RPKI servers
                    	**type**\: list of  		 :py:class:`RpkiServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiServerList.RpkiServer>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.RpkiServerList, self).__init__()

                        self.yang_name = "rpki-server-list"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpki-server", ("rpki_server", Bgp.Instances.Instance.InstanceActive.RpkiServerList.RpkiServer))])
                        self._leafs = OrderedDict()

                        self.rpki_server = YList(self)
                        self._segment_path = lambda: "rpki-server-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiServerList, [], name, value)


                    class RpkiServer(Entity):
                        """
                        Array of RPKI servers
                        
                        .. attribute:: name
                        
                        	Server Name
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Server Preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port
                        
                        	Server TCP Port number
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Server Internal State
                        	**type**\:  :py:class:`BgpRpkiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiState>`
                        
                        .. attribute:: state_time
                        
                        	Server Internal State timestamp (unix time)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: shutdown
                        
                        	Server Shutdown
                        	**type**\: bool
                        
                        .. attribute:: retries
                        
                        	Number of connection retries
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: close_reason
                        
                        	Server close reason
                        	**type**\:  :py:class:`BgpRpkiCreason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiCreason>`
                        
                        .. attribute:: close_time
                        
                        	Server close elapsed time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: close_time_real
                        
                        	Server close real timestamp (unix time)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: read_bytes
                        
                        	Number of bytes read from the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: write_bytes
                        
                        	Number of bytes written to the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: transport
                        
                        	Server transport type
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: username
                        
                        	Server SSH username
                        	**type**\: str
                        
                        .. attribute:: password
                        
                        	Server SSH password
                        	**type**\: str
                        
                        .. attribute:: sshpid
                        
                        	Server SSH process ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proto_state
                        
                        	Server Protocol state
                        	**type**\:  :py:class:`BgpRpkiPstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPstate>`
                        
                        .. attribute:: proto_state_time
                        
                        	Server Protocol state timestamp (unix time)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: serial
                        
                        	Server serial number
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nonce
                        
                        	Server nonce
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_time
                        
                        	Server refresh time (seconds)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: response_time
                        
                        	Server response time (seconds)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: purge_time
                        
                        	Server purge time (seconds)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: ipv4roa
                        
                        	Total IPv4 ROAs currently recv'd from server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_announce
                        
                        	Total IPv4 ROAs announced by the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_withdraw
                        
                        	Total IPv4 ROAs withdrawn by the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa
                        
                        	Total IPv6 ROAs currently recv'd from server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_announce
                        
                        	Total IPv6 ROAs announced by the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_withdraw
                        
                        	Total IPv6 ROAs withdrawn by the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proto_error
                        
                        	Protocol Error Reason
                        	**type**\:  :py:class:`BgpRpkiPerror <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPerror>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.RpkiServerList.RpkiServer, self).__init__()

                            self.yang_name = "rpki-server"
                            self.yang_parent_name = "rpki-server-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                ('port', (YLeaf(YType.uint32, 'port'), ['int'])),
                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiState', '')])),
                                ('state_time', (YLeaf(YType.uint32, 'state-time'), ['int'])),
                                ('shutdown', (YLeaf(YType.boolean, 'shutdown'), ['bool'])),
                                ('retries', (YLeaf(YType.uint32, 'retries'), ['int'])),
                                ('close_reason', (YLeaf(YType.enumeration, 'close-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiCreason', '')])),
                                ('close_time', (YLeaf(YType.uint32, 'close-time'), ['int'])),
                                ('close_time_real', (YLeaf(YType.uint32, 'close-time-real'), ['int'])),
                                ('read_bytes', (YLeaf(YType.uint32, 'read-bytes'), ['int'])),
                                ('write_bytes', (YLeaf(YType.uint32, 'write-bytes'), ['int'])),
                                ('transport', (YLeaf(YType.uint32, 'transport'), ['int'])),
                                ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                ('sshpid', (YLeaf(YType.uint32, 'sshpid'), ['int'])),
                                ('proto_state', (YLeaf(YType.enumeration, 'proto-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiPstate', '')])),
                                ('proto_state_time', (YLeaf(YType.uint32, 'proto-state-time'), ['int'])),
                                ('serial', (YLeaf(YType.uint32, 'serial'), ['int'])),
                                ('nonce', (YLeaf(YType.uint32, 'nonce'), ['int'])),
                                ('refresh_time', (YLeaf(YType.int32, 'refresh-time'), ['int'])),
                                ('response_time', (YLeaf(YType.int32, 'response-time'), ['int'])),
                                ('purge_time', (YLeaf(YType.int32, 'purge-time'), ['int'])),
                                ('ipv4roa', (YLeaf(YType.uint32, 'ipv4roa'), ['int'])),
                                ('ipv4roa_announce', (YLeaf(YType.uint32, 'ipv4roa-announce'), ['int'])),
                                ('ipv4roa_withdraw', (YLeaf(YType.uint32, 'ipv4roa-withdraw'), ['int'])),
                                ('ipv6roa', (YLeaf(YType.uint32, 'ipv6roa'), ['int'])),
                                ('ipv6roa_announce', (YLeaf(YType.uint32, 'ipv6roa-announce'), ['int'])),
                                ('ipv6roa_withdraw', (YLeaf(YType.uint32, 'ipv6roa-withdraw'), ['int'])),
                                ('proto_error', (YLeaf(YType.enumeration, 'proto-error'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiPerror', '')])),
                            ])
                            self.name = None
                            self.preference = None
                            self.port = None
                            self.state = None
                            self.state_time = None
                            self.shutdown = None
                            self.retries = None
                            self.close_reason = None
                            self.close_time = None
                            self.close_time_real = None
                            self.read_bytes = None
                            self.write_bytes = None
                            self.transport = None
                            self.username = None
                            self.password = None
                            self.sshpid = None
                            self.proto_state = None
                            self.proto_state_time = None
                            self.serial = None
                            self.nonce = None
                            self.refresh_time = None
                            self.response_time = None
                            self.purge_time = None
                            self.ipv4roa = None
                            self.ipv4roa_announce = None
                            self.ipv4roa_withdraw = None
                            self.ipv6roa = None
                            self.ipv6roa_announce = None
                            self.ipv6roa_withdraw = None
                            self.proto_error = None
                            self._segment_path = lambda: "rpki-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiServerList.RpkiServer, [u'name', u'preference', u'port', u'state', u'state_time', u'shutdown', u'retries', u'close_reason', u'close_time', u'close_time_real', u'read_bytes', u'write_bytes', u'transport', u'username', u'password', u'sshpid', u'proto_state', u'proto_state_time', u'serial', u'nonce', u'refresh_time', u'response_time', u'purge_time', u'ipv4roa', u'ipv4roa_announce', u'ipv4roa_withdraw', u'ipv6roa', u'ipv6roa_announce', u'ipv6roa_withdraw', u'proto_error'], name, value)


                class RpkiRoutes(Entity):
                    """
                    BGP RPKI ROA table
                    
                    .. attribute:: rpki_route
                    
                    	RPKI Path Group
                    	**type**\: list of  		 :py:class:`RpkiRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.RpkiRoutes, self).__init__()

                        self.yang_name = "rpki-routes"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpki-route", ("rpki_route", Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute))])
                        self._leafs = OrderedDict()

                        self.rpki_route = YList(self)
                        self._segment_path = lambda: "rpki-routes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiRoutes, [], name, value)


                    class RpkiRoute(Entity):
                        """
                        RPKI Path Group
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:  :py:class:`BgpRpkiEdmAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiEdmAf>`
                        
                        .. attribute:: address
                        
                        	Route Address (IPv4 / IPv6)
                        	**type**\: str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: minimum
                        
                        	Minimum Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum
                        
                        	Maximum Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpki_route
                        
                        	Array or RPKI routes
                        	**type**\: list of  		 :py:class:`RpkiRoute_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute.RpkiRoute_>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute, self).__init__()

                            self.yang_name = "rpki-route"
                            self.yang_parent_name = "rpki-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpki-route", ("rpki_route", Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute.RpkiRoute_))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiEdmAf', '')])),
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('minimum', (YLeaf(YType.uint32, 'minimum'), ['int'])),
                                ('maximum', (YLeaf(YType.uint32, 'maximum'), ['int'])),
                            ])
                            self.af_name = None
                            self.address = None
                            self.minimum = None
                            self.maximum = None

                            self.rpki_route = YList(self)
                            self._segment_path = lambda: "rpki-route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute, ['af_name', 'address', 'minimum', 'maximum'], name, value)


                        class RpkiRoute_(Entity):
                            """
                            Array or RPKI routes
                            
                            .. attribute:: af_name
                            
                            	Address Family
                            	**type**\:  :py:class:`BgpRpkiAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAf>`
                            
                            .. attribute:: address
                            
                            	Address Prefix
                            	**type**\: str
                            
                            .. attribute:: min_prefix_len
                            
                            	Minimum Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: max_prefix_len
                            
                            	Maximum Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: as_
                            
                            	AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: refcount
                            
                            	Refcount
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: server
                            
                            	Source Server
                            	**type**\: str
                            
                            .. attribute:: stale
                            
                            	ROA is stale
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute.RpkiRoute_, self).__init__()

                                self.yang_name = "rpki-route"
                                self.yang_parent_name = "rpki-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiAf', '')])),
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('min_prefix_len', (YLeaf(YType.uint8, 'min-prefix-len'), ['int'])),
                                    ('max_prefix_len', (YLeaf(YType.uint8, 'max-prefix-len'), ['int'])),
                                    ('as_', (YLeaf(YType.uint32, 'as'), ['int'])),
                                    ('refcount', (YLeaf(YType.uint16, 'refcount'), ['int'])),
                                    ('server', (YLeaf(YType.str, 'server'), ['str'])),
                                    ('stale', (YLeaf(YType.boolean, 'stale'), ['bool'])),
                                ])
                                self.af_name = None
                                self.address = None
                                self.min_prefix_len = None
                                self.max_prefix_len = None
                                self.as_ = None
                                self.refcount = None
                                self.server = None
                                self.stale = None
                                self._segment_path = lambda: "rpki-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiRoutes.RpkiRoute.RpkiRoute_, [u'af_name', u'address', u'min_prefix_len', u'max_prefix_len', u'as_', u'refcount', u'server', u'stale'], name, value)


                class UpdateInboundErrorProcess(Entity):
                    """
                    Update inbound error information for the process
                    
                    .. attribute:: last_update_malformed_timestamp
                    
                    	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:  :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp>`
                    
                    .. attribute:: update_error_handling_basic_ebgp
                    
                    	Is basic error\-handling for EBGP enabled
                    	**type**\: bool
                    
                    .. attribute:: update_error_handling_basic_ibgp
                    
                    	Is basic error\-handling for IBGP enabled
                    	**type**\: bool
                    
                    .. attribute:: update_error_handling_extended_ebgp
                    
                    	Is extended error\-handling for EBGP enabled
                    	**type**\: bool
                    
                    .. attribute:: update_error_handling_extended_ibgp
                    
                    	Is extended error\-handling for IBGP enabled
                    	**type**\: bool
                    
                    .. attribute:: update_malformed_message_count
                    
                    	Malformed messages count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_malformed_neighbor_count
                    
                    	Count of neighbors that received malformed messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_update_malformed_age
                    
                    	Time since last malformed messages received event (in seconds)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess, self).__init__()

                        self.yang_name = "update-inbound-error-process"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("last-update-malformed-timestamp", ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp))])
                        self._leafs = OrderedDict([
                            ('update_error_handling_basic_ebgp', (YLeaf(YType.boolean, 'update-error-handling-basic-ebgp'), ['bool'])),
                            ('update_error_handling_basic_ibgp', (YLeaf(YType.boolean, 'update-error-handling-basic-ibgp'), ['bool'])),
                            ('update_error_handling_extended_ebgp', (YLeaf(YType.boolean, 'update-error-handling-extended-ebgp'), ['bool'])),
                            ('update_error_handling_extended_ibgp', (YLeaf(YType.boolean, 'update-error-handling-extended-ibgp'), ['bool'])),
                            ('update_malformed_message_count', (YLeaf(YType.uint32, 'update-malformed-message-count'), ['int'])),
                            ('update_malformed_neighbor_count', (YLeaf(YType.uint32, 'update-malformed-neighbor-count'), ['int'])),
                            ('last_update_malformed_age', (YLeaf(YType.uint32, 'last-update-malformed-age'), ['int'])),
                        ])
                        self.update_error_handling_basic_ebgp = None
                        self.update_error_handling_basic_ibgp = None
                        self.update_error_handling_extended_ebgp = None
                        self.update_error_handling_extended_ibgp = None
                        self.update_malformed_message_count = None
                        self.update_malformed_neighbor_count = None
                        self.last_update_malformed_age = None

                        self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp()
                        self.last_update_malformed_timestamp.parent = self
                        self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                        self._segment_path = lambda: "update-inbound-error-process"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess, [u'update_error_handling_basic_ebgp', u'update_error_handling_basic_ibgp', u'update_error_handling_extended_ebgp', u'update_error_handling_extended_ibgp', u'update_malformed_message_count', u'update_malformed_neighbor_count', u'last_update_malformed_age'], name, value)


                    class LastUpdateMalformedTimestamp(Entity):
                        """
                        Last malformed messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp, self).__init__()

                            self.yang_name = "last-update-malformed-timestamp"
                            self.yang_parent_name = "update-inbound-error-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nanoseconds = None
                            self._segment_path = lambda: "last-update-malformed-timestamp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceActive.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                class RpkiSummary(Entity):
                    """
                    RPKI Summary Info
                    
                    .. attribute:: servers
                    
                    	Number of RPKI Servers configured
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv4roa_nets
                    
                    	Number of IPv4 ROA Nets
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv4roa_paths
                    
                    	Number of IPv4 ROA Paths
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_nets
                    
                    	Number of IPv6 ROA Nets
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_paths
                    
                    	Number of IPv6 ROA Paths
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceActive.RpkiSummary, self).__init__()

                        self.yang_name = "rpki-summary"
                        self.yang_parent_name = "instance-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('servers', (YLeaf(YType.uint32, 'servers'), ['int'])),
                            ('ipv4roa_nets', (YLeaf(YType.uint32, 'ipv4roa-nets'), ['int'])),
                            ('ipv4roa_paths', (YLeaf(YType.uint32, 'ipv4roa-paths'), ['int'])),
                            ('ipv6roa_nets', (YLeaf(YType.uint32, 'ipv6roa-nets'), ['int'])),
                            ('ipv6roa_paths', (YLeaf(YType.uint32, 'ipv6roa-paths'), ['int'])),
                        ])
                        self.servers = None
                        self.ipv4roa_nets = None
                        self.ipv4roa_paths = None
                        self.ipv6roa_nets = None
                        self.ipv6roa_paths = None
                        self._segment_path = lambda: "rpki-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceActive.RpkiSummary, [u'servers', u'ipv4roa_nets', u'ipv4roa_paths', u'ipv6roa_nets', u'ipv6roa_paths'], name, value)


            class InstanceStandby(Entity):
                """
                Standby BGP operational data
                
                .. attribute:: update_generation_process
                
                	Update generation for the process
                	**type**\:  :py:class:`UpdateGenerationProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess>`
                
                .. attribute:: vrfs
                
                	VRF related operational data
                	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs>`
                
                .. attribute:: default_vrf
                
                	Default VRF related operational data
                	**type**\:  :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf>`
                
                .. attribute:: update_inbound_filter_process
                
                	Update inbound filtering information for the process
                	**type**\:  :py:class:`UpdateInboundFilterProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess>`
                
                .. attribute:: attributes
                
                	The BGP Attribute table
                	**type**\:  :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes>`
                
                .. attribute:: rt_entries
                
                	BGP Route Target Sets Table
                	**type**\:  :py:class:`RtEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RtEntries>`
                
                .. attribute:: attribute_filter_groups
                
                	All attribute\-filter groups in this instance
                	**type**\:  :py:class:`AttributeFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups>`
                
                .. attribute:: rpki_server_list
                
                	RPKI Server Table
                	**type**\:  :py:class:`RpkiServerList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiServerList>`
                
                .. attribute:: rpki_routes
                
                	BGP RPKI ROA table
                	**type**\:  :py:class:`RpkiRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRoutes>`
                
                .. attribute:: update_inbound_error_process
                
                	Update inbound error information for the process
                	**type**\:  :py:class:`UpdateInboundErrorProcess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess>`
                
                .. attribute:: rpki_summary
                
                	RPKI Summary Info
                	**type**\:  :py:class:`RpkiSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiSummary>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Bgp.Instances.Instance.InstanceStandby, self).__init__()

                    self.yang_name = "instance-standby"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("update-generation-process", ("update_generation_process", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess)), ("vrfs", ("vrfs", Bgp.Instances.Instance.InstanceStandby.Vrfs)), ("default-vrf", ("default_vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf)), ("update-inbound-filter-process", ("update_inbound_filter_process", Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess)), ("attributes", ("attributes", Bgp.Instances.Instance.InstanceStandby.Attributes)), ("rt-entries", ("rt_entries", Bgp.Instances.Instance.InstanceStandby.RtEntries)), ("attribute-filter-groups", ("attribute_filter_groups", Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups)), ("rpki-server-list", ("rpki_server_list", Bgp.Instances.Instance.InstanceStandby.RpkiServerList)), ("rpki-routes", ("rpki_routes", Bgp.Instances.Instance.InstanceStandby.RpkiRoutes)), ("update-inbound-error-process", ("update_inbound_error_process", Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess)), ("rpki-summary", ("rpki_summary", Bgp.Instances.Instance.InstanceStandby.RpkiSummary))])
                    self._leafs = OrderedDict()

                    self.update_generation_process = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess()
                    self.update_generation_process.parent = self
                    self._children_name_map["update_generation_process"] = "update-generation-process"

                    self.vrfs = Bgp.Instances.Instance.InstanceStandby.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"

                    self.default_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf()
                    self.default_vrf.parent = self
                    self._children_name_map["default_vrf"] = "default-vrf"

                    self.update_inbound_filter_process = Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess()
                    self.update_inbound_filter_process.parent = self
                    self._children_name_map["update_inbound_filter_process"] = "update-inbound-filter-process"

                    self.attributes = Bgp.Instances.Instance.InstanceStandby.Attributes()
                    self.attributes.parent = self
                    self._children_name_map["attributes"] = "attributes"

                    self.rt_entries = Bgp.Instances.Instance.InstanceStandby.RtEntries()
                    self.rt_entries.parent = self
                    self._children_name_map["rt_entries"] = "rt-entries"

                    self.attribute_filter_groups = Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups()
                    self.attribute_filter_groups.parent = self
                    self._children_name_map["attribute_filter_groups"] = "attribute-filter-groups"

                    self.rpki_server_list = Bgp.Instances.Instance.InstanceStandby.RpkiServerList()
                    self.rpki_server_list.parent = self
                    self._children_name_map["rpki_server_list"] = "rpki-server-list"

                    self.rpki_routes = Bgp.Instances.Instance.InstanceStandby.RpkiRoutes()
                    self.rpki_routes.parent = self
                    self._children_name_map["rpki_routes"] = "rpki-routes"

                    self.update_inbound_error_process = Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess()
                    self.update_inbound_error_process.parent = self
                    self._children_name_map["update_inbound_error_process"] = "update-inbound-error-process"

                    self.rpki_summary = Bgp.Instances.Instance.InstanceStandby.RpkiSummary()
                    self.rpki_summary.parent = self
                    self._children_name_map["rpki_summary"] = "rpki-summary"
                    self._segment_path = lambda: "instance-standby"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby, [], name, value)


                class UpdateGenerationProcess(Entity):
                    """
                    Update generation for the process
                    
                    .. attribute:: update_statistics
                    
                    	Update statistics
                    	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics>`
                    
                    .. attribute:: update_out_logging
                    
                    	Enable syslog messages for update generation events
                    	**type**\: bool
                    
                    .. attribute:: current_update_limit_process
                    
                    	Current Process update limit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured_update_limit_process
                    
                    	Configured Process update limit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_out_queue_messages
                    
                    	OutQueue messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_out_queue_size
                    
                    	OutQueue size
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_throttled
                    
                    	Is update throttled
                    	**type**\: bool
                    
                    .. attribute:: update_address_family
                    
                    	List of address\-families
                    	**type**\: list of  		 :py:class:`UpdateAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateAddressFamily>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess, self).__init__()

                        self.yang_name = "update-generation-process"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics)), ("update-address-family", ("update_address_family", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateAddressFamily))])
                        self._leafs = OrderedDict([
                            ('update_out_logging', (YLeaf(YType.boolean, 'update-out-logging'), ['bool'])),
                            ('current_update_limit_process', (YLeaf(YType.uint32, 'current-update-limit-process'), ['int'])),
                            ('configured_update_limit_process', (YLeaf(YType.uint32, 'configured-update-limit-process'), ['int'])),
                            ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                            ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                            ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                        ])
                        self.update_out_logging = None
                        self.current_update_limit_process = None
                        self.configured_update_limit_process = None
                        self.update_out_queue_messages = None
                        self.update_out_queue_size = None
                        self.update_throttled = None

                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics()
                        self.update_statistics.parent = self
                        self._children_name_map["update_statistics"] = "update-statistics"

                        self.update_address_family = YList(self)
                        self._segment_path = lambda: "update-generation-process"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess, [u'update_out_logging', u'current_update_limit_process', u'configured_update_limit_process', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled'], name, value)


                    class UpdateStatistics(Entity):
                        """
                        Update statistics
                        
                        .. attribute:: last_update_discard_timestamp
                        
                        	Last Discarded time
                        	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp>`
                        
                        .. attribute:: last_update_cleared_timestamp
                        
                        	Last Cleared time
                        	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp>`
                        
                        .. attribute:: last_update_throttle_timestamp
                        
                        	Last Throttled time
                        	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp>`
                        
                        .. attribute:: last_update_recovery_timestamp
                        
                        	Last Recovery time
                        	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                        
                        .. attribute:: last_update_memory_allocation_fail_timestamp
                        
                        	Memory allocation failure time
                        	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                        
                        .. attribute:: update_out_queue_messages_high
                        
                        	OutQueue High Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cumulative
                        
                        	OutQueue Cumulative Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_discarded
                        
                        	OutQueue Discarded Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages_cleared
                        
                        	OutQueue Cleared Messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size_high
                        
                        	OutQueue Hi Size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size_cumulative
                        
                        	OutQueue Cumulative Size
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_discarded
                        
                        	OutQueue Discarded Size
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: update_out_queue_size_cleared
                        
                        	OutQueue Cleared Size
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: last_update_discard_age
                        
                        	Time since last Discard event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: last_update_cleard_age
                        
                        	Time since last Clear event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: update_throttle_count
                        
                        	Throttle Count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_update_throttle_age
                        
                        	Time since last Throttle event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: update_recovery_count
                        
                        	Recovery Count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_update_recovery_age
                        
                        	Time since last Recovery event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: update_memory_allocation_fail_count
                        
                        	Memory allocation failure count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_update_memory_allocation_fail_age
                        
                        	Time since last memory allocation failure event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics, self).__init__()

                            self.yang_name = "update-statistics"
                            self.yang_parent_name = "update-generation-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                            self._leafs = OrderedDict([
                                ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                            ])
                            self.update_out_queue_messages_high = None
                            self.update_out_queue_messages_cumulative = None
                            self.update_out_queue_messages_discarded = None
                            self.update_out_queue_messages_cleared = None
                            self.update_out_queue_size_high = None
                            self.update_out_queue_size_cumulative = None
                            self.update_out_queue_size_discarded = None
                            self.update_out_queue_size_cleared = None
                            self.last_update_discard_age = None
                            self.last_update_cleard_age = None
                            self.update_throttle_count = None
                            self.last_update_throttle_age = None
                            self.update_recovery_count = None
                            self.last_update_recovery_age = None
                            self.update_memory_allocation_fail_count = None
                            self.last_update_memory_allocation_fail_age = None

                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp()
                            self.last_update_discard_timestamp.parent = self
                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp()
                            self.last_update_cleared_timestamp.parent = self
                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp()
                            self.last_update_throttle_timestamp.parent = self
                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp()
                            self.last_update_recovery_timestamp.parent = self
                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                            self.last_update_memory_allocation_fail_timestamp.parent = self
                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                            self._segment_path = lambda: "update-statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                        class LastUpdateDiscardTimestamp(Entity):
                            """
                            Last Discarded time
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                self.yang_name = "last-update-discard-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-discard-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class LastUpdateClearedTimestamp(Entity):
                            """
                            Last Cleared time
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                self.yang_name = "last-update-cleared-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-cleared-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class LastUpdateThrottleTimestamp(Entity):
                            """
                            Last Throttled time
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                self.yang_name = "last-update-throttle-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-throttle-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class LastUpdateRecoveryTimestamp(Entity):
                            """
                            Last Recovery time
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                self.yang_name = "last-update-recovery-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-recovery-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                            """
                            Memory allocation failure time
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                self.yang_parent_name = "update-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                    class UpdateAddressFamily(Entity):
                        """
                        List of address\-families
                        
                        .. attribute:: update_group_af_name
                        
                        	Address family identifier
                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                        
                        .. attribute:: current_update_limit_af
                        
                        	Current AF update limit
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_messages
                        
                        	OutQueue messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_out_queue_size
                        
                        	OutQueue size
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_throttled
                        
                        	Is update throttled
                        	**type**\: bool
                        
                        .. attribute:: update_update_group_count
                        
                        	Update\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_sub_group_count
                        
                        	Sub\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sub_group_throttled_count
                        
                        	Throttled sub\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_count
                        
                        	Refresh sub\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_sub_group_throttled_count
                        
                        	Throttled refresh sub\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: filter_group_count
                        
                        	Filter\-group count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_count
                        
                        	Neighbor count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateAddressFamily, self).__init__()

                            self.yang_name = "update-address-family"
                            self.yang_parent_name = "update-generation-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                ('current_update_limit_af', (YLeaf(YType.uint32, 'current-update-limit-af'), ['int'])),
                                ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                                ('update_update_group_count', (YLeaf(YType.uint32, 'update-update-group-count'), ['int'])),
                                ('update_sub_group_count', (YLeaf(YType.uint32, 'update-sub-group-count'), ['int'])),
                                ('sub_group_throttled_count', (YLeaf(YType.uint32, 'sub-group-throttled-count'), ['int'])),
                                ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                ('refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'refresh-sub-group-throttled-count'), ['int'])),
                                ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                            ])
                            self.update_group_af_name = None
                            self.current_update_limit_af = None
                            self.update_out_queue_messages = None
                            self.update_out_queue_size = None
                            self.update_throttled = None
                            self.update_update_group_count = None
                            self.update_sub_group_count = None
                            self.sub_group_throttled_count = None
                            self.refresh_sub_group_count = None
                            self.refresh_sub_group_throttled_count = None
                            self.filter_group_count = None
                            self.neighbor_count = None
                            self._segment_path = lambda: "update-address-family"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateGenerationProcess.UpdateAddressFamily, [u'update_group_af_name', u'current_update_limit_af', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled', u'update_update_group_count', u'update_sub_group_count', u'sub_group_throttled_count', u'refresh_sub_group_count', u'refresh_sub_group_throttled_count', u'filter_group_count', u'neighbor_count'], name, value)


                class Vrfs(Entity):
                    """
                    VRF related operational data
                    
                    .. attribute:: vrf
                    
                    	Operational data for a particular VRF
                    	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs, self).__init__()

                        self.yang_name = "vrfs"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf))])
                        self._leafs = OrderedDict()

                        self.vrf = YList(self)
                        self._segment_path = lambda: "vrfs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs, [], name, value)


                    class Vrf(Entity):
                        """
                        Operational data for a particular VRF
                        
                        .. attribute:: vrf_name  (key)
                        
                        	Name of the VRF
                        	**type**\: str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: update_inbound_error_vrf
                        
                        	Update inbound error information for the VRF
                        	**type**\:  :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf>`
                        
                        .. attribute:: afs
                        
                        	BGP address family table
                        	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs>`
                        
                        .. attribute:: information
                        
                        	Meta data for VRF
                        	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information>`
                        
                        .. attribute:: update_inbound_filter_vrf
                        
                        	Update inbound filtering information for the VRF
                        	**type**\:  :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf>`
                        
                        .. attribute:: postits
                        
                        	The BGP Neighbor table
                        	**type**\:  :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits>`
                        
                        .. attribute:: global_process_info
                        
                        	The Global Process information table
                        	**type**\:  :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo>`
                        
                        .. attribute:: update_inbound_error_neighbors
                        
                        	Update inbound error information for all neighbors
                        	**type**\:  :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors>`
                        
                        .. attribute:: update_inbound_filter_neighbors
                        
                        	Update inbound filtering information for all neighbors
                        	**type**\:  :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors>`
                        
                        .. attribute:: bmp
                        
                        	BMP related Operational Data
                        	**type**\:  :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp>`
                        
                        .. attribute:: process_info
                        
                        	A Process instance table entry
                        	**type**\:  :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo>`
                        
                        .. attribute:: sessions
                        
                        	The BGP session table
                        	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions>`
                        
                        .. attribute:: neighbors
                        
                        	The BGP Neighbor table
                        	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors>`
                        
                        .. attribute:: next_hop_vrf
                        
                        	A BGP Next\-hop VRF table entry
                        	**type**\:  :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf>`
                        
                        .. attribute:: neighbor_ranges
                        
                        	The BGP Dynamic Neighbor Range table
                        	**type**\:  :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges>`
                        
                        .. attribute:: message_logs
                        
                        	The BGP Neighbor Message table
                        	**type**\:  :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "vrfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['vrf_name']
                            self._child_classes = OrderedDict([("update-inbound-error-vrf", ("update_inbound_error_vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf)), ("afs", ("afs", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs)), ("information", ("information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information)), ("update-inbound-filter-vrf", ("update_inbound_filter_vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf)), ("postits", ("postits", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits)), ("global-process-info", ("global_process_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo)), ("update-inbound-error-neighbors", ("update_inbound_error_neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors)), ("update-inbound-filter-neighbors", ("update_inbound_filter_neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors)), ("bmp", ("bmp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp)), ("process-info", ("process_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo)), ("sessions", ("sessions", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions)), ("neighbors", ("neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors)), ("next-hop-vrf", ("next_hop_vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf)), ("neighbor-ranges", ("neighbor_ranges", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges)), ("message-logs", ("message_logs", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs))])
                            self._leafs = OrderedDict([
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                            ])
                            self.vrf_name = None

                            self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf()
                            self.update_inbound_error_vrf.parent = self
                            self._children_name_map["update_inbound_error_vrf"] = "update-inbound-error-vrf"

                            self.afs = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs()
                            self.afs.parent = self
                            self._children_name_map["afs"] = "afs"

                            self.information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information()
                            self.information.parent = self
                            self._children_name_map["information"] = "information"

                            self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf()
                            self.update_inbound_filter_vrf.parent = self
                            self._children_name_map["update_inbound_filter_vrf"] = "update-inbound-filter-vrf"

                            self.postits = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits()
                            self.postits.parent = self
                            self._children_name_map["postits"] = "postits"

                            self.global_process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo()
                            self.global_process_info.parent = self
                            self._children_name_map["global_process_info"] = "global-process-info"

                            self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors()
                            self.update_inbound_error_neighbors.parent = self
                            self._children_name_map["update_inbound_error_neighbors"] = "update-inbound-error-neighbors"

                            self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors()
                            self.update_inbound_filter_neighbors.parent = self
                            self._children_name_map["update_inbound_filter_neighbors"] = "update-inbound-filter-neighbors"

                            self.bmp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp()
                            self.bmp.parent = self
                            self._children_name_map["bmp"] = "bmp"

                            self.process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo()
                            self.process_info.parent = self
                            self._children_name_map["process_info"] = "process-info"

                            self.sessions = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions()
                            self.sessions.parent = self
                            self._children_name_map["sessions"] = "sessions"

                            self.neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"

                            self.next_hop_vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf()
                            self.next_hop_vrf.parent = self
                            self._children_name_map["next_hop_vrf"] = "next-hop-vrf"

                            self.neighbor_ranges = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges()
                            self.neighbor_ranges.parent = self
                            self._children_name_map["neighbor_ranges"] = "neighbor-ranges"

                            self.message_logs = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs()
                            self.message_logs.parent = self
                            self._children_name_map["message_logs"] = "message-logs"
                            self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf, ['vrf_name'], name, value)


                        class UpdateInboundErrorVrf(Entity):
                            """
                            Update inbound error information for the VRF
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_neighbor_count
                            
                            	Count of neighbors that received malformed messages
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed messages received event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf, self).__init__()

                                self.yang_name = "update-inbound-error-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("last-update-malformed-timestamp", ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp))])
                                self._leafs = OrderedDict([
                                    ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                    ('update_malformed_message_count', (YLeaf(YType.uint32, 'update-malformed-message-count'), ['int'])),
                                    ('update_malformed_neighbor_count', (YLeaf(YType.uint32, 'update-malformed-neighbor-count'), ['int'])),
                                    ('last_update_malformed_age', (YLeaf(YType.uint32, 'last-update-malformed-age'), ['int'])),
                                ])
                                self.update_vrf_name = None
                                self.update_malformed_message_count = None
                                self.update_malformed_neighbor_count = None
                                self.last_update_malformed_age = None

                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                                self._segment_path = lambda: "update-inbound-error-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf, [u'update_vrf_name', u'update_malformed_message_count', u'update_malformed_neighbor_count', u'last_update_malformed_age'], name, value)


                            class LastUpdateMalformedTimestamp(Entity):
                                """
                                Last malformed messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "last-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-update-malformed-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class Afs(Entity):
                            """
                            BGP address family table
                            
                            .. attribute:: af
                            
                            	A particular address family
                            	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs, self).__init__()

                                self.yang_name = "afs"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("af", ("af", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af))])
                                self._leafs = OrderedDict()

                                self.af = YList(self)
                                self._segment_path = lambda: "afs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs, [], name, value)


                            class Af(Entity):
                                """
                                A particular address family
                                
                                .. attribute:: af_name  (key)
                                
                                	Address family
                                	**type**\:  :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                
                                .. attribute:: rpki_refresh_af_table
                                
                                	RPKI Refresh Table (per AF)
                                	**type**\:  :py:class:`RpkiRefreshAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable>`
                                
                                .. attribute:: policies
                                
                                	The BGP Policy Table
                                	**type**\:  :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies>`
                                
                                .. attribute:: convergence
                                
                                	A BGP Convergence table entry
                                	**type**\:  :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence>`
                                
                                .. attribute:: af_process_info
                                
                                	A BGP Process address family table entry
                                	**type**\:  :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo>`
                                
                                .. attribute:: path_used_table
                                
                                	The BGP Path Used Table
                                	**type**\:  :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable>`
                                
                                .. attribute:: bmp_path_table_generic
                                
                                	Summary Info about BMP Table
                                	**type**\:  :py:class:`BmpPathTableGeneric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric>`
                                
                                .. attribute:: rpc_sets
                                
                                	BGP next\-hop set table
                                	**type**\:  :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets>`
                                
                                .. attribute:: global_af_process_info
                                
                                	The Global Address Family Process information table
                                	**type**\:  :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo>`
                                
                                .. attribute:: advertised_path_xr
                                
                                	The BGP Advertised path table (bestpath)
                                	**type**\:  :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr>`
                                
                                .. attribute:: sourced_networks
                                
                                	The BGP Convergence table
                                	**type**\:  :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks>`
                                
                                .. attribute:: update_groups
                                
                                	The BGP Update group table
                                	**type**\:  :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups>`
                                
                                .. attribute:: update_generation_sub_groups
                                
                                	Update generation for all sub\-groups
                                	**type**\:  :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups>`
                                
                                .. attribute:: next_hop_address_families
                                
                                	Address family of nexthop table
                                	**type**\:  :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies>`
                                
                                .. attribute:: rt_set_counters
                                
                                	The RT\-set counter table
                                	**type**\:  :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters>`
                                
                                .. attribute:: bmp_paths
                                
                                	The paths in BMP Table
                                	**type**\:  :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths>`
                                
                                .. attribute:: update_generation_update_groups
                                
                                	Update generation for all update\-groups
                                	**type**\:  :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups>`
                                
                                .. attribute:: update_generation_filter_groups
                                
                                	Update generation for all filter\-groups under a sub\-group
                                	**type**\:  :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups>`
                                
                                .. attribute:: networks
                                
                                	The BGP Network Table
                                	**type**\:  :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks>`
                                
                                .. attribute:: path_table
                                
                                	The BGP Path Table
                                	**type**\:  :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable>`
                                
                                .. attribute:: epes
                                
                                	The BGP Egress Engineering table
                                	**type**\:  :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes>`
                                
                                .. attribute:: advertised_path_counts
                                
                                	The BGP Advertised paths table (bestpath)
                                	**type**\:  :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts>`
                                
                                .. attribute:: path_labeled_table
                                
                                	The BGP Path Labeled Table
                                	**type**\:  :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable>`
                                
                                .. attribute:: advertised_paths
                                
                                	The BGP Advertised paths table (add\-paths)
                                	**type**\:  :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths>`
                                
                                .. attribute:: neighbor_af_table
                                
                                	The BGP Neighbor AF table
                                	**type**\:  :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable>`
                                
                                .. attribute:: update_generation_neighbors
                                
                                	Update generation for all neighbors
                                	**type**\:  :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors>`
                                
                                .. attribute:: update_generation_address_family
                                
                                	Update generation for address\-family
                                	**type**\:  :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily>`
                                
                                .. attribute:: dampenings
                                
                                	The BGP Dampening table
                                	**type**\:  :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings>`
                                
                                .. attribute:: prefix_filters
                                
                                	The BGP Prefix Filter table
                                	**type**\:  :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters>`
                                
                                .. attribute:: attributes
                                
                                	The BGP Attribute table
                                	**type**\:  :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af, self).__init__()

                                    self.yang_name = "af"
                                    self.yang_parent_name = "afs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['af_name']
                                    self._child_classes = OrderedDict([("rpki-refresh-af-table", ("rpki_refresh_af_table", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable)), ("policies", ("policies", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies)), ("convergence", ("convergence", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence)), ("af-process-info", ("af_process_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo)), ("path-used-table", ("path_used_table", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable)), ("bmp-path-table-generic", ("bmp_path_table_generic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric)), ("rpc-sets", ("rpc_sets", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets)), ("global-af-process-info", ("global_af_process_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo)), ("advertised-path-xr", ("advertised_path_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr)), ("sourced-networks", ("sourced_networks", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks)), ("update-groups", ("update_groups", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups)), ("update-generation-sub-groups", ("update_generation_sub_groups", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups)), ("next-hop-address-families", ("next_hop_address_families", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies)), ("rt-set-counters", ("rt_set_counters", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters)), ("bmp-paths", ("bmp_paths", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths)), ("update-generation-update-groups", ("update_generation_update_groups", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups)), ("update-generation-filter-groups", ("update_generation_filter_groups", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups)), ("networks", ("networks", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks)), ("path-table", ("path_table", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable)), ("epes", ("epes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes)), ("advertised-path-counts", ("advertised_path_counts", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts)), ("path-labeled-table", ("path_labeled_table", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable)), ("advertised-paths", ("advertised_paths", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths)), ("neighbor-af-table", ("neighbor_af_table", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable)), ("update-generation-neighbors", ("update_generation_neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors)), ("update-generation-address-family", ("update_generation_address_family", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily)), ("dampenings", ("dampenings", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings)), ("prefix-filters", ("prefix_filters", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters)), ("attributes", ("attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes', 'BgpAddressFamily', '')])),
                                    ])
                                    self.af_name = None

                                    self.rpki_refresh_af_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable()
                                    self.rpki_refresh_af_table.parent = self
                                    self._children_name_map["rpki_refresh_af_table"] = "rpki-refresh-af-table"

                                    self.policies = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies()
                                    self.policies.parent = self
                                    self._children_name_map["policies"] = "policies"

                                    self.convergence = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence()
                                    self.convergence.parent = self
                                    self._children_name_map["convergence"] = "convergence"

                                    self.af_process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo()
                                    self.af_process_info.parent = self
                                    self._children_name_map["af_process_info"] = "af-process-info"

                                    self.path_used_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable()
                                    self.path_used_table.parent = self
                                    self._children_name_map["path_used_table"] = "path-used-table"

                                    self.bmp_path_table_generic = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric()
                                    self.bmp_path_table_generic.parent = self
                                    self._children_name_map["bmp_path_table_generic"] = "bmp-path-table-generic"

                                    self.rpc_sets = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets()
                                    self.rpc_sets.parent = self
                                    self._children_name_map["rpc_sets"] = "rpc-sets"

                                    self.global_af_process_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo()
                                    self.global_af_process_info.parent = self
                                    self._children_name_map["global_af_process_info"] = "global-af-process-info"

                                    self.advertised_path_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr()
                                    self.advertised_path_xr.parent = self
                                    self._children_name_map["advertised_path_xr"] = "advertised-path-xr"

                                    self.sourced_networks = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks()
                                    self.sourced_networks.parent = self
                                    self._children_name_map["sourced_networks"] = "sourced-networks"

                                    self.update_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups()
                                    self.update_groups.parent = self
                                    self._children_name_map["update_groups"] = "update-groups"

                                    self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups()
                                    self.update_generation_sub_groups.parent = self
                                    self._children_name_map["update_generation_sub_groups"] = "update-generation-sub-groups"

                                    self.next_hop_address_families = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies()
                                    self.next_hop_address_families.parent = self
                                    self._children_name_map["next_hop_address_families"] = "next-hop-address-families"

                                    self.rt_set_counters = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters()
                                    self.rt_set_counters.parent = self
                                    self._children_name_map["rt_set_counters"] = "rt-set-counters"

                                    self.bmp_paths = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths()
                                    self.bmp_paths.parent = self
                                    self._children_name_map["bmp_paths"] = "bmp-paths"

                                    self.update_generation_update_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups()
                                    self.update_generation_update_groups.parent = self
                                    self._children_name_map["update_generation_update_groups"] = "update-generation-update-groups"

                                    self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups()
                                    self.update_generation_filter_groups.parent = self
                                    self._children_name_map["update_generation_filter_groups"] = "update-generation-filter-groups"

                                    self.networks = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks()
                                    self.networks.parent = self
                                    self._children_name_map["networks"] = "networks"

                                    self.path_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable()
                                    self.path_table.parent = self
                                    self._children_name_map["path_table"] = "path-table"

                                    self.epes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes()
                                    self.epes.parent = self
                                    self._children_name_map["epes"] = "epes"

                                    self.advertised_path_counts = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts()
                                    self.advertised_path_counts.parent = self
                                    self._children_name_map["advertised_path_counts"] = "advertised-path-counts"

                                    self.path_labeled_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable()
                                    self.path_labeled_table.parent = self
                                    self._children_name_map["path_labeled_table"] = "path-labeled-table"

                                    self.advertised_paths = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths()
                                    self.advertised_paths.parent = self
                                    self._children_name_map["advertised_paths"] = "advertised-paths"

                                    self.neighbor_af_table = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable()
                                    self.neighbor_af_table.parent = self
                                    self._children_name_map["neighbor_af_table"] = "neighbor-af-table"

                                    self.update_generation_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors()
                                    self.update_generation_neighbors.parent = self
                                    self._children_name_map["update_generation_neighbors"] = "update-generation-neighbors"

                                    self.update_generation_address_family = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily()
                                    self.update_generation_address_family.parent = self
                                    self._children_name_map["update_generation_address_family"] = "update-generation-address-family"

                                    self.dampenings = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings()
                                    self.dampenings.parent = self
                                    self._children_name_map["dampenings"] = "dampenings"

                                    self.prefix_filters = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters()
                                    self.prefix_filters.parent = self
                                    self._children_name_map["prefix_filters"] = "prefix-filters"

                                    self.attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes()
                                    self.attributes.parent = self
                                    self._children_name_map["attributes"] = "attributes"
                                    self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                                class RpkiRefreshAfTable(Entity):
                                    """
                                    RPKI Refresh Table (per AF)
                                    
                                    .. attribute:: rpki_refresh_af
                                    
                                    	RPKI Refresh List
                                    	**type**\:  :py:class:`RpkiRefreshAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable, self).__init__()

                                        self.yang_name = "rpki-refresh-af-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rpki-refresh-af", ("rpki_refresh_af", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf))])
                                        self._leafs = OrderedDict()

                                        self.rpki_refresh_af = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf()
                                        self.rpki_refresh_af.parent = self
                                        self._children_name_map["rpki_refresh_af"] = "rpki-refresh-af"
                                        self._segment_path = lambda: "rpki-refresh-af-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable, [], name, value)


                                    class RpkiRefreshAf(Entity):
                                        """
                                        RPKI Refresh List
                                        
                                        .. attribute:: refresh_entry
                                        
                                        	Array of refresh entries
                                        	**type**\: list of  		 :py:class:`RefreshEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf, self).__init__()

                                            self.yang_name = "rpki-refresh-af"
                                            self.yang_parent_name = "rpki-refresh-af-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("refresh-entry", ("refresh_entry", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry))])
                                            self._leafs = OrderedDict()

                                            self.refresh_entry = YList(self)
                                            self._segment_path = lambda: "rpki-refresh-af"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf, [], name, value)


                                        class RefreshEntry(Entity):
                                            """
                                            Array of refresh entries
                                            
                                            .. attribute:: af_name
                                            
                                            	Address Family
                                            	**type**\:  :py:class:`BgpRpkiAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAf>`
                                            
                                            .. attribute:: neighbor
                                            
                                            	BGP neighbor
                                            	**type**\: str
                                            
                                            .. attribute:: policy
                                            
                                            	Route Policy
                                            	**type**\: str
                                            
                                            .. attribute:: paths
                                            
                                            	Number of BGP paths modified or dropped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: drop
                                            
                                            	BGP paths were dropped
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry, self).__init__()

                                                self.yang_name = "refresh-entry"
                                                self.yang_parent_name = "rpki-refresh-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiAf', '')])),
                                                    ('neighbor', (YLeaf(YType.str, 'neighbor'), ['str'])),
                                                    ('policy', (YLeaf(YType.str, 'policy'), ['str'])),
                                                    ('paths', (YLeaf(YType.uint32, 'paths'), ['int'])),
                                                    ('drop', (YLeaf(YType.boolean, 'drop'), ['bool'])),
                                                ])
                                                self.af_name = None
                                                self.neighbor = None
                                                self.policy = None
                                                self.paths = None
                                                self.drop = None
                                                self._segment_path = lambda: "refresh-entry"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry, [u'af_name', u'neighbor', u'policy', u'paths', u'drop'], name, value)


                                class Policies(Entity):
                                    """
                                    The BGP Policy Table
                                    
                                    .. attribute:: policy
                                    
                                    	A BGP Policy table entry
                                    	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies, self).__init__()

                                        self.yang_name = "policies"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("policy", ("policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy))])
                                        self._leafs = OrderedDict()

                                        self.policy = YList(self)
                                        self._segment_path = lambda: "policies"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies, [], name, value)


                                    class Policy(Entity):
                                        """
                                        A BGP Policy table entry
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:  :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:  :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy, self).__init__()

                                            self.yang_name = "policy"
                                            self.yang_parent_name = "policies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr)), ("path-info-after-policy-in", ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn)), ("path-info-after-policy-out", ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn)), ("attributes-after-policy-out", ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.vrf_name = None

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"

                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"

                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                            self._segment_path = lambda: "policy"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy, ['rd', 'network', 'prefix_length', 'neighbor_address', u'no_path', u'af_name', u'route_distinguisher', u'source_route_distinguisher', u'vrf_name'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address-xr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInfoAfterPolicyIn(Entity):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, self).__init__()

                                                self.yang_name = "path-info-after-policy-in"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInfoAfterPolicyOut(Entity):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, self).__init__()

                                                self.yang_name = "path-info-after-policy-out"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-out"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyOut(Entity):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, self).__init__()

                                                self.yang_name = "attributes-after-policy-out"
                                                self.yang_parent_name = "policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-out"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class Convergence(Entity):
                                    """
                                    A BGP Convergence table entry
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: has_converged
                                    
                                    	Convergence has been reached
                                    	**type**\: bool
                                    
                                    .. attribute:: are_write_queues_empty
                                    
                                    	All neighbor write queues are empty
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence, self).__init__()

                                        self.yang_name = "convergence"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('has_converged', (YLeaf(YType.boolean, 'has-converged'), ['bool'])),
                                            ('are_write_queues_empty', (YLeaf(YType.boolean, 'are-write-queues-empty'), ['bool'])),
                                        ])
                                        self.af_name = None
                                        self.has_converged = None
                                        self.are_write_queues_empty = None
                                        self._segment_path = lambda: "convergence"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Convergence, [u'af_name', u'has_converged', u'are_write_queues_empty'], name, value)


                                class AfProcessInfo(Entity):
                                    """
                                    A BGP Process address family table entry
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance
                                    
                                    	ID for the BGP process instance
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: vrf_totals
                                    
                                    	per VRF information aggregated across all VRFs
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo, self).__init__()

                                        self.yang_name = "af-process-info"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics))])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance', (YLeaf(YType.uint8, 'process-instance'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('vrf_totals', (YLeaf(YType.boolean, 'vrf-totals'), ['bool'])),
                                        ])
                                        self.af_name = None
                                        self.process_instance = None
                                        self.vrf_name = None
                                        self.vrf_totals = None

                                        self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"

                                        self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"
                                        self._segment_path = lambda: "af-process-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo, [u'af_name', u'process_instance', u'vrf_name', u'vrf_totals'], name, value)


                                    class Global(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: version_wrap_time_spec
                                        
                                        	Version Wrap timestamp
                                        	**type**\:  :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec>`
                                        
                                        .. attribute:: version_wrap_start_time_spec
                                        
                                        	Version Wrap handle start timestamp
                                        	**type**\:  :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec>`
                                        
                                        .. attribute:: version_wrap_done_time_spec
                                        
                                        	Version Wrap handle Done timestamp
                                        	**type**\:  :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec>`
                                        
                                        .. attribute:: trigger_rib
                                        
                                        	Trigger RIB
                                        	**type**\:  :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib>`
                                        
                                        .. attribute:: trigger_import
                                        
                                        	Trigger import
                                        	**type**\:  :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport>`
                                        
                                        .. attribute:: trigger_update
                                        
                                        	Trigger update
                                        	**type**\:  :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate>`
                                        
                                        .. attribute:: trigger_label
                                        
                                        	Trigger label
                                        	**type**\:  :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel>`
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:  :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall>`
                                        
                                        .. attribute:: router_state
                                        
                                        	Router state
                                        	**type**\:  :py:class:`BgpRtrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrState>`
                                        
                                        .. attribute:: table_version
                                        
                                        	BGP table version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrapped
                                        
                                        	Number of times Version Wrap happened
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version_wrapped_tid
                                        
                                        	Version Wrapped trigger tid
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_active_pelem_version
                                        
                                        	Maximum Active Pelem Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: merged_table_version
                                        
                                        	Merged Table Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_download_go_active_done_pending
                                        
                                        	Route Download Go Active Done Pending
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_brib_received_version
                                        
                                        	Version received from 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Version sent to RIB/bRIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_version
                                        
                                        	Version updated by label thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_version
                                        
                                        	Version updated by import thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: standby_version
                                        
                                        	Version updated by sync thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: send_version
                                        
                                        	Version for sending updates to peers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_init_sync_pfx
                                        
                                        	Num of prefix synced during Initsync
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_label_stack_depth_v4_next_hop
                                        
                                        	Max supported label stack depth for IPv4 Nexthop
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_label_stack_depth_v6_next_hop
                                        
                                        	Max supported label stack depth for IPv6 Nexthop
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_num
                                        
                                        	Total local networks
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_memory
                                        
                                        	Total local networks memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_malloced_num
                                        
                                        	Total local networks malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_networks_freed_num
                                        
                                        	Total local networks freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_num
                                        
                                        	Total local paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_memory
                                        
                                        	Total local paths memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_malloced_num
                                        
                                        	Total local paths malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths_freed_num
                                        
                                        	Total local paths freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_num
                                        
                                        	Total impoorted paths 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths_memory
                                        
                                        	Total imported paths memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_num
                                        
                                        	Total Num of networks
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_memory
                                        
                                        	Total networks memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_malloced_num
                                        
                                        	Total networks malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: networks_freed_num
                                        
                                        	Total networks freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_num
                                        
                                        	Total Num of paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_memory
                                        
                                        	Total paths memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_malloced_num
                                        
                                        	Total paths malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_freed_num
                                        
                                        	Total paths freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_num
                                        
                                        	Total Num of path\-elems
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_memory
                                        
                                        	Total path\-elems memory
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_malloced_num
                                        
                                        	Total path\-elems malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_freed_num
                                        
                                        	Total path\-elems freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_last_trigger
                                        
                                        	Timestamp when Label thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_label_version
                                        
                                        	Label thread version when last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_bgp_version
                                        
                                        	BGP version when label thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_triggers
                                        
                                        	Label thread triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_last_trigger
                                        
                                        	Timestamp when RIB thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_rib_version
                                        
                                        	RIB thread version when last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_bgp_version
                                        
                                        	BGP version when RIB thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_triggers
                                        
                                        	RIB thread triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_last_trigger
                                        
                                        	Timestamp when Import thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_import_version
                                        
                                        	Import thread version when last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_bgp_version
                                        
                                        	BGP version when Import thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_triggers
                                        
                                        	Import thread triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_gen_last_trigger
                                        
                                        	Timestamp when Update generation thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_gen_bgp_version
                                        
                                        	BGP version when Update generation thread is last triggered
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_triggers
                                        
                                        	Update thread triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_r_ds_num
                                        
                                        	Total Num of RDs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_remote_r_ds_num
                                        
                                        	Total Num of remote RDs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_same_r_ds_num
                                        
                                        	Total Num of same RDs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_rd_count
                                        
                                        	Activity\: Number of RDs malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_rd_count
                                        
                                        	Activity\: Number of RDs freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rd_memory
                                        
                                        	Memory (in bytes) used by RD data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: multipath_network_entry_count
                                        
                                        	Number of multipath network entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_network_entry_memory
                                        
                                        	Memory (in bytes) used bymultipath network entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: multipath_paths_count
                                        
                                        	Number of multipath paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multipath_paths_memory
                                        
                                        	Memory (in bytes) used bymultimpath paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("version-wrap-time-spec", ("version_wrap_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec)), ("version-wrap-start-time-spec", ("version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec)), ("version-wrap-done-time-spec", ("version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec)), ("trigger-rib", ("trigger_rib", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib)), ("trigger-import", ("trigger_import", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport)), ("trigger-update", ("trigger_update", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate)), ("trigger-label", ("trigger_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel)), ("rib-install", ("rib_install", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall))])
                                            self._leafs = OrderedDict([
                                                ('router_state', (YLeaf(YType.enumeration, 'router-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRtrState', '')])),
                                                ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                                ('version_wrapped', (YLeaf(YType.uint32, 'version-wrapped'), ['int'])),
                                                ('version_wrapped_tid', (YLeaf(YType.uint32, 'version-wrapped-tid'), ['int'])),
                                                ('max_active_pelem_version', (YLeaf(YType.uint32, 'max-active-pelem-version'), ['int'])),
                                                ('merged_table_version', (YLeaf(YType.uint32, 'merged-table-version'), ['int'])),
                                                ('route_download_go_active_done_pending', (YLeaf(YType.uint32, 'route-download-go-active-done-pending'), ['int'])),
                                                ('rib_brib_received_version', (YLeaf(YType.uint32, 'rib-brib-received-version'), ['int'])),
                                                ('table_brib_version', (YLeaf(YType.uint32, 'table-brib-version'), ['int'])),
                                                ('label_version', (YLeaf(YType.uint32, 'label-version'), ['int'])),
                                                ('import_version', (YLeaf(YType.uint32, 'import-version'), ['int'])),
                                                ('standby_version', (YLeaf(YType.uint32, 'standby-version'), ['int'])),
                                                ('send_version', (YLeaf(YType.uint32, 'send-version'), ['int'])),
                                                ('num_init_sync_pfx', (YLeaf(YType.uint32, 'num-init-sync-pfx'), ['int'])),
                                                ('max_label_stack_depth_v4_next_hop', (YLeaf(YType.uint32, 'max-label-stack-depth-v4-next-hop'), ['int'])),
                                                ('max_label_stack_depth_v6_next_hop', (YLeaf(YType.uint32, 'max-label-stack-depth-v6-next-hop'), ['int'])),
                                                ('local_networks_num', (YLeaf(YType.uint32, 'local-networks-num'), ['int'])),
                                                ('local_networks_memory', (YLeaf(YType.uint32, 'local-networks-memory'), ['int'])),
                                                ('local_networks_malloced_num', (YLeaf(YType.uint32, 'local-networks-malloced-num'), ['int'])),
                                                ('local_networks_freed_num', (YLeaf(YType.uint32, 'local-networks-freed-num'), ['int'])),
                                                ('local_paths_num', (YLeaf(YType.uint32, 'local-paths-num'), ['int'])),
                                                ('local_paths_memory', (YLeaf(YType.uint32, 'local-paths-memory'), ['int'])),
                                                ('local_paths_malloced_num', (YLeaf(YType.uint32, 'local-paths-malloced-num'), ['int'])),
                                                ('local_paths_freed_num', (YLeaf(YType.uint32, 'local-paths-freed-num'), ['int'])),
                                                ('imported_paths_num', (YLeaf(YType.uint32, 'imported-paths-num'), ['int'])),
                                                ('imported_paths_memory', (YLeaf(YType.uint32, 'imported-paths-memory'), ['int'])),
                                                ('networks_num', (YLeaf(YType.uint32, 'networks-num'), ['int'])),
                                                ('networks_memory', (YLeaf(YType.uint32, 'networks-memory'), ['int'])),
                                                ('networks_malloced_num', (YLeaf(YType.uint32, 'networks-malloced-num'), ['int'])),
                                                ('networks_freed_num', (YLeaf(YType.uint32, 'networks-freed-num'), ['int'])),
                                                ('paths_num', (YLeaf(YType.uint32, 'paths-num'), ['int'])),
                                                ('paths_memory', (YLeaf(YType.uint32, 'paths-memory'), ['int'])),
                                                ('paths_malloced_num', (YLeaf(YType.uint32, 'paths-malloced-num'), ['int'])),
                                                ('paths_freed_num', (YLeaf(YType.uint32, 'paths-freed-num'), ['int'])),
                                                ('path_elems_num', (YLeaf(YType.uint32, 'path-elems-num'), ['int'])),
                                                ('path_elems_memory', (YLeaf(YType.uint32, 'path-elems-memory'), ['int'])),
                                                ('path_elems_malloced_num', (YLeaf(YType.uint32, 'path-elems-malloced-num'), ['int'])),
                                                ('path_elems_freed_num', (YLeaf(YType.uint32, 'path-elems-freed-num'), ['int'])),
                                                ('label_last_trigger', (YLeaf(YType.uint64, 'label-last-trigger'), ['int'])),
                                                ('last_label_version', (YLeaf(YType.uint32, 'last-label-version'), ['int'])),
                                                ('label_bgp_version', (YLeaf(YType.uint32, 'label-bgp-version'), ['int'])),
                                                ('label_triggers', (YLeaf(YType.uint32, 'label-triggers'), ['int'])),
                                                ('rib_last_trigger', (YLeaf(YType.uint64, 'rib-last-trigger'), ['int'])),
                                                ('last_rib_version', (YLeaf(YType.uint32, 'last-rib-version'), ['int'])),
                                                ('rib_bgp_version', (YLeaf(YType.uint32, 'rib-bgp-version'), ['int'])),
                                                ('rib_triggers', (YLeaf(YType.uint32, 'rib-triggers'), ['int'])),
                                                ('import_last_trigger', (YLeaf(YType.uint64, 'import-last-trigger'), ['int'])),
                                                ('last_import_version', (YLeaf(YType.uint32, 'last-import-version'), ['int'])),
                                                ('import_bgp_version', (YLeaf(YType.uint32, 'import-bgp-version'), ['int'])),
                                                ('import_triggers', (YLeaf(YType.uint32, 'import-triggers'), ['int'])),
                                                ('update_gen_last_trigger', (YLeaf(YType.uint64, 'update-gen-last-trigger'), ['int'])),
                                                ('update_gen_bgp_version', (YLeaf(YType.uint32, 'update-gen-bgp-version'), ['int'])),
                                                ('update_triggers', (YLeaf(YType.uint32, 'update-triggers'), ['int'])),
                                                ('total_r_ds_num', (YLeaf(YType.uint32, 'total-r-ds-num'), ['int'])),
                                                ('total_remote_r_ds_num', (YLeaf(YType.uint32, 'total-remote-r-ds-num'), ['int'])),
                                                ('total_same_r_ds_num', (YLeaf(YType.uint32, 'total-same-r-ds-num'), ['int'])),
                                                ('malloced_rd_count', (YLeaf(YType.uint32, 'malloced-rd-count'), ['int'])),
                                                ('freed_rd_count', (YLeaf(YType.uint32, 'freed-rd-count'), ['int'])),
                                                ('rd_memory', (YLeaf(YType.uint32, 'rd-memory'), ['int'])),
                                                ('multipath_network_entry_count', (YLeaf(YType.uint32, 'multipath-network-entry-count'), ['int'])),
                                                ('multipath_network_entry_memory', (YLeaf(YType.uint32, 'multipath-network-entry-memory'), ['int'])),
                                                ('multipath_paths_count', (YLeaf(YType.uint32, 'multipath-paths-count'), ['int'])),
                                                ('multipath_paths_memory', (YLeaf(YType.uint32, 'multipath-paths-memory'), ['int'])),
                                                ('update_wait_install_enabled', (YLeaf(YType.uint32, 'update-wait-install-enabled'), ['int'])),
                                                ('rib_acked_table_version', (YLeaf(YType.uint32, 'rib-acked-table-version'), ['int'])),
                                                ('rib_ack_requests', (YLeaf(YType.uint32, 'rib-ack-requests'), ['int'])),
                                                ('rib_acks_received', (YLeaf(YType.uint32, 'rib-acks-received'), ['int'])),
                                                ('rib_slow_acks', (YLeaf(YType.uint32, 'rib-slow-acks'), ['int'])),
                                            ])
                                            self.router_state = None
                                            self.table_version = None
                                            self.version_wrapped = None
                                            self.version_wrapped_tid = None
                                            self.max_active_pelem_version = None
                                            self.merged_table_version = None
                                            self.route_download_go_active_done_pending = None
                                            self.rib_brib_received_version = None
                                            self.table_brib_version = None
                                            self.label_version = None
                                            self.import_version = None
                                            self.standby_version = None
                                            self.send_version = None
                                            self.num_init_sync_pfx = None
                                            self.max_label_stack_depth_v4_next_hop = None
                                            self.max_label_stack_depth_v6_next_hop = None
                                            self.local_networks_num = None
                                            self.local_networks_memory = None
                                            self.local_networks_malloced_num = None
                                            self.local_networks_freed_num = None
                                            self.local_paths_num = None
                                            self.local_paths_memory = None
                                            self.local_paths_malloced_num = None
                                            self.local_paths_freed_num = None
                                            self.imported_paths_num = None
                                            self.imported_paths_memory = None
                                            self.networks_num = None
                                            self.networks_memory = None
                                            self.networks_malloced_num = None
                                            self.networks_freed_num = None
                                            self.paths_num = None
                                            self.paths_memory = None
                                            self.paths_malloced_num = None
                                            self.paths_freed_num = None
                                            self.path_elems_num = None
                                            self.path_elems_memory = None
                                            self.path_elems_malloced_num = None
                                            self.path_elems_freed_num = None
                                            self.label_last_trigger = None
                                            self.last_label_version = None
                                            self.label_bgp_version = None
                                            self.label_triggers = None
                                            self.rib_last_trigger = None
                                            self.last_rib_version = None
                                            self.rib_bgp_version = None
                                            self.rib_triggers = None
                                            self.import_last_trigger = None
                                            self.last_import_version = None
                                            self.import_bgp_version = None
                                            self.import_triggers = None
                                            self.update_gen_last_trigger = None
                                            self.update_gen_bgp_version = None
                                            self.update_triggers = None
                                            self.total_r_ds_num = None
                                            self.total_remote_r_ds_num = None
                                            self.total_same_r_ds_num = None
                                            self.malloced_rd_count = None
                                            self.freed_rd_count = None
                                            self.rd_memory = None
                                            self.multipath_network_entry_count = None
                                            self.multipath_network_entry_memory = None
                                            self.multipath_paths_count = None
                                            self.multipath_paths_memory = None
                                            self.update_wait_install_enabled = None
                                            self.rib_acked_table_version = None
                                            self.rib_ack_requests = None
                                            self.rib_acks_received = None
                                            self.rib_slow_acks = None

                                            self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec()
                                            self.version_wrap_time_spec.parent = self
                                            self._children_name_map["version_wrap_time_spec"] = "version-wrap-time-spec"

                                            self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec()
                                            self.version_wrap_start_time_spec.parent = self
                                            self._children_name_map["version_wrap_start_time_spec"] = "version-wrap-start-time-spec"

                                            self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec()
                                            self.version_wrap_done_time_spec.parent = self
                                            self._children_name_map["version_wrap_done_time_spec"] = "version-wrap-done-time-spec"

                                            self.trigger_rib = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib()
                                            self.trigger_rib.parent = self
                                            self._children_name_map["trigger_rib"] = "trigger-rib"

                                            self.trigger_import = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport()
                                            self.trigger_import.parent = self
                                            self._children_name_map["trigger_import"] = "trigger-import"

                                            self.trigger_update = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate()
                                            self.trigger_update.parent = self
                                            self._children_name_map["trigger_update"] = "trigger-update"

                                            self.trigger_label = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel()
                                            self.trigger_label.parent = self
                                            self._children_name_map["trigger_label"] = "trigger-label"

                                            self.rib_install = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall()
                                            self.rib_install.parent = self
                                            self._children_name_map["rib_install"] = "rib-install"
                                            self._segment_path = lambda: "global"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global, [u'router_state', u'table_version', u'version_wrapped', u'version_wrapped_tid', u'max_active_pelem_version', u'merged_table_version', u'route_download_go_active_done_pending', u'rib_brib_received_version', u'table_brib_version', u'label_version', u'import_version', u'standby_version', u'send_version', u'num_init_sync_pfx', u'max_label_stack_depth_v4_next_hop', u'max_label_stack_depth_v6_next_hop', u'local_networks_num', u'local_networks_memory', u'local_networks_malloced_num', u'local_networks_freed_num', u'local_paths_num', u'local_paths_memory', u'local_paths_malloced_num', u'local_paths_freed_num', u'imported_paths_num', u'imported_paths_memory', u'networks_num', u'networks_memory', u'networks_malloced_num', u'networks_freed_num', u'paths_num', u'paths_memory', u'paths_malloced_num', u'paths_freed_num', u'path_elems_num', u'path_elems_memory', u'path_elems_malloced_num', u'path_elems_freed_num', u'label_last_trigger', u'last_label_version', u'label_bgp_version', u'label_triggers', u'rib_last_trigger', u'last_rib_version', u'rib_bgp_version', u'rib_triggers', u'import_last_trigger', u'last_import_version', u'import_bgp_version', u'import_triggers', u'update_gen_last_trigger', u'update_gen_bgp_version', u'update_triggers', u'total_r_ds_num', u'total_remote_r_ds_num', u'total_same_r_ds_num', u'malloced_rd_count', u'freed_rd_count', u'rd_memory', u'multipath_network_entry_count', u'multipath_network_entry_memory', u'multipath_paths_count', u'multipath_paths_memory', u'update_wait_install_enabled', u'rib_acked_table_version', u'rib_ack_requests', u'rib_acks_received', u'rib_slow_acks'], name, value)


                                        class VersionWrapTimeSpec(Entity):
                                            """
                                            Version Wrap timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-wrap-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class VersionWrapStartTimeSpec(Entity):
                                            """
                                            Version Wrap handle start timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-start-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-wrap-start-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class VersionWrapDoneTimeSpec(Entity):
                                            """
                                            Version Wrap handle Done timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec, self).__init__()

                                                self.yang_name = "version-wrap-done-time-spec"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-wrap-done-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TriggerRib(Entity):
                                            """
                                            Trigger RIB
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib, self).__init__()

                                                self.yang_name = "trigger-rib"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic))])
                                                self._leafs = OrderedDict([
                                                    ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                                ])
                                                self.triggers = None

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-rib"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib, [u'triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-rib"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                        ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                    ])
                                                    self.trigger_version = None
                                                    self.trigger_table_version = None

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._segment_path = lambda: "statistic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "trigger-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TriggerImport(Entity):
                                            """
                                            Trigger import
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport, self).__init__()

                                                self.yang_name = "trigger-import"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic))])
                                                self._leafs = OrderedDict([
                                                    ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                                ])
                                                self.triggers = None

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-import"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport, [u'triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-import"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                        ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                    ])
                                                    self.trigger_version = None
                                                    self.trigger_table_version = None

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._segment_path = lambda: "statistic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "trigger-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TriggerUpdate(Entity):
                                            """
                                            Trigger update
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate, self).__init__()

                                                self.yang_name = "trigger-update"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic))])
                                                self._leafs = OrderedDict([
                                                    ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                                ])
                                                self.triggers = None

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-update"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate, [u'triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                        ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                    ])
                                                    self.trigger_version = None
                                                    self.trigger_table_version = None

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._segment_path = lambda: "statistic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "trigger-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TriggerLabel(Entity):
                                            """
                                            Trigger label
                                            
                                            .. attribute:: triggers
                                            
                                            	Triggers
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: statistic
                                            
                                            	statistic
                                            	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel, self).__init__()

                                                self.yang_name = "trigger-label"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic))])
                                                self._leafs = OrderedDict([
                                                    ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                                ])
                                                self.triggers = None

                                                self.statistic = YList(self)
                                                self._segment_path = lambda: "trigger-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel, [u'triggers'], name, value)


                                            class Statistic(Entity):
                                                """
                                                statistic
                                                
                                                .. attribute:: trigger_time_spec
                                                
                                                	trigger time spec
                                                	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec>`
                                                
                                                .. attribute:: trigger_version
                                                
                                                	TriggerVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: trigger_table_version
                                                
                                                	TriggerTableVersion
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic, self).__init__()

                                                    self.yang_name = "statistic"
                                                    self.yang_parent_name = "trigger-label"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                        ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                    ])
                                                    self.trigger_version = None
                                                    self.trigger_table_version = None

                                                    self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec()
                                                    self.trigger_time_spec.parent = self
                                                    self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                    self._segment_path = lambda: "statistic"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                                class TriggerTimeSpec(Entity):
                                                    """
                                                    trigger time spec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec, self).__init__()

                                                        self.yang_name = "trigger-time-spec"
                                                        self.yang_parent_name = "statistic"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "trigger-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class RibInstall(Entity):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:  :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:  :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: skipped_count
                                            
                                            	Skipped routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall, self).__init__()

                                                self.yang_name = "rib-install"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("update-time", ("update_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime)), ("install-time", ("install_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime))])
                                                self._leafs = OrderedDict([
                                                    ('installed_count', (YLeaf(YType.uint32, 'installed-count'), ['int'])),
                                                    ('modified_count', (YLeaf(YType.uint32, 'modified-count'), ['int'])),
                                                    ('skipped_count', (YLeaf(YType.uint32, 'skipped-count'), ['int'])),
                                                    ('withdrawn_count', (YLeaf(YType.uint32, 'withdrawn-count'), ['int'])),
                                                    ('start_version', (YLeaf(YType.uint32, 'start-version'), ['int'])),
                                                    ('target_version', (YLeaf(YType.uint32, 'target-version'), ['int'])),
                                                ])
                                                self.installed_count = None
                                                self.modified_count = None
                                                self.skipped_count = None
                                                self.withdrawn_count = None
                                                self.start_version = None
                                                self.target_version = None

                                                self.update_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self._children_name_map["update_time"] = "update-time"

                                                self.install_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self._children_name_map["install_time"] = "install-time"
                                                self._segment_path = lambda: "rib-install"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall, [u'installed_count', u'modified_count', u'skipped_count', u'withdrawn_count', u'start_version', u'target_version'], name, value)


                                            class UpdateTime(Entity):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime, self).__init__()

                                                    self.yang_name = "update-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "update-time"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime, [u'seconds', u'nanoseconds'], name, value)


                                            class InstallTime(Entity):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime, self).__init__()

                                                    self.yang_name = "install-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "install-time"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime, [u'seconds', u'nanoseconds'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: network_entry_count
                                        
                                        	Number of network entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: paths_count
                                        
                                        	Number of paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: imported_paths
                                        
                                        	Number of imported paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_paths
                                        
                                        	Number of local paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_elems_count
                                        
                                        	Number of path elems
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: imported_path_memory
                                        
                                        	Memory (in bytes) used by imported paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: local_path_memory
                                        
                                        	Memory (in bytes) used by local paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: path_elem_memory
                                        
                                        	Memory (in bytes) used by pathelem data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_path_count
                                        
                                        	Number of (unused) received paths for inbound soft reconfiguration
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: history_path_count
                                        
                                        	Number of history paths (for dampening)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: damped_path_count
                                        
                                        	Number of dampened paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_prefix_count
                                        
                                        	Activity\: Number of prefixes malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_prefix_count
                                        
                                        	Activity\: Number of prefixes freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_count
                                        
                                        	Activity\: Number of paths malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_count
                                        
                                        	Activity\: Number of paths freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: malloced_path_elem_count
                                        
                                        	Activity\: Number of path elems malloced
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: freed_path_elem_count
                                        
                                        	Activity\: Number of pathelems freed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: any_ebgp_neighbor_missing_policy
                                        
                                        	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_download
                                        
                                        	Attribute download is 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_target_download
                                        
                                        	Route Target download is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: srms_prefix_sid
                                        
                                        	SRMS Prefix SID is 
                                        	**type**\: bool
                                        
                                        .. attribute:: add_path_install_enable
                                        
                                        	Additional paths installation is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: add_path_install_disable
                                        
                                        	Additional paths installation is disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: best_external
                                        
                                        	Best External is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: best_external_disable
                                        
                                        	Best External is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: label_retain
                                        
                                        	Label retention is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: label_retainvalue
                                        
                                        	Label retention value enabled
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tbl_bitf_size
                                        
                                        	Bitfield size on table
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tbl_chunk_bitf_size
                                        
                                        	Chunk Bitfield size on table
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_route_reflector
                                        
                                        	Router is an RR for this AF
                                        	**type**\: bool
                                        
                                        .. attribute:: asbr
                                        
                                        	Router is an ASBR for this AF
                                        	**type**\: bool
                                        
                                        .. attribute:: retain_rt_all
                                        
                                        	Retain\-RT\-All enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_nexthop_self_count
                                        
                                        	Number of iBGP sessions configured with nh\-self
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: use_igpsr_label
                                        
                                        	Use IGP SR label for resolution
                                        	**type**\: bool
                                        
                                        .. attribute:: bmp_network_entry_count
                                        
                                        	Number of BMP net entries
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_paths_count
                                        
                                        	Total Number of BMP paths
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_prefix_memory
                                        
                                        	Memory (in bytes) used by prefix data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bmp_path_memory
                                        
                                        	Memory (in bytes) used by path data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('network_entry_count', (YLeaf(YType.uint32, 'network-entry-count'), ['int'])),
                                                ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                                ('imported_paths', (YLeaf(YType.uint32, 'imported-paths'), ['int'])),
                                                ('local_paths', (YLeaf(YType.uint32, 'local-paths'), ['int'])),
                                                ('path_elems_count', (YLeaf(YType.uint32, 'path-elems-count'), ['int'])),
                                                ('path_memory', (YLeaf(YType.uint32, 'path-memory'), ['int'])),
                                                ('imported_path_memory', (YLeaf(YType.uint32, 'imported-path-memory'), ['int'])),
                                                ('local_path_memory', (YLeaf(YType.uint32, 'local-path-memory'), ['int'])),
                                                ('prefix_memory', (YLeaf(YType.uint32, 'prefix-memory'), ['int'])),
                                                ('path_elem_memory', (YLeaf(YType.uint32, 'path-elem-memory'), ['int'])),
                                                ('received_path_count', (YLeaf(YType.uint32, 'received-path-count'), ['int'])),
                                                ('history_path_count', (YLeaf(YType.uint32, 'history-path-count'), ['int'])),
                                                ('damped_path_count', (YLeaf(YType.uint32, 'damped-path-count'), ['int'])),
                                                ('malloced_prefix_count', (YLeaf(YType.uint32, 'malloced-prefix-count'), ['int'])),
                                                ('freed_prefix_count', (YLeaf(YType.uint32, 'freed-prefix-count'), ['int'])),
                                                ('malloced_path_count', (YLeaf(YType.uint32, 'malloced-path-count'), ['int'])),
                                                ('freed_path_count', (YLeaf(YType.uint32, 'freed-path-count'), ['int'])),
                                                ('malloced_path_elem_count', (YLeaf(YType.uint32, 'malloced-path-elem-count'), ['int'])),
                                                ('freed_path_elem_count', (YLeaf(YType.uint32, 'freed-path-elem-count'), ['int'])),
                                                ('any_ebgp_neighbor_missing_policy', (YLeaf(YType.boolean, 'any-ebgp-neighbor-missing-policy'), ['bool'])),
                                                ('attribute_download', (YLeaf(YType.boolean, 'attribute-download'), ['bool'])),
                                                ('route_target_download', (YLeaf(YType.boolean, 'route-target-download'), ['bool'])),
                                                ('srms_prefix_sid', (YLeaf(YType.boolean, 'srms-prefix-sid'), ['bool'])),
                                                ('add_path_install_enable', (YLeaf(YType.boolean, 'add-path-install-enable'), ['bool'])),
                                                ('add_path_install_disable', (YLeaf(YType.boolean, 'add-path-install-disable'), ['bool'])),
                                                ('best_external', (YLeaf(YType.boolean, 'best-external'), ['bool'])),
                                                ('best_external_disable', (YLeaf(YType.boolean, 'best-external-disable'), ['bool'])),
                                                ('label_retain', (YLeaf(YType.boolean, 'label-retain'), ['bool'])),
                                                ('label_retainvalue', (YLeaf(YType.uint32, 'label-retainvalue'), ['int'])),
                                                ('tbl_bitf_size', (YLeaf(YType.uint16, 'tbl-bitf-size'), ['int'])),
                                                ('tbl_chunk_bitf_size', (YLeaf(YType.uint16, 'tbl-chunk-bitf-size'), ['int'])),
                                                ('is_route_reflector', (YLeaf(YType.boolean, 'is-route-reflector'), ['bool'])),
                                                ('asbr', (YLeaf(YType.boolean, 'asbr'), ['bool'])),
                                                ('retain_rt_all', (YLeaf(YType.boolean, 'retain-rt-all'), ['bool'])),
                                                ('ibgp_nexthop_self_count', (YLeaf(YType.uint32, 'ibgp-nexthop-self-count'), ['int'])),
                                                ('use_igpsr_label', (YLeaf(YType.boolean, 'use-igpsr-label'), ['bool'])),
                                                ('bmp_network_entry_count', (YLeaf(YType.uint32, 'bmp-network-entry-count'), ['int'])),
                                                ('bmp_paths_count', (YLeaf(YType.uint32, 'bmp-paths-count'), ['int'])),
                                                ('bmp_prefix_memory', (YLeaf(YType.uint32, 'bmp-prefix-memory'), ['int'])),
                                                ('bmp_path_memory', (YLeaf(YType.uint32, 'bmp-path-memory'), ['int'])),
                                            ])
                                            self.network_entry_count = None
                                            self.paths_count = None
                                            self.imported_paths = None
                                            self.local_paths = None
                                            self.path_elems_count = None
                                            self.path_memory = None
                                            self.imported_path_memory = None
                                            self.local_path_memory = None
                                            self.prefix_memory = None
                                            self.path_elem_memory = None
                                            self.received_path_count = None
                                            self.history_path_count = None
                                            self.damped_path_count = None
                                            self.malloced_prefix_count = None
                                            self.freed_prefix_count = None
                                            self.malloced_path_count = None
                                            self.freed_path_count = None
                                            self.malloced_path_elem_count = None
                                            self.freed_path_elem_count = None
                                            self.any_ebgp_neighbor_missing_policy = None
                                            self.attribute_download = None
                                            self.route_target_download = None
                                            self.srms_prefix_sid = None
                                            self.add_path_install_enable = None
                                            self.add_path_install_disable = None
                                            self.best_external = None
                                            self.best_external_disable = None
                                            self.label_retain = None
                                            self.label_retainvalue = None
                                            self.tbl_bitf_size = None
                                            self.tbl_chunk_bitf_size = None
                                            self.is_route_reflector = None
                                            self.asbr = None
                                            self.retain_rt_all = None
                                            self.ibgp_nexthop_self_count = None
                                            self.use_igpsr_label = None
                                            self.bmp_network_entry_count = None
                                            self.bmp_paths_count = None
                                            self.bmp_prefix_memory = None
                                            self.bmp_path_memory = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.Vrf_, [u'network_entry_count', u'paths_count', u'imported_paths', u'local_paths', u'path_elems_count', u'path_memory', u'imported_path_memory', u'local_path_memory', u'prefix_memory', u'path_elem_memory', u'received_path_count', u'history_path_count', u'damped_path_count', u'malloced_prefix_count', u'freed_prefix_count', u'malloced_path_count', u'freed_path_count', u'malloced_path_elem_count', u'freed_path_elem_count', u'any_ebgp_neighbor_missing_policy', u'attribute_download', u'route_target_download', u'srms_prefix_sid', u'add_path_install_enable', u'add_path_install_disable', u'best_external', u'best_external_disable', u'label_retain', u'label_retainvalue', u'tbl_bitf_size', u'tbl_chunk_bitf_size', u'is_route_reflector', u'asbr', u'retain_rt_all', u'ibgp_nexthop_self_count', u'use_igpsr_label', u'bmp_network_entry_count', u'bmp_paths_count', u'bmp_prefix_memory', u'bmp_path_memory'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: global_
                                        
                                        	Global information
                                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global>`
                                        
                                        .. attribute:: vrf
                                        
                                        	VRF information
                                        	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_))])
                                            self._leafs = OrderedDict()

                                            self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global()
                                            self.global_.parent = self
                                            self._children_name_map["global_"] = "global"

                                            self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_()
                                            self.vrf.parent = self
                                            self._children_name_map["vrf"] = "vrf"
                                            self._segment_path = lambda: "performance-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics, [], name, value)


                                        class Global(Entity):
                                            """
                                            Global information
                                            
                                            .. attribute:: has_converged
                                            
                                            	TRUE if process has converged
                                            	**type**\: bool
                                            
                                            .. attribute:: first_nbr_up_time
                                            
                                            	Time when first peer came up (seconds since Jan 1 1970)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: total_pim_install
                                            
                                            	Total number of install to PIM
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_callbacks
                                            
                                            	Total number of PIM callbacks
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_pim_callback_batch
                                            
                                            	Total number of Pim callback batches
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mode_enter_time
                                            
                                            	Time that each mode was entered (seconds since  Jan 1 1970)
                                            	**type**\: list of  		 :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime>`
                                            
                                            .. attribute:: total_pim_install_add
                                            
                                            	Total number of install to PIM for add
                                            	**type**\: list of  		 :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd>`
                                            
                                            .. attribute:: total_pim_install_del
                                            
                                            	Total number of install to PIM for del
                                            	**type**\: list of  		 :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel>`
                                            
                                            .. attribute:: total_pim_callback_add
                                            
                                            	Total number of Pim callbacks for add
                                            	**type**\: list of  		 :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd>`
                                            
                                            .. attribute:: total_pim_callback_del
                                            
                                            	Total number of Pim callbacks for del
                                            	**type**\: list of  		 :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel>`
                                            
                                            .. attribute:: total_pim_callback_add_local
                                            
                                            	Total number of Pim callbacks for local add
                                            	**type**\: list of  		 :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal>`
                                            
                                            .. attribute:: total_pim_callback_del_local
                                            
                                            	Total number of Pim callbacks for Local del
                                            	**type**\: list of  		 :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global, self).__init__()

                                                self.yang_name = "global"
                                                self.yang_parent_name = "performance-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("mode-enter-time", ("mode_enter_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime)), ("total-pim-install-add", ("total_pim_install_add", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd)), ("total-pim-install-del", ("total_pim_install_del", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel)), ("total-pim-callback-add", ("total_pim_callback_add", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd)), ("total-pim-callback-del", ("total_pim_callback_del", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel)), ("total-pim-callback-add-local", ("total_pim_callback_add_local", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal)), ("total-pim-callback-del-local", ("total_pim_callback_del_local", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal))])
                                                self._leafs = OrderedDict([
                                                    ('has_converged', (YLeaf(YType.boolean, 'has-converged'), ['bool'])),
                                                    ('first_nbr_up_time', (YLeaf(YType.uint32, 'first-nbr-up-time'), ['int'])),
                                                    ('total_pim_install', (YLeaf(YType.uint32, 'total-pim-install'), ['int'])),
                                                    ('total_pim_callbacks', (YLeaf(YType.uint32, 'total-pim-callbacks'), ['int'])),
                                                    ('total_pim_callback_batch', (YLeaf(YType.uint32, 'total-pim-callback-batch'), ['int'])),
                                                ])
                                                self.has_converged = None
                                                self.first_nbr_up_time = None
                                                self.total_pim_install = None
                                                self.total_pim_callbacks = None
                                                self.total_pim_callback_batch = None

                                                self.mode_enter_time = YList(self)
                                                self.total_pim_install_add = YList(self)
                                                self.total_pim_install_del = YList(self)
                                                self.total_pim_callback_add = YList(self)
                                                self.total_pim_callback_del = YList(self)
                                                self.total_pim_callback_add_local = YList(self)
                                                self.total_pim_callback_del_local = YList(self)
                                                self._segment_path = lambda: "global"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global, [u'has_converged', u'first_nbr_up_time', u'total_pim_install', u'total_pim_callbacks', u'total_pim_callback_batch'], name, value)


                                            class ModeEnterTime(Entity):
                                                """
                                                Time that each mode was entered (seconds since
                                                
                                                Jan 1 1970)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime, self).__init__()

                                                    self.yang_name = "mode-enter-time"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mode-enter-time"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime, [u'entry'], name, value)


                                            class TotalPimInstallAdd(Entity):
                                                """
                                                Total number of install to PIM for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd, self).__init__()

                                                    self.yang_name = "total-pim-install-add"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-install-add"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd, [u'entry'], name, value)


                                            class TotalPimInstallDel(Entity):
                                                """
                                                Total number of install to PIM for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel, self).__init__()

                                                    self.yang_name = "total-pim-install-del"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-install-del"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel, [u'entry'], name, value)


                                            class TotalPimCallbackAdd(Entity):
                                                """
                                                Total number of Pim callbacks for add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd, self).__init__()

                                                    self.yang_name = "total-pim-callback-add"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-callback-add"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd, [u'entry'], name, value)


                                            class TotalPimCallbackDel(Entity):
                                                """
                                                Total number of Pim callbacks for del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel, self).__init__()

                                                    self.yang_name = "total-pim-callback-del"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-callback-del"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel, [u'entry'], name, value)


                                            class TotalPimCallbackAddLocal(Entity):
                                                """
                                                Total number of Pim callbacks for local add
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal, self).__init__()

                                                    self.yang_name = "total-pim-callback-add-local"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-callback-add-local"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal, [u'entry'], name, value)


                                            class TotalPimCallbackDelLocal(Entity):
                                                """
                                                Total number of Pim callbacks for Local del
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal, self).__init__()

                                                    self.yang_name = "total-pim-callback-del-local"
                                                    self.yang_parent_name = "global"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "total-pim-callback-del-local"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal, [u'entry'], name, value)


                                        class Vrf_(Entity):
                                            """
                                            VRF information
                                            
                                            .. attribute:: time_rib_coverged
                                            
                                            	Time last RIB ack was sent 
                                            	**type**\:  :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged>`
                                            
                                            .. attribute:: time_rib_down
                                            
                                            	Time last RIB down wassent. This field is deprecated
                                            	**type**\:  :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown>`
                                            
                                            .. attribute:: first_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the first time
                                            	**type**\:  :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp>`
                                            
                                            .. attribute:: last_rib_table_full_timestamp
                                            
                                            	Timestamp when RIB table was full for the last time
                                            	**type**\:  :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp>`
                                            
                                            .. attribute:: first_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the first time
                                            	**type**\:  :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: last_rib_table_has_space_timestamp
                                            
                                            	Timestamp when RIB table had space for the last time
                                            	**type**\:  :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp>`
                                            
                                            .. attribute:: time_label_retain
                                            
                                            	Time last label retentiontriggered 
                                            	**type**\:  :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain>`
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: rib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: prefixes_sent_to_rib
                                            
                                            	No. of prefixes sent to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_resent_to_rib
                                            
                                            	No. of prefixes re\-sent to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_not_sent_to_rib
                                            
                                            	No. of prefixes not sent to RIB due to unsupported label stack size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_removed_from_rib
                                            
                                            	No. of prefixes withdrawn from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_sent_to_rib
                                            
                                            	No. of attributes sent to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_removed_from_rib
                                            
                                            	No. of attributes withdrawn from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attributes_recover_from_rib
                                            
                                            	No. of attributes recovered from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: scanner_runs
                                            
                                            	# of times scanner has run
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: scanner_time
                                            
                                            	Time spent running scanner (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: rib_tbl_del_calls
                                            
                                            	No. of rib update skipped on account of table delete
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_invalid_calls
                                            
                                            	No. of  rib update skipped due to table invalid
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_skip_calls
                                            
                                            	No. of rib update skipped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_local_label
                                            
                                            	No. of rib update skipped. due to no local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_tbl_retry
                                            
                                            	No. of table rib retires
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_last_update_sent
                                            
                                            	Time last update was sent (seconds since Jan 1 1970)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: is_rib_table_full
                                            
                                            	Indicates if RIB table is in prefix\-limit state
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_table_full_version
                                            
                                            	Version when RIB table became full (from non\-full)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: first_rib_table_full_version
                                            
                                            	Version when RIB table was full for the first time
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_full_version
                                            
                                            	Version when RIB table was full for the last time
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_full_age
                                            
                                            	Time since RIB table was full for the last time (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: first_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the first time
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_has_space_version
                                            
                                            	Version when RIB table had space for the last time
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_rib_table_has_space_age
                                            
                                            	Times since RIB table had space for the last time (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: rib_trigger
                                            
                                            	Rib trigger enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: vrf_flags
                                            
                                            	VRF flags for debug display
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_calls
                                            
                                            	No. of calls to label allocation processing function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_time
                                            
                                            	Time spent running label processing (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: label_rewrite_count
                                            
                                            	Number of label rewrites created
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_release_count
                                            
                                            	Number of labels released
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_added_count
                                            
                                            	Number of labels requested
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_calls
                                            
                                            	Number of calls to import processing function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_time
                                            
                                            	Time spent in import processing (milliseconds) Note time accounted against source nets
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: import_src_net_processed_count
                                            
                                            	Number of source nets processed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_dest_net_processed_count
                                            
                                            	Number of destination nets processed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_added_path_count
                                            
                                            	Number of imported paths added
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_removed_path_count
                                            
                                            	Number of imported paths removed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: import_replaced_path_count
                                            
                                            	Number of imported paths 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_group_count
                                            
                                            	No. of update group
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subgroup_count
                                            
                                            	No. of update subgroup
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_, self).__init__()

                                                self.yang_name = "vrf"
                                                self.yang_parent_name = "performance-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("time-rib-coverged", ("time_rib_coverged", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged)), ("time-rib-down", ("time_rib_down", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown)), ("first-rib-table-full-timestamp", ("first_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp)), ("last-rib-table-full-timestamp", ("last_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp)), ("first-rib-table-has-space-timestamp", ("first_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp)), ("last-rib-table-has-space-timestamp", ("last_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp)), ("time-label-retain", ("time_label_retain", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain))])
                                                self._leafs = OrderedDict([
                                                    ('update_generation_calls', (YLeaf(YType.uint32, 'update-generation-calls'), ['int'])),
                                                    ('update_generation_prefixes_count', (YLeaf(YType.uint32, 'update-generation-prefixes-count'), ['int'])),
                                                    ('update_generation_be_prefixes_count', (YLeaf(YType.uint32, 'update-generation-be-prefixes-count'), ['int'])),
                                                    ('update_generation_messages_count', (YLeaf(YType.uint32, 'update-generation-messages-count'), ['int'])),
                                                    ('update_generation_time', (YLeaf(YType.uint32, 'update-generation-time'), ['int'])),
                                                    ('rib_update_calls', (YLeaf(YType.uint32, 'rib-update-calls'), ['int'])),
                                                    ('rib_update_time', (YLeaf(YType.uint32, 'rib-update-time'), ['int'])),
                                                    ('prefixes_sent_to_rib', (YLeaf(YType.uint32, 'prefixes-sent-to-rib'), ['int'])),
                                                    ('prefixes_resent_to_rib', (YLeaf(YType.uint32, 'prefixes-resent-to-rib'), ['int'])),
                                                    ('prefixes_not_sent_to_rib', (YLeaf(YType.uint32, 'prefixes-not-sent-to-rib'), ['int'])),
                                                    ('prefixes_removed_from_rib', (YLeaf(YType.uint32, 'prefixes-removed-from-rib'), ['int'])),
                                                    ('attributes_sent_to_rib', (YLeaf(YType.uint32, 'attributes-sent-to-rib'), ['int'])),
                                                    ('attributes_removed_from_rib', (YLeaf(YType.uint32, 'attributes-removed-from-rib'), ['int'])),
                                                    ('attributes_recover_from_rib', (YLeaf(YType.uint32, 'attributes-recover-from-rib'), ['int'])),
                                                    ('scanner_runs', (YLeaf(YType.uint32, 'scanner-runs'), ['int'])),
                                                    ('scanner_time', (YLeaf(YType.uint32, 'scanner-time'), ['int'])),
                                                    ('rib_tbl_del_calls', (YLeaf(YType.uint32, 'rib-tbl-del-calls'), ['int'])),
                                                    ('rib_tbl_invalid_calls', (YLeaf(YType.uint32, 'rib-tbl-invalid-calls'), ['int'])),
                                                    ('rib_tbl_skip_calls', (YLeaf(YType.uint32, 'rib-tbl-skip-calls'), ['int'])),
                                                    ('rib_tbl_local_label', (YLeaf(YType.uint32, 'rib-tbl-local-label'), ['int'])),
                                                    ('rib_tbl_retry', (YLeaf(YType.uint32, 'rib-tbl-retry'), ['int'])),
                                                    ('time_last_update_sent', (YLeaf(YType.uint32, 'time-last-update-sent'), ['int'])),
                                                    ('is_rib_table_full', (YLeaf(YType.boolean, 'is-rib-table-full'), ['bool'])),
                                                    ('rib_table_full_version', (YLeaf(YType.uint32, 'rib-table-full-version'), ['int'])),
                                                    ('first_rib_table_full_version', (YLeaf(YType.uint32, 'first-rib-table-full-version'), ['int'])),
                                                    ('last_rib_table_full_version', (YLeaf(YType.uint32, 'last-rib-table-full-version'), ['int'])),
                                                    ('last_rib_table_full_age', (YLeaf(YType.uint32, 'last-rib-table-full-age'), ['int'])),
                                                    ('first_rib_table_has_space_version', (YLeaf(YType.uint32, 'first-rib-table-has-space-version'), ['int'])),
                                                    ('last_rib_table_has_space_version', (YLeaf(YType.uint32, 'last-rib-table-has-space-version'), ['int'])),
                                                    ('last_rib_table_has_space_age', (YLeaf(YType.uint32, 'last-rib-table-has-space-age'), ['int'])),
                                                    ('rib_trigger', (YLeaf(YType.boolean, 'rib-trigger'), ['bool'])),
                                                    ('vrf_flags', (YLeaf(YType.uint32, 'vrf-flags'), ['int'])),
                                                    ('label_calls', (YLeaf(YType.uint32, 'label-calls'), ['int'])),
                                                    ('label_time', (YLeaf(YType.uint32, 'label-time'), ['int'])),
                                                    ('label_rewrite_count', (YLeaf(YType.uint32, 'label-rewrite-count'), ['int'])),
                                                    ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                                    ('label_added_count', (YLeaf(YType.uint32, 'label-added-count'), ['int'])),
                                                    ('import_calls', (YLeaf(YType.uint32, 'import-calls'), ['int'])),
                                                    ('import_time', (YLeaf(YType.uint32, 'import-time'), ['int'])),
                                                    ('import_src_net_processed_count', (YLeaf(YType.uint32, 'import-src-net-processed-count'), ['int'])),
                                                    ('import_dest_net_processed_count', (YLeaf(YType.uint32, 'import-dest-net-processed-count'), ['int'])),
                                                    ('import_added_path_count', (YLeaf(YType.uint32, 'import-added-path-count'), ['int'])),
                                                    ('import_removed_path_count', (YLeaf(YType.uint32, 'import-removed-path-count'), ['int'])),
                                                    ('import_replaced_path_count', (YLeaf(YType.uint32, 'import-replaced-path-count'), ['int'])),
                                                    ('update_group_count', (YLeaf(YType.uint32, 'update-group-count'), ['int'])),
                                                    ('subgroup_count', (YLeaf(YType.uint32, 'subgroup-count'), ['int'])),
                                                ])
                                                self.update_generation_calls = None
                                                self.update_generation_prefixes_count = None
                                                self.update_generation_be_prefixes_count = None
                                                self.update_generation_messages_count = None
                                                self.update_generation_time = None
                                                self.rib_update_calls = None
                                                self.rib_update_time = None
                                                self.prefixes_sent_to_rib = None
                                                self.prefixes_resent_to_rib = None
                                                self.prefixes_not_sent_to_rib = None
                                                self.prefixes_removed_from_rib = None
                                                self.attributes_sent_to_rib = None
                                                self.attributes_removed_from_rib = None
                                                self.attributes_recover_from_rib = None
                                                self.scanner_runs = None
                                                self.scanner_time = None
                                                self.rib_tbl_del_calls = None
                                                self.rib_tbl_invalid_calls = None
                                                self.rib_tbl_skip_calls = None
                                                self.rib_tbl_local_label = None
                                                self.rib_tbl_retry = None
                                                self.time_last_update_sent = None
                                                self.is_rib_table_full = None
                                                self.rib_table_full_version = None
                                                self.first_rib_table_full_version = None
                                                self.last_rib_table_full_version = None
                                                self.last_rib_table_full_age = None
                                                self.first_rib_table_has_space_version = None
                                                self.last_rib_table_has_space_version = None
                                                self.last_rib_table_has_space_age = None
                                                self.rib_trigger = None
                                                self.vrf_flags = None
                                                self.label_calls = None
                                                self.label_time = None
                                                self.label_rewrite_count = None
                                                self.label_release_count = None
                                                self.label_added_count = None
                                                self.import_calls = None
                                                self.import_time = None
                                                self.import_src_net_processed_count = None
                                                self.import_dest_net_processed_count = None
                                                self.import_added_path_count = None
                                                self.import_removed_path_count = None
                                                self.import_replaced_path_count = None
                                                self.update_group_count = None
                                                self.subgroup_count = None

                                                self.time_rib_coverged = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged()
                                                self.time_rib_coverged.parent = self
                                                self._children_name_map["time_rib_coverged"] = "time-rib-coverged"

                                                self.time_rib_down = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown()
                                                self.time_rib_down.parent = self
                                                self._children_name_map["time_rib_down"] = "time-rib-down"

                                                self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp()
                                                self.first_rib_table_full_timestamp.parent = self
                                                self._children_name_map["first_rib_table_full_timestamp"] = "first-rib-table-full-timestamp"

                                                self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp()
                                                self.last_rib_table_full_timestamp.parent = self
                                                self._children_name_map["last_rib_table_full_timestamp"] = "last-rib-table-full-timestamp"

                                                self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp()
                                                self.first_rib_table_has_space_timestamp.parent = self
                                                self._children_name_map["first_rib_table_has_space_timestamp"] = "first-rib-table-has-space-timestamp"

                                                self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp()
                                                self.last_rib_table_has_space_timestamp.parent = self
                                                self._children_name_map["last_rib_table_has_space_timestamp"] = "last-rib-table-has-space-timestamp"

                                                self.time_label_retain = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain()
                                                self.time_label_retain.parent = self
                                                self._children_name_map["time_label_retain"] = "time-label-retain"
                                                self._segment_path = lambda: "vrf"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_, [u'update_generation_calls', u'update_generation_prefixes_count', u'update_generation_be_prefixes_count', u'update_generation_messages_count', u'update_generation_time', u'rib_update_calls', u'rib_update_time', u'prefixes_sent_to_rib', u'prefixes_resent_to_rib', u'prefixes_not_sent_to_rib', u'prefixes_removed_from_rib', u'attributes_sent_to_rib', u'attributes_removed_from_rib', u'attributes_recover_from_rib', u'scanner_runs', u'scanner_time', u'rib_tbl_del_calls', u'rib_tbl_invalid_calls', u'rib_tbl_skip_calls', u'rib_tbl_local_label', u'rib_tbl_retry', u'time_last_update_sent', u'is_rib_table_full', u'rib_table_full_version', u'first_rib_table_full_version', u'last_rib_table_full_version', u'last_rib_table_full_age', u'first_rib_table_has_space_version', u'last_rib_table_has_space_version', u'last_rib_table_has_space_age', u'rib_trigger', u'vrf_flags', u'label_calls', u'label_time', u'label_rewrite_count', u'label_release_count', u'label_added_count', u'import_calls', u'import_time', u'import_src_net_processed_count', u'import_dest_net_processed_count', u'import_added_path_count', u'import_removed_path_count', u'import_replaced_path_count', u'update_group_count', u'subgroup_count'], name, value)


                                            class TimeRibCoverged(Entity):
                                                """
                                                Time last RIB ack was sent 
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged, self).__init__()

                                                    self.yang_name = "time-rib-coverged"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "time-rib-coverged"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibCoverged, [u'seconds', u'nanoseconds'], name, value)


                                            class TimeRibDown(Entity):
                                                """
                                                Time last RIB down wassent. This field is
                                                deprecated
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown, self).__init__()

                                                    self.yang_name = "time-rib-down"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "time-rib-down"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeRibDown, [u'seconds', u'nanoseconds'], name, value)


                                            class FirstRibTableFullTimestamp(Entity):
                                                """
                                                Timestamp when RIB table was full for the first
                                                time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp, self).__init__()

                                                    self.yang_name = "first-rib-table-full-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "first-rib-table-full-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableFullTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastRibTableFullTimestamp(Entity):
                                                """
                                                Timestamp when RIB table was full for the last
                                                time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp, self).__init__()

                                                    self.yang_name = "last-rib-table-full-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-rib-table-full-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableFullTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class FirstRibTableHasSpaceTimestamp(Entity):
                                                """
                                                Timestamp when RIB table had space for the first
                                                time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp, self).__init__()

                                                    self.yang_name = "first-rib-table-has-space-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "first-rib-table-has-space-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.FirstRibTableHasSpaceTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastRibTableHasSpaceTimestamp(Entity):
                                                """
                                                Timestamp when RIB table had space for the last
                                                time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp, self).__init__()

                                                    self.yang_name = "last-rib-table-has-space-timestamp"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-rib-table-has-space-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.LastRibTableHasSpaceTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class TimeLabelRetain(Entity):
                                                """
                                                Time last label retentiontriggered 
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain, self).__init__()

                                                    self.yang_name = "time-label-retain"
                                                    self.yang_parent_name = "vrf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "time-label-retain"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf_.TimeLabelRetain, [u'seconds', u'nanoseconds'], name, value)


                                class PathUsedTable(Entity):
                                    """
                                    The BGP Path Used Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable, self).__init__()

                                        self.yang_name = "path-used-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path))])
                                        self._leafs = OrderedDict()

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-used-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: orig_source_rd
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-used-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                                ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                                ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                                ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.orig_source_rd = None
                                            self.path_id = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class BmpPathTableGeneric(Entity):
                                    """
                                    Summary Info about BMP Table
                                    
                                    .. attribute:: bmp_version_wrap_time_spec
                                    
                                    	Version Wrap timestamp
                                    	**type**\:  :py:class:`BmpVersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec>`
                                    
                                    .. attribute:: bmp_version_wrap_start_time_spec
                                    
                                    	Version Wrap handle start timestamp
                                    	**type**\:  :py:class:`BmpVersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec>`
                                    
                                    .. attribute:: bmp_version_wrap_done_time_spec
                                    
                                    	Version Wrap handle Done timestamp
                                    	**type**\:  :py:class:`BmpVersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec>`
                                    
                                    .. attribute:: bmp_route_monitoringe_enabled
                                    
                                    	Is Route Monitoring mode enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_table_version
                                    
                                    	Table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_count
                                    
                                    	Number of nets in the table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_count
                                    
                                    	Number of paths in the table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_version_wrapped
                                    
                                    	Number of times Table Version Wrapped
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_version_wrapped_tid
                                    
                                    	Version Wrapped trigger thread id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_version_inprogress
                                    
                                    	Is Version wrap in progress
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_version_incremented
                                    
                                    	Is Version being incremented
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric, self).__init__()

                                        self.yang_name = "bmp-path-table-generic"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bmp-version-wrap-time-spec", ("bmp_version_wrap_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec)), ("bmp-version-wrap-start-time-spec", ("bmp_version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec)), ("bmp-version-wrap-done-time-spec", ("bmp_version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec))])
                                        self._leafs = OrderedDict([
                                            ('bmp_route_monitoringe_enabled', (YLeaf(YType.boolean, 'bmp-route-monitoringe-enabled'), ['bool'])),
                                            ('bmp_table_version', (YLeaf(YType.uint32, 'bmp-table-version'), ['int'])),
                                            ('network_count', (YLeaf(YType.uint32, 'network-count'), ['int'])),
                                            ('path_count', (YLeaf(YType.uint32, 'path-count'), ['int'])),
                                            ('bmp_version_wrapped', (YLeaf(YType.uint32, 'bmp-version-wrapped'), ['int'])),
                                            ('bmp_version_wrapped_tid', (YLeaf(YType.uint32, 'bmp-version-wrapped-tid'), ['int'])),
                                            ('bmp_version_inprogress', (YLeaf(YType.boolean, 'bmp-version-inprogress'), ['bool'])),
                                            ('bmp_version_incremented', (YLeaf(YType.boolean, 'bmp-version-incremented'), ['bool'])),
                                        ])
                                        self.bmp_route_monitoringe_enabled = None
                                        self.bmp_table_version = None
                                        self.network_count = None
                                        self.path_count = None
                                        self.bmp_version_wrapped = None
                                        self.bmp_version_wrapped_tid = None
                                        self.bmp_version_inprogress = None
                                        self.bmp_version_incremented = None

                                        self.bmp_version_wrap_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec()
                                        self.bmp_version_wrap_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_time_spec"] = "bmp-version-wrap-time-spec"

                                        self.bmp_version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec()
                                        self.bmp_version_wrap_start_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_start_time_spec"] = "bmp-version-wrap-start-time-spec"

                                        self.bmp_version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec()
                                        self.bmp_version_wrap_done_time_spec.parent = self
                                        self._children_name_map["bmp_version_wrap_done_time_spec"] = "bmp-version-wrap-done-time-spec"
                                        self._segment_path = lambda: "bmp-path-table-generic"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric, [u'bmp_route_monitoringe_enabled', u'bmp_table_version', u'network_count', u'path_count', u'bmp_version_wrapped', u'bmp_version_wrapped_tid', u'bmp_version_inprogress', u'bmp_version_incremented'], name, value)


                                    class BmpVersionWrapTimeSpec(Entity):
                                        """
                                        Version Wrap timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-version-wrap-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class BmpVersionWrapStartTimeSpec(Entity):
                                        """
                                        Version Wrap handle start timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-start-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-version-wrap-start-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class BmpVersionWrapDoneTimeSpec(Entity):
                                        """
                                        Version Wrap handle Done timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, self).__init__()

                                            self.yang_name = "bmp-version-wrap-done-time-spec"
                                            self.yang_parent_name = "bmp-path-table-generic"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-version-wrap-done-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class RpcSets(Entity):
                                    """
                                    BGP next\-hop set table
                                    
                                    .. attribute:: rpc_set
                                    
                                    	A BGP next\-hop set
                                    	**type**\: list of  		 :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets, self).__init__()

                                        self.yang_name = "rpc-sets"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rpc-set", ("rpc_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet))])
                                        self._leafs = OrderedDict()

                                        self.rpc_set = YList(self)
                                        self._segment_path = lambda: "rpc-sets"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets, [], name, value)


                                    class RpcSet(Entity):
                                        """
                                        A BGP next\-hop set
                                        
                                        .. attribute:: rpc_set_index  (key)
                                        
                                        	Nexthop set index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop_xr
                                        
                                        	Number of multipath next\-hops
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: srv6sid_address
                                        
                                        	SRv6 SID address value
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: srv6sid_address_len
                                        
                                        	SRv6 SID address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop
                                        
                                        	List of multipath next\-hops
                                        	**type**\: list of  		 :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet, self).__init__()

                                            self.yang_name = "rpc-set"
                                            self.yang_parent_name = "rpc-sets"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['rpc_set_index']
                                            self._child_classes = OrderedDict([("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop))])
                                            self._leafs = OrderedDict([
                                                ('rpc_set_index', (YLeaf(YType.uint32, 'rpc-set-index'), ['int'])),
                                                ('next_hop_xr', (YLeaf(YType.uint32, 'next-hop-xr'), ['int'])),
                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                ('ref_count', (YLeaf(YType.uint32, 'ref-count'), ['int'])),
                                                ('srv6sid_address', (YLeaf(YType.str, 'srv6sid-address'), ['str'])),
                                                ('srv6sid_address_len', (YLeaf(YType.uint32, 'srv6sid-address-len'), ['int'])),
                                            ])
                                            self.rpc_set_index = None
                                            self.next_hop_xr = None
                                            self.label = None
                                            self.ref_count = None
                                            self.srv6sid_address = None
                                            self.srv6sid_address_len = None

                                            self.next_hop = YList(self)
                                            self._segment_path = lambda: "rpc-set" + "[rpc-set-index='" + str(self.rpc_set_index) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet, ['rpc_set_index', u'next_hop_xr', u'label', u'ref_count', u'srv6sid_address', u'srv6sid_address_len'], name, value)


                                        class NextHop(Entity):
                                            """
                                            List of multipath next\-hops
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "rpc-set"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class GlobalAfProcessInfo(Entity):
                                    """
                                    The Global Address Family Process information
                                    table
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family id
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: is_nsr_enabled
                                    
                                    	Non\-stop routing enabled
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo, self).__init__()

                                        self.yang_name = "global-af-process-info"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_))])
                                        self._leafs = OrderedDict([
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('is_nsr_enabled', (YLeaf(YType.boolean, 'is-nsr-enabled'), ['bool'])),
                                        ])
                                        self.vrf_name = None
                                        self.af_name = None
                                        self.is_nsr_enabled = None

                                        self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"

                                        self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._segment_path = lambda: "global-af-process-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo, [u'vrf_name', u'af_name', u'is_nsr_enabled'], name, value)


                                    class Global(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: rib_install
                                        
                                        	RIB install info
                                        	**type**\:  :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall>`
                                        
                                        .. attribute:: scanner_period
                                        
                                        	Period (in seconds) of address\-family scanner runs
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nh_tunnel_version
                                        
                                        	NH Tunnel Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_prefixes
                                        
                                        	Total prefixes of address\-family scanned
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segment_prefixes
                                        
                                        	Number of prefixes scanned in a segment of address\-family
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scan_segments
                                        
                                        	Number of segments to scan all prefixes of address\-family
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: inter_as_install_enabled
                                        
                                        	Is inter\-AS install to pim on ASBR enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: global_mcast_enabled
                                        
                                        	Is global table mcast enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: segmented_mcast_enabled
                                        
                                        	Is segmented mcast enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: gblafrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: gblafrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\: bool
                                        
                                        .. attribute:: gblafrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: gblafrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\: bool
                                        
                                        .. attribute:: update_wait_install_enabled
                                        
                                        	Update wait\-install enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_ack_requests
                                        
                                        	Counter for RIB ack requests
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_acks_received
                                        
                                        	Counter for RIB ack received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_slow_acks
                                        
                                        	Counter for slow RIB acks
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_perm_net_cfg
                                        
                                        	Permanent Network Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: perm_net_del_count
                                        
                                        	Count of removed perm paths
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_del_count
                                        
                                        	Count of stale perm paths
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_stale_mark_count
                                        
                                        	Count of stale marked perm paths
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_insert_count
                                        
                                        	Count of inserted perm paths
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_existing_count
                                        
                                        	Count of existing perm paths
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_query_count
                                        
                                        	Count of perm nets given by RPL
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_net_rpl_process_count
                                        
                                        	Count of perm nets processed in RPL
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_nbr_count
                                        
                                        	Count of neighbors configured with perm net
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_not_found_count
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_path_not_found_count
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_pelem_found_count
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_reg_path_found_count
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rib_perm_path_found_count
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_free_count
                                        
                                        	Count of freed perm pelems
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_path_refresh_count
                                        
                                        	Count of perm paths refreshed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: perm_pelem_all_bump_count
                                        
                                        	Count of bumped perm pelems
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: syncgrp_version
                                        
                                        	Sync\-group Version
                                        	**type**\: list of  		 :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "global-af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rib-install", ("rib_install", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall)), ("syncgrp-version", ("syncgrp_version", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion))])
                                            self._leafs = OrderedDict([
                                                ('scanner_period', (YLeaf(YType.uint16, 'scanner-period'), ['int'])),
                                                ('nh_tunnel_version', (YLeaf(YType.uint32, 'nh-tunnel-version'), ['int'])),
                                                ('scan_prefixes', (YLeaf(YType.uint32, 'scan-prefixes'), ['int'])),
                                                ('scan_segment_prefixes', (YLeaf(YType.uint32, 'scan-segment-prefixes'), ['int'])),
                                                ('scan_segments', (YLeaf(YType.uint8, 'scan-segments'), ['int'])),
                                                ('inter_as_install_enabled', (YLeaf(YType.boolean, 'inter-as-install-enabled'), ['bool'])),
                                                ('global_mcast_enabled', (YLeaf(YType.boolean, 'global-mcast-enabled'), ['bool'])),
                                                ('segmented_mcast_enabled', (YLeaf(YType.boolean, 'segmented-mcast-enabled'), ['bool'])),
                                                ('gblafrpki_disable', (YLeaf(YType.boolean, 'gblafrpki-disable'), ['bool'])),
                                                ('gblafrpki_use_validity', (YLeaf(YType.boolean, 'gblafrpki-use-validity'), ['bool'])),
                                                ('gblafrpki_allow_invalid', (YLeaf(YType.boolean, 'gblafrpki-allow-invalid'), ['bool'])),
                                                ('gblafrpki_signal_ibgp', (YLeaf(YType.boolean, 'gblafrpki-signal-ibgp'), ['bool'])),
                                                ('update_wait_install_enabled', (YLeaf(YType.boolean, 'update-wait-install-enabled'), ['bool'])),
                                                ('rib_ack_requests', (YLeaf(YType.uint32, 'rib-ack-requests'), ['int'])),
                                                ('rib_acks_received', (YLeaf(YType.uint32, 'rib-acks-received'), ['int'])),
                                                ('rib_slow_acks', (YLeaf(YType.uint32, 'rib-slow-acks'), ['int'])),
                                                ('is_perm_net_cfg', (YLeaf(YType.boolean, 'is-perm-net-cfg'), ['bool'])),
                                                ('perm_net_del_count', (YLeaf(YType.uint16, 'perm-net-del-count'), ['int'])),
                                                ('perm_net_stale_del_count', (YLeaf(YType.uint16, 'perm-net-stale-del-count'), ['int'])),
                                                ('perm_net_stale_mark_count', (YLeaf(YType.uint16, 'perm-net-stale-mark-count'), ['int'])),
                                                ('perm_net_insert_count', (YLeaf(YType.uint16, 'perm-net-insert-count'), ['int'])),
                                                ('perm_net_existing_count', (YLeaf(YType.uint16, 'perm-net-existing-count'), ['int'])),
                                                ('perm_net_rpl_query_count', (YLeaf(YType.uint16, 'perm-net-rpl-query-count'), ['int'])),
                                                ('perm_net_rpl_process_count', (YLeaf(YType.uint16, 'perm-net-rpl-process-count'), ['int'])),
                                                ('perm_nbr_count', (YLeaf(YType.uint16, 'perm-nbr-count'), ['int'])),
                                                ('rib_perm_pelem_not_found_count', (YLeaf(YType.uint16, 'rib-perm-pelem-not-found-count'), ['int'])),
                                                ('rib_perm_path_not_found_count', (YLeaf(YType.uint16, 'rib-perm-path-not-found-count'), ['int'])),
                                                ('rib_perm_pelem_found_count', (YLeaf(YType.uint16, 'rib-perm-pelem-found-count'), ['int'])),
                                                ('rib_reg_path_found_count', (YLeaf(YType.uint16, 'rib-reg-path-found-count'), ['int'])),
                                                ('rib_perm_path_found_count', (YLeaf(YType.uint16, 'rib-perm-path-found-count'), ['int'])),
                                                ('perm_pelem_free_count', (YLeaf(YType.uint16, 'perm-pelem-free-count'), ['int'])),
                                                ('perm_path_refresh_count', (YLeaf(YType.uint16, 'perm-path-refresh-count'), ['int'])),
                                                ('perm_pelem_bump_count', (YLeaf(YType.uint16, 'perm-pelem-bump-count'), ['int'])),
                                                ('perm_pelem_all_bump_count', (YLeaf(YType.uint16, 'perm-pelem-all-bump-count'), ['int'])),
                                            ])
                                            self.scanner_period = None
                                            self.nh_tunnel_version = None
                                            self.scan_prefixes = None
                                            self.scan_segment_prefixes = None
                                            self.scan_segments = None
                                            self.inter_as_install_enabled = None
                                            self.global_mcast_enabled = None
                                            self.segmented_mcast_enabled = None
                                            self.gblafrpki_disable = None
                                            self.gblafrpki_use_validity = None
                                            self.gblafrpki_allow_invalid = None
                                            self.gblafrpki_signal_ibgp = None
                                            self.update_wait_install_enabled = None
                                            self.rib_ack_requests = None
                                            self.rib_acks_received = None
                                            self.rib_slow_acks = None
                                            self.is_perm_net_cfg = None
                                            self.perm_net_del_count = None
                                            self.perm_net_stale_del_count = None
                                            self.perm_net_stale_mark_count = None
                                            self.perm_net_insert_count = None
                                            self.perm_net_existing_count = None
                                            self.perm_net_rpl_query_count = None
                                            self.perm_net_rpl_process_count = None
                                            self.perm_nbr_count = None
                                            self.rib_perm_pelem_not_found_count = None
                                            self.rib_perm_path_not_found_count = None
                                            self.rib_perm_pelem_found_count = None
                                            self.rib_reg_path_found_count = None
                                            self.rib_perm_path_found_count = None
                                            self.perm_pelem_free_count = None
                                            self.perm_path_refresh_count = None
                                            self.perm_pelem_bump_count = None
                                            self.perm_pelem_all_bump_count = None

                                            self.rib_install = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall()
                                            self.rib_install.parent = self
                                            self._children_name_map["rib_install"] = "rib-install"

                                            self.syncgrp_version = YList(self)
                                            self._segment_path = lambda: "global"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global, [u'scanner_period', u'nh_tunnel_version', u'scan_prefixes', u'scan_segment_prefixes', u'scan_segments', u'inter_as_install_enabled', u'global_mcast_enabled', u'segmented_mcast_enabled', u'gblafrpki_disable', u'gblafrpki_use_validity', u'gblafrpki_allow_invalid', u'gblafrpki_signal_ibgp', u'update_wait_install_enabled', u'rib_ack_requests', u'rib_acks_received', u'rib_slow_acks', u'is_perm_net_cfg', u'perm_net_del_count', u'perm_net_stale_del_count', u'perm_net_stale_mark_count', u'perm_net_insert_count', u'perm_net_existing_count', u'perm_net_rpl_query_count', u'perm_net_rpl_process_count', u'perm_nbr_count', u'rib_perm_pelem_not_found_count', u'rib_perm_path_not_found_count', u'rib_perm_pelem_found_count', u'rib_reg_path_found_count', u'rib_perm_path_found_count', u'perm_pelem_free_count', u'perm_path_refresh_count', u'perm_pelem_bump_count', u'perm_pelem_all_bump_count'], name, value)


                                        class RibInstall(Entity):
                                            """
                                            RIB install info
                                            
                                            .. attribute:: update_time
                                            
                                            	RIB update time
                                            	**type**\:  :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime>`
                                            
                                            .. attribute:: install_time
                                            
                                            	RIB install time
                                            	**type**\:  :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime>`
                                            
                                            .. attribute:: installed_count
                                            
                                            	Installed routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified_count
                                            
                                            	Modified routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: skipped_count
                                            
                                            	Skipped routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: withdrawn_count
                                            
                                            	Withdrawn routes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: start_version
                                            
                                            	Start version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: target_version
                                            
                                            	Target version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall, self).__init__()

                                                self.yang_name = "rib-install"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("update-time", ("update_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime)), ("install-time", ("install_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime))])
                                                self._leafs = OrderedDict([
                                                    ('installed_count', (YLeaf(YType.uint32, 'installed-count'), ['int'])),
                                                    ('modified_count', (YLeaf(YType.uint32, 'modified-count'), ['int'])),
                                                    ('skipped_count', (YLeaf(YType.uint32, 'skipped-count'), ['int'])),
                                                    ('withdrawn_count', (YLeaf(YType.uint32, 'withdrawn-count'), ['int'])),
                                                    ('start_version', (YLeaf(YType.uint32, 'start-version'), ['int'])),
                                                    ('target_version', (YLeaf(YType.uint32, 'target-version'), ['int'])),
                                                ])
                                                self.installed_count = None
                                                self.modified_count = None
                                                self.skipped_count = None
                                                self.withdrawn_count = None
                                                self.start_version = None
                                                self.target_version = None

                                                self.update_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime()
                                                self.update_time.parent = self
                                                self._children_name_map["update_time"] = "update-time"

                                                self.install_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime()
                                                self.install_time.parent = self
                                                self._children_name_map["install_time"] = "install-time"
                                                self._segment_path = lambda: "rib-install"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall, [u'installed_count', u'modified_count', u'skipped_count', u'withdrawn_count', u'start_version', u'target_version'], name, value)


                                            class UpdateTime(Entity):
                                                """
                                                RIB update time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime, self).__init__()

                                                    self.yang_name = "update-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "update-time"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime, [u'seconds', u'nanoseconds'], name, value)


                                            class InstallTime(Entity):
                                                """
                                                RIB install time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime, self).__init__()

                                                    self.yang_name = "install-time"
                                                    self.yang_parent_name = "rib-install"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "install-time"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime, [u'seconds', u'nanoseconds'], name, value)


                                        class SyncgrpVersion(Entity):
                                            """
                                            Sync\-group Version
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion, self).__init__()

                                                self.yang_name = "syncgrp-version"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "syncgrp-version"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion, [u'entry'], name, value)


                                    class Vrf_(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: table_is_active
                                        
                                        	Table state is active
                                        	**type**\: bool
                                        
                                        .. attribute:: table_id
                                        
                                        	Table ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rd_version
                                        
                                        	RD version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_version
                                        
                                        	Table version synced to RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_conv_version
                                        
                                        	NSR conv version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_is_conv
                                        
                                        	NSR is converged
                                        	**type**\: bool
                                        
                                        .. attribute:: client_reflection_enabled
                                        
                                        	Client reflection enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: dampening_enabled
                                        
                                        	Dampening enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: ebgp_distance
                                        
                                        	Distance for eBGP routes (external)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ibgp_distance
                                        
                                        	Distance for iBGP routes (internal)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: aggregates_distance
                                        
                                        	Dist for aggregate routes (local)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: dynamic_med_enabled
                                        
                                        	Update generation enabled for MED change
                                        	**type**\: bool
                                        
                                        .. attribute:: dynamic_med_interval
                                        
                                        	Delay in update generation after a MED change (in minutes)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: dynamic_med_timer_running
                                        
                                        	Dynamic MED timer running
                                        	**type**\: bool
                                        
                                        .. attribute:: dynamic_med_timer_value
                                        
                                        	Dynamic MED timer value (in seconds) left on the timer
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dynamic_med_periodic_timer_running
                                        
                                        	Dynamic MED periodic timer running
                                        	**type**\: bool
                                        
                                        .. attribute:: dynamic_med_periodic_timer_value
                                        
                                        	Dynamic MED periodic timer value (in seconds) left on the timer
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_has_converged
                                        
                                        	Received convergence notification from RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_convergence_version
                                        
                                        	Last convergence version received from RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                        
                                        	Is nexthop resoultion minimum prefix\-length configured ?
                                        	**type**\: bool
                                        
                                        .. attribute:: nexthop_resolution_minimum_prefix_length
                                        
                                        	Nexthop resoultion minimum prefix\-length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: selective_ebgp_multipath_enabled
                                        
                                        	Selective eBGP multipath isenabled
                                        	**type**\: bool
                                        
                                        .. attribute:: selective_ibgp_multipath_enabled
                                        
                                        	Selective iBGP multipath isenabled
                                        	**type**\: bool
                                        
                                        .. attribute:: selective_eibgp_multipath_enabled
                                        
                                        	Selective eiBGP multipath isenabled
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_acked_table_version
                                        
                                        	Table version acked by RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "global-af-process-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('table_is_active', (YLeaf(YType.boolean, 'table-is-active'), ['bool'])),
                                                ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                                ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                                ('rd_version', (YLeaf(YType.uint32, 'rd-version'), ['int'])),
                                                ('rib_version', (YLeaf(YType.uint32, 'rib-version'), ['int'])),
                                                ('nsr_conv_version', (YLeaf(YType.uint32, 'nsr-conv-version'), ['int'])),
                                                ('nsr_is_conv', (YLeaf(YType.boolean, 'nsr-is-conv'), ['bool'])),
                                                ('client_reflection_enabled', (YLeaf(YType.boolean, 'client-reflection-enabled'), ['bool'])),
                                                ('dampening_enabled', (YLeaf(YType.boolean, 'dampening-enabled'), ['bool'])),
                                                ('ebgp_distance', (YLeaf(YType.uint16, 'ebgp-distance'), ['int'])),
                                                ('ibgp_distance', (YLeaf(YType.uint16, 'ibgp-distance'), ['int'])),
                                                ('aggregates_distance', (YLeaf(YType.uint16, 'aggregates-distance'), ['int'])),
                                                ('dynamic_med_enabled', (YLeaf(YType.boolean, 'dynamic-med-enabled'), ['bool'])),
                                                ('dynamic_med_interval', (YLeaf(YType.uint16, 'dynamic-med-interval'), ['int'])),
                                                ('dynamic_med_timer_running', (YLeaf(YType.boolean, 'dynamic-med-timer-running'), ['bool'])),
                                                ('dynamic_med_timer_value', (YLeaf(YType.uint16, 'dynamic-med-timer-value'), ['int'])),
                                                ('dynamic_med_periodic_timer_running', (YLeaf(YType.boolean, 'dynamic-med-periodic-timer-running'), ['bool'])),
                                                ('dynamic_med_periodic_timer_value', (YLeaf(YType.uint16, 'dynamic-med-periodic-timer-value'), ['int'])),
                                                ('rib_has_converged', (YLeaf(YType.boolean, 'rib-has-converged'), ['bool'])),
                                                ('rib_convergence_version', (YLeaf(YType.uint32, 'rib-convergence-version'), ['int'])),
                                                ('is_rib_table_full', (YLeaf(YType.boolean, 'is-rib-table-full'), ['bool'])),
                                                ('rib_table_full_version', (YLeaf(YType.uint32, 'rib-table-full-version'), ['int'])),
                                                ('nexthop_resolution_minimum_prefix_length_configured', (YLeaf(YType.boolean, 'nexthop-resolution-minimum-prefix-length-configured'), ['bool'])),
                                                ('nexthop_resolution_minimum_prefix_length', (YLeaf(YType.uint32, 'nexthop-resolution-minimum-prefix-length'), ['int'])),
                                                ('selective_ebgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-ebgp-multipath-enabled'), ['bool'])),
                                                ('selective_ibgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-ibgp-multipath-enabled'), ['bool'])),
                                                ('selective_eibgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-eibgp-multipath-enabled'), ['bool'])),
                                                ('rib_acked_table_version', (YLeaf(YType.uint32, 'rib-acked-table-version'), ['int'])),
                                            ])
                                            self.table_is_active = None
                                            self.table_id = None
                                            self.table_version = None
                                            self.rd_version = None
                                            self.rib_version = None
                                            self.nsr_conv_version = None
                                            self.nsr_is_conv = None
                                            self.client_reflection_enabled = None
                                            self.dampening_enabled = None
                                            self.ebgp_distance = None
                                            self.ibgp_distance = None
                                            self.aggregates_distance = None
                                            self.dynamic_med_enabled = None
                                            self.dynamic_med_interval = None
                                            self.dynamic_med_timer_running = None
                                            self.dynamic_med_timer_value = None
                                            self.dynamic_med_periodic_timer_running = None
                                            self.dynamic_med_periodic_timer_value = None
                                            self.rib_has_converged = None
                                            self.rib_convergence_version = None
                                            self.is_rib_table_full = None
                                            self.rib_table_full_version = None
                                            self.nexthop_resolution_minimum_prefix_length_configured = None
                                            self.nexthop_resolution_minimum_prefix_length = None
                                            self.selective_ebgp_multipath_enabled = None
                                            self.selective_ibgp_multipath_enabled = None
                                            self.selective_eibgp_multipath_enabled = None
                                            self.rib_acked_table_version = None
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.GlobalAfProcessInfo.Vrf_, [u'table_is_active', u'table_id', u'table_version', u'rd_version', u'rib_version', u'nsr_conv_version', u'nsr_is_conv', u'client_reflection_enabled', u'dampening_enabled', u'ebgp_distance', u'ibgp_distance', u'aggregates_distance', u'dynamic_med_enabled', u'dynamic_med_interval', u'dynamic_med_timer_running', u'dynamic_med_timer_value', u'dynamic_med_periodic_timer_running', u'dynamic_med_periodic_timer_value', u'rib_has_converged', u'rib_convergence_version', u'is_rib_table_full', u'rib_table_full_version', u'nexthop_resolution_minimum_prefix_length_configured', u'nexthop_resolution_minimum_prefix_length', u'selective_ebgp_multipath_enabled', u'selective_ibgp_multipath_enabled', u'selective_eibgp_multipath_enabled', u'rib_acked_table_version'], name, value)


                                class AdvertisedPathXr(Entity):
                                    """
                                    The BGP Advertised path table (bestpath)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised path table entry (bestpath)
                                    	**type**\: list of  		 :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr, self).__init__()

                                        self.yang_name = "advertised-path-xr"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-path", ("advertised_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath))])
                                        self._leafs = OrderedDict()

                                        self.advertised_path = YList(self)
                                        self._segment_path = lambda: "advertised-path-xr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr, [], name, value)


                                    class AdvertisedPath(Entity):
                                        """
                                        A BGP Advertised path table entry (bestpath)
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, self).__init__()

                                            self.yang_name = "advertised-path"
                                            self.yang_parent_name = "advertised-path-xr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "advertised-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, ['rd', 'network', 'prefix_length', 'neighbor_address', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SourcedNetworks(Entity):
                                    """
                                    The BGP Convergence table
                                    
                                    .. attribute:: sourced_network
                                    
                                    	A BGP network command table entry
                                    	**type**\: list of  		 :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks, self).__init__()

                                        self.yang_name = "sourced-networks"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sourced-network", ("sourced_network", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork))])
                                        self._leafs = OrderedDict()

                                        self.sourced_network = YList(self)
                                        self._segment_path = lambda: "sourced-networks"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks, [], name, value)


                                    class SourcedNetwork(Entity):
                                        """
                                        A BGP network command table entry
                                        
                                        .. attribute:: network  (key)
                                        
                                        	Network in prefix/length format
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                        
                                        .. attribute:: sourced_prefix
                                        
                                        	Prefix length
                                        	**type**\:  :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: is_backdoor
                                        
                                        	TRUE if net is a backdoor route
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork, self).__init__()

                                            self.yang_name = "sourced-network"
                                            self.yang_parent_name = "sourced-networks"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['network']
                                            self._child_classes = OrderedDict([("sourced-prefix", ("sourced_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix))])
                                            self._leafs = OrderedDict([
                                                ('network', (YLeaf(YType.str, 'network'), ['str','str'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('is_backdoor', (YLeaf(YType.boolean, 'is-backdoor'), ['bool'])),
                                            ])
                                            self.network = None
                                            self.af_name = None
                                            self.is_backdoor = None

                                            self.sourced_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                            self.sourced_prefix.parent = self
                                            self._children_name_map["sourced_prefix"] = "sourced-prefix"
                                            self._segment_path = lambda: "sourced-network" + "[network='" + str(self.network) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork, ['network', u'af_name', u'is_backdoor'], name, value)


                                        class SourcedPrefix(Entity):
                                            """
                                            Prefix length
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, self).__init__()

                                                self.yang_name = "sourced-prefix"
                                                self.yang_parent_name = "sourced-network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "sourced-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "sourced-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class UpdateGroups(Entity):
                                    """
                                    The BGP Update group table
                                    
                                    .. attribute:: update_group
                                    
                                    	A BGP Update group table entry
                                    	**type**\: list of  		 :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups, self).__init__()

                                        self.yang_name = "update-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-group", ("update_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.update_group = YList(self)
                                        self._segment_path = lambda: "update-groups"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups, [], name, value)


                                    class UpdateGroup(Entity):
                                        """
                                        A BGP Update group table entry
                                        
                                        .. attribute:: update_group_id
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_id
                                        
                                        	Filter group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_af_name
                                        
                                        	Neighbor session Address family
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family for update group
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: should_send_communities
                                        
                                        	Send communities
                                        	**type**\: bool
                                        
                                        .. attribute:: should_send_ext_communities
                                        
                                        	Send Extended communities
                                        	**type**\: bool
                                        
                                        .. attribute:: should_send_stitching_rt
                                        
                                        	Send Stitching RT
                                        	**type**\: bool
                                        
                                        .. attribute:: has_orf_receive_capability
                                        
                                        	ORF receive capability
                                        	**type**\: bool
                                        
                                        .. attribute:: is_route_reflector_client
                                        
                                        	Route\-reflector client
                                        	**type**\: bool
                                        
                                        .. attribute:: is_client_reflection_disabled
                                        
                                        	True if client\-to\-client reflection is disabled 
                                        	**type**\: bool
                                        
                                        .. attribute:: accepts_legacy_pe_rt_route
                                        
                                        	accept\-legacy\-pe\-RT route
                                        	**type**\: bool
                                        
                                        .. attribute:: updgrp_cluster_id
                                        
                                        	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updgrp_cluster_type
                                        
                                        	Cluster ID type\:undefined/number/Ip address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\: str
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\: bool
                                        
                                        .. attribute:: should_remove_private_a_ss
                                        
                                        	Remove private AS numbers
                                        	**type**\: bool
                                        
                                        .. attribute:: should_remove_private_as_ent_path
                                        
                                        	Remove private AS numbersif the entire path consistsof private ASes
                                        	**type**\: bool
                                        
                                        .. attribute:: use_next_hop_self
                                        
                                        	Next hop self
                                        	**type**\: bool
                                        
                                        .. attribute:: use_next_hop_unchanged_mpath
                                        
                                        	Next\-hop\-unchanged multipath
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_peers
                                        
                                        	Internal peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is_common_admin_peers
                                        
                                        	Common admin peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is4_byte_as_peer
                                        
                                        	4\-byte AS capable peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is_addpath_capable
                                        
                                        	Add\-path capable peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is_send_mcast_attr_enabled
                                        
                                        	Send mcast attribute enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aigp_capable
                                        
                                        	AIGP capable peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aigp_cost_community_capable
                                        
                                        	Send AIGP cost community to peers
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aigp_med_capable
                                        
                                        	Send AIGP cost in MED
                                        	**type**\: bool
                                        
                                        .. attribute:: is_llgr_capable
                                        
                                        	Send Long\-lived Stale paths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_adv_capable
                                        
                                        	Send tranlsated paths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_adv_reorg_capable
                                        
                                        	Send Re\-orig paths
                                        	**type**\: bool
                                        
                                        .. attribute:: disable_native_advertisement
                                        
                                        	Disable advertising native routes
                                        	**type**\: bool
                                        
                                        .. attribute:: disable_def_vrf_imp_advertisement
                                        
                                        	Disable advertising default VRF  imported routes
                                        	**type**\: bool
                                        
                                        .. attribute:: disable_vrf_re_imp_advertisement
                                        
                                        	Disable advertising VRF re\-imported routes
                                        	**type**\: bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: is_directly_connected_ebgp_v6_peers
                                        
                                        	Directly connected EBGP v6 peers
                                        	**type**\: bool
                                        
                                        .. attribute:: minimum_advertisement_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: minimum_advertisement_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outbound route policy name
                                        	**type**\: str
                                        
                                        .. attribute:: desync_count
                                        
                                        	Number of times the update has been desynchronized
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: subgrp_merge_count
                                        
                                        	Number of times sub\-groups have been merged
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_subgrp_count
                                        
                                        	Current count of refresh subgroups
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updates_formatted
                                        
                                        	Number of updates formatted
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: updates_replicated
                                        
                                        	No. of updates replicated
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\: bool
                                        
                                        .. attribute:: as_override
                                        
                                        	AS Override option
                                        	**type**\: bool
                                        
                                        .. attribute:: soo_value
                                        
                                        	Site\-of\-origin value
                                        	**type**\: str
                                        
                                        .. attribute:: split_horizon
                                        
                                        	Split horizon check
                                        	**type**\: bool
                                        
                                        .. attribute:: is_labeled_afi_enabled
                                        
                                        	Update group has labeled AFI enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_unlabeled_afi_enabled
                                        
                                        	Update group has unlabeled AFI enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: ext_nh_encoding
                                        
                                        	Extended nexthop encoding cap received
                                        	**type**\: bool
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_adv_perm_net_capable
                                        
                                        	Advertise Permanent\-Net capable peers
                                        	**type**\: bool
                                        
                                        .. attribute:: should_send_gshut_community
                                        
                                        	Send GSHUT community
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_active
                                        
                                        	GSHUT active
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	GSHUT local preference set
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	GSHUT local preference
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	GSHUT AS prepends
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with local\-label via Unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: enable_label_stack
                                        
                                        	Enable label stack
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this update group which are not in any sub\-group
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                        
                                        .. attribute:: update_sub_group
                                        
                                        	Update sub\-group list
                                        	**type**\: list of  		 :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup, self).__init__()

                                            self.yang_name = "update-group"
                                            self.yang_parent_name = "update-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor)), ("update-sub-group", ("update_sub_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup))])
                                            self._leafs = OrderedDict([
                                                ('update_group_id', (YLeaf(YType.uint32, 'update-group-id'), ['int'])),
                                                ('filter_group_id', (YLeaf(YType.uint32, 'filter-group-id'), ['int'])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('session_af_name', (YLeaf(YType.uint8, 'session-af-name'), ['int'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('should_send_communities', (YLeaf(YType.boolean, 'should-send-communities'), ['bool'])),
                                                ('should_send_ext_communities', (YLeaf(YType.boolean, 'should-send-ext-communities'), ['bool'])),
                                                ('should_send_stitching_rt', (YLeaf(YType.boolean, 'should-send-stitching-rt'), ['bool'])),
                                                ('has_orf_receive_capability', (YLeaf(YType.boolean, 'has-orf-receive-capability'), ['bool'])),
                                                ('is_route_reflector_client', (YLeaf(YType.boolean, 'is-route-reflector-client'), ['bool'])),
                                                ('is_client_reflection_disabled', (YLeaf(YType.boolean, 'is-client-reflection-disabled'), ['bool'])),
                                                ('accepts_legacy_pe_rt_route', (YLeaf(YType.boolean, 'accepts-legacy-pe-rt-route'), ['bool'])),
                                                ('updgrp_cluster_id', (YLeaf(YType.uint32, 'updgrp-cluster-id'), ['int'])),
                                                ('updgrp_cluster_type', (YLeaf(YType.uint8, 'updgrp-cluster-type'), ['int'])),
                                                ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                                ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                                ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                                ('should_remove_private_a_ss', (YLeaf(YType.boolean, 'should-remove-private-a-ss'), ['bool'])),
                                                ('should_remove_private_as_ent_path', (YLeaf(YType.boolean, 'should-remove-private-as-ent-path'), ['bool'])),
                                                ('use_next_hop_self', (YLeaf(YType.boolean, 'use-next-hop-self'), ['bool'])),
                                                ('use_next_hop_unchanged_mpath', (YLeaf(YType.boolean, 'use-next-hop-unchanged-mpath'), ['bool'])),
                                                ('is_internal_peers', (YLeaf(YType.boolean, 'is-internal-peers'), ['bool'])),
                                                ('is_common_admin_peers', (YLeaf(YType.boolean, 'is-common-admin-peers'), ['bool'])),
                                                ('is4_byte_as_peer', (YLeaf(YType.boolean, 'is4-byte-as-peer'), ['bool'])),
                                                ('is_addpath_capable', (YLeaf(YType.boolean, 'is-addpath-capable'), ['bool'])),
                                                ('is_send_mcast_attr_enabled', (YLeaf(YType.boolean, 'is-send-mcast-attr-enabled'), ['bool'])),
                                                ('is_aigp_capable', (YLeaf(YType.boolean, 'is-aigp-capable'), ['bool'])),
                                                ('is_aigp_cost_community_capable', (YLeaf(YType.boolean, 'is-aigp-cost-community-capable'), ['bool'])),
                                                ('is_aigp_med_capable', (YLeaf(YType.boolean, 'is-aigp-med-capable'), ['bool'])),
                                                ('is_llgr_capable', (YLeaf(YType.boolean, 'is-llgr-capable'), ['bool'])),
                                                ('is_adv_capable', (YLeaf(YType.boolean, 'is-adv-capable'), ['bool'])),
                                                ('is_adv_reorg_capable', (YLeaf(YType.boolean, 'is-adv-reorg-capable'), ['bool'])),
                                                ('disable_native_advertisement', (YLeaf(YType.boolean, 'disable-native-advertisement'), ['bool'])),
                                                ('disable_def_vrf_imp_advertisement', (YLeaf(YType.boolean, 'disable-def-vrf-imp-advertisement'), ['bool'])),
                                                ('disable_vrf_re_imp_advertisement', (YLeaf(YType.boolean, 'disable-vrf-re-imp-advertisement'), ['bool'])),
                                                ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                                ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                                ('is_directly_connected_ebgp_v6_peers', (YLeaf(YType.boolean, 'is-directly-connected-ebgp-v6-peers'), ['bool'])),
                                                ('minimum_advertisement_interval', (YLeaf(YType.uint32, 'minimum-advertisement-interval'), ['int'])),
                                                ('minimum_advertisement_interval_msecs', (YLeaf(YType.uint32, 'minimum-advertisement-interval-msecs'), ['int'])),
                                                ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                                ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                                ('desync_count', (YLeaf(YType.uint32, 'desync-count'), ['int'])),
                                                ('subgrp_merge_count', (YLeaf(YType.uint32, 'subgrp-merge-count'), ['int'])),
                                                ('refresh_subgrp_count', (YLeaf(YType.uint32, 'refresh-subgrp-count'), ['int'])),
                                                ('updates_formatted', (YLeaf(YType.uint32, 'updates-formatted'), ['int'])),
                                                ('updates_replicated', (YLeaf(YType.uint32, 'updates-replicated'), ['int'])),
                                                ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                                ('as_override', (YLeaf(YType.boolean, 'as-override'), ['bool'])),
                                                ('soo_value', (YLeaf(YType.str, 'soo-value'), ['str'])),
                                                ('split_horizon', (YLeaf(YType.boolean, 'split-horizon'), ['bool'])),
                                                ('is_labeled_afi_enabled', (YLeaf(YType.boolean, 'is-labeled-afi-enabled'), ['bool'])),
                                                ('is_unlabeled_afi_enabled', (YLeaf(YType.boolean, 'is-unlabeled-afi-enabled'), ['bool'])),
                                                ('ext_nh_encoding', (YLeaf(YType.boolean, 'ext-nh-encoding'), ['bool'])),
                                                ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                                ('is_adv_perm_net_capable', (YLeaf(YType.boolean, 'is-adv-perm-net-capable'), ['bool'])),
                                                ('should_send_gshut_community', (YLeaf(YType.boolean, 'should-send-gshut-community'), ['bool'])),
                                                ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                                ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                                ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                                ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                                ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                                ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                            ])
                                            self.update_group_id = None
                                            self.filter_group_id = None
                                            self.process_instance_id = None
                                            self.session_af_name = None
                                            self.update_group_number = None
                                            self.update_group_af_name = None
                                            self.should_send_communities = None
                                            self.should_send_ext_communities = None
                                            self.should_send_stitching_rt = None
                                            self.has_orf_receive_capability = None
                                            self.is_route_reflector_client = None
                                            self.is_client_reflection_disabled = None
                                            self.accepts_legacy_pe_rt_route = None
                                            self.updgrp_cluster_id = None
                                            self.updgrp_cluster_type = None
                                            self.orr_group_name = None
                                            self.orr_group_index = None
                                            self.is_orr_root_address_configured = None
                                            self.should_remove_private_a_ss = None
                                            self.should_remove_private_as_ent_path = None
                                            self.use_next_hop_self = None
                                            self.use_next_hop_unchanged_mpath = None
                                            self.is_internal_peers = None
                                            self.is_common_admin_peers = None
                                            self.is4_byte_as_peer = None
                                            self.is_addpath_capable = None
                                            self.is_send_mcast_attr_enabled = None
                                            self.is_aigp_capable = None
                                            self.is_aigp_cost_community_capable = None
                                            self.is_aigp_med_capable = None
                                            self.is_llgr_capable = None
                                            self.is_adv_capable = None
                                            self.is_adv_reorg_capable = None
                                            self.disable_native_advertisement = None
                                            self.disable_def_vrf_imp_advertisement = None
                                            self.disable_vrf_re_imp_advertisement = None
                                            self.encapsulation_type = None
                                            self.advertise_rt_type = None
                                            self.is_directly_connected_ebgp_v6_peers = None
                                            self.minimum_advertisement_interval = None
                                            self.minimum_advertisement_interval_msecs = None
                                            self.local_as = None
                                            self.route_policy_out = None
                                            self.desync_count = None
                                            self.subgrp_merge_count = None
                                            self.refresh_subgrp_count = None
                                            self.updates_formatted = None
                                            self.updates_replicated = None
                                            self.local_as_replace_as = None
                                            self.as_override = None
                                            self.soo_value = None
                                            self.split_horizon = None
                                            self.is_labeled_afi_enabled = None
                                            self.is_unlabeled_afi_enabled = None
                                            self.ext_nh_encoding = None
                                            self.remote_as = None
                                            self.is_adv_perm_net_capable = None
                                            self.should_send_gshut_community = None
                                            self.gshut_active = None
                                            self.gshut_locpref_set = None
                                            self.gshut_locpref = None
                                            self.gshut_prepends = None
                                            self.advertise_local_labeled_route_unicast = None
                                            self.enable_label_stack = None

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"

                                            self.neighbor = YList(self)
                                            self.update_sub_group = YList(self)
                                            self._segment_path = lambda: "update-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup, ['update_group_id', 'filter_group_id', u'process_instance_id', u'session_af_name', u'update_group_number', u'update_group_af_name', u'should_send_communities', u'should_send_ext_communities', u'should_send_stitching_rt', u'has_orf_receive_capability', u'is_route_reflector_client', u'is_client_reflection_disabled', u'accepts_legacy_pe_rt_route', u'updgrp_cluster_id', u'updgrp_cluster_type', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'should_remove_private_a_ss', u'should_remove_private_as_ent_path', u'use_next_hop_self', u'use_next_hop_unchanged_mpath', u'is_internal_peers', u'is_common_admin_peers', u'is4_byte_as_peer', u'is_addpath_capable', u'is_send_mcast_attr_enabled', u'is_aigp_capable', u'is_aigp_cost_community_capable', u'is_aigp_med_capable', u'is_llgr_capable', u'is_adv_capable', u'is_adv_reorg_capable', u'disable_native_advertisement', u'disable_def_vrf_imp_advertisement', u'disable_vrf_re_imp_advertisement', u'encapsulation_type', u'advertise_rt_type', u'is_directly_connected_ebgp_v6_peers', u'minimum_advertisement_interval', u'minimum_advertisement_interval_msecs', u'local_as', u'route_policy_out', u'desync_count', u'subgrp_merge_count', u'refresh_subgrp_count', u'updates_formatted', u'updates_replicated', u'local_as_replace_as', u'as_override', u'soo_value', u'split_horizon', u'is_labeled_afi_enabled', u'is_unlabeled_afi_enabled', u'ext_nh_encoding', u'remote_as', u'is_adv_perm_net_capable', u'should_send_gshut_community', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends', u'advertise_local_labeled_route_unicast', u'enable_label_stack'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: update_generation_calls
                                            
                                            	No. of calls to update generation function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_prefixes_count
                                            
                                            	No. of prefixes updates generated for
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_be_prefixes_count
                                            
                                            	No. of be prefixes updates generated for
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_messages_count
                                            
                                            	No. of update messages generated
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_generation_time
                                            
                                            	Time spent generating updates (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: updgen_timer_start_time
                                            
                                            	Timestamp when update timer started for updgrp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_stop_time
                                            
                                            	Timestamp when update timer stopped for updgrp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: updgen_timer_process_time
                                            
                                            	Timestamp when update timer processed for updgrp
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('update_generation_calls', (YLeaf(YType.uint32, 'update-generation-calls'), ['int'])),
                                                    ('update_generation_prefixes_count', (YLeaf(YType.uint32, 'update-generation-prefixes-count'), ['int'])),
                                                    ('update_generation_be_prefixes_count', (YLeaf(YType.uint32, 'update-generation-be-prefixes-count'), ['int'])),
                                                    ('update_generation_messages_count', (YLeaf(YType.uint32, 'update-generation-messages-count'), ['int'])),
                                                    ('update_generation_time', (YLeaf(YType.uint32, 'update-generation-time'), ['int'])),
                                                    ('updgen_timer_start_time', (YLeaf(YType.uint64, 'updgen-timer-start-time'), ['int'])),
                                                    ('updgen_timer_stop_time', (YLeaf(YType.uint64, 'updgen-timer-stop-time'), ['int'])),
                                                    ('updgen_timer_process_time', (YLeaf(YType.uint64, 'updgen-timer-process-time'), ['int'])),
                                                ])
                                                self.update_generation_calls = None
                                                self.update_generation_prefixes_count = None
                                                self.update_generation_be_prefixes_count = None
                                                self.update_generation_messages_count = None
                                                self.update_generation_time = None
                                                self.updgen_timer_start_time = None
                                                self.updgen_timer_stop_time = None
                                                self.updgen_timer_process_time = None
                                                self._segment_path = lambda: "performance-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, [u'update_generation_calls', u'update_generation_prefixes_count', u'update_generation_be_prefixes_count', u'update_generation_messages_count', u'update_generation_time', u'updgen_timer_start_time', u'updgen_timer_stop_time', u'updgen_timer_process_time'], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Neighbors in this update group which are not in
                                            any sub\-group
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class UpdateSubGroup(Entity):
                                            """
                                            Update sub\-group list
                                            
                                            .. attribute:: update_sub_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: filter_group
                                            
                                            	Update sub\-group fgrp\-num
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: wait_for_eo_rs
                                            
                                            	Wait for  RT Nbr EoRs
                                            	**type**\: bool
                                            
                                            .. attribute:: update_filter_group
                                            
                                            	Update f\-group list
                                            	**type**\: list of  		 :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this subgrp not in any filtergrp
                                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, self).__init__()

                                                self.yang_name = "update-sub-group"
                                                self.yang_parent_name = "update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("update-filter-group", ("update_filter_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor))])
                                                self._leafs = OrderedDict([
                                                    ('update_sub_group_number', (YLeaf(YType.uint32, 'update-sub-group-number'), ['int'])),
                                                    ('filter_group', (YLeaf(YType.uint16, 'filter-group'), ['int'])),
                                                    ('wait_for_eo_rs', (YLeaf(YType.boolean, 'wait-for-eo-rs'), ['bool'])),
                                                ])
                                                self.update_sub_group_number = None
                                                self.filter_group = None
                                                self.wait_for_eo_rs = None

                                                self.update_filter_group = YList(self)
                                                self.neighbor = YList(self)
                                                self._segment_path = lambda: "update-sub-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, [u'update_sub_group_number', u'filter_group', u'wait_for_eo_rs'], name, value)


                                            class UpdateFilterGroup(Entity):
                                                """
                                                Update f\-group list
                                                
                                                .. attribute:: update_filter_group_number
                                                
                                                	Update sub\-group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rts
                                                
                                                	RT count per filter group
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_flags
                                                
                                                	Flags per filter group
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fgroup_neighbors
                                                
                                                	Nbrs per filter group
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: fgroup_created_message_elements
                                                
                                                	Number of message elems created for filtergroup
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_deleted_message_elements
                                                
                                                	Number of message elems deleted
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_queued_message_elements
                                                
                                                	Number of message elems queued
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in last update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_advertised_prefixes
                                                
                                                	Number of prefixes advertised to filtergroup in all update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_withdrawn_prefixes
                                                
                                                	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_total_non_optimised_prefixes
                                                
                                                	Number of prefixes  non\-optm from filtergroupin all update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_skipped_prefixes
                                                
                                                	Number of prefixes skipped for filtergroup in last update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fgroup_suppressed_prefixes
                                                
                                                	Number of prefixes suppressed for filtergroup in last update walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_rt_present
                                                
                                                	RT attribute list present
                                                	**type**\: bool
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                                
                                                .. attribute:: neighbor
                                                
                                                	Neighbors in this update sub\-group
                                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, self).__init__()

                                                    self.yang_name = "update-filter-group"
                                                    self.yang_parent_name = "update-sub-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor))])
                                                    self._leafs = OrderedDict([
                                                        ('update_filter_group_number', (YLeaf(YType.uint32, 'update-filter-group-number'), ['int'])),
                                                        ('rts', (YLeaf(YType.uint32, 'rts'), ['int'])),
                                                        ('fgroup_flags', (YLeaf(YType.uint8, 'fgroup-flags'), ['int'])),
                                                        ('fgroup_neighbors', (YLeaf(YType.uint16, 'fgroup-neighbors'), ['int'])),
                                                        ('fgroup_created_message_elements', (YLeaf(YType.uint32, 'fgroup-created-message-elements'), ['int'])),
                                                        ('fgroup_deleted_message_elements', (YLeaf(YType.uint32, 'fgroup-deleted-message-elements'), ['int'])),
                                                        ('fgroup_queued_message_elements', (YLeaf(YType.uint32, 'fgroup-queued-message-elements'), ['int'])),
                                                        ('fgroup_advertised_prefixes', (YLeaf(YType.uint32, 'fgroup-advertised-prefixes'), ['int'])),
                                                        ('fgroup_total_advertised_prefixes', (YLeaf(YType.uint32, 'fgroup-total-advertised-prefixes'), ['int'])),
                                                        ('fgroup_withdrawn_prefixes', (YLeaf(YType.uint32, 'fgroup-withdrawn-prefixes'), ['int'])),
                                                        ('fgroup_total_withdrawn_prefixes', (YLeaf(YType.uint32, 'fgroup-total-withdrawn-prefixes'), ['int'])),
                                                        ('fgroup_total_non_optimised_prefixes', (YLeaf(YType.uint32, 'fgroup-total-non-optimised-prefixes'), ['int'])),
                                                        ('fgroup_skipped_prefixes', (YLeaf(YType.uint32, 'fgroup-skipped-prefixes'), ['int'])),
                                                        ('fgroup_suppressed_prefixes', (YLeaf(YType.uint32, 'fgroup-suppressed-prefixes'), ['int'])),
                                                        ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                                    ])
                                                    self.update_filter_group_number = None
                                                    self.rts = None
                                                    self.fgroup_flags = None
                                                    self.fgroup_neighbors = None
                                                    self.fgroup_created_message_elements = None
                                                    self.fgroup_deleted_message_elements = None
                                                    self.fgroup_queued_message_elements = None
                                                    self.fgroup_advertised_prefixes = None
                                                    self.fgroup_total_advertised_prefixes = None
                                                    self.fgroup_withdrawn_prefixes = None
                                                    self.fgroup_total_withdrawn_prefixes = None
                                                    self.fgroup_total_non_optimised_prefixes = None
                                                    self.fgroup_skipped_prefixes = None
                                                    self.fgroup_suppressed_prefixes = None
                                                    self.is_rt_present = None

                                                    self.extended_community = YList(self)
                                                    self.neighbor = YList(self)
                                                    self._segment_path = lambda: "update-filter-group"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, [u'update_filter_group_number', u'rts', u'fgroup_flags', u'fgroup_neighbors', u'fgroup_created_message_elements', u'fgroup_deleted_message_elements', u'fgroup_queued_message_elements', u'fgroup_advertised_prefixes', u'fgroup_total_advertised_prefixes', u'fgroup_withdrawn_prefixes', u'fgroup_total_withdrawn_prefixes', u'fgroup_total_non_optimised_prefixes', u'fgroup_skipped_prefixes', u'fgroup_suppressed_prefixes', u'is_rt_present'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "update-filter-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, [u'entry'], name, value)


                                                class Neighbor(Entity):
                                                    """
                                                    Neighbors in this update sub\-group
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, self).__init__()

                                                        self.yang_name = "neighbor"
                                                        self.yang_parent_name = "update-filter-group"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class Neighbor(Entity):
                                                """
                                                Neighbors in this subgrp not in any filtergrp
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, self).__init__()

                                                    self.yang_name = "neighbor"
                                                    self.yang_parent_name = "update-sub-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class UpdateGenerationSubGroups(Entity):
                                    """
                                    Update generation for all sub\-groups
                                    
                                    .. attribute:: update_generation_sub_group
                                    
                                    	Update generation for sub\-group
                                    	**type**\: list of  		 :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups, self).__init__()

                                        self.yang_name = "update-generation-sub-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-generation-sub-group", ("update_generation_sub_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup))])
                                        self._leafs = OrderedDict()

                                        self.update_generation_sub_group = YList(self)
                                        self._segment_path = lambda: "update-generation-sub-groups"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups, [], name, value)


                                    class UpdateGenerationSubGroup(Entity):
                                        """
                                        Update generation for sub\-group
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: creation_timestamp
                                        
                                        	Creation time
                                        	**type**\:  :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                        
                                        .. attribute:: last_merge_timestamp
                                        
                                        	Last merge time
                                        	**type**\:  :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                        
                                        .. attribute:: first_update_walk_start_timestamp
                                        
                                        	First update walk start time
                                        	**type**\:  :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: first_update_walk_end_timestamp
                                        
                                        	First update walk end time
                                        	**type**\:  :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: last_update_walk_start_timestamp
                                        
                                        	Last update walk start time
                                        	**type**\:  :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                        
                                        .. attribute:: last_update_walk_end_timestamp
                                        
                                        	Last update walk end time
                                        	**type**\:  :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:  :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: current_update_limit_sub_group
                                        
                                        	Current update limit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: configured_update_limit_sub_group
                                        
                                        	Configured update limit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_throttled
                                        
                                        	Is update throttled
                                        	**type**\: bool
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_version
                                        
                                        	NSR version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_resume_version
                                        
                                        	Next resume version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: io_write_event_pending
                                        
                                        	Is IO write event pending
                                        	**type**\: bool
                                        
                                        .. attribute:: update_default_route_sent
                                        
                                        	Is default route sent
                                        	**type**\: bool
                                        
                                        .. attribute:: merge_count
                                        
                                        	Merge count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_merged_sub_group_index
                                        
                                        	Last merged sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_attempted
                                        
                                        	Sending EoR has been attempted
                                        	**type**\: bool
                                        
                                        .. attribute:: last_update_walk_end_age
                                        
                                        	Time since last update walk end event
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, self).__init__()

                                            self.yang_name = "update-generation-sub-group"
                                            self.yang_parent_name = "update-generation-sub-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("creation-timestamp", ("creation_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp)), ("last-merge-timestamp", ("last_merge_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp)), ("first-update-walk-start-timestamp", ("first_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp)), ("first-update-walk-end-timestamp", ("first_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp)), ("last-update-walk-start-timestamp", ("last_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp)), ("last-update-walk-end-timestamp", ("last_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp)), ("last-update-queued-timestamp", ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics))])
                                            self._leafs = OrderedDict([
                                                ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                                ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                                ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                                ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                                ('sub_group_id_xr', (YLeaf(YType.uint32, 'sub-group-id-xr'), ['int'])),
                                                ('parent_sub_group_index', (YLeaf(YType.uint32, 'parent-sub-group-index'), ['int'])),
                                                ('parent_sub_group_id', (YLeaf(YType.uint32, 'parent-sub-group-id'), ['int'])),
                                                ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                                ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                                ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                                ('current_update_limit_sub_group', (YLeaf(YType.uint32, 'current-update-limit-sub-group'), ['int'])),
                                                ('configured_update_limit_sub_group', (YLeaf(YType.uint32, 'configured-update-limit-sub-group'), ['int'])),
                                                ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                                ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                                ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                                                ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                                ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                                ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                ('nsr_version', (YLeaf(YType.uint32, 'nsr-version'), ['int'])),
                                                ('pending_target_version', (YLeaf(YType.uint32, 'pending-target-version'), ['int'])),
                                                ('next_resume_version', (YLeaf(YType.uint32, 'next-resume-version'), ['int'])),
                                                ('update_refresh_target_version', (YLeaf(YType.uint32, 'update-refresh-target-version'), ['int'])),
                                                ('io_write_event_pending', (YLeaf(YType.boolean, 'io-write-event-pending'), ['bool'])),
                                                ('update_default_route_sent', (YLeaf(YType.boolean, 'update-default-route-sent'), ['bool'])),
                                                ('merge_count', (YLeaf(YType.uint32, 'merge-count'), ['int'])),
                                                ('last_merged_sub_group_index', (YLeaf(YType.uint32, 'last-merged-sub-group-index'), ['int'])),
                                                ('eo_r_attempted', (YLeaf(YType.boolean, 'eo-r-attempted'), ['bool'])),
                                                ('last_update_walk_end_age', (YLeaf(YType.uint32, 'last-update-walk-end-age'), ['int'])),
                                                ('last_update_queued_age', (YLeaf(YType.uint32, 'last-update-queued-age'), ['int'])),
                                            ])
                                            self.update_group_index = None
                                            self.sub_group_index = None
                                            self.sub_group_id = None
                                            self.process_id = None
                                            self.update_vrf_name = None
                                            self.update_group_af_name = None
                                            self.sub_group_index_xr = None
                                            self.sub_group_id_xr = None
                                            self.parent_sub_group_index = None
                                            self.parent_sub_group_id = None
                                            self.update_group_index_xr = None
                                            self.update_main_table_version = None
                                            self.update_vrf_table_rib_version = None
                                            self.current_update_limit_sub_group = None
                                            self.configured_update_limit_sub_group = None
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.update_throttled = None
                                            self.refresh_sub_group_count = None
                                            self.filter_group_count = None
                                            self.neighbor_count = None
                                            self.version = None
                                            self.nsr_version = None
                                            self.pending_target_version = None
                                            self.next_resume_version = None
                                            self.update_refresh_target_version = None
                                            self.io_write_event_pending = None
                                            self.update_default_route_sent = None
                                            self.merge_count = None
                                            self.last_merged_sub_group_index = None
                                            self.eo_r_attempted = None
                                            self.last_update_walk_end_age = None
                                            self.last_update_queued_age = None

                                            self.creation_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                            self.creation_timestamp.parent = self
                                            self._children_name_map["creation_timestamp"] = "creation-timestamp"

                                            self.last_merge_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                            self.last_merge_timestamp.parent = self
                                            self._children_name_map["last_merge_timestamp"] = "last-merge-timestamp"

                                            self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                            self.first_update_walk_start_timestamp.parent = self
                                            self._children_name_map["first_update_walk_start_timestamp"] = "first-update-walk-start-timestamp"

                                            self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                            self.first_update_walk_end_timestamp.parent = self
                                            self._children_name_map["first_update_walk_end_timestamp"] = "first-update-walk-end-timestamp"

                                            self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                            self.last_update_walk_start_timestamp.parent = self
                                            self._children_name_map["last_update_walk_start_timestamp"] = "last-update-walk-start-timestamp"

                                            self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                            self.last_update_walk_end_timestamp.parent = self
                                            self._children_name_map["last_update_walk_end_timestamp"] = "last-update-walk-end-timestamp"

                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"

                                            self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._segment_path = lambda: "update-generation-sub-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, ['update_group_index', 'sub_group_index', 'sub_group_id', u'process_id', u'update_vrf_name', u'update_group_af_name', u'sub_group_index_xr', u'sub_group_id_xr', u'parent_sub_group_index', u'parent_sub_group_id', u'update_group_index_xr', u'update_main_table_version', u'update_vrf_table_rib_version', u'current_update_limit_sub_group', u'configured_update_limit_sub_group', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled', u'refresh_sub_group_count', u'filter_group_count', u'neighbor_count', u'version', u'nsr_version', u'pending_target_version', u'next_resume_version', u'update_refresh_target_version', u'io_write_event_pending', u'update_default_route_sent', u'merge_count', u'last_merged_sub_group_index', u'eo_r_attempted', u'last_update_walk_end_age', u'last_update_queued_age'], name, value)


                                        class CreationTimestamp(Entity):
                                            """
                                            Creation time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, self).__init__()

                                                self.yang_name = "creation-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "creation-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastMergeTimestamp(Entity):
                                            """
                                            Last merge time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, self).__init__()

                                                self.yang_name = "last-merge-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-merge-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstUpdateWalkStartTimestamp(Entity):
                                            """
                                            First update walk start time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, self).__init__()

                                                self.yang_name = "first-update-walk-start-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-update-walk-start-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstUpdateWalkEndTimestamp(Entity):
                                            """
                                            First update walk end time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, self).__init__()

                                                self.yang_name = "first-update-walk-end-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-update-walk-end-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateWalkStartTimestamp(Entity):
                                            """
                                            Last update walk start time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-walk-start-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-walk-start-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateWalkEndTimestamp(Entity):
                                            """
                                            Last update walk end time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, self).__init__()

                                                self.yang_name = "last-update-walk-end-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-walk-end-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateQueuedTimestamp(Entity):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-queued-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                                self._leafs = OrderedDict([
                                                    ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                    ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                    ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                    ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                    ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                    ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                    ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                    ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                    ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                    ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                    ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                    ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                    ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                    ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                    ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                    ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                                ])
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_size_high = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_cleared = None
                                                self.last_update_discard_age = None
                                                self.last_update_cleard_age = None
                                                self.update_throttle_count = None
                                                self.last_update_throttle_age = None
                                                self.update_recovery_count = None
                                                self.last_update_recovery_age = None
                                                self.update_memory_allocation_fail_count = None
                                                self.last_update_memory_allocation_fail_age = None

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._segment_path = lambda: "update-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-discard-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class NextHopAddressFamilies(Entity):
                                    """
                                    Address family of nexthop table
                                    
                                    .. attribute:: next_hop_address_family
                                    
                                    	Nexthop Address family
                                    	**type**\: list of  		 :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies, self).__init__()

                                        self.yang_name = "next-hop-address-families"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("next-hop-address-family", ("next_hop_address_family", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily))])
                                        self._leafs = OrderedDict()

                                        self.next_hop_address_family = YList(self)
                                        self._segment_path = lambda: "next-hop-address-families"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies, [], name, value)


                                    class NextHopAddressFamily(Entity):
                                        """
                                        Nexthop Address family
                                        
                                        .. attribute:: next_hop_af_name  (key)
                                        
                                        	Address family
                                        	**type**\:  :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: next_hop_af_vrf_af
                                        
                                        	A BGP Next\-hop VRF AF table entry
                                        	**type**\:  :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                        
                                        .. attribute:: next_hop_afs
                                        
                                        	The BGP Next\-hop table
                                        	**type**\:  :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, self).__init__()

                                            self.yang_name = "next-hop-address-family"
                                            self.yang_parent_name = "next-hop-address-families"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['next_hop_af_name']
                                            self._child_classes = OrderedDict([("next-hop-af-vrf-af", ("next_hop_af_vrf_af", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf)), ("next-hop-afs", ("next_hop_afs", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs))])
                                            self._leafs = OrderedDict([
                                                ('next_hop_af_name', (YLeaf(YType.enumeration, 'next-hop-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes', 'BgpAddressFamily', '')])),
                                            ])
                                            self.next_hop_af_name = None

                                            self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                            self.next_hop_af_vrf_af.parent = self
                                            self._children_name_map["next_hop_af_vrf_af"] = "next-hop-af-vrf-af"

                                            self.next_hop_afs = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                            self.next_hop_afs.parent = self
                                            self._children_name_map["next_hop_afs"] = "next-hop-afs"
                                            self._segment_path = lambda: "next-hop-address-family" + "[next-hop-af-name='" + str(self.next_hop_af_name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, ['next_hop_af_name'], name, value)


                                        class NextHopAfVrfAf(Entity):
                                            """
                                            A BGP Next\-hop VRF AF table entry
                                            
                                            .. attribute:: performance_statistics
                                            
                                            	Performance statistics
                                            	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: gwaf_name
                                            
                                            	GW Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: total_nexthops
                                            
                                            	Total number of nexthops
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: critical_trigger_delay
                                            
                                            	Trigger delay for critical event processing
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: non_critical_trigger_delay
                                            
                                            	Trigger delay for non\-critical event processing
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: table_active
                                            
                                            	Whether the VRF is active
                                            	**type**\: bool
                                            
                                            .. attribute:: nh_rib_up
                                            
                                            	Whether the VRF is active
                                            	**type**\: bool
                                            
                                            .. attribute:: nh_rib_version
                                            
                                            	RIB version for gw\_ctx
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_nexthop_version
                                            
                                            	NH version for gw\_ctx
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_table_id
                                            
                                            	Gateway context table id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_table_version
                                            
                                            	Version of the EPE table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_label_version
                                            
                                            	Version of the EPE label walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_downloaded_version
                                            
                                            	Version of the EPE table downloaded
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: epe_standby_version
                                            
                                            	Version of the EPE table processed by sync thread
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, self).__init__()

                                                self.yang_name = "next-hop-af-vrf-af"
                                                self.yang_parent_name = "next-hop-address-family"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics))])
                                                self._leafs = OrderedDict([
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('gwaf_name', (YLeaf(YType.enumeration, 'gwaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('total_nexthops', (YLeaf(YType.uint32, 'total-nexthops'), ['int'])),
                                                    ('critical_trigger_delay', (YLeaf(YType.uint32, 'critical-trigger-delay'), ['int'])),
                                                    ('non_critical_trigger_delay', (YLeaf(YType.uint32, 'non-critical-trigger-delay'), ['int'])),
                                                    ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                                                    ('nh_rib_up', (YLeaf(YType.boolean, 'nh-rib-up'), ['bool'])),
                                                    ('nh_rib_version', (YLeaf(YType.uint32, 'nh-rib-version'), ['int'])),
                                                    ('nh_nexthop_version', (YLeaf(YType.uint32, 'nh-nexthop-version'), ['int'])),
                                                    ('nh_table_id', (YLeaf(YType.uint32, 'nh-table-id'), ['int'])),
                                                    ('epe_table_version', (YLeaf(YType.uint32, 'epe-table-version'), ['int'])),
                                                    ('epe_label_version', (YLeaf(YType.uint32, 'epe-label-version'), ['int'])),
                                                    ('epe_downloaded_version', (YLeaf(YType.uint32, 'epe-downloaded-version'), ['int'])),
                                                    ('epe_standby_version', (YLeaf(YType.uint32, 'epe-standby-version'), ['int'])),
                                                ])
                                                self.af_name = None
                                                self.gwaf_name = None
                                                self.total_nexthops = None
                                                self.critical_trigger_delay = None
                                                self.non_critical_trigger_delay = None
                                                self.table_active = None
                                                self.nh_rib_up = None
                                                self.nh_rib_version = None
                                                self.nh_nexthop_version = None
                                                self.nh_table_id = None
                                                self.epe_table_version = None
                                                self.epe_label_version = None
                                                self.epe_downloaded_version = None
                                                self.epe_standby_version = None

                                                self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                                self.performance_statistics.parent = self
                                                self._children_name_map["performance_statistics"] = "performance-statistics"
                                                self._segment_path = lambda: "next-hop-af-vrf-af"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, [u'af_name', u'gwaf_name', u'total_nexthops', u'critical_trigger_delay', u'non_critical_trigger_delay', u'table_active', u'nh_rib_up', u'nh_rib_version', u'nh_nexthop_version', u'nh_table_id', u'epe_table_version', u'epe_label_version', u'epe_downloaded_version', u'epe_standby_version'], name, value)


                                            class PerformanceStatistics(Entity):
                                                """
                                                Performance statistics
                                                
                                                .. attribute:: critical_notf_count
                                                
                                                	Number of critical event notifications from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: noncritical_notf_count
                                                
                                                	Number of non\-critical event notifications from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_deletes
                                                
                                                	Number of bestpath deletes due to last notification
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_notf_bestpath_changes
                                                
                                                	Number of bestpath changes due to last notification
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_sync_reg_calls
                                                
                                                	NH sync register calls
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_reg_calls
                                                
                                                	NH async register calls
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nha_sync_un_reg_calls
                                                
                                                	NH async unregister calls
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_pending_registrations
                                                
                                                	NH Registration List Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_peak_registrations
                                                
                                                	NH Registration List Count Peak
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_batch_finish_calls
                                                
                                                	NH batch finish calls
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_flush_timer_calls
                                                
                                                	NH flush timer calls
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_sync_reg_ts
                                                
                                                	NH Last sync Register TS
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_reg_ts
                                                
                                                	NH Last async Register TS
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_a_sync_un_reg_ts
                                                
                                                	NH Last async UnRegister TS
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_batch_finish_ts
                                                
                                                	NH Last batch finish TS
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_last_flush_timer_ts
                                                
                                                	NH Last flush timer TS
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_calls
                                                
                                                	No. of calls to RIB update function
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nhrib_update_time
                                                
                                                	Time spent sending RIB updates (milliseconds)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: millisecond
                                                
                                                .. attribute:: nexthops_sent_to_rib
                                                
                                                	No. of nexthops sent to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_resent_to_rib
                                                
                                                	No. of nexthops re\-sent to RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthops_removed_from_rib
                                                
                                                	No. of nexthops withdrawn from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rib_sync_registers_failed
                                                
                                                	No. of sync registers with RIB that failed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: riba_sync_registers_failed
                                                
                                                	No. of async registers with RIB that failed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                                
                                                	No. of nh registers failed because of no tbl\-id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                                
                                                	No. of nh registers failed because of no rib conn
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_nh_not_found
                                                
                                                	No. of times nexthop was not found during tunnel walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_gw_not_found
                                                
                                                	No. of times gw was not found during tunnel walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_walk_backup_creates
                                                
                                                	No. of times backup tid created during tunnel walk
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, self).__init__()

                                                    self.yang_name = "performance-statistics"
                                                    self.yang_parent_name = "next-hop-af-vrf-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical_notf_count', (YLeaf(YType.uint32, 'critical-notf-count'), ['int'])),
                                                        ('noncritical_notf_count', (YLeaf(YType.uint32, 'noncritical-notf-count'), ['int'])),
                                                        ('last_notf_bestpath_deletes', (YLeaf(YType.uint32, 'last-notf-bestpath-deletes'), ['int'])),
                                                        ('last_notf_bestpath_changes', (YLeaf(YType.uint32, 'last-notf-bestpath-changes'), ['int'])),
                                                        ('nh_sync_reg_calls', (YLeaf(YType.uint32, 'nh-sync-reg-calls'), ['int'])),
                                                        ('nha_sync_reg_calls', (YLeaf(YType.uint32, 'nha-sync-reg-calls'), ['int'])),
                                                        ('nha_sync_un_reg_calls', (YLeaf(YType.uint32, 'nha-sync-un-reg-calls'), ['int'])),
                                                        ('nh_pending_registrations', (YLeaf(YType.uint32, 'nh-pending-registrations'), ['int'])),
                                                        ('nh_peak_registrations', (YLeaf(YType.uint32, 'nh-peak-registrations'), ['int'])),
                                                        ('nh_batch_finish_calls', (YLeaf(YType.uint32, 'nh-batch-finish-calls'), ['int'])),
                                                        ('nh_flush_timer_calls', (YLeaf(YType.uint32, 'nh-flush-timer-calls'), ['int'])),
                                                        ('nh_last_sync_reg_ts', (YLeaf(YType.uint32, 'nh-last-sync-reg-ts'), ['int'])),
                                                        ('nh_last_a_sync_reg_ts', (YLeaf(YType.uint32, 'nh-last-a-sync-reg-ts'), ['int'])),
                                                        ('nh_last_a_sync_un_reg_ts', (YLeaf(YType.uint32, 'nh-last-a-sync-un-reg-ts'), ['int'])),
                                                        ('nh_last_batch_finish_ts', (YLeaf(YType.uint32, 'nh-last-batch-finish-ts'), ['int'])),
                                                        ('nh_last_flush_timer_ts', (YLeaf(YType.uint32, 'nh-last-flush-timer-ts'), ['int'])),
                                                        ('nhrib_update_calls', (YLeaf(YType.uint32, 'nhrib-update-calls'), ['int'])),
                                                        ('nhrib_update_time', (YLeaf(YType.uint32, 'nhrib-update-time'), ['int'])),
                                                        ('nexthops_sent_to_rib', (YLeaf(YType.uint32, 'nexthops-sent-to-rib'), ['int'])),
                                                        ('nexthops_resent_to_rib', (YLeaf(YType.uint32, 'nexthops-resent-to-rib'), ['int'])),
                                                        ('nexthops_removed_from_rib', (YLeaf(YType.uint32, 'nexthops-removed-from-rib'), ['int'])),
                                                        ('rib_sync_registers_failed', (YLeaf(YType.uint32, 'rib-sync-registers-failed'), ['int'])),
                                                        ('riba_sync_registers_failed', (YLeaf(YType.uint32, 'riba-sync-registers-failed'), ['int'])),
                                                        ('ribnh_reg_failed_for_no_tbl_id', (YLeaf(YType.uint32, 'ribnh-reg-failed-for-no-tbl-id'), ['int'])),
                                                        ('ribnh_reg_failed_for_no_rib_conn', (YLeaf(YType.uint32, 'ribnh-reg-failed-for-no-rib-conn'), ['int'])),
                                                        ('tunnel_walk_nh_not_found', (YLeaf(YType.uint32, 'tunnel-walk-nh-not-found'), ['int'])),
                                                        ('tunnel_walk_gw_not_found', (YLeaf(YType.uint32, 'tunnel-walk-gw-not-found'), ['int'])),
                                                        ('tunnel_walk_backup_creates', (YLeaf(YType.uint32, 'tunnel-walk-backup-creates'), ['int'])),
                                                    ])
                                                    self.critical_notf_count = None
                                                    self.noncritical_notf_count = None
                                                    self.last_notf_bestpath_deletes = None
                                                    self.last_notf_bestpath_changes = None
                                                    self.nh_sync_reg_calls = None
                                                    self.nha_sync_reg_calls = None
                                                    self.nha_sync_un_reg_calls = None
                                                    self.nh_pending_registrations = None
                                                    self.nh_peak_registrations = None
                                                    self.nh_batch_finish_calls = None
                                                    self.nh_flush_timer_calls = None
                                                    self.nh_last_sync_reg_ts = None
                                                    self.nh_last_a_sync_reg_ts = None
                                                    self.nh_last_a_sync_un_reg_ts = None
                                                    self.nh_last_batch_finish_ts = None
                                                    self.nh_last_flush_timer_ts = None
                                                    self.nhrib_update_calls = None
                                                    self.nhrib_update_time = None
                                                    self.nexthops_sent_to_rib = None
                                                    self.nexthops_resent_to_rib = None
                                                    self.nexthops_removed_from_rib = None
                                                    self.rib_sync_registers_failed = None
                                                    self.riba_sync_registers_failed = None
                                                    self.ribnh_reg_failed_for_no_tbl_id = None
                                                    self.ribnh_reg_failed_for_no_rib_conn = None
                                                    self.tunnel_walk_nh_not_found = None
                                                    self.tunnel_walk_gw_not_found = None
                                                    self.tunnel_walk_backup_creates = None
                                                    self._segment_path = lambda: "performance-statistics"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, [u'critical_notf_count', u'noncritical_notf_count', u'last_notf_bestpath_deletes', u'last_notf_bestpath_changes', u'nh_sync_reg_calls', u'nha_sync_reg_calls', u'nha_sync_un_reg_calls', u'nh_pending_registrations', u'nh_peak_registrations', u'nh_batch_finish_calls', u'nh_flush_timer_calls', u'nh_last_sync_reg_ts', u'nh_last_a_sync_reg_ts', u'nh_last_a_sync_un_reg_ts', u'nh_last_batch_finish_ts', u'nh_last_flush_timer_ts', u'nhrib_update_calls', u'nhrib_update_time', u'nexthops_sent_to_rib', u'nexthops_resent_to_rib', u'nexthops_removed_from_rib', u'rib_sync_registers_failed', u'riba_sync_registers_failed', u'ribnh_reg_failed_for_no_tbl_id', u'ribnh_reg_failed_for_no_rib_conn', u'tunnel_walk_nh_not_found', u'tunnel_walk_gw_not_found', u'tunnel_walk_backup_creates'], name, value)


                                        class NextHopAfs(Entity):
                                            """
                                            The BGP Next\-hop table
                                            
                                            .. attribute:: next_hop_af
                                            
                                            	A BGP Next hop entry
                                            	**type**\: list of  		 :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, self).__init__()

                                                self.yang_name = "next-hop-afs"
                                                self.yang_parent_name = "next-hop-address-family"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("next-hop-af", ("next_hop_af", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf))])
                                                self._leafs = OrderedDict()

                                                self.next_hop_af = YList(self)
                                                self._segment_path = lambda: "next-hop-afs"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, [], name, value)


                                            class NextHopAf(Entity):
                                                """
                                                A BGP Next hop entry
                                                
                                                .. attribute:: next_hop_address
                                                
                                                	Next hop address
                                                	**type**\: union of the below types:
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                		**type**\: str
                                                
                                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_set
                                                
                                                	Attribute Set Name
                                                	**type**\: str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:  :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel>`
                                                
                                                .. attribute:: nexthop_internal_info
                                                
                                                	Internal nexthop info
                                                	**type**\:  :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                                
                                                .. attribute:: af_name
                                                
                                                	Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: rib_nexthop_id
                                                
                                                	RIB Nexthop Id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_pending_registration
                                                
                                                	Nexthop registration is pending
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_reference_count
                                                
                                                	Number of neighbors/prefixes referencing this nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_reference_count_total
                                                
                                                	Number of neighbors/prefixes referencing this nexthop (AFs)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nh_first_hop_if_handle
                                                
                                                	First\-hop interface handle
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: nexthop_aigp_metric
                                                
                                                	AIGP metrice of nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_reachable
                                                
                                                	Is Gateway reachable ?
                                                	**type**\: bool
                                                
                                                .. attribute:: nexthop_gateway_prefix_connected
                                                
                                                	Is Gateway resolved through Connected route ?
                                                	**type**\: bool
                                                
                                                .. attribute:: nexthop_gateway_prefix_length
                                                
                                                	Gateway prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_gateway_info
                                                
                                                	Gateway related info, includingOptimal Route Reflector Gateways
                                                	**type**\: list of  		 :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address List
                                                	**type**\: list of  		 :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, self).__init__()

                                                    self.yang_name = "next-hop-af"
                                                    self.yang_parent_name = "next-hop-afs"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nexthop-address", ("nexthop_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel)), ("nexthop-internal-info", ("nexthop_internal_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo)), ("nexthop-gateway-info", ("nexthop_gateway_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                        ('attribute_set', (YLeaf(YType.str, 'attribute-set'), ['str'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('rib_nexthop_id', (YLeaf(YType.uint32, 'rib-nexthop-id'), ['int'])),
                                                        ('nexthop_pending_registration', (YLeaf(YType.uint8, 'nexthop-pending-registration'), ['int'])),
                                                        ('nexthop_reference_count', (YLeaf(YType.uint32, 'nexthop-reference-count'), ['int'])),
                                                        ('nh_reference_count_total', (YLeaf(YType.uint32, 'nh-reference-count-total'), ['int'])),
                                                        ('nh_first_hop_if_handle', (YLeaf(YType.str, 'nh-first-hop-if-handle'), ['str'])),
                                                        ('nexthop_aigp_metric', (YLeaf(YType.uint32, 'nexthop-aigp-metric'), ['int'])),
                                                        ('nexthop_gateway_reachable', (YLeaf(YType.boolean, 'nexthop-gateway-reachable'), ['bool'])),
                                                        ('nexthop_gateway_prefix_connected', (YLeaf(YType.boolean, 'nexthop-gateway-prefix-connected'), ['bool'])),
                                                        ('nexthop_gateway_prefix_length', (YLeaf(YType.uint32, 'nexthop-gateway-prefix-length'), ['int'])),
                                                    ])
                                                    self.next_hop_address = None
                                                    self.attribute_set = None
                                                    self.af_name = None
                                                    self.rib_nexthop_id = None
                                                    self.nexthop_pending_registration = None
                                                    self.nexthop_reference_count = None
                                                    self.nh_reference_count_total = None
                                                    self.nh_first_hop_if_handle = None
                                                    self.nexthop_aigp_metric = None
                                                    self.nexthop_gateway_reachable = None
                                                    self.nexthop_gateway_prefix_connected = None
                                                    self.nexthop_gateway_prefix_length = None

                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self._children_name_map["nexthop_address"] = "nexthop-address"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.nexthop_internal_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                    self.nexthop_internal_info.parent = self
                                                    self._children_name_map["nexthop_internal_info"] = "nexthop-internal-info"

                                                    self.nexthop_gateway_info = YList(self)
                                                    self.neighbor_address = YList(self)
                                                    self._segment_path = lambda: "next-hop-af"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, ['next_hop_address', 'attribute_set', u'af_name', u'rib_nexthop_id', u'nexthop_pending_registration', u'nexthop_reference_count', u'nh_reference_count_total', u'nh_first_hop_if_handle', u'nexthop_aigp_metric', u'nexthop_gateway_reachable', u'nexthop_gateway_prefix_connected', u'nexthop_gateway_prefix_length'], name, value)


                                                class NexthopAddress(Entity):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, self).__init__()

                                                        self.yang_name = "nexthop-address"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "nexthop-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class NexthopInternalInfo(Entity):
                                                    """
                                                    Internal nexthop info
                                                    
                                                    .. attribute:: nexthop_address
                                                    
                                                    	Nexthop address
                                                    	**type**\:  :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                    
                                                    .. attribute:: nexthop_id
                                                    
                                                    	Comm librray ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_version
                                                    
                                                    	Table version
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_flags
                                                    
                                                    	Nexthop flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_if_handle
                                                    
                                                    	Nexthop ifhandle
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_af_user_bits
                                                    
                                                    	Bitmask indicating the AFs which share the nexthop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_label
                                                    
                                                    	Nexthop label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_metrice
                                                    
                                                    	Nexthop metrices
                                                    	**type**\: list of  		 :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                    
                                                    .. attribute:: nexthop_refcount
                                                    
                                                    	Nexthop refcounts
                                                    	**type**\: list of  		 :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                    
                                                    .. attribute:: nexthop_gateway_internal_info
                                                    
                                                    	Internal nexthop Gateway info
                                                    	**type**\: list of  		 :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, self).__init__()

                                                        self.yang_name = "nexthop-internal-info"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("nexthop-address", ("nexthop_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress)), ("nexthop-metrice", ("nexthop_metrice", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice)), ("nexthop-refcount", ("nexthop_refcount", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount)), ("nexthop-gateway-internal-info", ("nexthop_gateway_internal_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo))])
                                                        self._leafs = OrderedDict([
                                                            ('nexthop_id', (YLeaf(YType.uint32, 'nexthop-id'), ['int'])),
                                                            ('nexthop_version', (YLeaf(YType.uint32, 'nexthop-version'), ['int'])),
                                                            ('nexthop_flags', (YLeaf(YType.uint32, 'nexthop-flags'), ['int'])),
                                                            ('nexthop_if_handle', (YLeaf(YType.uint32, 'nexthop-if-handle'), ['int'])),
                                                            ('nexthop_af_user_bits', (YLeaf(YType.uint32, 'nexthop-af-user-bits'), ['int'])),
                                                            ('nexthop_label', (YLeaf(YType.uint32, 'nexthop-label'), ['int'])),
                                                            ('gateway_flags', (YLeaf(YType.uint32, 'gateway-flags'), ['int'])),
                                                        ])
                                                        self.nexthop_id = None
                                                        self.nexthop_version = None
                                                        self.nexthop_flags = None
                                                        self.nexthop_if_handle = None
                                                        self.nexthop_af_user_bits = None
                                                        self.nexthop_label = None
                                                        self.gateway_flags = None

                                                        self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                        self.nexthop_address.parent = self
                                                        self._children_name_map["nexthop_address"] = "nexthop-address"

                                                        self.nexthop_metrice = YList(self)
                                                        self.nexthop_refcount = YList(self)
                                                        self.nexthop_gateway_internal_info = YList(self)
                                                        self._segment_path = lambda: "nexthop-internal-info"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, [u'nexthop_id', u'nexthop_version', u'nexthop_flags', u'nexthop_if_handle', u'nexthop_af_user_bits', u'nexthop_label', u'gateway_flags'], name, value)


                                                    class NexthopAddress(Entity):
                                                        """
                                                        Nexthop address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, self).__init__()

                                                            self.yang_name = "nexthop-address"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "nexthop-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                    class NexthopMetrice(Entity):
                                                        """
                                                        Nexthop metrices
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, self).__init__()

                                                            self.yang_name = "nexthop-metrice"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "nexthop-metrice"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, [u'entry'], name, value)


                                                    class NexthopRefcount(Entity):
                                                        """
                                                        Nexthop refcounts
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, self).__init__()

                                                            self.yang_name = "nexthop-refcount"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "nexthop-refcount"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, [u'entry'], name, value)


                                                    class NexthopGatewayInternalInfo(Entity):
                                                        """
                                                        Internal nexthop Gateway info
                                                        
                                                        .. attribute:: gateway_flags
                                                        
                                                        	Gateway flags
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: registration_type
                                                        
                                                        	Nexthop registration type
                                                        	**type**\:  :py:class:`BgpNhValidate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidate>`
                                                        
                                                        .. attribute:: registration_since
                                                        
                                                        	Time since registration
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, self).__init__()

                                                            self.yang_name = "nexthop-gateway-internal-info"
                                                            self.yang_parent_name = "nexthop-internal-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('gateway_flags', (YLeaf(YType.uint32, 'gateway-flags'), ['int'])),
                                                                ('registration_type', (YLeaf(YType.enumeration, 'registration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhValidate', '')])),
                                                                ('registration_since', (YLeaf(YType.uint32, 'registration-since'), ['int'])),
                                                            ])
                                                            self.gateway_flags = None
                                                            self.registration_type = None
                                                            self.registration_since = None
                                                            self._segment_path = lambda: "nexthop-gateway-internal-info"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, [u'gateway_flags', u'registration_type', u'registration_since'], name, value)


                                                class NexthopGatewayInfo(Entity):
                                                    """
                                                    Gateway related info, includingOptimal Route
                                                    Reflector Gateways
                                                    
                                                    .. attribute:: nexthop_route
                                                    
                                                    	Route resolving the nethop
                                                    	**type**\:  :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                    
                                                    .. attribute:: nexthop_route_prefix_length
                                                    
                                                    	Prefix length of the route resolving the nexthop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_route_protocol
                                                    
                                                    	Protocol that resolves the route to the nexthop
                                                    	**type**\: str
                                                    
                                                    .. attribute:: nexthop_route_path_count
                                                    
                                                    	Number of paths in the resolving route
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_af_invalid_bits
                                                    
                                                    	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: nexthop_status
                                                    
                                                    	Nexthop status
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nexthop_tableid
                                                    
                                                    	Nexthop Table id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: nexthop_metric
                                                    
                                                    	IGP metric for nexthop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_type
                                                    
                                                    	Last nexthop event type
                                                    	**type**\:  :py:class:`BgpNhEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEvent>`
                                                    
                                                    .. attribute:: last_update_type
                                                    
                                                    	Last nexthop update type
                                                    	**type**\:  :py:class:`BgpNhUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdate>`
                                                    
                                                    .. attribute:: critical_events
                                                    
                                                    	Number of critical events received from RIB
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: non_critical_events
                                                    
                                                    	Number of non\-critical events received from RIB
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_event_since
                                                    
                                                    	Time since the last event sent to or received from RIB
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_rib_update
                                                    
                                                    	Time since the last rib update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_enabled
                                                    
                                                    	TRUE if MPLS is configured for IAS/CsC application
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nexthop_mpls_interfaces
                                                    
                                                    	Number of interfaces on which MPLS is enabled
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_mpls_label
                                                    
                                                    	Local label allocated for IAS/CsC application
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: nexthop_route_path
                                                    
                                                    	Nexthops of the resolving route
                                                    	**type**\: list of  		 :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, self).__init__()

                                                        self.yang_name = "nexthop-gateway-info"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("nexthop-route", ("nexthop_route", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute)), ("nexthop-route-path", ("nexthop_route_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath))])
                                                        self._leafs = OrderedDict([
                                                            ('nexthop_route_prefix_length', (YLeaf(YType.uint8, 'nexthop-route-prefix-length'), ['int'])),
                                                            ('nexthop_route_protocol', (YLeaf(YType.str, 'nexthop-route-protocol'), ['str'])),
                                                            ('nexthop_route_path_count', (YLeaf(YType.uint32, 'nexthop-route-path-count'), ['int'])),
                                                            ('nexthop_af_invalid_bits', (YLeaf(YType.uint16, 'nexthop-af-invalid-bits'), ['int'])),
                                                            ('nexthop_status', (YLeaf(YType.uint8, 'nexthop-status'), ['int'])),
                                                            ('nexthop_tableid', (YLeaf(YType.uint64, 'nexthop-tableid'), ['int'])),
                                                            ('nexthop_metric', (YLeaf(YType.uint32, 'nexthop-metric'), ['int'])),
                                                            ('last_event_type', (YLeaf(YType.enumeration, 'last-event-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhEvent', '')])),
                                                            ('last_update_type', (YLeaf(YType.enumeration, 'last-update-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhUpdate', '')])),
                                                            ('critical_events', (YLeaf(YType.uint32, 'critical-events'), ['int'])),
                                                            ('non_critical_events', (YLeaf(YType.uint32, 'non-critical-events'), ['int'])),
                                                            ('last_event_since', (YLeaf(YType.uint32, 'last-event-since'), ['int'])),
                                                            ('last_rib_update', (YLeaf(YType.uint32, 'last-rib-update'), ['int'])),
                                                            ('nexthop_mpls_enabled', (YLeaf(YType.boolean, 'nexthop-mpls-enabled'), ['bool'])),
                                                            ('nexthop_mpls_interfaces', (YLeaf(YType.uint32, 'nexthop-mpls-interfaces'), ['int'])),
                                                            ('nexthop_mpls_label', (YLeaf(YType.uint32, 'nexthop-mpls-label'), ['int'])),
                                                        ])
                                                        self.nexthop_route_prefix_length = None
                                                        self.nexthop_route_protocol = None
                                                        self.nexthop_route_path_count = None
                                                        self.nexthop_af_invalid_bits = None
                                                        self.nexthop_status = None
                                                        self.nexthop_tableid = None
                                                        self.nexthop_metric = None
                                                        self.last_event_type = None
                                                        self.last_update_type = None
                                                        self.critical_events = None
                                                        self.non_critical_events = None
                                                        self.last_event_since = None
                                                        self.last_rib_update = None
                                                        self.nexthop_mpls_enabled = None
                                                        self.nexthop_mpls_interfaces = None
                                                        self.nexthop_mpls_label = None

                                                        self.nexthop_route = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                        self.nexthop_route.parent = self
                                                        self._children_name_map["nexthop_route"] = "nexthop-route"

                                                        self.nexthop_route_path = YList(self)
                                                        self._segment_path = lambda: "nexthop-gateway-info"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, [u'nexthop_route_prefix_length', u'nexthop_route_protocol', u'nexthop_route_path_count', u'nexthop_af_invalid_bits', u'nexthop_status', u'nexthop_tableid', u'nexthop_metric', u'last_event_type', u'last_update_type', u'critical_events', u'non_critical_events', u'last_event_since', u'last_rib_update', u'nexthop_mpls_enabled', u'nexthop_mpls_interfaces', u'nexthop_mpls_label'], name, value)


                                                    class NexthopRoute(Entity):
                                                        """
                                                        Route resolving the nethop
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, self).__init__()

                                                            self.yang_name = "nexthop-route"
                                                            self.yang_parent_name = "nexthop-gateway-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "nexthop-route"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                    class NexthopRoutePath(Entity):
                                                        """
                                                        Nexthops of the resolving route
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, self).__init__()

                                                            self.yang_name = "nexthop-route-path"
                                                            self.yang_parent_name = "nexthop-gateway-info"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "nexthop-route-path"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "nexthop-route-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address List
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "next-hop-af"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class RtSetCounters(Entity):
                                    """
                                    The RT\-set counter table
                                    
                                    .. attribute:: rt_set_counter
                                    
                                    	One RT\-set counter table entry
                                    	**type**\: list of  		 :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters, self).__init__()

                                        self.yang_name = "rt-set-counters"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rt-set-counter", ("rt_set_counter", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter))])
                                        self._leafs = OrderedDict()

                                        self.rt_set_counter = YList(self)
                                        self._segment_path = lambda: "rt-set-counters"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters, [], name, value)


                                    class RtSetCounter(Entity):
                                        """
                                        One RT\-set counter table entry
                                        
                                        .. attribute:: rt_set_id  (key)
                                        
                                        	RTSet ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_target_set
                                        
                                        	Route Target set
                                        	**type**\:  :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter, self).__init__()

                                            self.yang_name = "rt-set-counter"
                                            self.yang_parent_name = "rt-set-counters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['rt_set_id']
                                            self._child_classes = OrderedDict([("route-target-set", ("route_target_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet))])
                                            self._leafs = OrderedDict([
                                                ('rt_set_id', (YLeaf(YType.uint32, 'rt-set-id'), ['int'])),
                                            ])
                                            self.rt_set_id = None

                                            self.route_target_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                            self.route_target_set.parent = self
                                            self._children_name_map["route_target_set"] = "route-target-set"
                                            self._segment_path = lambda: "rt-set-counter" + "[rt-set-id='" + str(self.rt_set_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter, ['rt_set_id'], name, value)


                                        class RouteTargetSet(Entity):
                                            """
                                            Route Target set
                                            
                                            .. attribute:: rt_set_len
                                            
                                            	Length in bytes of set of route targets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rt_set_id
                                            
                                            	Identifier of the rtset
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rt_set_net_count
                                            
                                            	Count of nets with paths with the rtset
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rt_set
                                            
                                            	Set of route targets
                                            	**type**\: list of  		 :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, self).__init__()

                                                self.yang_name = "route-target-set"
                                                self.yang_parent_name = "rt-set-counter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rt-set", ("rt_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet))])
                                                self._leafs = OrderedDict([
                                                    ('rt_set_len', (YLeaf(YType.uint8, 'rt-set-len'), ['int'])),
                                                    ('rt_set_id', (YLeaf(YType.uint32, 'rt-set-id'), ['int'])),
                                                    ('rt_set_net_count', (YLeaf(YType.uint32, 'rt-set-net-count'), ['int'])),
                                                ])
                                                self.rt_set_len = None
                                                self.rt_set_id = None
                                                self.rt_set_net_count = None

                                                self.rt_set = YList(self)
                                                self._segment_path = lambda: "route-target-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, [u'rt_set_len', u'rt_set_id', u'rt_set_net_count'], name, value)


                                            class RtSet(Entity):
                                                """
                                                Set of route targets
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, self).__init__()

                                                    self.yang_name = "rt-set"
                                                    self.yang_parent_name = "route-target-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rt-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, [u'entry'], name, value)


                                class BmpPaths(Entity):
                                    """
                                    The paths in BMP Table
                                    
                                    .. attribute:: bmp_path
                                    
                                    	A BMP path table entry
                                    	**type**\: list of  		 :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths, self).__init__()

                                        self.yang_name = "bmp-paths"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bmp-path", ("bmp_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath))])
                                        self._leafs = OrderedDict()

                                        self.bmp_path = YList(self)
                                        self._segment_path = lambda: "bmp-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths, [], name, value)


                                    class BmpPath(Entity):
                                        """
                                        A BMP path table entry
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Net Version bump timestamp
                                        	**type**\:  :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                        
                                        .. attribute:: version_age
                                        
                                        	Net Version bump age
                                        	**type**\:  :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: bmp_net_flags
                                        
                                        	Flags associated with net
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_net_version
                                        
                                        	Net's version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for the net
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path
                                        
                                        	List of paths under the BMP net
                                        	**type**\: list of  		 :py:class:`BmpPath_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath, self).__init__()

                                            self.yang_name = "bmp-path"
                                            self.yang_parent_name = "bmp-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix)), ("version-timestamp", ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp)), ("version-age", ("version_age", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge)), ("bmp-path", ("bmp_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_))])
                                            self._leafs = OrderedDict([
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('bmp_net_flags', (YLeaf(YType.uint32, 'bmp-net-flags'), ['int'])),
                                                ('bmp_net_version', (YLeaf(YType.uint32, 'bmp-net-version'), ['int'])),
                                                ('num_of_path', (YLeaf(YType.uint32, 'num-of-path'), ['int'])),
                                                ('has_local_label', (YLeaf(YType.boolean, 'has-local-label'), ['bool'])),
                                                ('net_local_label', (YLeaf(YType.uint32, 'net-local-label'), ['int'])),
                                            ])
                                            self.network = None
                                            self.prefix_length = None
                                            self.af_name = None
                                            self.bmp_net_flags = None
                                            self.bmp_net_version = None
                                            self.num_of_path = None
                                            self.has_local_label = None
                                            self.net_local_label = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self._children_name_map["version_timestamp"] = "version-timestamp"

                                            self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                            self.version_age.parent = self
                                            self._children_name_map["version_age"] = "version-age"

                                            self.bmp_path = YList(self)
                                            self._segment_path = lambda: "bmp-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath, ['network', 'prefix_length', u'af_name', u'bmp_net_flags', u'bmp_net_version', u'num_of_path', u'has_local_label', u'net_local_label'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VersionTimestamp(Entity):
                                            """
                                            Net Version bump timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, self).__init__()

                                                self.yang_name = "version-timestamp"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class VersionAge(Entity):
                                            """
                                            Net Version bump age
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge, self).__init__()

                                                self.yang_name = "version-age"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-age"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.VersionAge, [u'seconds', u'nanoseconds'], name, value)


                                        class BmpPath_(Entity):
                                            """
                                            List of paths under the BMP net
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress>`
                                            
                                            .. attribute:: bmp_path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_path_adv_bit_map
                                            
                                            	Path's Adv bit map
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bmp_path_snd_bit_map
                                            
                                            	Path's pending snd bit map
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: bmp_nbr_bit_map
                                            
                                            	Paths Nbr bmp bit map
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path
                                            
                                            	Is path originated locally?
                                            	**type**\: bool
                                            
                                            .. attribute:: bpath_pointer
                                            
                                            	BGP Path pointer
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: received_label
                                            
                                            	Set of received label stack
                                            	**type**\: list of  		 :py:class:`ReceivedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_, self).__init__()

                                                self.yang_name = "bmp-path"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress)), ("received-label", ("received_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel))])
                                                self._leafs = OrderedDict([
                                                    ('bmp_path_flags', (YLeaf(YType.uint32, 'bmp-path-flags'), ['int'])),
                                                    ('bmp_path_adv_bit_map', (YLeaf(YType.uint16, 'bmp-path-adv-bit-map'), ['int'])),
                                                    ('bmp_path_snd_bit_map', (YLeaf(YType.uint16, 'bmp-path-snd-bit-map'), ['int'])),
                                                    ('bmp_nbr_bit_map', (YLeaf(YType.uint32, 'bmp-nbr-bit-map'), ['int'])),
                                                    ('local_path', (YLeaf(YType.boolean, 'local-path'), ['bool'])),
                                                    ('bpath_pointer', (YLeaf(YType.uint64, 'bpath-pointer'), ['int'])),
                                                ])
                                                self.bmp_path_flags = None
                                                self.bmp_path_adv_bit_map = None
                                                self.bmp_path_snd_bit_map = None
                                                self.bmp_nbr_bit_map = None
                                                self.local_path = None
                                                self.bpath_pointer = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.received_label = YList(self)
                                                self._segment_path = lambda: "bmp-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_, [u'bmp_path_flags', u'bmp_path_adv_bit_map', u'bmp_path_snd_bit_map', u'bmp_nbr_bit_map', u'local_path', u'bpath_pointer'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "bmp-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class ReceivedLabel(Entity):
                                                """
                                                Set of received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel, self).__init__()

                                                    self.yang_name = "received-label"
                                                    self.yang_parent_name = "bmp-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "received-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel, [u'entry'], name, value)


                                class UpdateGenerationUpdateGroups(Entity):
                                    """
                                    Update generation for all update\-groups
                                    
                                    .. attribute:: update_generation_update_group
                                    
                                    	Update generation for update\-group
                                    	**type**\: list of  		 :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups, self).__init__()

                                        self.yang_name = "update-generation-update-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-generation-update-group", ("update_generation_update_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup))])
                                        self._leafs = OrderedDict()

                                        self.update_generation_update_group = YList(self)
                                        self._segment_path = lambda: "update-generation-update-groups"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups, [], name, value)


                                    class UpdateGenerationUpdateGroup(Entity):
                                        """
                                        Update generation for update\-group
                                        
                                        .. attribute:: update_group_index  (key)
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_timer_start_timestamp
                                        
                                        	Last update timer start time
                                        	**type**\:  :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                        
                                        .. attribute:: last_update_timer_stop_timestamp
                                        
                                        	Last update timer stop time
                                        	**type**\:  :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                        
                                        .. attribute:: last_update_timer_expiry_timestamp
                                        
                                        	Last update timer expiry time
                                        	**type**\:  :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                        
                                        .. attribute:: last_update_timer_remaining_value
                                        
                                        	Update timer remaining time
                                        	**type**\:  :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                        
                                        .. attribute:: last_update_timer_delay_value
                                        
                                        	Last update timer delay value
                                        	**type**\:  :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: neighbor_session_af_name
                                        
                                        	Neighbor session address family
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_flags2
                                        
                                        	Update\-group internal flags2
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue Size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_sub_group_count
                                        
                                        	Sub\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_throttled_count
                                        
                                        	Throttled sub\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_count
                                        
                                        	Refresh sub\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_throttled_count
                                        
                                        	Throttled refresh sub\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_count
                                        
                                        	Filter\-group count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_leaving_count
                                        
                                        	Count of neighbors leaving the update\-group
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_recovery_pending
                                        
                                        	Is update generation recovery pending
                                        	**type**\: bool
                                        
                                        .. attribute:: last_update_timer_expiry_age
                                        
                                        	Time since last update timer expiry event
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_update_timer_running
                                        
                                        	Is update timer running
                                        	**type**\: bool
                                        
                                        .. attribute:: perm_pelem_encountered
                                        
                                        	Count of Perm Pelems seen by updgen
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_allowed
                                        
                                        	Count of Perm Pelems allowed by updgen
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_not_allowed
                                        
                                        	Count of Perm Pelems not allowed by updgen
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_exp_wdr
                                        
                                        	Count of Perm Pelems explicitly wdrn by updgen
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: perm_pelem_spur_wdr
                                        
                                        	Count of Perm Pelems Spurious withdraws by updgen
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_permanent
                                        
                                        	Permanent UG check
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, self).__init__()

                                            self.yang_name = "update-generation-update-group"
                                            self.yang_parent_name = "update-generation-update-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['update_group_index']
                                            self._child_classes = OrderedDict([("last-update-timer-start-timestamp", ("last_update_timer_start_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp)), ("last-update-timer-stop-timestamp", ("last_update_timer_stop_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp)), ("last-update-timer-expiry-timestamp", ("last_update_timer_expiry_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp)), ("last-update-timer-remaining-value", ("last_update_timer_remaining_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue)), ("last-update-timer-delay-value", ("last_update_timer_delay_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics))])
                                            self._leafs = OrderedDict([
                                                ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                                ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('neighbor_session_af_name', (YLeaf(YType.uint8, 'neighbor-session-af-name'), ['int'])),
                                                ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                                ('update_group_flags2', (YLeaf(YType.uint32, 'update-group-flags2'), ['int'])),
                                                ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                                ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                                ('update_sub_group_count', (YLeaf(YType.uint32, 'update-sub-group-count'), ['int'])),
                                                ('sub_group_throttled_count', (YLeaf(YType.uint32, 'sub-group-throttled-count'), ['int'])),
                                                ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                                ('refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'refresh-sub-group-throttled-count'), ['int'])),
                                                ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                                ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                                ('neighbor_leaving_count', (YLeaf(YType.uint32, 'neighbor-leaving-count'), ['int'])),
                                                ('update_generation_recovery_pending', (YLeaf(YType.boolean, 'update-generation-recovery-pending'), ['bool'])),
                                                ('last_update_timer_expiry_age', (YLeaf(YType.uint32, 'last-update-timer-expiry-age'), ['int'])),
                                                ('is_update_timer_running', (YLeaf(YType.boolean, 'is-update-timer-running'), ['bool'])),
                                                ('perm_pelem_encountered', (YLeaf(YType.uint32, 'perm-pelem-encountered'), ['int'])),
                                                ('perm_pelem_allowed', (YLeaf(YType.uint32, 'perm-pelem-allowed'), ['int'])),
                                                ('perm_pelem_not_allowed', (YLeaf(YType.uint32, 'perm-pelem-not-allowed'), ['int'])),
                                                ('perm_pelem_exp_wdr', (YLeaf(YType.uint32, 'perm-pelem-exp-wdr'), ['int'])),
                                                ('perm_pelem_spur_wdr', (YLeaf(YType.uint32, 'perm-pelem-spur-wdr'), ['int'])),
                                                ('is_permanent', (YLeaf(YType.boolean, 'is-permanent'), ['bool'])),
                                            ])
                                            self.update_group_index = None
                                            self.process_id = None
                                            self.update_vrf_name = None
                                            self.update_group_af_name = None
                                            self.neighbor_session_af_name = None
                                            self.update_group_index_xr = None
                                            self.update_group_flags2 = None
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.update_sub_group_count = None
                                            self.sub_group_throttled_count = None
                                            self.refresh_sub_group_count = None
                                            self.refresh_sub_group_throttled_count = None
                                            self.filter_group_count = None
                                            self.neighbor_count = None
                                            self.neighbor_leaving_count = None
                                            self.update_generation_recovery_pending = None
                                            self.last_update_timer_expiry_age = None
                                            self.is_update_timer_running = None
                                            self.perm_pelem_encountered = None
                                            self.perm_pelem_allowed = None
                                            self.perm_pelem_not_allowed = None
                                            self.perm_pelem_exp_wdr = None
                                            self.perm_pelem_spur_wdr = None
                                            self.is_permanent = None

                                            self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                            self.last_update_timer_start_timestamp.parent = self
                                            self._children_name_map["last_update_timer_start_timestamp"] = "last-update-timer-start-timestamp"

                                            self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                            self.last_update_timer_stop_timestamp.parent = self
                                            self._children_name_map["last_update_timer_stop_timestamp"] = "last-update-timer-stop-timestamp"

                                            self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                            self.last_update_timer_expiry_timestamp.parent = self
                                            self._children_name_map["last_update_timer_expiry_timestamp"] = "last-update-timer-expiry-timestamp"

                                            self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                            self.last_update_timer_remaining_value.parent = self
                                            self._children_name_map["last_update_timer_remaining_value"] = "last-update-timer-remaining-value"

                                            self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                            self.last_update_timer_delay_value.parent = self
                                            self._children_name_map["last_update_timer_delay_value"] = "last-update-timer-delay-value"

                                            self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._segment_path = lambda: "update-generation-update-group" + "[update-group-index='" + str(self.update_group_index) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, ['update_group_index', u'process_id', u'update_vrf_name', u'update_group_af_name', u'neighbor_session_af_name', u'update_group_index_xr', u'update_group_flags2', u'update_out_queue_messages', u'update_out_queue_size', u'update_sub_group_count', u'sub_group_throttled_count', u'refresh_sub_group_count', u'refresh_sub_group_throttled_count', u'filter_group_count', u'neighbor_count', u'neighbor_leaving_count', u'update_generation_recovery_pending', u'last_update_timer_expiry_age', u'is_update_timer_running', u'perm_pelem_encountered', u'perm_pelem_allowed', u'perm_pelem_not_allowed', u'perm_pelem_exp_wdr', u'perm_pelem_spur_wdr', u'is_permanent'], name, value)


                                        class LastUpdateTimerStartTimestamp(Entity):
                                            """
                                            Last update timer start time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-start-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-timer-start-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateTimerStopTimestamp(Entity):
                                            """
                                            Last update timer stop time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-stop-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-timer-stop-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateTimerExpiryTimestamp(Entity):
                                            """
                                            Last update timer expiry time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, self).__init__()

                                                self.yang_name = "last-update-timer-expiry-timestamp"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-timer-expiry-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateTimerRemainingValue(Entity):
                                            """
                                            Update timer remaining time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, self).__init__()

                                                self.yang_name = "last-update-timer-remaining-value"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-timer-remaining-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateTimerDelayValue(Entity):
                                            """
                                            Last update timer delay value
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, self).__init__()

                                                self.yang_name = "last-update-timer-delay-value"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-timer-delay-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, [u'seconds', u'nanoseconds'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-update-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                                self._leafs = OrderedDict([
                                                    ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                    ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                    ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                    ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                    ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                    ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                    ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                    ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                    ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                    ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                    ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                    ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                    ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                    ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                    ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                    ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                                ])
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_size_high = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_cleared = None
                                                self.last_update_discard_age = None
                                                self.last_update_cleard_age = None
                                                self.update_throttle_count = None
                                                self.last_update_throttle_age = None
                                                self.update_recovery_count = None
                                                self.last_update_recovery_age = None
                                                self.update_memory_allocation_fail_count = None
                                                self.last_update_memory_allocation_fail_age = None

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._segment_path = lambda: "update-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-discard-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateGenerationFilterGroups(Entity):
                                    """
                                    Update generation for all filter\-groups under
                                    a sub\-group
                                    
                                    .. attribute:: update_generation_filter_group
                                    
                                    	Update generation for filter\-group
                                    	**type**\: list of  		 :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups, self).__init__()

                                        self.yang_name = "update-generation-filter-groups"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-generation-filter-group", ("update_generation_filter_group", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup))])
                                        self._leafs = OrderedDict()

                                        self.update_generation_filter_group = YList(self)
                                        self._segment_path = lambda: "update-generation-filter-groups"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups, [], name, value)


                                    class UpdateGenerationFilterGroup(Entity):
                                        """
                                        Update generation for filter\-group
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_filter_group_index
                                        
                                        	Parent Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id_xr
                                        
                                        	Sub\-group identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_index
                                        
                                        	Parent Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: parent_sub_group_id
                                        
                                        	Parent Sub\-group identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_count
                                        
                                        	Neighbor count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, self).__init__()

                                            self.yang_name = "update-generation-filter-group"
                                            self.yang_parent_name = "update-generation-filter-groups"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                                ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                                ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                                ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                                ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('update_filter_group_index', (YLeaf(YType.uint32, 'update-filter-group-index'), ['int'])),
                                                ('parent_filter_group_index', (YLeaf(YType.uint32, 'parent-filter-group-index'), ['int'])),
                                                ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                                ('sub_group_id_xr', (YLeaf(YType.uint32, 'sub-group-id-xr'), ['int'])),
                                                ('parent_sub_group_index', (YLeaf(YType.uint32, 'parent-sub-group-index'), ['int'])),
                                                ('parent_sub_group_id', (YLeaf(YType.uint32, 'parent-sub-group-id'), ['int'])),
                                                ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                                ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                            ])
                                            self.update_group_index = None
                                            self.sub_group_index = None
                                            self.sub_group_id = None
                                            self.filter_group_index = None
                                            self.process_id = None
                                            self.update_vrf_name = None
                                            self.update_group_af_name = None
                                            self.update_filter_group_index = None
                                            self.parent_filter_group_index = None
                                            self.sub_group_index_xr = None
                                            self.sub_group_id_xr = None
                                            self.parent_sub_group_index = None
                                            self.parent_sub_group_id = None
                                            self.update_group_index_xr = None
                                            self.neighbor_count = None
                                            self._segment_path = lambda: "update-generation-filter-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, ['update_group_index', 'sub_group_index', 'sub_group_id', 'filter_group_index', u'process_id', u'update_vrf_name', u'update_group_af_name', u'update_filter_group_index', u'parent_filter_group_index', u'sub_group_index_xr', u'sub_group_id_xr', u'parent_sub_group_index', u'parent_sub_group_id', u'update_group_index_xr', u'neighbor_count'], name, value)


                                class Networks(Entity):
                                    """
                                    The BGP Network Table
                                    
                                    .. attribute:: network
                                    
                                    	A BGP Network table entry
                                    	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks, self).__init__()

                                        self.yang_name = "networks"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("network", ("network", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network))])
                                        self._leafs = OrderedDict()

                                        self.network = YList(self)
                                        self._segment_path = lambda: "networks"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks, [], name, value)


                                    class Network(Entity):
                                        """
                                        A BGP Network table entry
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix>`
                                        
                                        .. attribute:: version_timestamp
                                        
                                        	Version timestamp
                                        	**type**\:  :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                        
                                        .. attribute:: version_age
                                        
                                        	Version age
                                        	**type**\:  :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: has_inconsistent_paths
                                        
                                        	Net has inconsistent paths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_net_aggregation_suppressed
                                        
                                        	Net suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_net_ldp_signaled
                                        
                                        	L2VPN Net LDP signaled  aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: table_version
                                        
                                        	Table version # for net
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_brib_version
                                        
                                        	Table version # for updates
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_label
                                        
                                        	Net has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: net_local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_local_label_rewrite
                                        
                                        	Net label has rewrite
                                        	**type**\: bool
                                        
                                        .. attribute:: net_local_label_srgb
                                        
                                        	Net label allocated fromSegment routing global block
                                        	**type**\: bool
                                        
                                        .. attribute:: has_lbl_retained
                                        
                                        	Net has label retained
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: net_flags
                                        
                                        	Flags associated with                            net
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_extended_flags
                                        
                                        	Net extended flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: net_multipath
                                        
                                        	Net has multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: net_eibgp_multipath
                                        
                                        	Net has EIBGP multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: net_backup_available
                                        
                                        	Net has backup path
                                        	**type**\: bool
                                        
                                        .. attribute:: net_backup_label_rewrite_available
                                        
                                        	Net has label rewrite for backup path
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	RIB install failed
                                        	**type**\: bool
                                        
                                        .. attribute:: gateway_array
                                        
                                        	Gateway array ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: resilient_nexthop_set
                                        
                                        	Resilient nexthop set ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_permanent_network
                                        
                                        	Permanent Network
                                        	**type**\: bool
                                        
                                        .. attribute:: num_of_path
                                        
                                        	Number of path for this net
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bit
                                        
                                        	Bit
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: flags
                                        
                                        	Flags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: has_s_rv6sid_allocated
                                        
                                        	Net has SRv6 SID allocated
                                        	**type**\: bool
                                        
                                        .. attribute:: srv6sid_address
                                        
                                        	SRv6 SID address value
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: srv6sid_address_len
                                        
                                        	SRv6 SID address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                        
                                        .. attribute:: local_process_instance_path
                                        
                                        	Local (to process instance) paths for this net 
                                        	**type**\: list of  		 :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                        
                                        .. attribute:: active_process_instance_path
                                        
                                        	Active's paths for this net 
                                        	**type**\: list of  		 :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                        
                                        .. attribute:: local_path_element
                                        
                                        	Local path element list
                                        	**type**\: list of  		 :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement>`
                                        
                                        .. attribute:: active_path_element
                                        
                                        	Path element list received from Active inst
                                        	**type**\: list of  		 :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network, self).__init__()

                                            self.yang_name = "network"
                                            self.yang_parent_name = "networks"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix)), ("version-timestamp", ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp)), ("version-age", ("version_age", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield)), ("local-process-instance-path", ("local_process_instance_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath)), ("active-process-instance-path", ("active_process_instance_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath)), ("local-path-element", ("local_path_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement)), ("active-path-element", ("active_path_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('has_inconsistent_paths', (YLeaf(YType.boolean, 'has-inconsistent-paths'), ['bool'])),
                                                ('is_net_aggregation_suppressed', (YLeaf(YType.boolean, 'is-net-aggregation-suppressed'), ['bool'])),
                                                ('is_net_ldp_signaled', (YLeaf(YType.boolean, 'is-net-ldp-signaled'), ['bool'])),
                                                ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                                ('table_brib_version', (YLeaf(YType.uint32, 'table-brib-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('has_local_label', (YLeaf(YType.boolean, 'has-local-label'), ['bool'])),
                                                ('net_local_label', (YLeaf(YType.uint32, 'net-local-label'), ['int'])),
                                                ('net_local_label_rewrite', (YLeaf(YType.boolean, 'net-local-label-rewrite'), ['bool'])),
                                                ('net_local_label_srgb', (YLeaf(YType.boolean, 'net-local-label-srgb'), ['bool'])),
                                                ('has_lbl_retained', (YLeaf(YType.boolean, 'has-lbl-retained'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('net_flags', (YLeaf(YType.uint32, 'net-flags'), ['int'])),
                                                ('net_extended_flags', (YLeaf(YType.uint32, 'net-extended-flags'), ['int'])),
                                                ('net_multipath', (YLeaf(YType.boolean, 'net-multipath'), ['bool'])),
                                                ('net_eibgp_multipath', (YLeaf(YType.boolean, 'net-eibgp-multipath'), ['bool'])),
                                                ('net_backup_available', (YLeaf(YType.boolean, 'net-backup-available'), ['bool'])),
                                                ('net_backup_label_rewrite_available', (YLeaf(YType.boolean, 'net-backup-label-rewrite-available'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('gateway_array', (YLeaf(YType.uint32, 'gateway-array'), ['int'])),
                                                ('resilient_nexthop_set', (YLeaf(YType.uint32, 'resilient-nexthop-set'), ['int'])),
                                                ('is_permanent_network', (YLeaf(YType.boolean, 'is-permanent-network'), ['bool'])),
                                                ('num_of_path', (YLeaf(YType.uint32, 'num-of-path'), ['int'])),
                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                ('bit', (YLeaf(YType.uint16, 'bit'), ['int'])),
                                                ('flags', (YLeaf(YType.uint8, 'flags'), ['int'])),
                                                ('has_s_rv6sid_allocated', (YLeaf(YType.boolean, 'has-s-rv6sid-allocated'), ['bool'])),
                                                ('srv6sid_address', (YLeaf(YType.str, 'srv6sid-address'), ['str'])),
                                                ('srv6sid_address_len', (YLeaf(YType.uint32, 'srv6sid-address-len'), ['int'])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.has_inconsistent_paths = None
                                            self.is_net_aggregation_suppressed = None
                                            self.is_net_ldp_signaled = None
                                            self.table_version = None
                                            self.table_brib_version = None
                                            self.advertisedto_pe = None
                                            self.has_local_label = None
                                            self.net_local_label = None
                                            self.net_local_label_rewrite = None
                                            self.net_local_label_srgb = None
                                            self.has_lbl_retained = None
                                            self.route_distinguisher = None
                                            self.vrf_name = None
                                            self.net_flags = None
                                            self.net_extended_flags = None
                                            self.net_multipath = None
                                            self.net_eibgp_multipath = None
                                            self.net_backup_available = None
                                            self.net_backup_label_rewrite_available = None
                                            self.rib_failed = None
                                            self.gateway_array = None
                                            self.resilient_nexthop_set = None
                                            self.is_permanent_network = None
                                            self.num_of_path = None
                                            self.version = None
                                            self.bit = None
                                            self.flags = None
                                            self.has_s_rv6sid_allocated = None
                                            self.srv6sid_address = None
                                            self.srv6sid_address_len = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp()
                                            self.version_timestamp.parent = self
                                            self._children_name_map["version_timestamp"] = "version-timestamp"

                                            self.version_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge()
                                            self.version_age.parent = self
                                            self._children_name_map["version_age"] = "version-age"

                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self.local_process_instance_path = YList(self)
                                            self.active_process_instance_path = YList(self)
                                            self.local_path_element = YList(self)
                                            self.active_path_element = YList(self)
                                            self._segment_path = lambda: "network"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network, ['rd', 'network', 'prefix_length', u'af_name', u'process_instance_id', u'has_inconsistent_paths', u'is_net_aggregation_suppressed', u'is_net_ldp_signaled', u'table_version', u'table_brib_version', u'advertisedto_pe', u'has_local_label', u'net_local_label', u'net_local_label_rewrite', u'net_local_label_srgb', u'has_lbl_retained', u'route_distinguisher', u'vrf_name', u'net_flags', u'net_extended_flags', u'net_multipath', u'net_eibgp_multipath', u'net_backup_available', u'net_backup_label_rewrite_available', u'rib_failed', u'gateway_array', u'resilient_nexthop_set', u'is_permanent_network', u'num_of_path', u'version', u'bit', u'flags', u'has_s_rv6sid_allocated', u'srv6sid_address', u'srv6sid_address_len'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VersionTimestamp(Entity):
                                            """
                                            Version timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp, self).__init__()

                                                self.yang_name = "version-timestamp"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class VersionAge(Entity):
                                            """
                                            Version age
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge, self).__init__()

                                                self.yang_name = "version-age"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "version-age"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.VersionAge, [u'seconds', u'nanoseconds'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class LocalProcessInstancePath(Entity):
                                            """
                                            Local (to process instance) paths for this net 
                                            
                                            .. attribute:: advertised_neighbor
                                            
                                            	Advertised Neighbor Address. Valid in the case of Advertised table
                                            	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor>`
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                            	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\: bool
                                            
                                            .. attribute:: label_oor_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\: bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: original_source_route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\: str
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\: str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath, self).__init__()

                                                self.yang_name = "local-process-instance-path"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn))])
                                                self._leafs = OrderedDict([
                                                    ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                    ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                    ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                    ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                    ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                    ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                    ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.no_path = None
                                                self.af_name = None
                                                self.process_instance_id = None
                                                self.label_oor = None
                                                self.label_oor_version = None
                                                self.label_fail = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.original_source_route_distinguisher = None
                                                self.prefix_version = None
                                                self.vrf_name = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None

                                                self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor()
                                                self.advertised_neighbor.parent = self
                                                self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._segment_path = lambda: "local-process-instance-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                            class AdvertisedNeighbor(Entity):
                                                """
                                                Advertised Neighbor Address. Valid in the case
                                                of Advertised table
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor, self).__init__()

                                                    self.yang_name = "advertised-neighbor"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "advertised-neighbor"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\: bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\: bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgp
                                                
                                                	Not advertised to EBGPs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\: bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\: bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\: bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\: bool
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\: str
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\: bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\: bool
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\: bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\: bool
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_self_originated_path
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\: bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\: bool
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\: bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\: bool
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\: bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\: bool
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\: bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\: bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: mac_ip_present
                                                
                                                	Mac IP Present  present
                                                	**type**\: bool
                                                
                                                .. attribute:: mac_ip
                                                
                                                	Mac associated with IP
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue>`
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield))])
                                                    self._leafs = OrderedDict([
                                                        ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                        ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                        ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                        ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                        ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                        ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                        ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                        ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                        ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                        ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                        ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                        ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                        ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                        ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                        ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                        ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                        ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                        ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                        ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                        ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                        ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                        ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                        ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                        ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                        ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                        ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                        ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                        ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                        ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                        ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                        ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                        ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                        ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                        ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                        ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                        ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                        ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                        ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                        ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                        ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                        ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                        ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                        ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                        ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                        ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                        ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                        ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                        ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                        ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                        ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                        ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                        ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                        ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                        ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                        ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                        ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                        ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                        ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                        ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                        ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                        ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                        ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                        ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                        ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                        ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                        ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                        ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                        ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                        ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                        ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                        ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                        ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                        ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                        ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                        ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                        ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                        ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                        ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                        ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                        ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                        ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                        ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                        ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                        ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                        ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                        ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                        ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                        ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                        ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                        ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                        ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                        ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                        ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                        ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                        ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                    ])
                                                    self.route_type = None
                                                    self.is_path_valid = None
                                                    self.is_path_damped = None
                                                    self.is_path_history_held = None
                                                    self.is_internal_path = None
                                                    self.is_best_path = None
                                                    self.is_as_best = None
                                                    self.is_spkr_as_best = None
                                                    self.is_partial_best = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebgp = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_received_only = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_imported = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_vpn_only = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_multipath = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_stale = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.has_local_net_label = None
                                                    self.local_label = None
                                                    self.igp_metric = None
                                                    self.path_weight = None
                                                    self.neighbor_router_id = None
                                                    self.has_mdt_group_addr = None
                                                    self.l2vpn_size = None
                                                    self.l2vpn_evpn_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_nh_addr = None
                                                    self.has_second_label = None
                                                    self.second_label = None
                                                    self.path_flap_count = None
                                                    self.seconds_since_first_flap = None
                                                    self.time_to_unsuppress = None
                                                    self.dampen_penalty = None
                                                    self.halflife_time = None
                                                    self.suppress_penalty = None
                                                    self.reuse_value = None
                                                    self.maximum_suppress_time = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_id_comp_winner = None
                                                    self.path_flags = None
                                                    self.path_import_flags = None
                                                    self.best_path_id = None
                                                    self.local_path_id = None
                                                    self.rcvd_path_id = None
                                                    self.path_table_version = None
                                                    self.advertisedto_pe = None
                                                    self.rib_failed = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.ibgp_signaled_validity = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_path = None
                                                    self.aigp_metric = None
                                                    self.mvpn_sfs_path = None
                                                    self.fspec_invalid_path = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.has_mvpn_extcomm = None
                                                    self.mvpn_path_flags = None
                                                    self.local_nh = None
                                                    self.rt_set_limit_enabled = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_permanent_path = None
                                                    self.graceful_shutdown = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.has_vpn_nexthop_addr = None
                                                    self.is_orig_src_rd_present = None
                                                    self.af_name = None
                                                    self.route_distinguisher = None
                                                    self.mac_ip_present = None
                                                    self.mac_ip = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                    self.rcvd_label = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self._segment_path = lambda: "path-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mdt-group-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "gw-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "nh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "best-path-comp-winner"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nbr-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "vpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rcvd-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                                class L2vpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "mvpn-pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "local-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "pe-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "best-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "add-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied. In the
                                                case of path type received\-only this will be
                                                attributes before inbound policy
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\: bool
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\: bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "local-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp))])
                                                    self._leafs = OrderedDict([
                                                        ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                        ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                        ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                        ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                        ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                        ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                        ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                        ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                        ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                        ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                        ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                        ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                        ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                        ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                        ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                        ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                        ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                        ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                        ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                        ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                        ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                        ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                        ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                    ])
                                                    self.is_as_path2_byte = None
                                                    self.is_application_gateway_present = None
                                                    self.is_attr_set_present = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.is_rnh_present = None
                                                    self.is_ribrnh_present = None
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.vpn_distinguisher = None
                                                    self.rnh_type = None
                                                    self.rnh_len = None
                                                    self.rnh_addr_len = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_mac = None
                                                    self.ribrnhip_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnh_encap = None

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._segment_path = lambda: "attributes-after-policy-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "common-attributes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "attr-set"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.mac_address = None
                                                        self._segment_path = lambda: "rnh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "ribrnh-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class ActiveProcessInstancePath(Entity):
                                            """
                                            Active's paths for this net 
                                            
                                            .. attribute:: advertised_neighbor
                                            
                                            	Advertised Neighbor Address. Valid in the case of Advertised table
                                            	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor>`
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                            	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\: bool
                                            
                                            .. attribute:: label_oor_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\: bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: original_source_route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\: str
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\: str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, self).__init__()

                                                self.yang_name = "active-process-instance-path"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn))])
                                                self._leafs = OrderedDict([
                                                    ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                    ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                    ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                    ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                    ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                    ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                    ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.no_path = None
                                                self.af_name = None
                                                self.process_instance_id = None
                                                self.label_oor = None
                                                self.label_oor_version = None
                                                self.label_fail = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.original_source_route_distinguisher = None
                                                self.prefix_version = None
                                                self.vrf_name = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None

                                                self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor()
                                                self.advertised_neighbor.parent = self
                                                self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._segment_path = lambda: "active-process-instance-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                            class AdvertisedNeighbor(Entity):
                                                """
                                                Advertised Neighbor Address. Valid in the case
                                                of Advertised table
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor, self).__init__()

                                                    self.yang_name = "advertised-neighbor"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "advertised-neighbor"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\: bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\: bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgp
                                                
                                                	Not advertised to EBGPs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\: bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\: bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\: bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\: bool
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\: str
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\: bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\: bool
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\: bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\: bool
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_self_originated_path
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\: bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\: bool
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\: bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\: bool
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\: bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\: bool
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\: bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\: bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: mac_ip_present
                                                
                                                	Mac IP Present  present
                                                	**type**\: bool
                                                
                                                .. attribute:: mac_ip
                                                
                                                	Mac associated with IP
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue>`
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield))])
                                                    self._leafs = OrderedDict([
                                                        ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                        ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                        ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                        ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                        ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                        ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                        ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                        ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                        ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                        ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                        ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                        ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                        ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                        ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                        ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                        ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                        ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                        ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                        ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                        ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                        ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                        ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                        ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                        ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                        ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                        ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                        ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                        ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                        ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                        ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                        ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                        ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                        ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                        ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                        ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                        ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                        ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                        ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                        ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                        ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                        ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                        ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                        ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                        ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                        ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                        ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                        ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                        ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                        ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                        ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                        ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                        ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                        ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                        ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                        ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                        ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                        ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                        ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                        ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                        ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                        ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                        ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                        ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                        ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                        ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                        ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                        ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                        ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                        ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                        ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                        ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                        ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                        ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                        ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                        ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                        ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                        ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                        ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                        ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                        ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                        ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                        ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                        ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                        ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                        ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                        ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                        ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                        ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                        ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                        ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                        ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                        ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                        ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                        ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                        ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                    ])
                                                    self.route_type = None
                                                    self.is_path_valid = None
                                                    self.is_path_damped = None
                                                    self.is_path_history_held = None
                                                    self.is_internal_path = None
                                                    self.is_best_path = None
                                                    self.is_as_best = None
                                                    self.is_spkr_as_best = None
                                                    self.is_partial_best = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebgp = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_received_only = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_imported = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_vpn_only = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_multipath = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_stale = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.has_local_net_label = None
                                                    self.local_label = None
                                                    self.igp_metric = None
                                                    self.path_weight = None
                                                    self.neighbor_router_id = None
                                                    self.has_mdt_group_addr = None
                                                    self.l2vpn_size = None
                                                    self.l2vpn_evpn_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_nh_addr = None
                                                    self.has_second_label = None
                                                    self.second_label = None
                                                    self.path_flap_count = None
                                                    self.seconds_since_first_flap = None
                                                    self.time_to_unsuppress = None
                                                    self.dampen_penalty = None
                                                    self.halflife_time = None
                                                    self.suppress_penalty = None
                                                    self.reuse_value = None
                                                    self.maximum_suppress_time = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_id_comp_winner = None
                                                    self.path_flags = None
                                                    self.path_import_flags = None
                                                    self.best_path_id = None
                                                    self.local_path_id = None
                                                    self.rcvd_path_id = None
                                                    self.path_table_version = None
                                                    self.advertisedto_pe = None
                                                    self.rib_failed = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.ibgp_signaled_validity = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_path = None
                                                    self.aigp_metric = None
                                                    self.mvpn_sfs_path = None
                                                    self.fspec_invalid_path = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.has_mvpn_extcomm = None
                                                    self.mvpn_path_flags = None
                                                    self.local_nh = None
                                                    self.rt_set_limit_enabled = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_permanent_path = None
                                                    self.graceful_shutdown = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.has_vpn_nexthop_addr = None
                                                    self.is_orig_src_rd_present = None
                                                    self.af_name = None
                                                    self.route_distinguisher = None
                                                    self.mac_ip_present = None
                                                    self.mac_ip = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                    self.rcvd_label = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self._segment_path = lambda: "path-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mdt-group-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "gw-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "nh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "best-path-comp-winner"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nbr-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "vpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rcvd-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                                class L2vpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "mvpn-pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "local-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "pe-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "best-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "add-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied. In the
                                                case of path type received\-only this will be
                                                attributes before inbound policy
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\: bool
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\: bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "active-process-instance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp))])
                                                    self._leafs = OrderedDict([
                                                        ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                        ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                        ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                        ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                        ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                        ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                        ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                        ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                        ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                        ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                        ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                        ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                        ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                        ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                        ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                        ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                        ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                        ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                        ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                        ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                        ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                        ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                        ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                    ])
                                                    self.is_as_path2_byte = None
                                                    self.is_application_gateway_present = None
                                                    self.is_attr_set_present = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.is_rnh_present = None
                                                    self.is_ribrnh_present = None
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.vpn_distinguisher = None
                                                    self.rnh_type = None
                                                    self.rnh_len = None
                                                    self.rnh_addr_len = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_mac = None
                                                    self.ribrnhip_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnh_encap = None

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._segment_path = lambda: "attributes-after-policy-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "common-attributes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "attr-set"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.mac_address = None
                                                        self._segment_path = lambda: "rnh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "ribrnh-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class LocalPathElement(Entity):
                                            """
                                            Local path element list
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:  :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:  :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement, self).__init__()

                                                self.yang_name = "local-path-element"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("pelem-path-nexthop", ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel)), ("pelem-path-neighbor-addr", ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr))])
                                                self._leafs = OrderedDict([
                                                    ('pelem_path_id', (YLeaf(YType.uint32, 'pelem-path-id'), ['int'])),
                                                    ('pelem_version', (YLeaf(YType.uint32, 'pelem-version'), ['int'])),
                                                    ('pelem_flags', (YLeaf(YType.uint32, 'pelem-flags'), ['int'])),
                                                    ('pelem_gw_metric', (YLeaf(YType.uint32, 'pelem-gw-metric'), ['int'])),
                                                    ('pelem_path_flags', (YLeaf(YType.uint64, 'pelem-path-flags'), ['int'])),
                                                    ('pelem_path_peer_path_id', (YLeaf(YType.uint32, 'pelem-path-peer-path-id'), ['int'])),
                                                    ('pelem_table_attr_version', (YLeaf(YType.uint32, 'pelem-table-attr-version'), ['int'])),
                                                    ('pelem_path_table_attr_version', (YLeaf(YType.uint32, 'pelem-path-table-attr-version'), ['int'])),
                                                    ('pelem_no_bestpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-bestpath-table-attr-version'), ['int'])),
                                                    ('pelem_no_addpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-addpath-table-attr-version'), ['int'])),
                                                    ('is_perm_path_pelem', (YLeaf(YType.boolean, 'is-perm-path-pelem'), ['bool'])),
                                                ])
                                                self.pelem_path_id = None
                                                self.pelem_version = None
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.is_perm_path_pelem = None

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._segment_path = lambda: "local-path-element"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement, [u'pelem_path_id', u'pelem_version', u'pelem_flags', u'pelem_gw_metric', u'pelem_path_flags', u'pelem_path_peer_path_id', u'pelem_table_attr_version', u'pelem_path_table_attr_version', u'pelem_no_bestpath_table_attr_version', u'pelem_no_addpath_table_attr_version', u'is_perm_path_pelem'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "pelem-path-nexthop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "local-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class ActivePathElement(Entity):
                                            """
                                            Path element list received from Active inst
                                            
                                            .. attribute:: pelem_path_nexthop
                                            
                                            	Path nexthop address
                                            	**type**\:  :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel>`
                                            
                                            .. attribute:: pelem_path_neighbor_addr
                                            
                                            	Path neighbor address
                                            	**type**\:  :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                            
                                            .. attribute:: pelem_path_id
                                            
                                            	Local Path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_version
                                            
                                            	Version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_flags
                                            
                                            	Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_gw_metric
                                            
                                            	Gateway metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_flags
                                            
                                            	Path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pelem_path_peer_path_id
                                            
                                            	Path peer path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_table_attr_version
                                            
                                            	Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_path_table_attr_version
                                            
                                            	Path Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_bestpath_table_attr_version
                                            
                                            	No\-bestpath Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pelem_no_addpath_table_attr_version
                                            
                                            	No\-addpath Table Attr version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_perm_path_pelem
                                            
                                            	Pelem for permanent path
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement, self).__init__()

                                                self.yang_name = "active-path-element"
                                                self.yang_parent_name = "network"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("pelem-path-nexthop", ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel)), ("pelem-path-neighbor-addr", ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr))])
                                                self._leafs = OrderedDict([
                                                    ('pelem_path_id', (YLeaf(YType.uint32, 'pelem-path-id'), ['int'])),
                                                    ('pelem_version', (YLeaf(YType.uint32, 'pelem-version'), ['int'])),
                                                    ('pelem_flags', (YLeaf(YType.uint32, 'pelem-flags'), ['int'])),
                                                    ('pelem_gw_metric', (YLeaf(YType.uint32, 'pelem-gw-metric'), ['int'])),
                                                    ('pelem_path_flags', (YLeaf(YType.uint64, 'pelem-path-flags'), ['int'])),
                                                    ('pelem_path_peer_path_id', (YLeaf(YType.uint32, 'pelem-path-peer-path-id'), ['int'])),
                                                    ('pelem_table_attr_version', (YLeaf(YType.uint32, 'pelem-table-attr-version'), ['int'])),
                                                    ('pelem_path_table_attr_version', (YLeaf(YType.uint32, 'pelem-path-table-attr-version'), ['int'])),
                                                    ('pelem_no_bestpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-bestpath-table-attr-version'), ['int'])),
                                                    ('pelem_no_addpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-addpath-table-attr-version'), ['int'])),
                                                    ('is_perm_path_pelem', (YLeaf(YType.boolean, 'is-perm-path-pelem'), ['bool'])),
                                                ])
                                                self.pelem_path_id = None
                                                self.pelem_version = None
                                                self.pelem_flags = None
                                                self.pelem_gw_metric = None
                                                self.pelem_path_flags = None
                                                self.pelem_path_peer_path_id = None
                                                self.pelem_table_attr_version = None
                                                self.pelem_path_table_attr_version = None
                                                self.pelem_no_bestpath_table_attr_version = None
                                                self.pelem_no_addpath_table_attr_version = None
                                                self.is_perm_path_pelem = None

                                                self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                                self.pelem_path_nexthop.parent = self
                                                self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                                self.pelem_path_neighbor_addr.parent = self
                                                self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                                self._segment_path = lambda: "active-path-element"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement, [u'pelem_path_id', u'pelem_version', u'pelem_flags', u'pelem_gw_metric', u'pelem_path_flags', u'pelem_path_peer_path_id', u'pelem_table_attr_version', u'pelem_path_table_attr_version', u'pelem_no_bestpath_table_attr_version', u'pelem_no_addpath_table_attr_version', u'is_perm_path_pelem'], name, value)


                                            class PelemPathNexthop(Entity):
                                                """
                                                Path nexthop address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, self).__init__()

                                                    self.yang_name = "pelem-path-nexthop"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "pelem-path-nexthop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-nexthop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class PelemPathNeighborAddr(Entity):
                                                """
                                                Path neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                    self.yang_name = "pelem-path-neighbor-addr"
                                                    self.yang_parent_name = "active-path-element"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "pelem-path-neighbor-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "pelem-path-neighbor-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class PathTable(Entity):
                                    """
                                    The BGP Path Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable, self).__init__()

                                        self.yang_name = "path-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path))])
                                        self._leafs = OrderedDict()

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: orig_source_rd
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                                ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                                ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                                ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.orig_source_rd = None
                                            self.path_id = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class Epes(Entity):
                                    """
                                    The BGP Egress Engineering table
                                    
                                    .. attribute:: epe
                                    
                                    	A BGP Egress Engineering table entry
                                    	**type**\: list of  		 :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes, self).__init__()

                                        self.yang_name = "epes"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("epe", ("epe", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe))])
                                        self._leafs = OrderedDict()

                                        self.epe = YList(self)
                                        self._segment_path = lambda: "epes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes, [], name, value)


                                    class Epe(Entity):
                                        """
                                        A BGP Egress Engineering table entry
                                        
                                        .. attribute:: epe_key_length
                                        
                                        	Epe Key Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_set_key
                                        
                                        	Epe Set Key
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: epe_local_address
                                        
                                        	Local address
                                        	**type**\:  :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                        
                                        .. attribute:: epe_next_hop
                                        
                                        	Nexthop address
                                        	**type**\:  :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                        
                                        .. attribute:: epe_key_length_xr
                                        
                                        	EPE key length in bits
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_version
                                        
                                        	EPE object's version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_flags
                                        
                                        	EPE object's flags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: epe_local_asn
                                        
                                        	Local AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_remote_asn
                                        
                                        	Remote AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_remote_router_id
                                        
                                        	Remote router id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_local_router_id
                                        
                                        	Local router id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label
                                        
                                        	Label assigned to the RPCnext\-hop set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ref_count
                                        
                                        	Refcount
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rpc_set_object_id
                                        
                                        	RPC set object ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_key
                                        
                                        	Key of EPE object
                                        	**type**\: list of  		 :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey>`
                                        
                                        .. attribute:: nexthop_id
                                        
                                        	List of nexthop ID of EPE
                                        	**type**\: list of  		 :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId>`
                                        
                                        .. attribute:: ifhandle
                                        
                                        	List of ifhandle of EPE
                                        	**type**\: list of  		 :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle>`
                                        
                                        .. attribute:: first_hop
                                        
                                        	List of firsthops of EPE
                                        	**type**\: list of  		 :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe, self).__init__()

                                            self.yang_name = "epe"
                                            self.yang_parent_name = "epes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("epe-local-address", ("epe_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress)), ("epe-next-hop", ("epe_next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop)), ("epe-key", ("epe_key", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey)), ("nexthop-id", ("nexthop_id", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId)), ("ifhandle", ("ifhandle", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle)), ("first-hop", ("first_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop))])
                                            self._leafs = OrderedDict([
                                                ('epe_key_length', (YLeaf(YType.uint32, 'epe-key-length'), ['int'])),
                                                ('epe_set_key', (YLeaf(YType.str, 'epe-set-key'), ['str'])),
                                                ('epe_key_length_xr', (YLeaf(YType.uint8, 'epe-key-length-xr'), ['int'])),
                                                ('epe_version', (YLeaf(YType.uint32, 'epe-version'), ['int'])),
                                                ('epe_flags', (YLeaf(YType.uint8, 'epe-flags'), ['int'])),
                                                ('epe_local_asn', (YLeaf(YType.uint32, 'epe-local-asn'), ['int'])),
                                                ('epe_remote_asn', (YLeaf(YType.uint32, 'epe-remote-asn'), ['int'])),
                                                ('epe_remote_router_id', (YLeaf(YType.uint32, 'epe-remote-router-id'), ['int'])),
                                                ('epe_local_router_id', (YLeaf(YType.uint32, 'epe-local-router-id'), ['int'])),
                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                ('ref_count', (YLeaf(YType.uint32, 'ref-count'), ['int'])),
                                                ('rpc_set_object_id', (YLeaf(YType.uint32, 'rpc-set-object-id'), ['int'])),
                                            ])
                                            self.epe_key_length = None
                                            self.epe_set_key = None
                                            self.epe_key_length_xr = None
                                            self.epe_version = None
                                            self.epe_flags = None
                                            self.epe_local_asn = None
                                            self.epe_remote_asn = None
                                            self.epe_remote_router_id = None
                                            self.epe_local_router_id = None
                                            self.label = None
                                            self.ref_count = None
                                            self.rpc_set_object_id = None

                                            self.epe_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                            self.epe_local_address.parent = self
                                            self._children_name_map["epe_local_address"] = "epe-local-address"

                                            self.epe_next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop()
                                            self.epe_next_hop.parent = self
                                            self._children_name_map["epe_next_hop"] = "epe-next-hop"

                                            self.epe_key = YList(self)
                                            self.nexthop_id = YList(self)
                                            self.ifhandle = YList(self)
                                            self.first_hop = YList(self)
                                            self._segment_path = lambda: "epe"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe, ['epe_key_length', 'epe_set_key', u'epe_key_length_xr', u'epe_version', u'epe_flags', u'epe_local_asn', u'epe_remote_asn', u'epe_remote_router_id', u'epe_local_router_id', u'label', u'ref_count', u'rpc_set_object_id'], name, value)


                                        class EpeLocalAddress(Entity):
                                            """
                                            Local address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress, self).__init__()

                                                self.yang_name = "epe-local-address"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "epe-local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "epe-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class EpeNextHop(Entity):
                                            """
                                            Nexthop address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop, self).__init__()

                                                self.yang_name = "epe-next-hop"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "epe-next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "epe-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class EpeKey(Entity):
                                            """
                                            Key of EPE object
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey, self).__init__()

                                                self.yang_name = "epe-key"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "epe-key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.EpeKey, [u'entry'], name, value)


                                        class NexthopId(Entity):
                                            """
                                            List of nexthop ID of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId, self).__init__()

                                                self.yang_name = "nexthop-id"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "nexthop-id"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.NexthopId, [u'entry'], name, value)


                                        class Ifhandle(Entity):
                                            """
                                            List of ifhandle of EPE
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle, self).__init__()

                                                self.yang_name = "ifhandle"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "ifhandle"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.Ifhandle, [u'entry'], name, value)


                                        class FirstHop(Entity):
                                            """
                                            List of firsthops of EPE
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop, self).__init__()

                                                self.yang_name = "first-hop"
                                                self.yang_parent_name = "epe"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "first-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "first-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertisedPathCounts(Entity):
                                    """
                                    The BGP Advertised paths table (bestpath)
                                    
                                    .. attribute:: advertised_path_count
                                    
                                    	The BGP Advertised path table Count (bestpath)
                                    	**type**\: list of  		 :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts, self).__init__()

                                        self.yang_name = "advertised-path-counts"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-path-count", ("advertised_path_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount))])
                                        self._leafs = OrderedDict()

                                        self.advertised_path_count = YList(self)
                                        self._segment_path = lambda: "advertised-path-counts"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts, [], name, value)


                                    class AdvertisedPathCount(Entity):
                                        """
                                        The BGP Advertised path table Count
                                        (bestpath)
                                        
                                        .. attribute:: neighbor_address  (key)
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: max_prefix_advertisedcount
                                        
                                        	Number of prefixes advertsied to neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, self).__init__()

                                            self.yang_name = "advertised-path-count"
                                            self.yang_parent_name = "advertised-path-counts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['neighbor_address']
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('max_prefix_advertisedcount', (YLeaf(YType.uint32, 'max-prefix-advertisedcount'), ['int'])),
                                            ])
                                            self.neighbor_address = None
                                            self.max_prefix_advertisedcount = None
                                            self._segment_path = lambda: "advertised-path-count" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, ['neighbor_address', u'max_prefix_advertisedcount'], name, value)


                                class PathLabeledTable(Entity):
                                    """
                                    The BGP Path Labeled Table
                                    
                                    .. attribute:: path
                                    
                                    	A BGP path table entry
                                    	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable, self).__init__()

                                        self.yang_name = "path-labeled-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path))])
                                        self._leafs = OrderedDict()

                                        self.path = YList(self)
                                        self._segment_path = lambda: "path-labeled-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable, [], name, value)


                                    class Path(Entity):
                                        """
                                        A BGP path table entry
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor adddress
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type
                                        	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: orig_source_rd
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path, self).__init__()

                                            self.yang_name = "path"
                                            self.yang_parent_name = "path-labeled-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                                ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                                ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                                ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None
                                            self.route_type = None
                                            self.source_rd = None
                                            self.orig_source_rd = None
                                            self.path_id = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AdvertisedPaths(Entity):
                                    """
                                    The BGP Advertised paths table (add\-paths)
                                    
                                    .. attribute:: advertised_path
                                    
                                    	A BGP Advertised paths table entry (add\-paths)
                                    	**type**\: list of  		 :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths, self).__init__()

                                        self.yang_name = "advertised-paths"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-path", ("advertised_path", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath))])
                                        self._leafs = OrderedDict()

                                        self.advertised_path = YList(self)
                                        self._segment_path = lambda: "advertised-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths, [], name, value)


                                    class AdvertisedPath(Entity):
                                        """
                                        A BGP Advertised paths table entry
                                        (add\-paths)
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Network prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor 
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: paths
                                        
                                        	paths
                                        	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                        
                                        .. attribute:: adv_path_info
                                        
                                        	Net Advertized Paths
                                        	**type**\: list of  		 :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath, self).__init__()

                                            self.yang_name = "advertised-path"
                                            self.yang_parent_name = "advertised-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("paths", ("paths", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths)), ("adv-path-info", ("adv_path_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo))])
                                            self._leafs = OrderedDict([
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ])
                                            self.rd = None
                                            self.network = None
                                            self.prefix_length = None
                                            self.neighbor_address = None

                                            self.paths = YList(self)
                                            self.adv_path_info = YList(self)
                                            self._segment_path = lambda: "advertised-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath, ['rd', 'network', 'prefix_length', 'neighbor_address'], name, value)


                                        class Paths(Entity):
                                            """
                                            paths
                                            
                                            .. attribute:: advertised_neighbor
                                            
                                            	Advertised Neighbor Address. Valid in the case of Advertised table
                                            	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor>`
                                            
                                            .. attribute:: path_information
                                            
                                            	Path information
                                            	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                            	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: process_instance_id
                                            
                                            	Process instance ID
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: label_oor
                                            
                                            	LSD label space is exhausted
                                            	**type**\: bool
                                            
                                            .. attribute:: label_oor_version
                                            
                                            	Label Version when OOR happens
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: label_fail
                                            
                                            	LSD label allocation failed 
                                            	**type**\: bool
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: original_source_route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: prefix_version
                                            
                                            	Version of BGP Prefix Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\: str
                                            
                                            .. attribute:: source_vrf_name
                                            
                                            	Name of the source VRF
                                            	**type**\: str
                                            
                                            .. attribute:: srcaf_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn))])
                                                self._leafs = OrderedDict([
                                                    ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                    ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                    ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                    ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                    ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                    ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                    ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                    ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.no_path = None
                                                self.af_name = None
                                                self.process_instance_id = None
                                                self.label_oor = None
                                                self.label_oor_version = None
                                                self.label_fail = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.original_source_route_distinguisher = None
                                                self.prefix_version = None
                                                self.vrf_name = None
                                                self.source_vrf_name = None
                                                self.srcaf_name = None

                                                self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor()
                                                self.advertised_neighbor.parent = self
                                                self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                                self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                                self.path_information.parent = self
                                                self._children_name_map["path_information"] = "path-information"

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                                self._segment_path = lambda: "paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                            class AdvertisedNeighbor(Entity):
                                                """
                                                Advertised Neighbor Address. Valid in the case
                                                of Advertised table
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor, self).__init__()

                                                    self.yang_name = "advertised-neighbor"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "advertised-neighbor"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "advertised-neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PathInformation(Entity):
                                                """
                                                Path information
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel>`
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr>`
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\: bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\: bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgp
                                                
                                                	Not advertised to EBGPs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\: bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\: bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\: bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\: bool
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\: str
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\: bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\: bool
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\: bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\: bool
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_self_originated_path
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\: bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\: bool
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\: bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\: bool
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\: bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\: bool
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\: bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\: bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: mac_ip_present
                                                
                                                	Mac IP Present  present
                                                	**type**\: bool
                                                
                                                .. attribute:: mac_ip
                                                
                                                	Mac associated with IP
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel>`
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue>`
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, self).__init__()

                                                    self.yang_name = "path-information"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield))])
                                                    self._leafs = OrderedDict([
                                                        ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                        ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                        ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                        ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                        ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                        ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                        ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                        ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                        ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                        ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                        ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                        ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                        ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                        ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                        ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                        ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                        ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                        ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                        ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                        ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                        ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                        ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                        ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                        ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                        ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                        ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                        ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                        ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                        ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                        ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                        ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                        ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                        ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                        ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                        ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                        ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                        ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                        ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                        ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                        ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                        ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                        ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                        ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                        ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                        ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                        ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                        ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                        ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                        ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                        ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                        ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                        ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                        ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                        ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                        ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                        ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                        ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                        ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                        ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                        ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                        ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                        ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                        ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                        ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                        ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                        ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                        ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                        ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                        ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                        ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                        ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                        ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                        ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                        ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                        ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                        ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                        ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                        ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                        ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                        ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                        ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                        ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                        ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                        ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                        ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                        ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                        ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                        ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                        ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                        ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                        ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                        ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                        ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                        ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                        ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                    ])
                                                    self.route_type = None
                                                    self.is_path_valid = None
                                                    self.is_path_damped = None
                                                    self.is_path_history_held = None
                                                    self.is_internal_path = None
                                                    self.is_best_path = None
                                                    self.is_as_best = None
                                                    self.is_spkr_as_best = None
                                                    self.is_partial_best = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebgp = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_received_only = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_imported = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_vpn_only = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_multipath = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_stale = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.has_local_net_label = None
                                                    self.local_label = None
                                                    self.igp_metric = None
                                                    self.path_weight = None
                                                    self.neighbor_router_id = None
                                                    self.has_mdt_group_addr = None
                                                    self.l2vpn_size = None
                                                    self.l2vpn_evpn_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_nh_addr = None
                                                    self.has_second_label = None
                                                    self.second_label = None
                                                    self.path_flap_count = None
                                                    self.seconds_since_first_flap = None
                                                    self.time_to_unsuppress = None
                                                    self.dampen_penalty = None
                                                    self.halflife_time = None
                                                    self.suppress_penalty = None
                                                    self.reuse_value = None
                                                    self.maximum_suppress_time = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_id_comp_winner = None
                                                    self.path_flags = None
                                                    self.path_import_flags = None
                                                    self.best_path_id = None
                                                    self.local_path_id = None
                                                    self.rcvd_path_id = None
                                                    self.path_table_version = None
                                                    self.advertisedto_pe = None
                                                    self.rib_failed = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.ibgp_signaled_validity = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_path = None
                                                    self.aigp_metric = None
                                                    self.mvpn_sfs_path = None
                                                    self.fspec_invalid_path = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.has_mvpn_extcomm = None
                                                    self.mvpn_path_flags = None
                                                    self.local_nh = None
                                                    self.rt_set_limit_enabled = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_permanent_path = None
                                                    self.graceful_shutdown = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.has_vpn_nexthop_addr = None
                                                    self.is_orig_src_rd_present = None
                                                    self.af_name = None
                                                    self.route_distinguisher = None
                                                    self.mac_ip_present = None
                                                    self.mac_ip = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                    self.rcvd_label = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self._segment_path = lambda: "path-information"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mdt-group-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "gw-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "nh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "best-path-comp-winner"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nbr-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "vpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rcvd-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, [u'entry'], name, value)


                                                class L2vpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "mvpn-pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "local-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "pe-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "best-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-information"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "add-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy applied. In the
                                                case of path type received\-only this will be
                                                attributes before inbound policy
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\: bool
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\: bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp))])
                                                    self._leafs = OrderedDict([
                                                        ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                        ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                        ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                        ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                        ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                        ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                        ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                        ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                        ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                        ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                        ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                        ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                        ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                        ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                        ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                        ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                        ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                        ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                        ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                        ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                        ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                        ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                        ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                    ])
                                                    self.is_as_path2_byte = None
                                                    self.is_application_gateway_present = None
                                                    self.is_attr_set_present = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.is_rnh_present = None
                                                    self.is_ribrnh_present = None
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.vpn_distinguisher = None
                                                    self.rnh_type = None
                                                    self.rnh_len = None
                                                    self.rnh_addr_len = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_mac = None
                                                    self.ribrnhip_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnh_encap = None

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._segment_path = lambda: "attributes-after-policy-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "common-attributes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "attr-set"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.mac_address = None
                                                        self._segment_path = lambda: "rnh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "ribrnh-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AdvPathInfo(Entity):
                                            """
                                            Net Advertized Paths
                                            
                                            .. attribute:: neighbor_address_xr
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                            
                                            .. attribute:: path_info_after_policy_in
                                            
                                            	Path information after inbound policy
                                            	**type**\:  :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                            
                                            .. attribute:: path_info_after_policy_out
                                            
                                            	Path information after outbound policy
                                            	**type**\:  :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                            
                                            .. attribute:: attributes_after_policy_in
                                            
                                            	Attributes after inbound policy
                                            	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                            
                                            .. attribute:: attributes_after_policy_out
                                            
                                            	Attributes after outbound policy
                                            	**type**\:  :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                            
                                            .. attribute:: no_path
                                            
                                            	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: source_route_distinguisher
                                            
                                            	Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: vrf_name
                                            
                                            	Name of the VRF
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, self).__init__()

                                                self.yang_name = "adv-path-info"
                                                self.yang_parent_name = "advertised-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr)), ("path-info-after-policy-in", ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn)), ("path-info-after-policy-out", ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn)), ("attributes-after-policy-out", ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut))])
                                                self._leafs = OrderedDict([
                                                    ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ])
                                                self.no_path = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.source_route_distinguisher = None
                                                self.vrf_name = None

                                                self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                                self.neighbor_address_xr.parent = self
                                                self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                                self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                                self.path_info_after_policy_in.parent = self
                                                self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"

                                                self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                                self.path_info_after_policy_out.parent = self
                                                self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"

                                                self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                                self.attributes_after_policy_in.parent = self
                                                self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"

                                                self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                                self.attributes_after_policy_out.parent = self
                                                self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                                self._segment_path = lambda: "adv-path-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, [u'no_path', u'af_name', u'route_distinguisher', u'source_route_distinguisher', u'vrf_name'], name, value)


                                            class NeighborAddressXr(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, self).__init__()

                                                    self.yang_name = "neighbor-address-xr"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address-xr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address-xr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PathInfoAfterPolicyIn(Entity):
                                                """
                                                Path information after inbound policy
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel>`
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\: bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\: bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgp
                                                
                                                	Not advertised to EBGPs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\: bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\: bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\: bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\: bool
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\: str
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\: bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\: bool
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\: bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\: bool
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_self_originated_path
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\: bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\: bool
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\: bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\: bool
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\: bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\: bool
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\: bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\: bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: mac_ip_present
                                                
                                                	Mac IP Present  present
                                                	**type**\: bool
                                                
                                                .. attribute:: mac_ip
                                                
                                                	Mac associated with IP
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel>`
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue>`
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, self).__init__()

                                                    self.yang_name = "path-info-after-policy-in"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield))])
                                                    self._leafs = OrderedDict([
                                                        ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                        ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                        ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                        ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                        ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                        ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                        ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                        ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                        ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                        ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                        ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                        ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                        ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                        ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                        ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                        ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                        ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                        ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                        ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                        ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                        ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                        ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                        ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                        ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                        ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                        ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                        ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                        ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                        ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                        ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                        ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                        ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                        ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                        ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                        ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                        ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                        ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                        ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                        ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                        ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                        ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                        ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                        ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                        ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                        ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                        ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                        ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                        ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                        ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                        ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                        ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                        ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                        ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                        ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                        ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                        ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                        ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                        ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                        ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                        ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                        ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                        ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                        ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                        ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                        ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                        ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                        ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                        ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                        ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                        ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                        ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                        ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                        ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                        ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                        ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                        ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                        ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                        ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                        ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                        ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                        ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                        ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                        ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                        ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                        ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                        ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                        ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                        ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                        ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                        ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                        ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                        ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                        ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                        ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                        ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                    ])
                                                    self.route_type = None
                                                    self.is_path_valid = None
                                                    self.is_path_damped = None
                                                    self.is_path_history_held = None
                                                    self.is_internal_path = None
                                                    self.is_best_path = None
                                                    self.is_as_best = None
                                                    self.is_spkr_as_best = None
                                                    self.is_partial_best = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebgp = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_received_only = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_imported = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_vpn_only = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_multipath = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_stale = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.has_local_net_label = None
                                                    self.local_label = None
                                                    self.igp_metric = None
                                                    self.path_weight = None
                                                    self.neighbor_router_id = None
                                                    self.has_mdt_group_addr = None
                                                    self.l2vpn_size = None
                                                    self.l2vpn_evpn_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_nh_addr = None
                                                    self.has_second_label = None
                                                    self.second_label = None
                                                    self.path_flap_count = None
                                                    self.seconds_since_first_flap = None
                                                    self.time_to_unsuppress = None
                                                    self.dampen_penalty = None
                                                    self.halflife_time = None
                                                    self.suppress_penalty = None
                                                    self.reuse_value = None
                                                    self.maximum_suppress_time = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_id_comp_winner = None
                                                    self.path_flags = None
                                                    self.path_import_flags = None
                                                    self.best_path_id = None
                                                    self.local_path_id = None
                                                    self.rcvd_path_id = None
                                                    self.path_table_version = None
                                                    self.advertisedto_pe = None
                                                    self.rib_failed = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.ibgp_signaled_validity = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_path = None
                                                    self.aigp_metric = None
                                                    self.mvpn_sfs_path = None
                                                    self.fspec_invalid_path = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.has_mvpn_extcomm = None
                                                    self.mvpn_path_flags = None
                                                    self.local_nh = None
                                                    self.rt_set_limit_enabled = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_permanent_path = None
                                                    self.graceful_shutdown = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.has_vpn_nexthop_addr = None
                                                    self.is_orig_src_rd_present = None
                                                    self.af_name = None
                                                    self.route_distinguisher = None
                                                    self.mac_ip_present = None
                                                    self.mac_ip = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                    self.rcvd_label = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self._segment_path = lambda: "path-info-after-policy-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mdt-group-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "gw-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "nh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "best-path-comp-winner"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nbr-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "vpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rcvd-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, [u'entry'], name, value)


                                                class L2vpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "mvpn-pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, [u'entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "local-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "pe-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "best-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "add-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PathInfoAfterPolicyOut(Entity):
                                                """
                                                Path information after outbound policy
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                                
                                                .. attribute:: next_hop
                                                
                                                	Next hop
                                                	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                                
                                                .. attribute:: nh_tunnel
                                                
                                                	NH tunnel information
                                                	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel>`
                                                
                                                .. attribute:: mdt_group_addr
                                                
                                                	IPv4 MDT Group Address for the path
                                                	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                                
                                                .. attribute:: gw_addr
                                                
                                                	Path GW Address
                                                	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                                
                                                .. attribute:: nh_addr
                                                
                                                	Path next\-hop Address
                                                	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr>`
                                                
                                                .. attribute:: best_path_comp_winner
                                                
                                                	Neighbor address of the path which won best path comparison
                                                	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                                
                                                .. attribute:: mvpn_nbr_addr
                                                
                                                	Mvpn nbr Address for the path
                                                	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                                
                                                .. attribute:: mvpn_nexthop_addr
                                                
                                                	Mvpn nexthop Address for the path
                                                	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                                
                                                .. attribute:: vpn_nexthop_addr
                                                
                                                	Vpn nexthop Address for the path
                                                	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                                
                                                .. attribute:: route_type
                                                
                                                	Route Type of path
                                                	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                                
                                                .. attribute:: is_path_valid
                                                
                                                	Path attributes are usable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_damped
                                                
                                                	Path suppressed due to dampening
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_history_held
                                                
                                                	Path entry held to remember history
                                                	**type**\: bool
                                                
                                                .. attribute:: is_internal_path
                                                
                                                	Received over an internal link
                                                	**type**\: bool
                                                
                                                .. attribute:: is_best_path
                                                
                                                	Best available path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_best
                                                
                                                	Best available path within AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_spkr_as_best
                                                
                                                	Best available path within AS in speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_best
                                                
                                                	Partial best path within distributed speaker
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregation_suppressed
                                                
                                                	Path suppressed due to aggregation
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_dampened
                                                
                                                	net import dampened
                                                	**type**\: bool
                                                
                                                .. attribute:: is_import_suspect
                                                
                                                	net import suspect
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised
                                                
                                                	Not advertised to any peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_not_advertised_to_ebgp
                                                
                                                	Not advertised to EBGPs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_advertised_local_as_only
                                                
                                                	Not advertised outside local AS
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_route_reflector
                                                
                                                	Path received from route reflector
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_received_only
                                                
                                                	Path is received only
                                                	**type**\: bool
                                                
                                                .. attribute:: is_received_path_not_modified
                                                
                                                	Received path used without modification
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_locally_sourced
                                                
                                                	Path sourced locally
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_local_aggregate
                                                
                                                	Path is a locally created aggregate
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_network_command
                                                
                                                	Path sourced by network command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_redistribute_command
                                                
                                                	Path sourced by redistribute command
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imported
                                                
                                                	Path is imported
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated
                                                
                                                	Path is reoriginated
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_reoriginated_stitching
                                                
                                                	Path is reoriginated with stitching RTs
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_vpn_only
                                                
                                                	Path is not in the vrf
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_from_confederation_peer
                                                
                                                	Path received from confederation peer
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_synced_with_igp
                                                
                                                	Path synchronized with IGP
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_multipath
                                                
                                                	Path is one of multipath best routes
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_imp_candidate
                                                
                                                	Path is a candidate for multipath import
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_stale
                                                
                                                	Stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_long_lived_stale
                                                
                                                	Long lived stale routes learnt before neighbor restarts
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup
                                                
                                                	Path is a backup path 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_backup_protect_multipath
                                                
                                                	Path is a backup path to protect multipaths
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_best_external
                                                
                                                	Path is a best external path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_additional_path
                                                
                                                	Path is an additional\-path
                                                	**type**\: bool
                                                
                                                .. attribute:: is_path_nexthop_discarded
                                                
                                                	Path is redirected to Null0
                                                	**type**\: bool
                                                
                                                .. attribute:: has_local_net_label
                                                
                                                	Path has local label
                                                	**type**\: bool
                                                
                                                .. attribute:: local_label
                                                
                                                	Path local label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: igp_metric
                                                
                                                	IGP metric to the gateway
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_weight
                                                
                                                	Weight for the path
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: neighbor_router_id
                                                
                                                	Router ID of the neighbor for the path
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: has_mdt_group_addr
                                                
                                                	Path has MDT Group Address
                                                	**type**\: bool
                                                
                                                .. attribute:: l2vpn_size
                                                
                                                	Path block size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: l2vpn_evpn_esi
                                                
                                                	L2VPN EVPN ESI
                                                	**type**\: str
                                                
                                                .. attribute:: has_gw_addr
                                                
                                                	Path has GW Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_nh_addr
                                                
                                                	Path has next\-hop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_second_label
                                                
                                                	Path has second received label
                                                	**type**\: bool
                                                
                                                .. attribute:: second_label
                                                
                                                	Path second received label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flap_count
                                                
                                                	Number of times this route has flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: seconds_since_first_flap
                                                
                                                	Seconds since route first flapped
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: time_to_unsuppress
                                                
                                                	Seconds until route is unsuppressed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: dampen_penalty
                                                
                                                	Dampening penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: halflife_time
                                                
                                                	Half\-life time for the penalty
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: suppress_penalty
                                                
                                                	Value to start suppressing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reuse_value
                                                
                                                	Value to start reusing a route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_suppress_time
                                                
                                                	Maximum duration to suppress a stable route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_comp_stage
                                                
                                                	Stage where the path lost to the best path or group best
                                                	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                                
                                                .. attribute:: best_path_id_comp_winner
                                                
                                                	Path ID of the path which won best path comparison
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_flags
                                                
                                                	Flags associated with path
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: path_import_flags
                                                
                                                	Path import flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: best_path_id
                                                
                                                	Best path ID; DEPRECATED BYLocalPathId
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_path_id
                                                
                                                	Local path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rcvd_path_id
                                                
                                                	Received path ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_table_version
                                                
                                                	Table version # for pelem
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertisedto_pe
                                                
                                                	Net could be advertised                          to PE peers
                                                	**type**\: bool
                                                
                                                .. attribute:: rib_failed
                                                
                                                	Is net failed installed                          in RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: sn_rpki_origin_as_validity
                                                
                                                	RPKI origin validation state
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: show_rpki_origin_as_validity
                                                
                                                	Display validity state ?
                                                	**type**\: bool
                                                
                                                .. attribute:: ibgp_signaled_validity
                                                
                                                	IBGP signalled validation
                                                	**type**\: bool
                                                
                                                .. attribute:: rpki_origin_as_validation_disabled
                                                
                                                	RPKI originAS V. Disabled
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_path
                                                
                                                	Accept Own
                                                	**type**\: bool
                                                
                                                .. attribute:: accept_own_self_originated_path
                                                
                                                	Accept\-Own self\-originated
                                                	**type**\: bool
                                                
                                                .. attribute:: aigp_metric
                                                
                                                	Total AIGP metric
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: mvpn_sfs_path
                                                
                                                	Is MVPN single forwarder PE path
                                                	**type**\: bool
                                                
                                                .. attribute:: fspec_invalid_path
                                                
                                                	Is Fspec invalid path
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nbr_addr
                                                
                                                	Path has Mvpn nbr Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_nexthop_addr
                                                
                                                	Path has MVPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: has_mvpn_pmsi
                                                
                                                	Path has MVPN PMSI feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_pmsi_type
                                                
                                                	Mvpn PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: mvpn_pmsi_flags
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mvpn_pmsi_label
                                                
                                                	Mvpn PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: has_mvpn_extcomm
                                                
                                                	Path has MVPN EXTCOMM feedback
                                                	**type**\: bool
                                                
                                                .. attribute:: mvpn_path_flags
                                                
                                                	Mvpn path flags
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: local_nh
                                                
                                                	Path has local nexthop
                                                	**type**\: bool
                                                
                                                .. attribute:: rt_set_limit_enabled
                                                
                                                	Path subject to RT\-set net limit
                                                	**type**\: bool
                                                
                                                .. attribute:: path_rt_set_id
                                                
                                                	RT\-set id of the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: path_rt_set_route_count
                                                
                                                	Count in RT\-set
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_path_af_install_eligible
                                                
                                                	Path can be installed in AF RIB
                                                	**type**\: bool
                                                
                                                .. attribute:: is_permanent_path
                                                
                                                	Path is of type Permanent path
                                                	**type**\: bool
                                                
                                                .. attribute:: graceful_shutdown
                                                
                                                	Marked for graceful shutdown
                                                	**type**\: bool
                                                
                                                .. attribute:: labeled_unicast_safi_path
                                                
                                                	Path was learnt by labeled\-unicast SAFI
                                                	**type**\: bool
                                                
                                                .. attribute:: has_vpn_nexthop_addr
                                                
                                                	Path has VPN nexthop Address
                                                	**type**\: bool
                                                
                                                .. attribute:: is_orig_src_rd_present
                                                
                                                	Original Source RD  present
                                                	**type**\: bool
                                                
                                                .. attribute:: af_name
                                                
                                                	Original Source Address family identifier
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: route_distinguisher
                                                
                                                	Original Source Route Distinguisher
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{16}
                                                
                                                .. attribute:: mac_ip_present
                                                
                                                	Mac IP Present  present
                                                	**type**\: bool
                                                
                                                .. attribute:: mac_ip
                                                
                                                	Mac associated with IP
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: rcvd_label
                                                
                                                	Path received label stack
                                                	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel>`
                                                
                                                .. attribute:: l2vpn_circuit_status_value
                                                
                                                	L2VPN Circuit Status Value
                                                	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue>`
                                                
                                                .. attribute:: mvpn_pmsi_value
                                                
                                                	Mvpn PMSI Value
                                                	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Mvpn Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                                
                                                .. attribute:: local_peers_advertised_to
                                                
                                                	Local peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                                
                                                .. attribute:: pe_peers_advertised_to
                                                
                                                	PE peers that this prefix has been advertised to
                                                	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                                
                                                .. attribute:: best_path_orr_bitfield
                                                
                                                	ORR Best path Bitfields
                                                	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                                
                                                .. attribute:: add_path_orr_bitfield
                                                
                                                	ORR Add path Bitfields
                                                	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, self).__init__()

                                                    self.yang_name = "path-info-after-policy-out"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield))])
                                                    self._leafs = OrderedDict([
                                                        ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                        ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                        ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                        ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                        ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                        ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                        ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                        ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                        ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                        ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                        ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                        ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                        ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                        ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                        ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                        ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                        ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                        ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                        ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                        ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                        ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                        ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                        ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                        ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                        ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                        ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                        ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                        ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                        ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                        ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                        ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                        ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                        ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                        ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                        ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                        ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                        ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                        ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                        ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                        ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                        ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                        ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                        ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                        ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                        ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                        ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                        ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                        ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                        ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                        ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                        ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                        ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                        ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                        ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                        ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                        ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                        ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                        ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                        ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                        ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                        ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                        ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                        ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                        ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                        ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                        ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                        ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                        ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                        ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                        ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                        ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                        ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                        ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                        ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                        ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                        ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                        ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                        ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                        ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                        ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                        ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                        ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                        ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                        ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                        ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                        ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                        ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                        ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                        ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                        ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                        ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                        ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                        ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                        ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                        ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                        ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                    ])
                                                    self.route_type = None
                                                    self.is_path_valid = None
                                                    self.is_path_damped = None
                                                    self.is_path_history_held = None
                                                    self.is_internal_path = None
                                                    self.is_best_path = None
                                                    self.is_as_best = None
                                                    self.is_spkr_as_best = None
                                                    self.is_partial_best = None
                                                    self.is_aggregation_suppressed = None
                                                    self.is_import_dampened = None
                                                    self.is_import_suspect = None
                                                    self.is_path_not_advertised = None
                                                    self.is_path_not_advertised_to_ebgp = None
                                                    self.is_path_advertised_local_as_only = None
                                                    self.is_path_from_route_reflector = None
                                                    self.is_path_received_only = None
                                                    self.is_received_path_not_modified = None
                                                    self.is_path_locally_sourced = None
                                                    self.is_path_local_aggregate = None
                                                    self.is_path_from_network_command = None
                                                    self.is_path_from_redistribute_command = None
                                                    self.is_path_imported = None
                                                    self.is_path_reoriginated = None
                                                    self.is_path_reoriginated_stitching = None
                                                    self.is_path_vpn_only = None
                                                    self.is_path_from_confederation_peer = None
                                                    self.is_path_synced_with_igp = None
                                                    self.is_path_multipath = None
                                                    self.is_path_imp_candidate = None
                                                    self.is_path_stale = None
                                                    self.is_path_long_lived_stale = None
                                                    self.is_path_backup = None
                                                    self.is_path_backup_protect_multipath = None
                                                    self.is_path_best_external = None
                                                    self.is_path_additional_path = None
                                                    self.is_path_nexthop_discarded = None
                                                    self.has_local_net_label = None
                                                    self.local_label = None
                                                    self.igp_metric = None
                                                    self.path_weight = None
                                                    self.neighbor_router_id = None
                                                    self.has_mdt_group_addr = None
                                                    self.l2vpn_size = None
                                                    self.l2vpn_evpn_esi = None
                                                    self.has_gw_addr = None
                                                    self.has_nh_addr = None
                                                    self.has_second_label = None
                                                    self.second_label = None
                                                    self.path_flap_count = None
                                                    self.seconds_since_first_flap = None
                                                    self.time_to_unsuppress = None
                                                    self.dampen_penalty = None
                                                    self.halflife_time = None
                                                    self.suppress_penalty = None
                                                    self.reuse_value = None
                                                    self.maximum_suppress_time = None
                                                    self.best_path_comp_stage = None
                                                    self.best_path_id_comp_winner = None
                                                    self.path_flags = None
                                                    self.path_import_flags = None
                                                    self.best_path_id = None
                                                    self.local_path_id = None
                                                    self.rcvd_path_id = None
                                                    self.path_table_version = None
                                                    self.advertisedto_pe = None
                                                    self.rib_failed = None
                                                    self.sn_rpki_origin_as_validity = None
                                                    self.show_rpki_origin_as_validity = None
                                                    self.ibgp_signaled_validity = None
                                                    self.rpki_origin_as_validation_disabled = None
                                                    self.accept_own_path = None
                                                    self.accept_own_self_originated_path = None
                                                    self.aigp_metric = None
                                                    self.mvpn_sfs_path = None
                                                    self.fspec_invalid_path = None
                                                    self.has_mvpn_nbr_addr = None
                                                    self.has_mvpn_nexthop_addr = None
                                                    self.has_mvpn_pmsi = None
                                                    self.mvpn_pmsi_type = None
                                                    self.mvpn_pmsi_flags = None
                                                    self.mvpn_pmsi_label = None
                                                    self.has_mvpn_extcomm = None
                                                    self.mvpn_path_flags = None
                                                    self.local_nh = None
                                                    self.rt_set_limit_enabled = None
                                                    self.path_rt_set_id = None
                                                    self.path_rt_set_route_count = None
                                                    self.is_path_af_install_eligible = None
                                                    self.is_permanent_path = None
                                                    self.graceful_shutdown = None
                                                    self.labeled_unicast_safi_path = None
                                                    self.has_vpn_nexthop_addr = None
                                                    self.is_orig_src_rd_present = None
                                                    self.af_name = None
                                                    self.route_distinguisher = None
                                                    self.mac_ip_present = None
                                                    self.mac_ip = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                                    self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                    self.next_hop.parent = self
                                                    self._children_name_map["next_hop"] = "next-hop"

                                                    self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel()
                                                    self.nh_tunnel.parent = self
                                                    self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                    self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                    self.mdt_group_addr.parent = self
                                                    self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                    self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                    self.gw_addr.parent = self
                                                    self._children_name_map["gw_addr"] = "gw-addr"

                                                    self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr()
                                                    self.nh_addr.parent = self
                                                    self._children_name_map["nh_addr"] = "nh-addr"

                                                    self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                    self.best_path_comp_winner.parent = self
                                                    self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                    self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                    self.mvpn_nbr_addr.parent = self
                                                    self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                    self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                    self.mvpn_nexthop_addr.parent = self
                                                    self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                    self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                    self.vpn_nexthop_addr.parent = self
                                                    self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                    self.rcvd_label = YList(self)
                                                    self.l2vpn_circuit_status_value = YList(self)
                                                    self.mvpn_pmsi_value = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.local_peers_advertised_to = YList(self)
                                                    self.pe_peers_advertised_to = YList(self)
                                                    self.best_path_orr_bitfield = YList(self)
                                                    self.add_path_orr_bitfield = YList(self)
                                                    self._segment_path = lambda: "path-info-after-policy-out"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NextHop(Entity):
                                                    """
                                                    Next hop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                        self.yang_name = "next-hop"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "next-hop"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "next-hop"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NhTunnel(Entity):
                                                    """
                                                    NH tunnel information
                                                    
                                                    .. attribute:: tunnel_type
                                                    
                                                    	Nexthop Tunnel Type
                                                    	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                    
                                                    .. attribute:: tunnel_name
                                                    
                                                    	Tunnel name attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_tunnel_up
                                                    
                                                    	Tunnel Up flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_info_stale
                                                    
                                                    	Tunnel is stale
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_registered
                                                    
                                                    	Tunnel registered flag
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_required
                                                    
                                                    	Tunnel need IPv6
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_v6_enabled
                                                    
                                                    	IPv6 enabled
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_notif_first_rcvd
                                                    
                                                    	Tunnel first notif received
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_state_skip_reg
                                                    
                                                    	Skip tunnel registration for Stale entry
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	Binding label for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_if_handle
                                                    
                                                    	Interface handle for the tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: last_tunnel_update
                                                    
                                                    	Time since the last tunnel update happened
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tunnel_color
                                                    
                                                    	Color corresponding to this SR tunnel
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_tunnel_color_only
                                                    
                                                    	Is a Color Only (Null Endpoint) tunnel
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: tunnel_endpoint_afi
                                                    
                                                    	AFI of the Null Endpoint (IPv4/IPv6)
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                        self.yang_name = "nh-tunnel"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                            ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                            ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                            ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                            ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                            ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                            ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                            ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                            ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                            ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                            ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                            ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                            ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                            ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                            ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ])
                                                        self.tunnel_type = None
                                                        self.tunnel_name = None
                                                        self.is_tunnel_up = None
                                                        self.is_tunnel_info_stale = None
                                                        self.is_tunnel_registered = None
                                                        self.tunnel_v6_required = None
                                                        self.tunnel_v6_enabled = None
                                                        self.tunnel_notif_first_rcvd = None
                                                        self.tunnel_state_skip_reg = None
                                                        self.binding_label = None
                                                        self.tunnel_if_handle = None
                                                        self.last_tunnel_update = None
                                                        self.tunnel_color = None
                                                        self.is_tunnel_color_only = None
                                                        self.tunnel_endpoint_afi = None
                                                        self._segment_path = lambda: "nh-tunnel"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                                class MdtGroupAddr(Entity):
                                                    """
                                                    IPv4 MDT Group Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                        self.yang_name = "mdt-group-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mdt-group-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mdt-group-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class GwAddr(Entity):
                                                    """
                                                    Path GW Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                        self.yang_name = "gw-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "gw-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class NhAddr(Entity):
                                                    """
                                                    Path next\-hop Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                        self.yang_name = "nh-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self._segment_path = lambda: "nh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                                class BestPathCompWinner(Entity):
                                                    """
                                                    Neighbor address of the path which won best path
                                                    comparison
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                        self.yang_name = "best-path-comp-winner"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "best-path-comp-winner"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "best-path-comp-winner"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNbrAddr(Entity):
                                                    """
                                                    Mvpn nbr Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                        self.yang_name = "mvpn-nbr-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nbr-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nbr-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class MvpnNexthopAddr(Entity):
                                                    """
                                                    Mvpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                        self.yang_name = "mvpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "mvpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "mvpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class VpnNexthopAddr(Entity):
                                                    """
                                                    Vpn nexthop Address for the path
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                        self.yang_name = "vpn-nexthop-addr"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "vpn-nexthop-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "vpn-nexthop-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class RcvdLabel(Entity):
                                                    """
                                                    Path received label stack
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                        self.yang_name = "rcvd-label"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rcvd-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, [u'entry'], name, value)


                                                class L2vpnCircuitStatusValue(Entity):
                                                    """
                                                    L2VPN Circuit Status Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, self).__init__()

                                                        self.yang_name = "l2vpn-circuit-status-value"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                                class MvpnPmsiValue(Entity):
                                                    """
                                                    Mvpn PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                        self.yang_name = "mvpn-pmsi-value"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "mvpn-pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Mvpn Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, [u'entry'], name, value)


                                                class LocalPeersAdvertisedTo(Entity):
                                                    """
                                                    Local peers that this prefix has been advertised
                                                    to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "local-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "local-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "local-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class PePeersAdvertisedTo(Entity):
                                                    """
                                                    PE peers that this prefix has been advertised to
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                        self.yang_name = "pe-peers-advertised-to"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "pe-peers-advertised-to"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "pe-peers-advertised-to"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class BestPathOrrBitfield(Entity):
                                                    """
                                                    ORR Best path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                        self.yang_name = "best-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "best-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "best-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class AddPathOrrBitfield(Entity):
                                                    """
                                                    ORR Add path Bitfields
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Neighbor Address
                                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                    
                                                    .. attribute:: is_neighbor
                                                    
                                                    	Entry is a neighbor (not an update group)
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: update_group_afi
                                                    
                                                    	AFI of the Update group it is advertised to
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: update_group_number
                                                    
                                                    	Update group index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                        self.yang_name = "add-path-orr-bitfield"
                                                        self.yang_parent_name = "path-info-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                            ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                        ])
                                                        self.is_neighbor = None
                                                        self.update_group_afi = None
                                                        self.update_group_number = None

                                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                        self.neighbor_address.parent = self
                                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                                        self._segment_path = lambda: "add-path-orr-bitfield"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                    class NeighborAddress(Entity):
                                                        """
                                                        Neighbor Address
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                            self.yang_name = "neighbor-address"
                                                            self.yang_parent_name = "add-path-orr-bitfield"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "neighbor-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "neighbor-address"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AttributesAfterPolicyIn(Entity):
                                                """
                                                Attributes after inbound policy
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\: bool
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\: bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, self).__init__()

                                                    self.yang_name = "attributes-after-policy-in"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp))])
                                                    self._leafs = OrderedDict([
                                                        ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                        ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                        ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                        ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                        ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                        ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                        ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                        ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                        ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                        ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                        ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                        ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                        ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                        ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                        ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                        ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                        ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                        ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                        ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                        ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                        ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                        ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                        ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                    ])
                                                    self.is_as_path2_byte = None
                                                    self.is_application_gateway_present = None
                                                    self.is_attr_set_present = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.is_rnh_present = None
                                                    self.is_ribrnh_present = None
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.vpn_distinguisher = None
                                                    self.rnh_type = None
                                                    self.rnh_len = None
                                                    self.rnh_addr_len = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_mac = None
                                                    self.ribrnhip_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnh_encap = None

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._segment_path = lambda: "attributes-after-policy-in"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "common-attributes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "attr-set"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.mac_address = None
                                                        self._segment_path = lambda: "rnh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-in"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "ribrnh-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AttributesAfterPolicyOut(Entity):
                                                """
                                                Attributes after outbound policy
                                                
                                                .. attribute:: common_attributes
                                                
                                                	Common attributes
                                                	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                                
                                                .. attribute:: attr_set
                                                
                                                	ATTR\_SET attribute
                                                	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                                
                                                .. attribute:: rnh_addr
                                                
                                                	RNH Address
                                                	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                                
                                                .. attribute:: ribrnh_ip
                                                
                                                	RIB RNH IP Address
                                                	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                                
                                                .. attribute:: is_as_path2_byte
                                                
                                                	AS path encoded as 2\-byte
                                                	**type**\: bool
                                                
                                                .. attribute:: is_application_gateway_present
                                                
                                                	Application gateway present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_attr_set_present
                                                
                                                	BGP ATTR\_SET attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_igp
                                                
                                                	AIGP set by policy inbound IGP 
                                                	**type**\: bool
                                                
                                                .. attribute:: set_aigp_inbound_metric
                                                
                                                	AIGP set by policy inbound metric
                                                	**type**\: bool
                                                
                                                .. attribute:: is_rnh_present
                                                
                                                	RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ribrnh_present
                                                
                                                	RIB RNH Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_key_number
                                                
                                                	Attribute key number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_config
                                                
                                                	Attribute reuse ID Configured
                                                	**type**\: bool
                                                
                                                .. attribute:: attribute_reuse_id_max_id
                                                
                                                	Attribute reuse ID maximum ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_node
                                                
                                                	Attribute reuse ID nodes
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_current
                                                
                                                	Attribute reuse ID current ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_keys
                                                
                                                	Attribute reuse ID allocated keys
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: attribute_reuse_id_recover_sec
                                                
                                                	Attribute reuse ID timer in seconds
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: vpn_distinguisher
                                                
                                                	VPN Distinguisher
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rnh_type
                                                
                                                	RNH Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rnh_len
                                                
                                                	RNH Length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rnh_addr_len
                                                
                                                	RNH Address Length
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_table
                                                
                                                	RIB RNH Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_mac
                                                
                                                	RIB RNH MAC Address
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                .. attribute:: ribrnhip_table
                                                
                                                	RIB RNH IP Table
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_vni
                                                
                                                	RIB RNH Vni
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ribrnh_encap
                                                
                                                	RIB RNH Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, self).__init__()

                                                    self.yang_name = "attributes-after-policy-out"
                                                    self.yang_parent_name = "adv-path-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp))])
                                                    self._leafs = OrderedDict([
                                                        ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                        ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                        ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                        ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                        ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                        ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                        ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                        ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                        ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                        ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                        ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                        ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                        ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                        ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                        ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                        ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                        ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                        ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                        ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                        ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                        ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                        ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                        ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                    ])
                                                    self.is_as_path2_byte = None
                                                    self.is_application_gateway_present = None
                                                    self.is_attr_set_present = None
                                                    self.set_aigp_inbound_igp = None
                                                    self.set_aigp_inbound_metric = None
                                                    self.is_rnh_present = None
                                                    self.is_ribrnh_present = None
                                                    self.attribute_key_number = None
                                                    self.attribute_reuse_id_config = None
                                                    self.attribute_reuse_id_max_id = None
                                                    self.attribute_reuse_id_node = None
                                                    self.attribute_reuse_id_current = None
                                                    self.attribute_reuse_id_keys = None
                                                    self.attribute_reuse_id_recover_sec = None
                                                    self.vpn_distinguisher = None
                                                    self.rnh_type = None
                                                    self.rnh_len = None
                                                    self.rnh_addr_len = None
                                                    self.ribrnh_table = None
                                                    self.ribrnh_mac = None
                                                    self.ribrnhip_table = None
                                                    self.ribrnh_vni = None
                                                    self.ribrnh_encap = None

                                                    self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                    self.common_attributes.parent = self
                                                    self._children_name_map["common_attributes"] = "common-attributes"

                                                    self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                    self.attr_set.parent = self
                                                    self._children_name_map["attr_set"] = "attr-set"

                                                    self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                    self.rnh_addr.parent = self
                                                    self._children_name_map["rnh_addr"] = "rnh-addr"

                                                    self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                    self.ribrnh_ip.parent = self
                                                    self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                    self._segment_path = lambda: "attributes-after-policy-out"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                                class CommonAttributes(Entity):
                                                    """
                                                    Common attributes
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                        self.yang_name = "common-attributes"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "common-attributes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "common-attributes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class AttrSet(Entity):
                                                    """
                                                    ATTR\_SET attribute
                                                    
                                                    .. attribute:: prefix_sid_attr
                                                    
                                                    	Prefix SID attribute
                                                    	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr>`
                                                    
                                                    .. attribute:: tunnel_encap
                                                    
                                                    	Tunnel Encapsulation attribute
                                                    	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                    
                                                    .. attribute:: is_metric_present
                                                    
                                                    	Metric attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_local_pref_present
                                                    
                                                    	Local Preference attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_atomic_aggregate_present
                                                    
                                                    	Atomic aggregate attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aggregator_present
                                                    
                                                    	Aggregator attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_origin_present
                                                    
                                                    	Origin attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_as_path_present
                                                    
                                                    	AS path attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_community_present
                                                    
                                                    	Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_extended_community_present
                                                    
                                                    	Extended community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ssa_present
                                                    
                                                    	SSA attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_connector_present
                                                    
                                                    	Connector present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pmsi_present
                                                    
                                                    	PMSI Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pppmp_present
                                                    
                                                    	PPMP Attribute  present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_aigp_present
                                                    
                                                    	AIGP Present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_pe_distinguisher_label_present
                                                    
                                                    	PE distinguisher label  attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_ls_attribute_present
                                                    
                                                    	BGP LS attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_label_index_present
                                                    
                                                    	Label Index attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: neighbor_as
                                                    
                                                    	Neighbor AS number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_as
                                                    
                                                    	AS where aggregation was last performed
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: aggregator_address
                                                    
                                                    	Address where aggregation was performed
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metric
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_preference
                                                    
                                                    	Local preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: origin
                                                    
                                                    	Origin
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: as_path
                                                    
                                                    	AS path attribute
                                                    	**type**\: str
                                                    
                                                    .. attribute:: extended_community_flags
                                                    
                                                    	Extended community Flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: originator
                                                    
                                                    	Originator attribute
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: l2tpv3_session_id
                                                    
                                                    	L2TPv3 session id
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: connector_type
                                                    
                                                    	Connector Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: aigp_metric_value
                                                    
                                                    	AIGP metric value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: pmsi_type
                                                    
                                                    	PMSI Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: pmsi_flags
                                                    
                                                    	PMSI Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pmsi_label
                                                    
                                                    	PMSI label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ppm_pvalue
                                                    
                                                    	PPMP Value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_large_community_present
                                                    
                                                    	Large Community attribute present
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: community
                                                    
                                                    	Community attribute
                                                    	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                    
                                                    .. attribute:: extended_community
                                                    
                                                    	Extended community attribute
                                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                    
                                                    .. attribute:: unknown_attribute
                                                    
                                                    	Unknown attributes
                                                    	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                    
                                                    .. attribute:: cluster
                                                    
                                                    	Cluster list attribute
                                                    	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                    
                                                    .. attribute:: l2tpv3_cookie
                                                    
                                                    	L2TPv3 Cookie
                                                    	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie>`
                                                    
                                                    .. attribute:: connector_value
                                                    
                                                    	Connector Value
                                                    	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                    
                                                    .. attribute:: pmsi_value
                                                    
                                                    	PMSI Value
                                                    	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                    
                                                    .. attribute:: ls_attr
                                                    
                                                    	BGP LS attribute
                                                    	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                    
                                                    .. attribute:: pe_distinguisher_label
                                                    
                                                    	PE distinguisher label attribute
                                                    	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                    
                                                    .. attribute:: large_community
                                                    
                                                    	Large Community attribute
                                                    	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                        self.yang_name = "attr-set"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity))])
                                                        self._leafs = OrderedDict([
                                                            ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                            ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                            ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                            ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                            ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                            ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                            ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                            ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                            ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                            ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                            ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                            ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                            ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                            ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                            ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                            ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                            ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                            ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                            ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                            ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                            ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                            ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                            ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                            ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                            ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                            ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                            ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                            ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                            ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                            ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                            ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                            ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                        ])
                                                        self.is_metric_present = None
                                                        self.is_local_pref_present = None
                                                        self.is_atomic_aggregate_present = None
                                                        self.is_aggregator_present = None
                                                        self.is_origin_present = None
                                                        self.is_as_path_present = None
                                                        self.is_community_present = None
                                                        self.is_extended_community_present = None
                                                        self.is_ssa_present = None
                                                        self.is_connector_present = None
                                                        self.is_pmsi_present = None
                                                        self.is_pppmp_present = None
                                                        self.is_aigp_present = None
                                                        self.is_pe_distinguisher_label_present = None
                                                        self.is_ls_attribute_present = None
                                                        self.is_label_index_present = None
                                                        self.neighbor_as = None
                                                        self.aggregator_as = None
                                                        self.aggregator_address = None
                                                        self.metric = None
                                                        self.local_preference = None
                                                        self.origin = None
                                                        self.as_path = None
                                                        self.extended_community_flags = None
                                                        self.originator = None
                                                        self.l2tpv3_session_id = None
                                                        self.connector_type = None
                                                        self.aigp_metric_value = None
                                                        self.pmsi_type = None
                                                        self.pmsi_flags = None
                                                        self.pmsi_label = None
                                                        self.ppm_pvalue = None
                                                        self.is_large_community_present = None

                                                        self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr()
                                                        self.prefix_sid_attr.parent = self
                                                        self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                        self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                        self.tunnel_encap.parent = self
                                                        self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                        self.community = YList(self)
                                                        self.extended_community = YList(self)
                                                        self.unknown_attribute = YList(self)
                                                        self.cluster = YList(self)
                                                        self.l2tpv3_cookie = YList(self)
                                                        self.connector_value = YList(self)
                                                        self.pmsi_value = YList(self)
                                                        self.ls_attr = YList(self)
                                                        self.pe_distinguisher_label = YList(self)
                                                        self.large_community = YList(self)
                                                        self._segment_path = lambda: "attr-set"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                    class PrefixSidAttr(Entity):
                                                        """
                                                        Prefix SID attribute
                                                        
                                                        .. attribute:: prefix_sid_tlv
                                                        
                                                        	Prefix SID TLV array
                                                        	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, self).__init__()

                                                            self.yang_name = "prefix-sid-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                            self._leafs = OrderedDict()

                                                            self.prefix_sid_tlv = YList(self)
                                                            self._segment_path = lambda: "prefix-sid-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, [], name, value)


                                                        class PrefixSidTlv(Entity):
                                                            """
                                                            Prefix SID TLV array
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Prefix SID TLV type field
                                                            	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                            
                                                            .. attribute:: len
                                                            
                                                            	Prefix SID TLV Length in bytes
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            	**units**\: byte
                                                            
                                                            .. attribute:: val
                                                            
                                                            	Prefix SID TLV value string
                                                            	**type**\: str
                                                            
                                                            	**length:** 0..46
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                                self.yang_name = "prefix-sid-tlv"
                                                                self.yang_parent_name = "prefix-sid-attr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                    ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                    ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.len = None
                                                                self.val = None
                                                                self._segment_path = lambda: "prefix-sid-tlv"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                    class TunnelEncap(Entity):
                                                        """
                                                        Tunnel Encapsulation attribute
                                                        
                                                        .. attribute:: sr_policy
                                                        
                                                        	Tunnel encap type SR policy
                                                        	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                            self.yang_name = "tunnel-encap"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy))])
                                                            self._leafs = OrderedDict()

                                                            self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                            self.sr_policy.parent = self
                                                            self._children_name_map["sr_policy"] = "sr-policy"
                                                            self._segment_path = lambda: "tunnel-encap"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, [], name, value)


                                                        class SrPolicy(Entity):
                                                            """
                                                            Tunnel encap type SR policy
                                                            
                                                            .. attribute:: binding_sid
                                                            
                                                            	SR Policy incoming Binding sid
                                                            	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                            
                                                            .. attribute:: allocated_binding_sid
                                                            
                                                            	SR Policy allocated Binding sid by the router
                                                            	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                            
                                                            .. attribute:: tunnel_encap_type
                                                            
                                                            	Tunnel Encapsulation Type
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: preference
                                                            
                                                            	SR Policy Preference
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	SR Policy active state in forwarding
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: request_state
                                                            
                                                            	SR Policy programming Status
                                                            	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                            
                                                            .. attribute:: usable
                                                            
                                                            	SR Policy is usable on this node
                                                            	**type**\: bool
                                                            
                                                            .. attribute:: segment_list
                                                            
                                                            	SR Policy Segment Lists
                                                            	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                                self.yang_name = "sr-policy"
                                                                self.yang_parent_name = "tunnel-encap"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                                self._leafs = OrderedDict([
                                                                    ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                    ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                    ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                    ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                    ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                                ])
                                                                self.tunnel_encap_type = None
                                                                self.preference = None
                                                                self.state = None
                                                                self.request_state = None
                                                                self.usable = None

                                                                self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                                self.binding_sid.parent = self
                                                                self._children_name_map["binding_sid"] = "binding-sid"

                                                                self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                                self.allocated_binding_sid.parent = self
                                                                self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                                self.segment_list = YList(self)
                                                                self._segment_path = lambda: "sr-policy"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                            class BindingSid(Entity):
                                                                """
                                                                SR Policy incoming Binding sid
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                    self.yang_name = "binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class AllocatedBindingSid(Entity):
                                                                """
                                                                SR Policy allocated Binding sid by the router
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 Addr
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                    self.yang_name = "allocated-binding-sid"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "allocated-binding-sid"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                            class SegmentList(Entity):
                                                                """
                                                                SR Policy Segment Lists
                                                                
                                                                .. attribute:: weight
                                                                
                                                                	Weight of segment list
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: segment
                                                                
                                                                	Segments in segment list
                                                                	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                    self.yang_name = "segment-list"
                                                                    self.yang_parent_name = "sr-policy"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                    self._leafs = OrderedDict([
                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                    ])
                                                                    self.weight = None

                                                                    self.segment = YList(self)
                                                                    self._segment_path = lambda: "segment-list"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                                class Segment(Entity):
                                                                    """
                                                                    Segments in segment list
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	Type
                                                                    	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                    
                                                                    .. attribute:: label
                                                                    
                                                                    	MPLS Label value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: ipv4_address
                                                                    
                                                                    	IPv4 Address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    .. attribute:: ipv6_address
                                                                    
                                                                    	IPv6 address value
                                                                    	**type**\: str
                                                                    
                                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-bgp-oper'
                                                                    _revision = '2017-09-07'

                                                                    def __init__(self):
                                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                        self.yang_name = "segment"
                                                                        self.yang_parent_name = "segment-list"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.label = None
                                                                        self.ipv4_address = None
                                                                        self.ipv6_address = None
                                                                        self._segment_path = lambda: "segment"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                    class Community(Entity):
                                                        """
                                                        Community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                            self.yang_name = "community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, [u'entry'], name, value)


                                                    class ExtendedCommunity(Entity):
                                                        """
                                                        Extended community attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                            self.yang_name = "extended-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "extended-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                    class UnknownAttribute(Entity):
                                                        """
                                                        Unknown attributes
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                            self.yang_name = "unknown-attribute"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "unknown-attribute"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                    class Cluster(Entity):
                                                        """
                                                        Cluster list attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                            self.yang_name = "cluster"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "cluster"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, [u'entry'], name, value)


                                                    class L2tpv3Cookie(Entity):
                                                        """
                                                        L2TPv3 Cookie
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, self).__init__()

                                                            self.yang_name = "l2tpv3-cookie"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "l2tpv3-cookie"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                    class ConnectorValue(Entity):
                                                        """
                                                        Connector Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                            self.yang_name = "connector-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "connector-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                    class PmsiValue(Entity):
                                                        """
                                                        PMSI Value
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                            self.yang_name = "pmsi-value"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "pmsi-value"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, [u'entry'], name, value)


                                                    class LsAttr(Entity):
                                                        """
                                                        BGP LS attribute
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                            self.yang_name = "ls-attr"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "ls-attr"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, [u'entry'], name, value)


                                                    class PeDistinguisherLabel(Entity):
                                                        """
                                                        PE distinguisher label attribute
                                                        
                                                        .. attribute:: pe_address
                                                        
                                                        	 PE address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: label
                                                        
                                                        	Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                            self.yang_name = "pe-distinguisher-label"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                            ])
                                                            self.pe_address = None
                                                            self.label = None
                                                            self._segment_path = lambda: "pe-distinguisher-label"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                    class LargeCommunity(Entity):
                                                        """
                                                        Large Community attribute
                                                        
                                                        .. attribute:: global_admin
                                                        
                                                        	Global Administrator
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data1
                                                        
                                                        	Local Data 1
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: local_data2
                                                        
                                                        	Local Data 2
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                            self.yang_name = "large-community"
                                                            self.yang_parent_name = "attr-set"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                                ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                                ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                            ])
                                                            self.global_admin = None
                                                            self.local_data1 = None
                                                            self.local_data2 = None
                                                            self._segment_path = lambda: "large-community"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                                class RnhAddr(Entity):
                                                    """
                                                    RNH Address
                                                    
                                                    .. attribute:: len
                                                    
                                                    	len
                                                    	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPv6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: mac_address
                                                    
                                                    	MAC Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                        self.yang_name = "rnh-addr"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                        ])
                                                        self.len = None
                                                        self.ipv4_address = None
                                                        self.ipv6_address = None
                                                        self.mac_address = None
                                                        self._segment_path = lambda: "rnh-addr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                                class RibrnhIp(Entity):
                                                    """
                                                    RIB RNH IP Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                        self.yang_name = "ribrnh-ip"
                                                        self.yang_parent_name = "attributes-after-policy-out"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "ribrnh-ip"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "ribrnh-ip"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NeighborAfTable(Entity):
                                    """
                                    The BGP Neighbor AF table
                                    
                                    .. attribute:: neighbor
                                    
                                    	A BGP Neighbor table entry
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable, self).__init__()

                                        self.yang_name = "neighbor-af-table"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor))])
                                        self._leafs = OrderedDict()

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "neighbor-af-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        A BGP Neighbor table entry
                                        
                                        .. attribute:: neighbor_address  (key)
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: connection_local_address
                                        
                                        	Local address for the connection
                                        	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                        
                                        .. attribute:: connection_remote_address
                                        
                                        	Remote address for the connection
                                        	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                        
                                        .. attribute:: send_notification_info
                                        
                                        	Information on the last notification sent
                                        	**type**\:  :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                        
                                        .. attribute:: received_notification_info
                                        
                                        	Information on the last notification received
                                        	**type**\:  :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                        
                                        .. attribute:: message_statistics
                                        
                                        	Message statistics
                                        	**type**\:  :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                        
                                        .. attribute:: tcp_init_sync_time_spec
                                        
                                        	Time When neighbor entered TCP Init Sync
                                        	**type**\:  :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_phase_two_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Phase Two
                                        	**type**\:  :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                        
                                        .. attribute:: tcp_init_sync_done_time_spec
                                        
                                        	Time when neighbor entered TCP Init Sync Done
                                        	**type**\:  :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                        
                                        .. attribute:: graceful_maintenance
                                        
                                        	Graceful Maintenance
                                        	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                        
                                        .. attribute:: speaker_id
                                        
                                        	Speaker this neighbor is allocated to
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: description
                                        
                                        	Description
                                        	**type**\: str
                                        
                                        .. attribute:: local_as
                                        
                                        	Local AS number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as
                                        
                                        	Remote AS number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_internal_link
                                        
                                        	Internal link to neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: is_external_neighbor_not_directly_connected
                                        
                                        	External neighbor not directly connected
                                        	**type**\: bool
                                        
                                        .. attribute:: messages_received
                                        
                                        	Number of messages received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_sent
                                        
                                        	Number of messages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_messages_in
                                        
                                        	No. of update msgs received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_messages_out
                                        
                                        	No. of update messages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_queued_in
                                        
                                        	No. of msgs on receive queue
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: messages_queued_out
                                        
                                        	No. of messages on send queue
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_established_time
                                        
                                        	Time (in secs) that the connection has been established
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_state
                                        
                                        	State of connection
                                        	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                        
                                        .. attribute:: previous_connection_state
                                        
                                        	Previous state of connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_admin_status
                                        
                                        	Administrative status of connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: open_check_error_code
                                        
                                        	Open check error code
                                        	**type**\:  :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                        
                                        .. attribute:: is_local_address_configured
                                        
                                        	Local address configured for the neighbor connection
                                        	**type**\: bool
                                        
                                        .. attribute:: connection_local_port
                                        
                                        	Local port for the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_remote_port
                                        
                                        	Remote port for the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_interface_handle
                                        
                                        	Interface Handle of Neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_notification_sent
                                        
                                        	Notification was sent during last reset
                                        	**type**\: bool
                                        
                                        .. attribute:: is_administratively_shut_down
                                        
                                        	Neighbor is administratively shut down
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_max_prefix_shutdown
                                        
                                        	Neighbor shut down because it exceeded max prfx count
                                        	**type**\: bool
                                        
                                        .. attribute:: is_out_of_memory_shutdown
                                        
                                        	Neighbor shut down during a SEVERE low memory condition
                                        	**type**\: bool
                                        
                                        .. attribute:: is_out_of_memory_forced_up
                                        
                                        	Neighbor forced up during a low memory condition
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ebgp_peer_as_league
                                        
                                        	EBGP peer belongs to AS League
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ebgp_peer_common_admin
                                        
                                        	EBGP peer with common administation
                                        	**type**\: bool
                                        
                                        .. attribute:: ttl_security_enabled
                                        
                                        	TTL Security enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: suppress4_byte_as
                                        
                                        	Suppress 4byteas capability
                                        	**type**\: bool
                                        
                                        .. attribute:: bfd_session_state
                                        
                                        	BFD state for this peer
                                        	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                        
                                        .. attribute:: bfd_session_created_state
                                        
                                        	BFD state for this peer
                                        	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                        
                                        .. attribute:: bfd_session_enable_mode
                                        
                                        	BFD enable mode for this peer
                                        	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                        
                                        .. attribute:: bfd_minintervalval
                                        
                                        	BFD Mininterval for this peer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_multiplierval
                                        
                                        	BFD Multiplier for this peer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_state_ts
                                        
                                        	Timestamp since when nbr is in this bfd state
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: router_id
                                        
                                        	Router ID for the neighbor
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: negotiated_protocol_version
                                        
                                        	Negotiated protocol version
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ebgp_time_to_live
                                        
                                        	Maximum number of hops for external BGP neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                        
                                        	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: tcpmss
                                        
                                        	Neighbor TCP Maximum Segment                     size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_log_in
                                        
                                        	Message in log count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: msg_log_out
                                        
                                        	Message out log count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_local_as
                                        
                                        	Local AS configured on the neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_as_no_prepend
                                        
                                        	Option to not prepend the Local AS to announcements
                                        	**type**\: bool
                                        
                                        .. attribute:: is_capability_negotiation_suppressed
                                        
                                        	Capability negotiation suppressed
                                        	**type**\: bool
                                        
                                        .. attribute:: is_capability_negotiation_performed
                                        
                                        	Capability negotiation performed
                                        	**type**\: bool
                                        
                                        .. attribute:: is_route_refresh_capability_received
                                        
                                        	Route refresh capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_route_refresh_old_capability_received
                                        
                                        	Route refresh old capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_gr_aware
                                        
                                        	GR awareness received
                                        	**type**\: bool
                                        
                                        .. attribute:: is4_byte_as_capability_received
                                        
                                        	4\-byte AScapability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is4_byte_as_capability_sent
                                        
                                        	4\-byte AScapability Snt
                                        	**type**\: bool
                                        
                                        .. attribute:: multi_protocol_capability_received
                                        
                                        	Multi\-protocol capability has been received
                                        	**type**\: bool
                                        
                                        .. attribute:: hold_time
                                        
                                        	Hold time (in secs) negotiated for this connection
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: keep_alive_time
                                        
                                        	Keepalive time (in secs) negotiated for this connection
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_hold_time
                                        
                                        	Hold time (in secs) configured for this connection
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_keepalive
                                        
                                        	Keepalive time (in secs) configured for this connection
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: configured_min_acc_hold_time
                                        
                                        	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: min_advertise_interval
                                        
                                        	Minimum advertisement interval, secs part
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: min_advertise_interval_msecs
                                        
                                        	Minimum advertisement interval, msecs part
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: min_origination_interval
                                        
                                        	Minimum origination interval (in secs)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connect_retry_interval
                                        
                                        	Time (in secs) for connect retry timer
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_update
                                        
                                        	Time (in secs) since last update message was received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read
                                        
                                        	Time (in secs) since last read
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_since_last_read_reset
                                        
                                        	Time (in secs) since last read before last reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_last_cb
                                        
                                        	CB
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: time_last_cb_reset
                                        
                                        	Last CB before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_fb
                                        
                                        	FB
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: count_last_write
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_last_write
                                        
                                        	Time (in secs) since last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: attempted_last_write_bytes
                                        
                                        	Attempted size of last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_last_write_bytes
                                        
                                        	Actual size of last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_second_last_write
                                        
                                        	Time (in secs) since second  last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: attempted_second_last_write_bytes
                                        
                                        	Attempted size of second last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_bytes
                                        
                                        	Actual size of second last write
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: attempted_last_write_reset_bytes
                                        
                                        	Attempted size of last write before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_last_write_reset_bytes
                                        
                                        	Actual size of last write before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_second_last_write_reset
                                        
                                        	Time (in secs) since last write before last reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: attempted_second_last_write_reset_bytes
                                        
                                        	Attempted size of second last write before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: actual_second_last_write_reset_bytes
                                        
                                        	Actual size of second last write before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_write_event
                                        
                                        	Time (in secs) since last write thread event
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_write_event
                                        
                                        	Time (in secs) since second last write thread event
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_aexpiry_reset
                                        
                                        	Time (in secs) since last KA timer expiry before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_k_aexpiry_reset
                                        
                                        	Time (in secs) since second last KA timer expiry before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_anotsent_reset
                                        
                                        	Duration (in secs) since last time that KA was not sent before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_aerror_reset
                                        
                                        	Duration (in secs) since last time that an error was encountered after KA expiry
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_k_astart_reset
                                        
                                        	Time (in secs) since the last KA timer start before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: second_last_k_astart_reset
                                        
                                        	Time (in secs) since the second last KA timer start before reset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of times the connection was established
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of times connection was dropped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_connection_last_dropped
                                        
                                        	Time since the connection last went down (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: reset_reason
                                        
                                        	Reason for last connection reset
                                        	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                        
                                        .. attribute:: peer_reset_reason
                                        
                                        	Reason for last peer close event
                                        	**type**\:  :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                        
                                        .. attribute:: peer_error_code
                                        
                                        	If peer closed, error received from transport
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_notify_error_code
                                        
                                        	Code for the last error notification seen on the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notify_error_subcode
                                        
                                        	Error subcode of the last error notification seen on the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: error_notifies_received
                                        
                                        	Number of error notifications received on the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: error_notifies_sent
                                        
                                        	Number of error notifications sent on the connection
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_as_number
                                        
                                        	Remote AS number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dmz_link_bandwidth
                                        
                                        	Bandwidth of link to single\-hop eBGP peer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ebgp_recv_dmz
                                        
                                        	Receive Bandwidth of link to single\-hop eBGP peer
                                        	**type**\: bool
                                        
                                        .. attribute:: ebgp_send_dmz_mode
                                        
                                        	Ebgp send dmz link bw mode
                                        	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                        
                                        .. attribute:: tos_type
                                        
                                        	Precedence or DSCP type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_value
                                        
                                        	Precedence or DSCP value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tcp_session_open_mode
                                        
                                        	The TCP mode to be used to set up BGP session with the neighbor
                                        	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: standby_rp
                                        
                                        	Standby RP socket inited for Active Open
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_enabled
                                        
                                        	Neighbor supports NSR
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_restart_enabled_nbr
                                        
                                        	Neighbor supports graceful\-restart
                                        	**type**\: bool
                                        
                                        .. attribute:: gr_restart_time
                                        
                                        	Neighbor restart time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: gr_stale_path_time
                                        
                                        	Neighbor stale\-path time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: fssn_offset
                                        
                                        	First standby SeqNo offset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fpbsn_offset
                                        
                                        	First standby PDU boundary SeqNo offset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_ackd_seq_no
                                        
                                        	SeqNo of the last Ackd byte
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bytes_written
                                        
                                        	Total bytes written by write thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bytes_read
                                        
                                        	Total bytes read
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: socket_read_bytes
                                        
                                        	Total read bytes value insocket\-lib
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: is_read_disabled
                                        
                                        	If true, socket read isdisabled
                                        	**type**\: bool
                                        
                                        .. attribute:: update_bytes_read
                                        
                                        	Total update bytes read
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: nsr_state
                                        
                                        	NSR state
                                        	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                        
                                        .. attribute:: is_passive_close
                                        
                                        	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: nbr_enforce_first_as
                                        
                                        	Neighbor enforce first AS
                                        	**type**\: bool
                                        
                                        .. attribute:: active_bmp_servers
                                        
                                        	BMP Servers to which the neighbor sends logs
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nbr_cluster_id
                                        
                                        	Cluster id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nbr_in_cluster
                                        
                                        	Type of cluster\_id\:undefined/number/Ip address
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ignore_connected
                                        
                                        	If true, the VPN client isan IBGP CE peer
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_vpn_client
                                        
                                        	If true, don't do NHconnected check for nbr
                                        	**type**\: bool
                                        
                                        .. attribute:: io_armed
                                        
                                        	If true, socket has beenauto\-armed for io control
                                        	**type**\: bool
                                        
                                        .. attribute:: read_armed
                                        
                                        	If true, socket has beenauto\-armed for read
                                        	**type**\: bool
                                        
                                        .. attribute:: write_armed
                                        
                                        	If true, socket has beenauto\-armed for write
                                        	**type**\: bool
                                        
                                        .. attribute:: discard_data_bytes
                                        
                                        	Remaining discard data (bytes) on Standby
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: local_as_replace_as
                                        
                                        	Local AS Replace\-AS option
                                        	**type**\: bool
                                        
                                        .. attribute:: local_as_dual_as
                                        
                                        	Local AS Dual\-AS option
                                        	**type**\: bool
                                        
                                        .. attribute:: local_as_dual_as_mode_native
                                        
                                        	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                        	**type**\: bool
                                        
                                        .. attribute:: egress_peer_engineering_enabled
                                        
                                        	Indicates if Egress Peer Engineering is enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: discard_as4_path
                                        
                                        	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\: bool
                                        
                                        .. attribute:: dynamic_neighbor
                                        
                                        	Dynamic neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: af_data
                                        
                                        	Address family specific neighbor data
                                        	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbor-af-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['neighbor_address']
                                            self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress)), ("send-notification-info", ("send_notification_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo)), ("received-notification-info", ("received_notification_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics)), ("message-statistics", ("message_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics)), ("tcp-init-sync-time-spec", ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec)), ("tcp-init-sync-phase-two-time-spec", ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec)), ("tcp-init-sync-done-time-spec", ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData))])
                                            self._leafs = OrderedDict([
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                                ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                                ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                                ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                                ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                                ('is_external_neighbor_not_directly_connected', (YLeaf(YType.boolean, 'is-external-neighbor-not-directly-connected'), ['bool'])),
                                                ('messages_received', (YLeaf(YType.uint32, 'messages-received'), ['int'])),
                                                ('messages_sent', (YLeaf(YType.uint32, 'messages-sent'), ['int'])),
                                                ('update_messages_in', (YLeaf(YType.uint32, 'update-messages-in'), ['int'])),
                                                ('update_messages_out', (YLeaf(YType.uint32, 'update-messages-out'), ['int'])),
                                                ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                                ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                                ('connection_established_time', (YLeaf(YType.uint32, 'connection-established-time'), ['int'])),
                                                ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                                ('previous_connection_state', (YLeaf(YType.uint32, 'previous-connection-state'), ['int'])),
                                                ('connection_admin_status', (YLeaf(YType.uint32, 'connection-admin-status'), ['int'])),
                                                ('open_check_error_code', (YLeaf(YType.enumeration, 'open-check-error-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpOpenCheckErr', '')])),
                                                ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                                ('connection_local_port', (YLeaf(YType.uint32, 'connection-local-port'), ['int'])),
                                                ('connection_remote_port', (YLeaf(YType.uint32, 'connection-remote-port'), ['int'])),
                                                ('neighbor_interface_handle', (YLeaf(YType.uint32, 'neighbor-interface-handle'), ['int'])),
                                                ('reset_notification_sent', (YLeaf(YType.boolean, 'reset-notification-sent'), ['bool'])),
                                                ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                                ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                                ('is_out_of_memory_shutdown', (YLeaf(YType.boolean, 'is-out-of-memory-shutdown'), ['bool'])),
                                                ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                                ('is_ebgp_peer_as_league', (YLeaf(YType.boolean, 'is-ebgp-peer-as-league'), ['bool'])),
                                                ('is_ebgp_peer_common_admin', (YLeaf(YType.boolean, 'is-ebgp-peer-common-admin'), ['bool'])),
                                                ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                                ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                                ('bfd_session_state', (YLeaf(YType.enumeration, 'bfd-session-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                                ('bfd_session_created_state', (YLeaf(YType.enumeration, 'bfd-session-created-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                                ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                                ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                                ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                                ('bfd_state_ts', (YLeaf(YType.uint64, 'bfd-state-ts'), ['int'])),
                                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                ('negotiated_protocol_version', (YLeaf(YType.uint16, 'negotiated-protocol-version'), ['int'])),
                                                ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                                ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                                ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                                ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                                ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                                ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                                ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                                ('is_capability_negotiation_suppressed', (YLeaf(YType.boolean, 'is-capability-negotiation-suppressed'), ['bool'])),
                                                ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                                ('is_route_refresh_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-capability-received'), ['bool'])),
                                                ('is_route_refresh_old_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-old-capability-received'), ['bool'])),
                                                ('is_gr_aware', (YLeaf(YType.boolean, 'is-gr-aware'), ['bool'])),
                                                ('is4_byte_as_capability_received', (YLeaf(YType.boolean, 'is4-byte-as-capability-received'), ['bool'])),
                                                ('is4_byte_as_capability_sent', (YLeaf(YType.boolean, 'is4-byte-as-capability-sent'), ['bool'])),
                                                ('multi_protocol_capability_received', (YLeaf(YType.boolean, 'multi-protocol-capability-received'), ['bool'])),
                                                ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                                ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                                ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                                ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                                ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                                ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                                ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                                ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                                ('connect_retry_interval', (YLeaf(YType.uint16, 'connect-retry-interval'), ['int'])),
                                                ('time_since_last_update', (YLeaf(YType.uint32, 'time-since-last-update'), ['int'])),
                                                ('time_since_last_read', (YLeaf(YType.uint32, 'time-since-last-read'), ['int'])),
                                                ('time_since_last_read_reset', (YLeaf(YType.uint32, 'time-since-last-read-reset'), ['int'])),
                                                ('time_last_cb', (YLeaf(YType.uint64, 'time-last-cb'), ['int'])),
                                                ('time_last_cb_reset', (YLeaf(YType.uint32, 'time-last-cb-reset'), ['int'])),
                                                ('time_last_fb', (YLeaf(YType.uint64, 'time-last-fb'), ['int'])),
                                                ('count_last_write', (YLeaf(YType.uint32, 'count-last-write'), ['int'])),
                                                ('time_since_last_write', (YLeaf(YType.uint32, 'time-since-last-write'), ['int'])),
                                                ('attempted_last_write_bytes', (YLeaf(YType.uint32, 'attempted-last-write-bytes'), ['int'])),
                                                ('actual_last_write_bytes', (YLeaf(YType.uint32, 'actual-last-write-bytes'), ['int'])),
                                                ('time_since_second_last_write', (YLeaf(YType.uint32, 'time-since-second-last-write'), ['int'])),
                                                ('attempted_second_last_write_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-bytes'), ['int'])),
                                                ('actual_second_last_write_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-bytes'), ['int'])),
                                                ('time_since_last_write_reset', (YLeaf(YType.uint32, 'time-since-last-write-reset'), ['int'])),
                                                ('attempted_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-last-write-reset-bytes'), ['int'])),
                                                ('actual_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-last-write-reset-bytes'), ['int'])),
                                                ('time_since_second_last_write_reset', (YLeaf(YType.uint32, 'time-since-second-last-write-reset'), ['int'])),
                                                ('attempted_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-reset-bytes'), ['int'])),
                                                ('actual_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-reset-bytes'), ['int'])),
                                                ('last_write_event', (YLeaf(YType.uint32, 'last-write-event'), ['int'])),
                                                ('second_last_write_event', (YLeaf(YType.uint32, 'second-last-write-event'), ['int'])),
                                                ('last_k_aexpiry_reset', (YLeaf(YType.uint32, 'last-k-aexpiry-reset'), ['int'])),
                                                ('second_last_k_aexpiry_reset', (YLeaf(YType.uint32, 'second-last-k-aexpiry-reset'), ['int'])),
                                                ('last_k_anotsent_reset', (YLeaf(YType.uint32, 'last-k-anotsent-reset'), ['int'])),
                                                ('last_k_aerror_reset', (YLeaf(YType.uint32, 'last-k-aerror-reset'), ['int'])),
                                                ('last_k_astart_reset', (YLeaf(YType.uint32, 'last-k-astart-reset'), ['int'])),
                                                ('second_last_k_astart_reset', (YLeaf(YType.uint32, 'second-last-k-astart-reset'), ['int'])),
                                                ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                                ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                                ('time_since_connection_last_dropped', (YLeaf(YType.uint32, 'time-since-connection-last-dropped'), ['int'])),
                                                ('reset_reason', (YLeaf(YType.enumeration, 'reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                                ('peer_reset_reason', (YLeaf(YType.enumeration, 'peer-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPeerResetReasonIndex', '')])),
                                                ('peer_error_code', (YLeaf(YType.uint32, 'peer-error-code'), ['int'])),
                                                ('last_notify_error_code', (YLeaf(YType.uint8, 'last-notify-error-code'), ['int'])),
                                                ('last_notify_error_subcode', (YLeaf(YType.uint8, 'last-notify-error-subcode'), ['int'])),
                                                ('error_notifies_received', (YLeaf(YType.uint32, 'error-notifies-received'), ['int'])),
                                                ('error_notifies_sent', (YLeaf(YType.uint32, 'error-notifies-sent'), ['int'])),
                                                ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                                ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                                ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                                ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                                ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                                ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                                ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                                ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                                ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                                ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                                ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                                ('fssn_offset', (YLeaf(YType.uint32, 'fssn-offset'), ['int'])),
                                                ('fpbsn_offset', (YLeaf(YType.uint32, 'fpbsn-offset'), ['int'])),
                                                ('last_ackd_seq_no', (YLeaf(YType.uint32, 'last-ackd-seq-no'), ['int'])),
                                                ('bytes_written', (YLeaf(YType.uint32, 'bytes-written'), ['int'])),
                                                ('bytes_read', (YLeaf(YType.uint32, 'bytes-read'), ['int'])),
                                                ('socket_read_bytes', (YLeaf(YType.uint32, 'socket-read-bytes'), ['int'])),
                                                ('is_read_disabled', (YLeaf(YType.boolean, 'is-read-disabled'), ['bool'])),
                                                ('update_bytes_read', (YLeaf(YType.uint32, 'update-bytes-read'), ['int'])),
                                                ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                                ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                                ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                                ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                                ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                                ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                                ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                                ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                                ('io_armed', (YLeaf(YType.boolean, 'io-armed'), ['bool'])),
                                                ('read_armed', (YLeaf(YType.boolean, 'read-armed'), ['bool'])),
                                                ('write_armed', (YLeaf(YType.boolean, 'write-armed'), ['bool'])),
                                                ('discard_data_bytes', (YLeaf(YType.uint32, 'discard-data-bytes'), ['int'])),
                                                ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                                ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                                ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                                ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                                ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                                ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                                ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                                ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                                ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                                ('dynamic_neighbor', (YLeaf(YType.boolean, 'dynamic-neighbor'), ['bool'])),
                                            ])
                                            self.neighbor_address = None
                                            self.speaker_id = None
                                            self.description = None
                                            self.local_as = None
                                            self.remote_as = None
                                            self.has_internal_link = None
                                            self.is_external_neighbor_not_directly_connected = None
                                            self.messages_received = None
                                            self.messages_sent = None
                                            self.update_messages_in = None
                                            self.update_messages_out = None
                                            self.messages_queued_in = None
                                            self.messages_queued_out = None
                                            self.connection_established_time = None
                                            self.connection_state = None
                                            self.previous_connection_state = None
                                            self.connection_admin_status = None
                                            self.open_check_error_code = None
                                            self.is_local_address_configured = None
                                            self.connection_local_port = None
                                            self.connection_remote_port = None
                                            self.neighbor_interface_handle = None
                                            self.reset_notification_sent = None
                                            self.is_administratively_shut_down = None
                                            self.is_neighbor_max_prefix_shutdown = None
                                            self.is_out_of_memory_shutdown = None
                                            self.is_out_of_memory_forced_up = None
                                            self.is_ebgp_peer_as_league = None
                                            self.is_ebgp_peer_common_admin = None
                                            self.ttl_security_enabled = None
                                            self.suppress4_byte_as = None
                                            self.bfd_session_state = None
                                            self.bfd_session_created_state = None
                                            self.bfd_session_enable_mode = None
                                            self.bfd_minintervalval = None
                                            self.bfd_multiplierval = None
                                            self.bfd_state_ts = None
                                            self.router_id = None
                                            self.negotiated_protocol_version = None
                                            self.ebgp_time_to_live = None
                                            self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                            self.tcpmss = None
                                            self.msg_log_in = None
                                            self.msg_log_out = None
                                            self.neighbor_local_as = None
                                            self.local_as_no_prepend = None
                                            self.is_capability_negotiation_suppressed = None
                                            self.is_capability_negotiation_performed = None
                                            self.is_route_refresh_capability_received = None
                                            self.is_route_refresh_old_capability_received = None
                                            self.is_gr_aware = None
                                            self.is4_byte_as_capability_received = None
                                            self.is4_byte_as_capability_sent = None
                                            self.multi_protocol_capability_received = None
                                            self.hold_time = None
                                            self.keep_alive_time = None
                                            self.configured_hold_time = None
                                            self.configured_keepalive = None
                                            self.configured_min_acc_hold_time = None
                                            self.min_advertise_interval = None
                                            self.min_advertise_interval_msecs = None
                                            self.min_origination_interval = None
                                            self.connect_retry_interval = None
                                            self.time_since_last_update = None
                                            self.time_since_last_read = None
                                            self.time_since_last_read_reset = None
                                            self.time_last_cb = None
                                            self.time_last_cb_reset = None
                                            self.time_last_fb = None
                                            self.count_last_write = None
                                            self.time_since_last_write = None
                                            self.attempted_last_write_bytes = None
                                            self.actual_last_write_bytes = None
                                            self.time_since_second_last_write = None
                                            self.attempted_second_last_write_bytes = None
                                            self.actual_second_last_write_bytes = None
                                            self.time_since_last_write_reset = None
                                            self.attempted_last_write_reset_bytes = None
                                            self.actual_last_write_reset_bytes = None
                                            self.time_since_second_last_write_reset = None
                                            self.attempted_second_last_write_reset_bytes = None
                                            self.actual_second_last_write_reset_bytes = None
                                            self.last_write_event = None
                                            self.second_last_write_event = None
                                            self.last_k_aexpiry_reset = None
                                            self.second_last_k_aexpiry_reset = None
                                            self.last_k_anotsent_reset = None
                                            self.last_k_aerror_reset = None
                                            self.last_k_astart_reset = None
                                            self.second_last_k_astart_reset = None
                                            self.connection_up_count = None
                                            self.connection_down_count = None
                                            self.time_since_connection_last_dropped = None
                                            self.reset_reason = None
                                            self.peer_reset_reason = None
                                            self.peer_error_code = None
                                            self.last_notify_error_code = None
                                            self.last_notify_error_subcode = None
                                            self.error_notifies_received = None
                                            self.error_notifies_sent = None
                                            self.remote_as_number = None
                                            self.dmz_link_bandwidth = None
                                            self.ebgp_recv_dmz = None
                                            self.ebgp_send_dmz_mode = None
                                            self.tos_type = None
                                            self.tos_value = None
                                            self.tcp_session_open_mode = None
                                            self.vrf_name = None
                                            self.standby_rp = None
                                            self.nsr_enabled = None
                                            self.graceful_restart_enabled_nbr = None
                                            self.gr_restart_time = None
                                            self.gr_stale_path_time = None
                                            self.fssn_offset = None
                                            self.fpbsn_offset = None
                                            self.last_ackd_seq_no = None
                                            self.bytes_written = None
                                            self.bytes_read = None
                                            self.socket_read_bytes = None
                                            self.is_read_disabled = None
                                            self.update_bytes_read = None
                                            self.nsr_state = None
                                            self.is_passive_close = None
                                            self.nbr_enforce_first_as = None
                                            self.active_bmp_servers = None
                                            self.nbr_cluster_id = None
                                            self.nbr_in_cluster = None
                                            self.ignore_connected = None
                                            self.internal_vpn_client = None
                                            self.io_armed = None
                                            self.read_armed = None
                                            self.write_armed = None
                                            self.discard_data_bytes = None
                                            self.local_as_replace_as = None
                                            self.local_as_dual_as = None
                                            self.local_as_dual_as_mode_native = None
                                            self.egress_peer_engineering_enabled = None
                                            self.discard_as4_path = None
                                            self.rpki_disable = None
                                            self.rpki_use_validity = None
                                            self.rpki_allow_invalid = None
                                            self.rpki_signal_ibgp = None
                                            self.dynamic_neighbor = None

                                            self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                            self.connection_local_address.parent = self
                                            self._children_name_map["connection_local_address"] = "connection-local-address"

                                            self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                            self.connection_remote_address.parent = self
                                            self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                            self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                            self.send_notification_info.parent = self
                                            self._children_name_map["send_notification_info"] = "send-notification-info"

                                            self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                            self.received_notification_info.parent = self
                                            self._children_name_map["received_notification_info"] = "received-notification-info"

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"

                                            self.message_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                            self.message_statistics.parent = self
                                            self._children_name_map["message_statistics"] = "message-statistics"

                                            self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                            self.tcp_init_sync_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"

                                            self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                            self.tcp_init_sync_phase_two_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"

                                            self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                            self.tcp_init_sync_done_time_spec.parent = self
                                            self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"

                                            self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                            self.graceful_maintenance.parent = self
                                            self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                            self.af_data = YList(self)
                                            self._segment_path = lambda: "neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_external_neighbor_not_directly_connected', u'messages_received', u'messages_sent', u'update_messages_in', u'update_messages_out', u'messages_queued_in', u'messages_queued_out', u'connection_established_time', u'connection_state', u'previous_connection_state', u'connection_admin_status', u'open_check_error_code', u'is_local_address_configured', u'connection_local_port', u'connection_remote_port', u'neighbor_interface_handle', u'reset_notification_sent', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_shutdown', u'is_out_of_memory_forced_up', u'is_ebgp_peer_as_league', u'is_ebgp_peer_common_admin', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_state', u'bfd_session_created_state', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'bfd_state_ts', u'router_id', u'negotiated_protocol_version', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_suppressed', u'is_capability_negotiation_performed', u'is_route_refresh_capability_received', u'is_route_refresh_old_capability_received', u'is_gr_aware', u'is4_byte_as_capability_received', u'is4_byte_as_capability_sent', u'multi_protocol_capability_received', u'hold_time', u'keep_alive_time', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'connect_retry_interval', u'time_since_last_update', u'time_since_last_read', u'time_since_last_read_reset', u'time_last_cb', u'time_last_cb_reset', u'time_last_fb', u'count_last_write', u'time_since_last_write', u'attempted_last_write_bytes', u'actual_last_write_bytes', u'time_since_second_last_write', u'attempted_second_last_write_bytes', u'actual_second_last_write_bytes', u'time_since_last_write_reset', u'attempted_last_write_reset_bytes', u'actual_last_write_reset_bytes', u'time_since_second_last_write_reset', u'attempted_second_last_write_reset_bytes', u'actual_second_last_write_reset_bytes', u'last_write_event', u'second_last_write_event', u'last_k_aexpiry_reset', u'second_last_k_aexpiry_reset', u'last_k_anotsent_reset', u'last_k_aerror_reset', u'last_k_astart_reset', u'second_last_k_astart_reset', u'connection_up_count', u'connection_down_count', u'time_since_connection_last_dropped', u'reset_reason', u'peer_reset_reason', u'peer_error_code', u'last_notify_error_code', u'last_notify_error_subcode', u'error_notifies_received', u'error_notifies_sent', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'fssn_offset', u'fpbsn_offset', u'last_ackd_seq_no', u'bytes_written', u'bytes_read', u'socket_read_bytes', u'is_read_disabled', u'update_bytes_read', u'nsr_state', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'io_armed', u'read_armed', u'write_armed', u'discard_data_bytes', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'dynamic_neighbor'], name, value)


                                        class ConnectionLocalAddress(Entity):
                                            """
                                            Local address for the connection
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, self).__init__()

                                                self.yang_name = "connection-local-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "connection-local-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "connection-local-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class ConnectionRemoteAddress(Entity):
                                            """
                                            Remote address for the connection
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, self).__init__()

                                                self.yang_name = "connection-remote-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "connection-remote-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "connection-remote-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class SendNotificationInfo(Entity):
                                            """
                                            Information on the last notification sent
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, self).__init__()

                                                self.yang_name = "send-notification-info"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData))])
                                                self._leafs = OrderedDict([
                                                    ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                                    ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                                    ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                                ])
                                                self.time_since_last_notification = None
                                                self.notification_error_code = None
                                                self.notification_error_subcode = None

                                                self.last_notification_data = YList(self)
                                                self._segment_path = lambda: "send-notification-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                            class LastNotificationData(Entity):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                                    self.yang_name = "last-notification-data"
                                                    self.yang_parent_name = "send-notification-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "last-notification-data"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                        class ReceivedNotificationInfo(Entity):
                                            """
                                            Information on the last notification received
                                            
                                            .. attribute:: time_since_last_notification
                                            
                                            	Time since the last notification was sent or received (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: notification_error_code
                                            
                                            	Error code in last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: notification_error_subcode
                                            
                                            	Error subcode in last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: last_notification_data
                                            
                                            	Message data in last notification
                                            	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, self).__init__()

                                                self.yang_name = "received-notification-info"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData))])
                                                self._leafs = OrderedDict([
                                                    ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                                    ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                                    ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                                ])
                                                self.time_since_last_notification = None
                                                self.notification_error_code = None
                                                self.notification_error_subcode = None

                                                self.last_notification_data = YList(self)
                                                self._segment_path = lambda: "received-notification-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                            class LastNotificationData(Entity):
                                                """
                                                Message data in last notification
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                                    self.yang_name = "last-notification-data"
                                                    self.yang_parent_name = "received-notification-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "last-notification-data"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: read_throttles
                                            
                                            	Number of partial read throttles
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: low_throttled_read
                                            
                                            	Num socket reads after nbrs crossed low threshold
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: high_throttled_read
                                            
                                            	Num of socket reads after nbr crossed high threshold
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: time_since_last_throttled_read
                                            
                                            	Time (in secs) since last read after being throttled
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: read_calls_count
                                            
                                            	No. of calls to function to read inbound data
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: read_messages_count
                                            
                                            	Number of BGP messages read
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: data_bytes_read
                                            
                                            	No. of bytes of data read
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: io_read_time
                                            
                                            	Time spent reading inbound data (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: write_calls_count
                                            
                                            	No. of calls to function to write outbound data
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: data_bytes_written
                                            
                                            	No. of data bytes written
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: io_write_time
                                            
                                            	Time spent writing outbound data (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: last_sent_seq_no
                                            
                                            	Seq No of the last sent byte
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_subgroup_calls_count
                                            
                                            	No. of calls to function to process sub\-group message list
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_subgroup_messages_count
                                            
                                            	Number of sub\-group msgs processed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: subgroup_list_time
                                            
                                            	Time spent processing sub\-group message list  (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: write_queue_calls_count
                                            
                                            	No. of calls to function to process write queue
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_messages_count
                                            
                                            	Number of write queue messages processed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: write_queue_time
                                            
                                            	Time spent processing write queue (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: inbound_update_messages
                                            
                                            	Number of inbound update messages processed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: inbound_update_messages_time
                                            
                                            	Time spent processing inbound update messages (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: maximum_read_size
                                            
                                            	Size of largest socket (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: actives
                                            
                                            	Number of retried Active opens for this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: failed_post_actives
                                            
                                            	Number of Active Opens that failed in the Post Active State for this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passives
                                            
                                            	Number of retried Passive opens for this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rejected_passives
                                            
                                            	Number of rejected Passive opens for this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: active_collision
                                            
                                            	Number of Closed Active connections for this neighbor due to collision 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: passive_collision
                                            
                                            	Number of Closed Remote opens for this neighborneighbor due to collision 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_read_thread_trigger
                                            
                                            	Number of times io\-control thread trigger read thread
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: control_to_write_thread_trigger
                                            
                                            	Number of times io\-control thread trigger write thread
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: network_status
                                            
                                            	Socket status, TRUE if socket closed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reset_flags
                                            
                                            	Reset flags, per thread
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nbr_flags
                                            
                                            	Nbr flags, per thread
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nbr_fd
                                            
                                            	Primary FD, per nbr
                                            	**type**\: int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: reset_retries
                                            
                                            	Reset Retries, per nbr
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sync_flags
                                            
                                            	Sync flags, per nbr
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nsr_oper_down_count
                                            
                                            	Number of times NSR scoped sync has been done
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_nsr_scoped_sync
                                            
                                            	Last time NSR scoped syncwas done for the neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('read_throttles', (YLeaf(YType.uint32, 'read-throttles'), ['int'])),
                                                    ('low_throttled_read', (YLeaf(YType.uint32, 'low-throttled-read'), ['int'])),
                                                    ('high_throttled_read', (YLeaf(YType.uint32, 'high-throttled-read'), ['int'])),
                                                    ('time_since_last_throttled_read', (YLeaf(YType.uint32, 'time-since-last-throttled-read'), ['int'])),
                                                    ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                                    ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                                    ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                                    ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                                    ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                                    ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                                    ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                                    ('last_sent_seq_no', (YLeaf(YType.uint32, 'last-sent-seq-no'), ['int'])),
                                                    ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                                    ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                                    ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                                    ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                                    ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                                    ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                                    ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                                    ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                                    ('maximum_read_size', (YLeaf(YType.uint32, 'maximum-read-size'), ['int'])),
                                                    ('actives', (YLeaf(YType.uint32, 'actives'), ['int'])),
                                                    ('failed_post_actives', (YLeaf(YType.uint32, 'failed-post-actives'), ['int'])),
                                                    ('passives', (YLeaf(YType.uint32, 'passives'), ['int'])),
                                                    ('rejected_passives', (YLeaf(YType.uint32, 'rejected-passives'), ['int'])),
                                                    ('active_collision', (YLeaf(YType.uint32, 'active-collision'), ['int'])),
                                                    ('passive_collision', (YLeaf(YType.uint32, 'passive-collision'), ['int'])),
                                                    ('control_to_read_thread_trigger', (YLeaf(YType.uint32, 'control-to-read-thread-trigger'), ['int'])),
                                                    ('control_to_write_thread_trigger', (YLeaf(YType.uint32, 'control-to-write-thread-trigger'), ['int'])),
                                                    ('network_status', (YLeaf(YType.uint32, 'network-status'), ['int'])),
                                                    ('reset_flags', (YLeaf(YType.uint32, 'reset-flags'), ['int'])),
                                                    ('nbr_flags', (YLeaf(YType.uint32, 'nbr-flags'), ['int'])),
                                                    ('nbr_fd', (YLeaf(YType.int32, 'nbr-fd'), ['int'])),
                                                    ('reset_retries', (YLeaf(YType.uint8, 'reset-retries'), ['int'])),
                                                    ('sync_flags', (YLeaf(YType.uint32, 'sync-flags'), ['int'])),
                                                    ('nsr_oper_down_count', (YLeaf(YType.uint32, 'nsr-oper-down-count'), ['int'])),
                                                    ('last_nsr_scoped_sync', (YLeaf(YType.uint32, 'last-nsr-scoped-sync'), ['int'])),
                                                ])
                                                self.read_throttles = None
                                                self.low_throttled_read = None
                                                self.high_throttled_read = None
                                                self.time_since_last_throttled_read = None
                                                self.read_calls_count = None
                                                self.read_messages_count = None
                                                self.data_bytes_read = None
                                                self.io_read_time = None
                                                self.write_calls_count = None
                                                self.data_bytes_written = None
                                                self.io_write_time = None
                                                self.last_sent_seq_no = None
                                                self.write_subgroup_calls_count = None
                                                self.write_subgroup_messages_count = None
                                                self.subgroup_list_time = None
                                                self.write_queue_calls_count = None
                                                self.write_queue_messages_count = None
                                                self.write_queue_time = None
                                                self.inbound_update_messages = None
                                                self.inbound_update_messages_time = None
                                                self.maximum_read_size = None
                                                self.actives = None
                                                self.failed_post_actives = None
                                                self.passives = None
                                                self.rejected_passives = None
                                                self.active_collision = None
                                                self.passive_collision = None
                                                self.control_to_read_thread_trigger = None
                                                self.control_to_write_thread_trigger = None
                                                self.network_status = None
                                                self.reset_flags = None
                                                self.nbr_flags = None
                                                self.nbr_fd = None
                                                self.reset_retries = None
                                                self.sync_flags = None
                                                self.nsr_oper_down_count = None
                                                self.last_nsr_scoped_sync = None
                                                self._segment_path = lambda: "performance-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, [u'read_throttles', u'low_throttled_read', u'high_throttled_read', u'time_since_last_throttled_read', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'last_sent_seq_no', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time', u'maximum_read_size', u'actives', u'failed_post_actives', u'passives', u'rejected_passives', u'active_collision', u'passive_collision', u'control_to_read_thread_trigger', u'control_to_write_thread_trigger', u'network_status', u'reset_flags', u'nbr_flags', u'nbr_fd', u'reset_retries', u'sync_flags', u'nsr_oper_down_count', u'last_nsr_scoped_sync'], name, value)


                                        class MessageStatistics(Entity):
                                            """
                                            Message statistics
                                            
                                            .. attribute:: open
                                            
                                            	Open
                                            	**type**\:  :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                            
                                            .. attribute:: notification
                                            
                                            	Notification
                                            	**type**\:  :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                            
                                            .. attribute:: update
                                            
                                            	Update
                                            	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                            
                                            .. attribute:: keepalive
                                            
                                            	Keepalive
                                            	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                            
                                            .. attribute:: route_refresh
                                            
                                            	Route refresh
                                            	**type**\:  :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                            
                                            .. attribute:: total
                                            
                                            	Total
                                            	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, self).__init__()

                                                self.yang_name = "message-statistics"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("open", ("open", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open)), ("notification", ("notification", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification)), ("update", ("update", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update)), ("keepalive", ("keepalive", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive)), ("route-refresh", ("route_refresh", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh)), ("total", ("total", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total))])
                                                self._leafs = OrderedDict()

                                                self.open = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                                self.open.parent = self
                                                self._children_name_map["open"] = "open"

                                                self.notification = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                                self.notification.parent = self
                                                self._children_name_map["notification"] = "notification"

                                                self.update = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                                self.update.parent = self
                                                self._children_name_map["update"] = "update"

                                                self.keepalive = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                                self.keepalive.parent = self
                                                self._children_name_map["keepalive"] = "keepalive"

                                                self.route_refresh = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                                self.route_refresh.parent = self
                                                self._children_name_map["route_refresh"] = "route-refresh"

                                                self.total = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                                self.total.parent = self
                                                self._children_name_map["total"] = "total"
                                                self._segment_path = lambda: "message-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, [], name, value)


                                            class Open(Entity):
                                                """
                                                Open
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, self).__init__()

                                                    self.yang_name = "open"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "open"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "open"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "open"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Notification(Entity):
                                                """
                                                Notification
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, self).__init__()

                                                    self.yang_name = "notification"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "notification"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "notification"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "notification"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Update(Entity):
                                                """
                                                Update
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, self).__init__()

                                                    self.yang_name = "update"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "update"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Keepalive(Entity):
                                                """
                                                Keepalive
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                                    self.yang_name = "keepalive"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "keepalive"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "keepalive"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "keepalive"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class RouteRefresh(Entity):
                                                """
                                                Route refresh
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                                    self.yang_name = "route-refresh"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "route-refresh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "route-refresh"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "route-refresh"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Total(Entity):
                                                """
                                                Total
                                                
                                                .. attribute:: tx
                                                
                                                	Transmit
                                                	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                                
                                                .. attribute:: rx
                                                
                                                	Receive
                                                	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, self).__init__()

                                                    self.yang_name = "total"
                                                    self.yang_parent_name = "message-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx))])
                                                    self._leafs = OrderedDict()

                                                    self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                    self.tx.parent = self
                                                    self._children_name_map["tx"] = "tx"

                                                    self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                    self.rx.parent = self
                                                    self._children_name_map["rx"] = "rx"
                                                    self._segment_path = lambda: "total"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, [], name, value)


                                                class Tx(Entity):
                                                    """
                                                    Transmit
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                        self.yang_name = "tx"
                                                        self.yang_parent_name = "total"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "tx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "tx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                                class Rx(Entity):
                                                    """
                                                    Receive
                                                    
                                                    .. attribute:: last_time_spec
                                                    
                                                    	Last timespec
                                                    	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                    
                                                    .. attribute:: count
                                                    
                                                    	Count
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                        self.yang_name = "rx"
                                                        self.yang_parent_name = "total"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec))])
                                                        self._leafs = OrderedDict([
                                                            ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                        ])
                                                        self.count = None

                                                        self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                        self.last_time_spec.parent = self
                                                        self._children_name_map["last_time_spec"] = "last-time-spec"
                                                        self._segment_path = lambda: "rx"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, [u'count'], name, value)


                                                    class LastTimeSpec(Entity):
                                                        """
                                                        Last timespec
                                                        
                                                        .. attribute:: seconds
                                                        
                                                        	Seconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: nanoseconds
                                                        
                                                        	Nanoseconds part of time value
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                            self.yang_name = "last-time-spec"
                                                            self.yang_parent_name = "rx"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                            ])
                                                            self.seconds = None
                                                            self.nanoseconds = None
                                                            self._segment_path = lambda: "last-time-spec"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TcpInitSyncTimeSpec(Entity):
                                            """
                                            Time When neighbor entered TCP Init Sync
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "tcp-init-sync-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                            """
                                            Time when neighbor entered TCP Init Sync Phase
                                            Two
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class TcpInitSyncDoneTimeSpec(Entity):
                                            """
                                            Time when neighbor entered TCP Init Sync Done
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                                self.yang_name = "tcp-init-sync-done-time-spec"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "tcp-init-sync-done-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class GracefulMaintenance(Entity):
                                            """
                                            Graceful Maintenance
                                            
                                            .. attribute:: gshut_exists
                                            
                                            	Graceful Maintenance enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: gshut_local_active
                                            
                                            	Graceful Maintenance locally activated
                                            	**type**\: bool
                                            
                                            .. attribute:: gshut_active
                                            
                                            	Graceful Maintenance activated
                                            	**type**\: bool
                                            
                                            .. attribute:: gshut_locpref_set
                                            
                                            	Graceful Maintenance Local Preference set
                                            	**type**\: bool
                                            
                                            .. attribute:: gshut_locpref
                                            
                                            	Graceful Maintenance Local Preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: gshut_prepends
                                            
                                            	Graceful Maintenance number of AS prepends
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, self).__init__()

                                                self.yang_name = "graceful-maintenance"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                                    ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                                    ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                                    ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                                    ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                                    ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                                ])
                                                self.gshut_exists = None
                                                self.gshut_local_active = None
                                                self.gshut_active = None
                                                self.gshut_locpref_set = None
                                                self.gshut_locpref = None
                                                self.gshut_prepends = None
                                                self._segment_path = lambda: "graceful-maintenance"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                                        class AfData(Entity):
                                            """
                                            Address family specific neighbor data
                                            
                                            .. attribute:: neighbor_af_performance_statistics
                                            
                                            	Neighbor AF statistics
                                            	**type**\:  :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: is_neighbor_route_reflector_client
                                            
                                            	Nbr is a route reflector client
                                            	**type**\: bool
                                            
                                            .. attribute:: is_legacy_pe_rt
                                            
                                            	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_af_capable
                                            
                                            	Address family capability received from neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: is_soft_reconfiguration_inbound_allowed
                                            
                                            	Inbound soft reconfiguration allowed
                                            	**type**\: bool
                                            
                                            .. attribute:: is_use_soft_reconfiguration_always_on
                                            
                                            	Soft reconf overrides route refresh
                                            	**type**\: bool
                                            
                                            .. attribute:: remove_private_as_from_updates
                                            
                                            	Private AS numbers removed from updates to this nbr
                                            	**type**\: bool
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_updates
                                            
                                            	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                            	**type**\: bool
                                            
                                            .. attribute:: remove_private_as_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr
                                            	**type**\: bool
                                            
                                            .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                            
                                            	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                            	**type**\: bool
                                            
                                            .. attribute:: flowspec_validation_d_isable
                                            
                                            	Flowspec Validation Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: flowspec_redirect_validation_d_isable
                                            
                                            	Flowspec Redirect Validation Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: orr_group_name
                                            
                                            	ORR Group Name
                                            	**type**\: str
                                            
                                            .. attribute:: orr_group_index
                                            
                                            	ORR Group Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_orr_root_address_configured
                                            
                                            	ORR Root address configuredfor the neighbor connection
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_afi
                                            
                                            	Encode in Advertise AFI
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_afi_reorg
                                            
                                            	Encode in Advertise AFI
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_afi_disable
                                            
                                            	Encode in Advertise AFI
                                            	**type**\: bool
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation type
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_rt_type
                                            
                                            	Advertise RT type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: advertise_afi_def_vrf_imp_disable
                                            
                                            	Advertise of default VRF import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                            
                                            	Advertise of v4 default VRF import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                            
                                            	Advertise of v6 default VRF import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_afi_vrf_re_imp_disable
                                            
                                            	Advertise of VRF re\-import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                            
                                            	Advertise of v4 VRF re\-import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                            
                                            	Advertise of v6 VRF re\-import disable
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_afi_eo_r_ready
                                            
                                            	EoR Can be sent for Advertise AFI
                                            	**type**\: bool
                                            
                                            .. attribute:: always_use_next_hop_local
                                            
                                            	Local router always used for next\-hop
                                            	**type**\: bool
                                            
                                            .. attribute:: sent_community_to_neighbor
                                            
                                            	Community attribute sent to neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: sent_gshut_community_to_neighbor
                                            
                                            	GSHUT Community attribute sent to neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: sent_extended_community_to_neighbor
                                            
                                            	Extended community attribute sent to neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_default_originate
                                            
                                            	Neighbor originates default
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orf_sent
                                            
                                            	Outbound route filter sent to neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: is_update_deferred
                                            
                                            	Update deferred until ORF/route refresh received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orf_send_scheduled
                                            
                                            	Scheduled to send prefix based ORF
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: filter_group_index
                                            
                                            	Filter group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_update_throttled
                                            
                                            	Updates Throttled becausewrite limit is reached
                                            	**type**\: bool
                                            
                                            .. attribute:: is_update_leaving
                                            
                                            	Nbr leaving update\-groupto another
                                            	**type**\: bool
                                            
                                            .. attribute:: vpn_update_gen_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\: bool
                                            
                                            .. attribute:: vpn_update_gen_trigger_enabled
                                            
                                            	RT Nbr enabled for updategento another
                                            	**type**\: bool
                                            
                                            .. attribute:: is_addpath_send_operational
                                            
                                            	Addpath is operational on send\-side
                                            	**type**\: bool
                                            
                                            .. attribute:: is_addpath_receive_operational
                                            
                                            	Addpath is operational on receive\-side
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_version
                                            
                                            	Neighbor version
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight for this AF
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: max_prefix_limit
                                            
                                            	Max limit for # of prefixes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: use_max_prefix_warning_only
                                            
                                            	Warning only when maximum prefix limit reached
                                            	**type**\: bool
                                            
                                            .. attribute:: max_prefix_discard_extra_paths
                                            
                                            	Discard extra paths when prefix limit reached
                                            	**type**\: bool
                                            
                                            .. attribute:: max_prefix_exceed_discard_paths
                                            
                                            	Did we discard extra paths when prefix limit reached
                                            	**type**\: bool
                                            
                                            .. attribute:: max_prefix_threshold_percent
                                            
                                            	Percentage of maximum no. of prefixes at which to generate warning
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: percentage
                                            
                                            .. attribute:: max_prefix_restart_time
                                            
                                            	Time interval (in minutes) after which peering session will be reestablished
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: minute
                                            
                                            .. attribute:: prefixes_accepted
                                            
                                            	No. of prefixes accepted
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_synced
                                            
                                            	Number of prefixes synced to standby
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn_not_found
                                            
                                            	No. of prefixes withdrawn but not found
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied
                                            
                                            	No. of prefixes denied
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_no_policy
                                            
                                            	No. of prefixes denied because there was no inbound policy
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_rt_permit
                                            
                                            	No. of prefixes denied because RT extended community is not imported
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_orf_policy
                                            
                                            	No. of prefixes denied by prefix based ORF policy
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_denied_policy
                                            
                                            	No. of prefixes denied by inbound policy
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_bestpaths
                                            
                                            	No. of bestpaths from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_best_externalpaths
                                            
                                            	No. of best\-external paths from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_advertised
                                            
                                            	No. of prefixes advertised
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_be_advertised
                                            
                                            	No BE prefixes advertised
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_suppressed
                                            
                                            	No. of prefixes suppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefixes_withdrawn
                                            
                                            	No. of prefixes withdrawn
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_peer_orf_capable
                                            
                                            	Peer has outbound route filter capability
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertised_orf_send
                                            
                                            	Prefix based ORF send mode capability advertised
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_orf_send_capable
                                            
                                            	Prefix based ORF send mode capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertised_orf_receive
                                            
                                            	Prefix based ORF receive mode capability advertised
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_orf_receive_capable
                                            
                                            	Prefix based ORF receive mode capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertised_graceful_restart
                                            
                                            	Graceful Restart Capability advertised
                                            	**type**\: bool
                                            
                                            .. attribute:: is_graceful_restart_state_flag
                                            
                                            	Restart state flag enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_graceful_restart_capable
                                            
                                            	Graceful Restart Capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_add_path_send_capability_advertised
                                            
                                            	Addpath Send capability advertised
                                            	**type**\: bool
                                            
                                            .. attribute:: is_add_path_send_capability_received
                                            
                                            	Addpath Send capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_add_path_receive_capability_advertised
                                            
                                            	Addpath Receive capability advertised
                                            	**type**\: bool
                                            
                                            .. attribute:: is_add_path_receive_capability_received
                                            
                                            	Addpath Receive capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_received
                                            
                                            	Extended nexthop encoding capability received
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ext_nh_encoding_capability_sent
                                            
                                            	Extended nexhop encoding capability Sent
                                            	**type**\: bool
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart time advertised (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: local_restart_time
                                            
                                            	Local Restart time (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: stale_path_timeout
                                            
                                            	Stale path timeout time (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: rib_purge_timeout_value
                                            
                                            	RIB purge timeout time (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_preserved_forwarding_state
                                            
                                            	Neighbor preserved forwarding state
                                            	**type**\: bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_configured
                                            
                                            	Long\-lived graceful\-restart stale time is configured
                                            	**type**\: bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_sent
                                            
                                            	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_accept
                                            
                                            	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: long_lived_graceful_restart_capability_received
                                            
                                            	Long\-lived graceful\-restart capability received from the neighbor
                                            	**type**\: bool
                                            
                                            .. attribute:: long_lived_graceful_restart_stale_time_received
                                            
                                            	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                            
                                            	Neighbor preserved long\-lived forwarding state
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_capable
                                            
                                            	Treat neighbor as long\-lived graceful\-restart capable
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                            
                                            	Remaining long\-lived graceful\-restart time
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_refreshes_received
                                            
                                            	Number of route refresh requests received
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_refreshes_sent
                                            
                                            	Number of route refresh requests sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_target_version
                                            
                                            	Target version for refresh update generation
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_version
                                            
                                            	Version till which refresh updates have been generated
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: refresh_acked_version
                                            
                                            	Version acked by the peer for refresh updates sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_prefix_orf_present
                                            
                                            	Outbound route filter prefix ORF present
                                            	**type**\: bool
                                            
                                            .. attribute:: orf_entries_received
                                            
                                            	Number of outbound route filter entries received
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_default_originate_sent
                                            
                                            	Default origination update sent
                                            	**type**\: bool
                                            
                                            .. attribute:: route_policy_prefix_orf
                                            
                                            	Prefix based ORF for incoming updates
                                            	**type**\: str
                                            
                                            .. attribute:: route_policy_in
                                            
                                            	Incoming route policy name
                                            	**type**\: str
                                            
                                            .. attribute:: route_policy_out
                                            
                                            	Outgoing route policy name
                                            	**type**\: str
                                            
                                            .. attribute:: route_policy_default_originate
                                            
                                            	Default\-originate route policy name
                                            	**type**\: str
                                            
                                            .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                            
                                            	eBGP neighbor with no configured inbound policy
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                            
                                            	eBGP neighbor with no configured outbound policy
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_override_set
                                            
                                            	As override set 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_allow_as_in_set
                                            
                                            	Allowas\-in set 
                                            	**type**\: bool
                                            
                                            .. attribute:: allow_as_in_count
                                            
                                            	Allowas\-in count config
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: address_family_long_lived_time
                                            
                                            	AF specific Long\-lived\-time config
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: eo_r_received_in_read_only
                                            
                                            	An EoR was received while in read\-only mode
                                            	**type**\: bool
                                            
                                            .. attribute:: acked_version
                                            
                                            	Version mapped from acked seqNo
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: synced_acked_version
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: outstanding_version
                                            
                                            	No. of all outstanding version objects waiting for ack from the peer
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: outstanding_refresh_version
                                            
                                            	No. of only refresh version objects waiting for ack from the peer
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: outstanding_version_max
                                            
                                            	Version mapped from acked seqNo that was synced last
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_aigp_set
                                            
                                            	AIGP set 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rt_present_standby
                                            
                                            	RT attribute list present
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_enabled
                                            
                                            	Accept\-Own enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: selective_multipath_eligible
                                            
                                            	Selective multipath eligible
                                            	**type**\: bool
                                            
                                            .. attribute:: afrpki_disable
                                            
                                            	Prefix validation disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: afrpki_use_validity
                                            
                                            	Prefix v. use validity
                                            	**type**\: bool
                                            
                                            .. attribute:: afrpki_allow_invalid
                                            
                                            	Prefix v. allow invalid
                                            	**type**\: bool
                                            
                                            .. attribute:: afrpki_signal_ibgp
                                            
                                            	Prefix v. signal ibgp
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertise_permanent_network
                                            
                                            	Advertise Permanent Network
                                            	**type**\: bool
                                            
                                            .. attribute:: is_send_mcast_attr
                                            
                                            	Send Mcast Attr
                                            	**type**\: bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	Import Stitching enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	Import Reoriginate enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	Import Reoriginate Stitching enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: advertise_v4_flags
                                            
                                            	Advertise options for VPNV4
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_v6_flags
                                            
                                            	Advertise options for VPNV6
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertise_local_labeled_route_unicast
                                            
                                            	Advertise routes with 
                                            	**type**\: bool
                                            
                                            .. attribute:: prefixes_denied_non_cumulative
                                            
                                            	No. of prefixes exactly denied (non cumulative)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: enable_label_stack
                                            
                                            	Enable label stack
                                            	**type**\: bool
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                            
                                            .. attribute:: extended_community_standby
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData, self).__init__()

                                                self.yang_name = "af-data"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-af-performance-statistics", ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby))])
                                                self._leafs = OrderedDict([
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                                    ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                                    ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                                    ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                                    ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                                    ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                                    ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                                    ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                                    ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                                    ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                                    ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                                    ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                                    ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                                    ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                                    ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                                    ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                                    ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                                    ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                                    ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                                    ('advertise_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-def-vrf-imp-disable'), ['bool'])),
                                                    ('advertise_evpnv4_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-def-vrf-imp-disable'), ['bool'])),
                                                    ('advertise_evpnv6_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-def-vrf-imp-disable'), ['bool'])),
                                                    ('advertise_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-vrf-re-imp-disable'), ['bool'])),
                                                    ('advertise_evpnv4_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-vrf-re-imp-disable'), ['bool'])),
                                                    ('advertise_evpnv6_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-vrf-re-imp-disable'), ['bool'])),
                                                    ('advertise_afi_eo_r_ready', (YLeaf(YType.boolean, 'advertise-afi-eo-r-ready'), ['bool'])),
                                                    ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                                    ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                                    ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                                    ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                                    ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                                    ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                                    ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                                    ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                                    ('is_update_throttled', (YLeaf(YType.boolean, 'is-update-throttled'), ['bool'])),
                                                    ('is_update_leaving', (YLeaf(YType.boolean, 'is-update-leaving'), ['bool'])),
                                                    ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                                    ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                                    ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                                    ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                                    ('neighbor_version', (YLeaf(YType.uint32, 'neighbor-version'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                                    ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                                    ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                                    ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                                    ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                                    ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                                    ('prefixes_accepted', (YLeaf(YType.uint32, 'prefixes-accepted'), ['int'])),
                                                    ('prefixes_synced', (YLeaf(YType.uint32, 'prefixes-synced'), ['int'])),
                                                    ('prefixes_withdrawn_not_found', (YLeaf(YType.uint32, 'prefixes-withdrawn-not-found'), ['int'])),
                                                    ('prefixes_denied', (YLeaf(YType.uint32, 'prefixes-denied'), ['int'])),
                                                    ('prefixes_denied_no_policy', (YLeaf(YType.uint32, 'prefixes-denied-no-policy'), ['int'])),
                                                    ('prefixes_denied_rt_permit', (YLeaf(YType.uint32, 'prefixes-denied-rt-permit'), ['int'])),
                                                    ('prefixes_denied_orf_policy', (YLeaf(YType.uint32, 'prefixes-denied-orf-policy'), ['int'])),
                                                    ('prefixes_denied_policy', (YLeaf(YType.uint32, 'prefixes-denied-policy'), ['int'])),
                                                    ('number_of_bestpaths', (YLeaf(YType.uint32, 'number-of-bestpaths'), ['int'])),
                                                    ('number_of_best_externalpaths', (YLeaf(YType.uint32, 'number-of-best-externalpaths'), ['int'])),
                                                    ('prefixes_advertised', (YLeaf(YType.uint32, 'prefixes-advertised'), ['int'])),
                                                    ('prefixes_be_advertised', (YLeaf(YType.uint32, 'prefixes-be-advertised'), ['int'])),
                                                    ('prefixes_suppressed', (YLeaf(YType.uint32, 'prefixes-suppressed'), ['int'])),
                                                    ('prefixes_withdrawn', (YLeaf(YType.uint32, 'prefixes-withdrawn'), ['int'])),
                                                    ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                                    ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                                    ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                                    ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                                    ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                                    ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                                    ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                                    ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                                    ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                                    ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                                    ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                                    ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                                    ('is_ext_nh_encoding_capability_received', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-received'), ['bool'])),
                                                    ('is_ext_nh_encoding_capability_sent', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-sent'), ['bool'])),
                                                    ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                                    ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                                    ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                                    ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                                    ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                                    ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                                    ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                                    ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                                    ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                                    ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                                    ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                                    ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                                    ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                                    ('route_refreshes_received', (YLeaf(YType.uint32, 'route-refreshes-received'), ['int'])),
                                                    ('route_refreshes_sent', (YLeaf(YType.uint32, 'route-refreshes-sent'), ['int'])),
                                                    ('refresh_target_version', (YLeaf(YType.uint32, 'refresh-target-version'), ['int'])),
                                                    ('refresh_version', (YLeaf(YType.uint32, 'refresh-version'), ['int'])),
                                                    ('refresh_acked_version', (YLeaf(YType.uint32, 'refresh-acked-version'), ['int'])),
                                                    ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                                    ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                                    ('is_default_originate_sent', (YLeaf(YType.boolean, 'is-default-originate-sent'), ['bool'])),
                                                    ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                                    ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                                    ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                                    ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                                    ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                                    ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                                    ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                                    ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                                    ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                                    ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                                    ('eo_r_received_in_read_only', (YLeaf(YType.boolean, 'eo-r-received-in-read-only'), ['bool'])),
                                                    ('acked_version', (YLeaf(YType.uint32, 'acked-version'), ['int'])),
                                                    ('synced_acked_version', (YLeaf(YType.uint32, 'synced-acked-version'), ['int'])),
                                                    ('outstanding_version', (YLeaf(YType.uint32, 'outstanding-version'), ['int'])),
                                                    ('outstanding_refresh_version', (YLeaf(YType.uint32, 'outstanding-refresh-version'), ['int'])),
                                                    ('outstanding_version_max', (YLeaf(YType.uint32, 'outstanding-version-max'), ['int'])),
                                                    ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                                    ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                                    ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                                    ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                                    ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                                    ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                                    ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                                    ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                                    ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                                    ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                                    ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                                    ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                                    ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                                    ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                                    ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                                    ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                                    ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                                    ('prefixes_denied_non_cumulative', (YLeaf(YType.uint32, 'prefixes-denied-non-cumulative'), ['int'])),
                                                    ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                                ])
                                                self.af_name = None
                                                self.is_neighbor_route_reflector_client = None
                                                self.is_legacy_pe_rt = None
                                                self.is_neighbor_af_capable = None
                                                self.is_soft_reconfiguration_inbound_allowed = None
                                                self.is_use_soft_reconfiguration_always_on = None
                                                self.remove_private_as_from_updates = None
                                                self.remove_private_as_entire_aspath_from_updates = None
                                                self.remove_private_as_from_inbound_updates = None
                                                self.remove_private_as_entire_aspath_from_inbound_updates = None
                                                self.flowspec_validation_d_isable = None
                                                self.flowspec_redirect_validation_d_isable = None
                                                self.orr_group_name = None
                                                self.orr_group_index = None
                                                self.is_orr_root_address_configured = None
                                                self.advertise_afi = None
                                                self.advertise_afi_reorg = None
                                                self.advertise_afi_disable = None
                                                self.encapsulation_type = None
                                                self.advertise_rt_type = None
                                                self.advertise_afi_def_vrf_imp_disable = None
                                                self.advertise_evpnv4_afi_def_vrf_imp_disable = None
                                                self.advertise_evpnv6_afi_def_vrf_imp_disable = None
                                                self.advertise_afi_vrf_re_imp_disable = None
                                                self.advertise_evpnv4_afi_vrf_re_imp_disable = None
                                                self.advertise_evpnv6_afi_vrf_re_imp_disable = None
                                                self.advertise_afi_eo_r_ready = None
                                                self.always_use_next_hop_local = None
                                                self.sent_community_to_neighbor = None
                                                self.sent_gshut_community_to_neighbor = None
                                                self.sent_extended_community_to_neighbor = None
                                                self.neighbor_default_originate = None
                                                self.is_orf_sent = None
                                                self.is_update_deferred = None
                                                self.is_orf_send_scheduled = None
                                                self.update_group_number = None
                                                self.filter_group_index = None
                                                self.is_update_throttled = None
                                                self.is_update_leaving = None
                                                self.vpn_update_gen_enabled = None
                                                self.vpn_update_gen_trigger_enabled = None
                                                self.is_addpath_send_operational = None
                                                self.is_addpath_receive_operational = None
                                                self.neighbor_version = None
                                                self.weight = None
                                                self.max_prefix_limit = None
                                                self.use_max_prefix_warning_only = None
                                                self.max_prefix_discard_extra_paths = None
                                                self.max_prefix_exceed_discard_paths = None
                                                self.max_prefix_threshold_percent = None
                                                self.max_prefix_restart_time = None
                                                self.prefixes_accepted = None
                                                self.prefixes_synced = None
                                                self.prefixes_withdrawn_not_found = None
                                                self.prefixes_denied = None
                                                self.prefixes_denied_no_policy = None
                                                self.prefixes_denied_rt_permit = None
                                                self.prefixes_denied_orf_policy = None
                                                self.prefixes_denied_policy = None
                                                self.number_of_bestpaths = None
                                                self.number_of_best_externalpaths = None
                                                self.prefixes_advertised = None
                                                self.prefixes_be_advertised = None
                                                self.prefixes_suppressed = None
                                                self.prefixes_withdrawn = None
                                                self.is_peer_orf_capable = None
                                                self.is_advertised_orf_send = None
                                                self.is_received_orf_send_capable = None
                                                self.is_advertised_orf_receive = None
                                                self.is_received_orf_receive_capable = None
                                                self.is_advertised_graceful_restart = None
                                                self.is_graceful_restart_state_flag = None
                                                self.is_received_graceful_restart_capable = None
                                                self.is_add_path_send_capability_advertised = None
                                                self.is_add_path_send_capability_received = None
                                                self.is_add_path_receive_capability_advertised = None
                                                self.is_add_path_receive_capability_received = None
                                                self.is_ext_nh_encoding_capability_received = None
                                                self.is_ext_nh_encoding_capability_sent = None
                                                self.restart_time = None
                                                self.local_restart_time = None
                                                self.stale_path_timeout = None
                                                self.rib_purge_timeout_value = None
                                                self.neighbor_preserved_forwarding_state = None
                                                self.long_lived_graceful_restart_stale_time_configured = None
                                                self.long_lived_graceful_restart_stale_time_sent = None
                                                self.long_lived_graceful_restart_stale_time_accept = None
                                                self.long_lived_graceful_restart_capability_received = None
                                                self.long_lived_graceful_restart_stale_time_received = None
                                                self.neighbor_preserved_long_lived_forwarding_state = None
                                                self.neighbor_long_lived_graceful_restart_capable = None
                                                self.neighbor_long_lived_graceful_restart_time_remaining = None
                                                self.route_refreshes_received = None
                                                self.route_refreshes_sent = None
                                                self.refresh_target_version = None
                                                self.refresh_version = None
                                                self.refresh_acked_version = None
                                                self.is_prefix_orf_present = None
                                                self.orf_entries_received = None
                                                self.is_default_originate_sent = None
                                                self.route_policy_prefix_orf = None
                                                self.route_policy_in = None
                                                self.route_policy_out = None
                                                self.route_policy_default_originate = None
                                                self.is_neighbor_ebgp_without_inbound_policy = None
                                                self.is_neighbor_ebgp_without_outbound_policy = None
                                                self.is_as_override_set = None
                                                self.is_allow_as_in_set = None
                                                self.allow_as_in_count = None
                                                self.address_family_long_lived_time = None
                                                self.eo_r_received_in_read_only = None
                                                self.acked_version = None
                                                self.synced_acked_version = None
                                                self.outstanding_version = None
                                                self.outstanding_refresh_version = None
                                                self.outstanding_version_max = None
                                                self.is_aigp_set = None
                                                self.is_rt_present = None
                                                self.is_rt_present_standby = None
                                                self.accept_own_enabled = None
                                                self.selective_multipath_eligible = None
                                                self.afrpki_disable = None
                                                self.afrpki_use_validity = None
                                                self.afrpki_allow_invalid = None
                                                self.afrpki_signal_ibgp = None
                                                self.is_advertise_permanent_network = None
                                                self.is_send_mcast_attr = None
                                                self.import_stitching = None
                                                self.import_reoriginate = None
                                                self.import_reoriginate_stitching = None
                                                self.advertise_v4_flags = None
                                                self.advertise_v6_flags = None
                                                self.advertise_local_labeled_route_unicast = None
                                                self.prefixes_denied_non_cumulative = None
                                                self.enable_label_stack = None

                                                self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                                self.neighbor_af_performance_statistics.parent = self
                                                self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"

                                                self.extended_community = YList(self)
                                                self.extended_community_standby = YList(self)
                                                self._segment_path = lambda: "af-data"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_disable', u'encapsulation_type', u'advertise_rt_type', u'advertise_afi_def_vrf_imp_disable', u'advertise_evpnv4_afi_def_vrf_imp_disable', u'advertise_evpnv6_afi_def_vrf_imp_disable', u'advertise_afi_vrf_re_imp_disable', u'advertise_evpnv4_afi_vrf_re_imp_disable', u'advertise_evpnv6_afi_vrf_re_imp_disable', u'advertise_afi_eo_r_ready', u'always_use_next_hop_local', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'update_group_number', u'filter_group_index', u'is_update_throttled', u'is_update_leaving', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'neighbor_version', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'prefixes_accepted', u'prefixes_synced', u'prefixes_withdrawn_not_found', u'prefixes_denied', u'prefixes_denied_no_policy', u'prefixes_denied_rt_permit', u'prefixes_denied_orf_policy', u'prefixes_denied_policy', u'number_of_bestpaths', u'number_of_best_externalpaths', u'prefixes_advertised', u'prefixes_be_advertised', u'prefixes_suppressed', u'prefixes_withdrawn', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'is_ext_nh_encoding_capability_received', u'is_ext_nh_encoding_capability_sent', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'route_refreshes_received', u'route_refreshes_sent', u'refresh_target_version', u'refresh_version', u'refresh_acked_version', u'is_prefix_orf_present', u'orf_entries_received', u'is_default_originate_sent', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'eo_r_received_in_read_only', u'acked_version', u'synced_acked_version', u'outstanding_version', u'outstanding_refresh_version', u'outstanding_version_max', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'advertise_local_labeled_route_unicast', u'prefixes_denied_non_cumulative', u'enable_label_stack'], name, value)


                                            class NeighborAfPerformanceStatistics(Entity):
                                                """
                                                Neighbor AF statistics
                                                
                                                .. attribute:: sub_group_pending_message_count
                                                
                                                	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: processed_messages
                                                
                                                	Number of messages processed from the neighbor's write queue
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: sent_messages
                                                
                                                	Number of messages sent from the neighbor's write queue
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_transmit
                                                
                                                	No. of update messages with split\-horizon flag that were sent out
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_update_blocked
                                                
                                                	No. of update messages with split\-horizon flag that were blocked
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_transmit
                                                
                                                	No. of withdraw messages with split\-horizon flag that were sent out
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: split_horizon_withdraw_blocked
                                                
                                                	No. of withdraw messages with split\-horizon flag that were blocked
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                                    self.yang_name = "neighbor-af-performance-statistics"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sub_group_pending_message_count', (YLeaf(YType.uint32, 'sub-group-pending-message-count'), ['int'])),
                                                        ('processed_messages', (YLeaf(YType.uint32, 'processed-messages'), ['int'])),
                                                        ('sent_messages', (YLeaf(YType.uint32, 'sent-messages'), ['int'])),
                                                        ('split_horizon_update_transmit', (YLeaf(YType.uint32, 'split-horizon-update-transmit'), ['int'])),
                                                        ('split_horizon_update_blocked', (YLeaf(YType.uint32, 'split-horizon-update-blocked'), ['int'])),
                                                        ('split_horizon_withdraw_transmit', (YLeaf(YType.uint32, 'split-horizon-withdraw-transmit'), ['int'])),
                                                        ('split_horizon_withdraw_blocked', (YLeaf(YType.uint32, 'split-horizon-withdraw-blocked'), ['int'])),
                                                    ])
                                                    self.sub_group_pending_message_count = None
                                                    self.processed_messages = None
                                                    self.sent_messages = None
                                                    self.split_horizon_update_transmit = None
                                                    self.split_horizon_update_blocked = None
                                                    self.split_horizon_withdraw_transmit = None
                                                    self.split_horizon_withdraw_blocked = None
                                                    self._segment_path = lambda: "neighbor-af-performance-statistics"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, [u'sub_group_pending_message_count', u'processed_messages', u'sent_messages', u'split_horizon_update_transmit', u'split_horizon_update_blocked', u'split_horizon_withdraw_transmit', u'split_horizon_withdraw_blocked'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, [u'entry'], name, value)


                                            class ExtendedCommunityStandby(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                                    self.yang_name = "extended-community-standby"
                                                    self.yang_parent_name = "af-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community-standby"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                                class UpdateGenerationNeighbors(Entity):
                                    """
                                    Update generation for all neighbors
                                    
                                    .. attribute:: update_generation_neighbor
                                    
                                    	Update generation for neighbor
                                    	**type**\: list of  		 :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors, self).__init__()

                                        self.yang_name = "update-generation-neighbors"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-generation-neighbor", ("update_generation_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor))])
                                        self._leafs = OrderedDict()

                                        self.update_generation_neighbor = YList(self)
                                        self._segment_path = lambda: "update-generation-neighbors"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors, [], name, value)


                                    class UpdateGenerationNeighbor(Entity):
                                        """
                                        Update generation for neighbor
                                        
                                        .. attribute:: update_group_index
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_id
                                        
                                        	Sub\-group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: update_neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                        
                                        .. attribute:: last_sub_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:  :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                        
                                        .. attribute:: last_sub_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:  :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                        
                                        .. attribute:: last_filter_group_add_timestamp
                                        
                                        	Last added time
                                        	**type**\:  :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                        
                                        .. attribute:: last_filter_group_remove_timestamp
                                        
                                        	Last removed time
                                        	**type**\:  :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                        
                                        .. attribute:: first_default_originate_timestamp
                                        
                                        	First default\-origination time
                                        	**type**\:  :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: last_default_originate_timestamp
                                        
                                        	Last default\-origination time
                                        	**type**\:  :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                        
                                        .. attribute:: last_update_group_start_timestamp
                                        
                                        	Last update\-group timer start
                                        	**type**\:  :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                        
                                        .. attribute:: last_update_group_expiry_timestamp
                                        
                                        	Last update\-group timer expiry
                                        	**type**\:  :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                        
                                        .. attribute:: first_update_queued_timestamp
                                        
                                        	First update queued time
                                        	**type**\:  :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_update_queued_timestamp
                                        
                                        	Last update queued time
                                        	**type**\:  :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_queued_timestamp
                                        
                                        	Last refresh update queued time
                                        	**type**\:  :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                        
                                        .. attribute:: first_update_write_timestamp
                                        
                                        	First update write time
                                        	**type**\:  :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                        
                                        .. attribute:: last_update_write_timestamp
                                        
                                        	Last update write time
                                        	**type**\:  :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                        
                                        .. attribute:: last_refresh_update_write_timestamp
                                        
                                        	Last refresh update write time
                                        	**type**\:  :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                        
                                        .. attribute:: update_statistics
                                        
                                        	Update statistics
                                        	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                        
                                        .. attribute:: process_id
                                        
                                        	ProcessID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_name
                                        
                                        	VRF Name
                                        	**type**\: str
                                        
                                        .. attribute:: update_group_af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: update_filter_group_index
                                        
                                        	Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_filter_group_index
                                        
                                        	Refresh Filter\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sub_group_index_xr
                                        
                                        	Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_index
                                        
                                        	Refresh Sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_sub_group_id
                                        
                                        	Refresh sub\-group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_index_xr
                                        
                                        	Update\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_main_table_version
                                        
                                        	Main table version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_vrf_table_rib_version
                                        
                                        	VRF Table RIB version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages
                                        
                                        	OutQueue messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size
                                        
                                        	OutQueue size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_messages
                                        
                                        	Refresh OutQueue messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_update_out_queue_size
                                        
                                        	Refresh OutQueue size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_filter_group_messages
                                        
                                        	Filter\-group messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_target_version
                                        
                                        	Pending target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_resume_version
                                        
                                        	Resume version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ack_version
                                        
                                        	Ack version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: synced_ack_version
                                        
                                        	Synced ack version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_count
                                        
                                        	Outstanding version count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_version
                                        
                                        	Refresh version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_requested_target_version
                                        
                                        	Requested refresh target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_refresh_target_version
                                        
                                        	Refresh target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_pending_target_version
                                        
                                        	Pending refresh target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_next_resume_version
                                        
                                        	Refresh resume version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_ack_version
                                        
                                        	Refresh Ack version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_default_originate_age
                                        
                                        	Time since last default\-origination event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: default_originate_state
                                        
                                        	Default\-origination state
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: default_originate_internal_context
                                        
                                        	Default\-origination context
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: is_eor_outstanding
                                        
                                        	Number of EORs outstanding
                                        	**type**\: bool
                                        
                                        .. attribute:: outbound_refresh_count
                                        
                                        	Refresh Outbound count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_refresh_count
                                        
                                        	Refresh Inbound count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_update_group_timer_running
                                        
                                        	Is update\-group timer running
                                        	**type**\: bool
                                        
                                        .. attribute:: current_update_group_af_name
                                        
                                        	Current Update\-group address\-family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: last_update_group_af_name
                                        
                                        	Last Update\-group address\-family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: last_update_queued_age
                                        
                                        	Time since last update queued event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_queued_age
                                        
                                        	Time since last refresh update queued event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_write_age
                                        
                                        	Time since last update write event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_refresh_update_write_age
                                        
                                        	Time since last refresh update write event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, self).__init__()

                                            self.yang_name = "update-generation-neighbor"
                                            self.yang_parent_name = "update-generation-neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress)), ("last-sub-group-add-timestamp", ("last_sub_group_add_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp)), ("last-sub-group-remove-timestamp", ("last_sub_group_remove_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp)), ("last-filter-group-add-timestamp", ("last_filter_group_add_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp)), ("last-filter-group-remove-timestamp", ("last_filter_group_remove_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp)), ("first-default-originate-timestamp", ("first_default_originate_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp)), ("last-default-originate-timestamp", ("last_default_originate_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp)), ("last-update-group-start-timestamp", ("last_update_group_start_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp)), ("last-update-group-expiry-timestamp", ("last_update_group_expiry_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp)), ("first-update-queued-timestamp", ("first_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp)), ("last-update-queued-timestamp", ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp)), ("last-refresh-update-queued-timestamp", ("last_refresh_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp)), ("first-update-write-timestamp", ("first_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp)), ("last-update-write-timestamp", ("last_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp)), ("last-refresh-update-write-timestamp", ("last_refresh_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics))])
                                            self._leafs = OrderedDict([
                                                ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                                ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                                ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                                ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                                ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('update_filter_group_index', (YLeaf(YType.uint32, 'update-filter-group-index'), ['int'])),
                                                ('refresh_filter_group_index', (YLeaf(YType.uint32, 'refresh-filter-group-index'), ['int'])),
                                                ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                                ('refresh_sub_group_index', (YLeaf(YType.uint32, 'refresh-sub-group-index'), ['int'])),
                                                ('refresh_sub_group_id', (YLeaf(YType.uint32, 'refresh-sub-group-id'), ['int'])),
                                                ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                                ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                                ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                                ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                                ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                                ('refresh_update_out_queue_messages', (YLeaf(YType.uint32, 'refresh-update-out-queue-messages'), ['int'])),
                                                ('refresh_update_out_queue_size', (YLeaf(YType.uint32, 'refresh-update-out-queue-size'), ['int'])),
                                                ('update_filter_group_messages', (YLeaf(YType.uint32, 'update-filter-group-messages'), ['int'])),
                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                ('pending_target_version', (YLeaf(YType.uint32, 'pending-target-version'), ['int'])),
                                                ('next_resume_version', (YLeaf(YType.uint32, 'next-resume-version'), ['int'])),
                                                ('ack_version', (YLeaf(YType.uint32, 'ack-version'), ['int'])),
                                                ('synced_ack_version', (YLeaf(YType.uint32, 'synced-ack-version'), ['int'])),
                                                ('outstanding_version_count', (YLeaf(YType.uint32, 'outstanding-version-count'), ['int'])),
                                                ('update_refresh_version', (YLeaf(YType.uint32, 'update-refresh-version'), ['int'])),
                                                ('refresh_requested_target_version', (YLeaf(YType.uint32, 'refresh-requested-target-version'), ['int'])),
                                                ('update_refresh_target_version', (YLeaf(YType.uint32, 'update-refresh-target-version'), ['int'])),
                                                ('refresh_pending_target_version', (YLeaf(YType.uint32, 'refresh-pending-target-version'), ['int'])),
                                                ('refresh_next_resume_version', (YLeaf(YType.uint32, 'refresh-next-resume-version'), ['int'])),
                                                ('refresh_ack_version', (YLeaf(YType.uint32, 'refresh-ack-version'), ['int'])),
                                                ('last_default_originate_age', (YLeaf(YType.uint32, 'last-default-originate-age'), ['int'])),
                                                ('default_originate_state', (YLeaf(YType.int32, 'default-originate-state'), ['int'])),
                                                ('default_originate_internal_context', (YLeaf(YType.int32, 'default-originate-internal-context'), ['int'])),
                                                ('is_eor_outstanding', (YLeaf(YType.boolean, 'is-eor-outstanding'), ['bool'])),
                                                ('outbound_refresh_count', (YLeaf(YType.uint32, 'outbound-refresh-count'), ['int'])),
                                                ('inbound_refresh_count', (YLeaf(YType.uint32, 'inbound-refresh-count'), ['int'])),
                                                ('is_update_group_timer_running', (YLeaf(YType.boolean, 'is-update-group-timer-running'), ['bool'])),
                                                ('current_update_group_af_name', (YLeaf(YType.enumeration, 'current-update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('last_update_group_af_name', (YLeaf(YType.enumeration, 'last-update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('last_update_queued_age', (YLeaf(YType.uint32, 'last-update-queued-age'), ['int'])),
                                                ('last_refresh_update_queued_age', (YLeaf(YType.uint32, 'last-refresh-update-queued-age'), ['int'])),
                                                ('last_update_write_age', (YLeaf(YType.uint32, 'last-update-write-age'), ['int'])),
                                                ('last_refresh_update_write_age', (YLeaf(YType.uint32, 'last-refresh-update-write-age'), ['int'])),
                                            ])
                                            self.update_group_index = None
                                            self.sub_group_index = None
                                            self.sub_group_id = None
                                            self.filter_group_index = None
                                            self.neighbor_address = None
                                            self.process_id = None
                                            self.update_vrf_name = None
                                            self.update_group_af_name = None
                                            self.update_filter_group_index = None
                                            self.refresh_filter_group_index = None
                                            self.sub_group_index_xr = None
                                            self.refresh_sub_group_index = None
                                            self.refresh_sub_group_id = None
                                            self.update_group_index_xr = None
                                            self.update_main_table_version = None
                                            self.update_vrf_table_rib_version = None
                                            self.update_out_queue_messages = None
                                            self.update_out_queue_size = None
                                            self.refresh_update_out_queue_messages = None
                                            self.refresh_update_out_queue_size = None
                                            self.update_filter_group_messages = None
                                            self.version = None
                                            self.pending_target_version = None
                                            self.next_resume_version = None
                                            self.ack_version = None
                                            self.synced_ack_version = None
                                            self.outstanding_version_count = None
                                            self.update_refresh_version = None
                                            self.refresh_requested_target_version = None
                                            self.update_refresh_target_version = None
                                            self.refresh_pending_target_version = None
                                            self.refresh_next_resume_version = None
                                            self.refresh_ack_version = None
                                            self.last_default_originate_age = None
                                            self.default_originate_state = None
                                            self.default_originate_internal_context = None
                                            self.is_eor_outstanding = None
                                            self.outbound_refresh_count = None
                                            self.inbound_refresh_count = None
                                            self.is_update_group_timer_running = None
                                            self.current_update_group_af_name = None
                                            self.last_update_group_af_name = None
                                            self.last_update_queued_age = None
                                            self.last_refresh_update_queued_age = None
                                            self.last_update_write_age = None
                                            self.last_refresh_update_write_age = None

                                            self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                            self.update_neighbor_address.parent = self
                                            self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                            self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                            self.last_sub_group_add_timestamp.parent = self
                                            self._children_name_map["last_sub_group_add_timestamp"] = "last-sub-group-add-timestamp"

                                            self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                            self.last_sub_group_remove_timestamp.parent = self
                                            self._children_name_map["last_sub_group_remove_timestamp"] = "last-sub-group-remove-timestamp"

                                            self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                            self.last_filter_group_add_timestamp.parent = self
                                            self._children_name_map["last_filter_group_add_timestamp"] = "last-filter-group-add-timestamp"

                                            self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                            self.last_filter_group_remove_timestamp.parent = self
                                            self._children_name_map["last_filter_group_remove_timestamp"] = "last-filter-group-remove-timestamp"

                                            self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                            self.first_default_originate_timestamp.parent = self
                                            self._children_name_map["first_default_originate_timestamp"] = "first-default-originate-timestamp"

                                            self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                            self.last_default_originate_timestamp.parent = self
                                            self._children_name_map["last_default_originate_timestamp"] = "last-default-originate-timestamp"

                                            self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                            self.last_update_group_start_timestamp.parent = self
                                            self._children_name_map["last_update_group_start_timestamp"] = "last-update-group-start-timestamp"

                                            self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                            self.last_update_group_expiry_timestamp.parent = self
                                            self._children_name_map["last_update_group_expiry_timestamp"] = "last-update-group-expiry-timestamp"

                                            self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                            self.first_update_queued_timestamp.parent = self
                                            self._children_name_map["first_update_queued_timestamp"] = "first-update-queued-timestamp"

                                            self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                            self.last_update_queued_timestamp.parent = self
                                            self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"

                                            self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                            self.last_refresh_update_queued_timestamp.parent = self
                                            self._children_name_map["last_refresh_update_queued_timestamp"] = "last-refresh-update-queued-timestamp"

                                            self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                            self.first_update_write_timestamp.parent = self
                                            self._children_name_map["first_update_write_timestamp"] = "first-update-write-timestamp"

                                            self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                            self.last_update_write_timestamp.parent = self
                                            self._children_name_map["last_update_write_timestamp"] = "last-update-write-timestamp"

                                            self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                            self.last_refresh_update_write_timestamp.parent = self
                                            self._children_name_map["last_refresh_update_write_timestamp"] = "last-refresh-update-write-timestamp"

                                            self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                            self.update_statistics.parent = self
                                            self._children_name_map["update_statistics"] = "update-statistics"
                                            self._segment_path = lambda: "update-generation-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, ['update_group_index', 'sub_group_index', 'sub_group_id', 'filter_group_index', 'neighbor_address', u'process_id', u'update_vrf_name', u'update_group_af_name', u'update_filter_group_index', u'refresh_filter_group_index', u'sub_group_index_xr', u'refresh_sub_group_index', u'refresh_sub_group_id', u'update_group_index_xr', u'update_main_table_version', u'update_vrf_table_rib_version', u'update_out_queue_messages', u'update_out_queue_size', u'refresh_update_out_queue_messages', u'refresh_update_out_queue_size', u'update_filter_group_messages', u'version', u'pending_target_version', u'next_resume_version', u'ack_version', u'synced_ack_version', u'outstanding_version_count', u'update_refresh_version', u'refresh_requested_target_version', u'update_refresh_target_version', u'refresh_pending_target_version', u'refresh_next_resume_version', u'refresh_ack_version', u'last_default_originate_age', u'default_originate_state', u'default_originate_internal_context', u'is_eor_outstanding', u'outbound_refresh_count', u'inbound_refresh_count', u'is_update_group_timer_running', u'current_update_group_af_name', u'last_update_group_af_name', u'last_update_queued_age', u'last_refresh_update_queued_age', u'last_update_write_age', u'last_refresh_update_write_age'], name, value)


                                        class UpdateNeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, self).__init__()

                                                self.yang_name = "update-neighbor-address"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "update-neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "update-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class LastSubGroupAddTimestamp(Entity):
                                            """
                                            Last added time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, self).__init__()

                                                self.yang_name = "last-sub-group-add-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-sub-group-add-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastSubGroupRemoveTimestamp(Entity):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, self).__init__()

                                                self.yang_name = "last-sub-group-remove-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-sub-group-remove-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastFilterGroupAddTimestamp(Entity):
                                            """
                                            Last added time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, self).__init__()

                                                self.yang_name = "last-filter-group-add-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-filter-group-add-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastFilterGroupRemoveTimestamp(Entity):
                                            """
                                            Last removed time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, self).__init__()

                                                self.yang_name = "last-filter-group-remove-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-filter-group-remove-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstDefaultOriginateTimestamp(Entity):
                                            """
                                            First default\-origination time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, self).__init__()

                                                self.yang_name = "first-default-originate-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-default-originate-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastDefaultOriginateTimestamp(Entity):
                                            """
                                            Last default\-origination time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, self).__init__()

                                                self.yang_name = "last-default-originate-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-default-originate-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateGroupStartTimestamp(Entity):
                                            """
                                            Last update\-group timer start
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, self).__init__()

                                                self.yang_name = "last-update-group-start-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-group-start-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateGroupExpiryTimestamp(Entity):
                                            """
                                            Last update\-group timer expiry
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, self).__init__()

                                                self.yang_name = "last-update-group-expiry-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-group-expiry-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstUpdateQueuedTimestamp(Entity):
                                            """
                                            First update queued time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "first-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-update-queued-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateQueuedTimestamp(Entity):
                                            """
                                            Last update queued time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-queued-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRefreshUpdateQueuedTimestamp(Entity):
                                            """
                                            Last refresh update queued time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, self).__init__()

                                                self.yang_name = "last-refresh-update-queued-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-refresh-update-queued-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstUpdateWriteTimestamp(Entity):
                                            """
                                            First update write time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "first-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-update-write-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateWriteTimestamp(Entity):
                                            """
                                            Last update write time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "last-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-write-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRefreshUpdateWriteTimestamp(Entity):
                                            """
                                            Last refresh update write time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, self).__init__()

                                                self.yang_name = "last-refresh-update-write-timestamp"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-refresh-update-write-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class UpdateStatistics(Entity):
                                            """
                                            Update statistics
                                            
                                            .. attribute:: last_update_discard_timestamp
                                            
                                            	Last Discarded time
                                            	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                            
                                            .. attribute:: last_update_cleared_timestamp
                                            
                                            	Last Cleared time
                                            	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                            
                                            .. attribute:: last_update_throttle_timestamp
                                            
                                            	Last Throttled time
                                            	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                            
                                            .. attribute:: last_update_recovery_timestamp
                                            
                                            	Last Recovery time
                                            	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                            
                                            .. attribute:: last_update_memory_allocation_fail_timestamp
                                            
                                            	Memory allocation failure time
                                            	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                            
                                            .. attribute:: update_out_queue_messages_high
                                            
                                            	OutQueue High Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cumulative
                                            
                                            	OutQueue Cumulative Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_discarded
                                            
                                            	OutQueue Discarded Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_messages_cleared
                                            
                                            	OutQueue Cleared Messages
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_high
                                            
                                            	OutQueue Hi Size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: update_out_queue_size_cumulative
                                            
                                            	OutQueue Cumulative Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_discarded
                                            
                                            	OutQueue Discarded Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: update_out_queue_size_cleared
                                            
                                            	OutQueue Cleared Size
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: last_update_discard_age
                                            
                                            	Time since last Discard event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: last_update_cleard_age
                                            
                                            	Time since last Clear event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_throttle_count
                                            
                                            	Throttle Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_throttle_age
                                            
                                            	Time since last Throttle event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_recovery_count
                                            
                                            	Recovery Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_recovery_age
                                            
                                            	Time since last Recovery event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: update_memory_allocation_fail_count
                                            
                                            	Memory allocation failure count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_update_memory_allocation_fail_age
                                            
                                            	Time since last memory allocation failure event (in seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, self).__init__()

                                                self.yang_name = "update-statistics"
                                                self.yang_parent_name = "update-generation-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                                self._leafs = OrderedDict([
                                                    ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                    ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                    ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                    ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                    ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                    ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                    ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                    ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                    ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                    ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                    ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                    ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                    ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                    ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                    ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                    ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                                ])
                                                self.update_out_queue_messages_high = None
                                                self.update_out_queue_messages_cumulative = None
                                                self.update_out_queue_messages_discarded = None
                                                self.update_out_queue_messages_cleared = None
                                                self.update_out_queue_size_high = None
                                                self.update_out_queue_size_cumulative = None
                                                self.update_out_queue_size_discarded = None
                                                self.update_out_queue_size_cleared = None
                                                self.last_update_discard_age = None
                                                self.last_update_cleard_age = None
                                                self.update_throttle_count = None
                                                self.last_update_throttle_age = None
                                                self.update_recovery_count = None
                                                self.last_update_recovery_age = None
                                                self.update_memory_allocation_fail_count = None
                                                self.last_update_memory_allocation_fail_age = None

                                                self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                                self.last_update_discard_timestamp.parent = self
                                                self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                                self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                                self.last_update_cleared_timestamp.parent = self
                                                self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                                self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                                self.last_update_throttle_timestamp.parent = self
                                                self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                                self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                                self.last_update_recovery_timestamp.parent = self
                                                self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                                self._segment_path = lambda: "update-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                            class LastUpdateDiscardTimestamp(Entity):
                                                """
                                                Last Discarded time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                    self.yang_name = "last-update-discard-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-discard-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateClearedTimestamp(Entity):
                                                """
                                                Last Cleared time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                    self.yang_name = "last-update-cleared-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-cleared-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateThrottleTimestamp(Entity):
                                                """
                                                Last Throttled time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                    self.yang_name = "last-update-throttle-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-throttle-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateRecoveryTimestamp(Entity):
                                                """
                                                Last Recovery time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                    self.yang_name = "last-update-recovery-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-recovery-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                                """
                                                Memory allocation failure time
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                    self.yang_parent_name = "update-statistics"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateGenerationAddressFamily(Entity):
                                    """
                                    Update generation for address\-family
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Upate statistics
                                    	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_rib_version
                                    
                                    	RIB version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_min_neighbor_version
                                    
                                    	Minimum Neighbor version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_af
                                    
                                    	Current AF update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_af
                                    
                                    	Configured AF update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_subgrp_ebgp
                                    
                                    	Current EBGP sub\-group update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_subgrp_ebgp
                                    
                                    	Configured EBGP sub\-group update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_sub_group_ibgp
                                    
                                    	Current IBGP sub\-group update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_sub_group_ibgp
                                    
                                    	Configured IBGP sub\-group update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messsages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is Update throttled
                                    	**type**\: bool
                                    
                                    .. attribute:: update_update_group_count
                                    
                                    	Update\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: update_vrfaf_name
                                    
                                    	Address family identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_rd_version
                                    
                                    	RD Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_update_group_count
                                    
                                    	VRF Table update\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_sub_group_count
                                    
                                    	VRF Table sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_sub_group_throttled_count
                                    
                                    	VRF Table throttled sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_count
                                    
                                    	VRF Table refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_refresh_sub_group_throttled_count
                                    
                                    	VRF Table throttled refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_table_filter_group_count
                                    
                                    	VRF Table filter\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_neighbor_count
                                    
                                    	VRF Table neighbor count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily, self).__init__()

                                        self.yang_name = "update-generation-address-family"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics))])
                                        self._leafs = OrderedDict([
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                            ('update_rib_version', (YLeaf(YType.uint32, 'update-rib-version'), ['int'])),
                                            ('update_min_neighbor_version', (YLeaf(YType.uint32, 'update-min-neighbor-version'), ['int'])),
                                            ('current_update_limit_af', (YLeaf(YType.uint32, 'current-update-limit-af'), ['int'])),
                                            ('configured_update_limit_af', (YLeaf(YType.uint32, 'configured-update-limit-af'), ['int'])),
                                            ('current_update_limit_subgrp_ebgp', (YLeaf(YType.uint32, 'current-update-limit-subgrp-ebgp'), ['int'])),
                                            ('configured_update_limit_subgrp_ebgp', (YLeaf(YType.uint32, 'configured-update-limit-subgrp-ebgp'), ['int'])),
                                            ('current_update_limit_sub_group_ibgp', (YLeaf(YType.uint32, 'current-update-limit-sub-group-ibgp'), ['int'])),
                                            ('configured_update_limit_sub_group_ibgp', (YLeaf(YType.uint32, 'configured-update-limit-sub-group-ibgp'), ['int'])),
                                            ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                            ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                            ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                                            ('update_update_group_count', (YLeaf(YType.uint32, 'update-update-group-count'), ['int'])),
                                            ('update_sub_group_count', (YLeaf(YType.uint32, 'update-sub-group-count'), ['int'])),
                                            ('sub_group_throttled_count', (YLeaf(YType.uint32, 'sub-group-throttled-count'), ['int'])),
                                            ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                            ('refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'refresh-sub-group-throttled-count'), ['int'])),
                                            ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                            ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                            ('update_table_vrf_name', (YLeaf(YType.str, 'update-table-vrf-name'), ['str'])),
                                            ('update_vrfaf_name', (YLeaf(YType.uint32, 'update-vrfaf-name'), ['int'])),
                                            ('update_vrf_rd_version', (YLeaf(YType.uint32, 'update-vrf-rd-version'), ['int'])),
                                            ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                            ('table_update_group_count', (YLeaf(YType.uint32, 'table-update-group-count'), ['int'])),
                                            ('update_table_sub_group_count', (YLeaf(YType.uint32, 'update-table-sub-group-count'), ['int'])),
                                            ('table_sub_group_throttled_count', (YLeaf(YType.uint32, 'table-sub-group-throttled-count'), ['int'])),
                                            ('table_refresh_sub_group_count', (YLeaf(YType.uint32, 'table-refresh-sub-group-count'), ['int'])),
                                            ('table_refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'table-refresh-sub-group-throttled-count'), ['int'])),
                                            ('update_table_filter_group_count', (YLeaf(YType.uint32, 'update-table-filter-group-count'), ['int'])),
                                            ('table_neighbor_count', (YLeaf(YType.uint32, 'table-neighbor-count'), ['int'])),
                                        ])
                                        self.update_group_af_name = None
                                        self.update_main_table_version = None
                                        self.update_rib_version = None
                                        self.update_min_neighbor_version = None
                                        self.current_update_limit_af = None
                                        self.configured_update_limit_af = None
                                        self.current_update_limit_subgrp_ebgp = None
                                        self.configured_update_limit_subgrp_ebgp = None
                                        self.current_update_limit_sub_group_ibgp = None
                                        self.configured_update_limit_sub_group_ibgp = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_throttled = None
                                        self.update_update_group_count = None
                                        self.update_sub_group_count = None
                                        self.sub_group_throttled_count = None
                                        self.refresh_sub_group_count = None
                                        self.refresh_sub_group_throttled_count = None
                                        self.filter_group_count = None
                                        self.neighbor_count = None
                                        self.update_table_vrf_name = None
                                        self.update_vrfaf_name = None
                                        self.update_vrf_rd_version = None
                                        self.update_vrf_table_rib_version = None
                                        self.table_update_group_count = None
                                        self.update_table_sub_group_count = None
                                        self.table_sub_group_throttled_count = None
                                        self.table_refresh_sub_group_count = None
                                        self.table_refresh_sub_group_throttled_count = None
                                        self.update_table_filter_group_count = None
                                        self.table_neighbor_count = None

                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._segment_path = lambda: "update-generation-address-family"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily, [u'update_group_af_name', u'update_main_table_version', u'update_rib_version', u'update_min_neighbor_version', u'current_update_limit_af', u'configured_update_limit_af', u'current_update_limit_subgrp_ebgp', u'configured_update_limit_subgrp_ebgp', u'current_update_limit_sub_group_ibgp', u'configured_update_limit_sub_group_ibgp', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled', u'update_update_group_count', u'update_sub_group_count', u'sub_group_throttled_count', u'refresh_sub_group_count', u'refresh_sub_group_throttled_count', u'filter_group_count', u'neighbor_count', u'update_table_vrf_name', u'update_vrfaf_name', u'update_vrf_rd_version', u'update_vrf_table_rib_version', u'table_update_group_count', u'update_table_sub_group_count', u'table_sub_group_throttled_count', u'table_refresh_sub_group_count', u'table_refresh_sub_group_throttled_count', u'update_table_filter_group_count', u'table_neighbor_count'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Upate statistics
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                            ])
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_size_high = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_cleared = None
                                            self.last_update_discard_age = None
                                            self.last_update_cleard_age = None
                                            self.update_throttle_count = None
                                            self.last_update_throttle_age = None
                                            self.update_recovery_count = None
                                            self.last_update_recovery_age = None
                                            self.update_memory_allocation_fail_count = None
                                            self.last_update_memory_allocation_fail_age = None

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._segment_path = lambda: "update-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-discard-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-cleared-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-throttle-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-recovery-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class Dampenings(Entity):
                                    """
                                    The BGP Dampening table
                                    
                                    .. attribute:: dampening
                                    
                                    	A BGP Dampening table entry
                                    	**type**\: list of  		 :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings, self).__init__()

                                        self.yang_name = "dampenings"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("dampening", ("dampening", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening))])
                                        self._leafs = OrderedDict()

                                        self.dampening = YList(self)
                                        self._segment_path = lambda: "dampenings"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings, [], name, value)


                                    class Dampening(Entity):
                                        """
                                        A BGP Dampening table entry
                                        
                                        .. attribute:: reuse
                                        
                                        	Reuse array index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: version
                                        
                                        	Version number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rd
                                        
                                        	Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: network
                                        
                                        	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                        	**type**\: str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_rd
                                        
                                        	Source Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: orig_source_rd
                                        
                                        	Original Source Route Distinguisher value
                                        	**type**\: str
                                        
                                        .. attribute:: path_id
                                        
                                        	Received Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "dampenings"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('reuse', (YLeaf(YType.uint32, 'reuse'), ['int'])),
                                                ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                                ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                                ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                                ('length', (YLeaf(YType.uint32, 'length'), ['int'])),
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                                ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                                ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.reuse = None
                                            self.version = None
                                            self.rd = None
                                            self.network = None
                                            self.length = None
                                            self.neighbor_address = None
                                            self.source_rd = None
                                            self.orig_source_rd = None
                                            self.path_id = None
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "dampening"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening, ['reuse', 'version', 'rd', 'network', 'length', 'neighbor_address', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "dampening"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class PrefixFilters(Entity):
                                    """
                                    The BGP Prefix Filter table
                                    
                                    .. attribute:: prefix_filter
                                    
                                    	A BGP prefix filter table entry
                                    	**type**\: list of  		 :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters, self).__init__()

                                        self.yang_name = "prefix-filters"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-filter", ("prefix_filter", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter))])
                                        self._leafs = OrderedDict()

                                        self.prefix_filter = YList(self)
                                        self._segment_path = lambda: "prefix-filters"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters, [], name, value)


                                    class PrefixFilter(Entity):
                                        """
                                        A BGP prefix filter table entry
                                        
                                        .. attribute:: neighbor_address  (key)
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                        
                                        .. attribute:: prefix_list_info
                                        
                                        	Prefix list
                                        	**type**\:  :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identfier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter, self).__init__()

                                            self.yang_name = "prefix-filter"
                                            self.yang_parent_name = "prefix-filters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['neighbor_address']
                                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr)), ("prefix-list-info", ("prefix_list_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo))])
                                            self._leafs = OrderedDict([
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.neighbor_address = None
                                            self.af_name = None

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                            self.prefix_list_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                            self.prefix_list_info.parent = self
                                            self._children_name_map["prefix_list_info"] = "prefix-list-info"
                                            self._segment_path = lambda: "prefix-filter" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter, ['neighbor_address', u'af_name'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "prefix-filter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address-xr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PrefixListInfo(Entity):
                                            """
                                            Prefix list
                                            
                                            .. attribute:: bgp_pfxlst
                                            
                                            	bgp pfxlst
                                            	**type**\: list of  		 :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, self).__init__()

                                                self.yang_name = "prefix-list-info"
                                                self.yang_parent_name = "prefix-filter"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-pfxlst", ("bgp_pfxlst", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst))])
                                                self._leafs = OrderedDict()

                                                self.bgp_pfxlst = YList(self)
                                                self._segment_path = lambda: "prefix-list-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, [], name, value)


                                            class BgpPfxlst(Entity):
                                                """
                                                bgp pfxlst
                                                
                                                .. attribute:: bgp_prefix
                                                
                                                	BGP prefix
                                                	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_prefix_grant
                                                
                                                	TRUE = permit, FALSE = deny
                                                	**type**\: bool
                                                
                                                .. attribute:: min_prefix_length
                                                
                                                	Minimum prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: max_prefix_length
                                                
                                                	Maximum prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, self).__init__()

                                                    self.yang_name = "bgp-pfxlst"
                                                    self.yang_parent_name = "prefix-list-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix))])
                                                    self._leafs = OrderedDict([
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('is_prefix_grant', (YLeaf(YType.boolean, 'is-prefix-grant'), ['bool'])),
                                                        ('min_prefix_length', (YLeaf(YType.uint8, 'min-prefix-length'), ['int'])),
                                                        ('max_prefix_length', (YLeaf(YType.uint8, 'max-prefix-length'), ['int'])),
                                                    ])
                                                    self.sequence_number = None
                                                    self.is_prefix_grant = None
                                                    self.min_prefix_length = None
                                                    self.max_prefix_length = None

                                                    self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                    self.bgp_prefix.parent = self
                                                    self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                    self._segment_path = lambda: "bgp-pfxlst"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, [u'sequence_number', u'is_prefix_grant', u'min_prefix_length', u'max_prefix_length'], name, value)


                                                class BgpPrefix(Entity):
                                                    """
                                                    BGP prefix
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	Prefix
                                                    	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                    
                                                    .. attribute:: prefix_length
                                                    
                                                    	Prefix length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, self).__init__()

                                                        self.yang_name = "bgp-prefix"
                                                        self.yang_parent_name = "bgp-pfxlst"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix))])
                                                        self._leafs = OrderedDict([
                                                            ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                        ])
                                                        self.prefix_length = None

                                                        self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                        self.prefix.parent = self
                                                        self._children_name_map["prefix"] = "prefix"
                                                        self._segment_path = lambda: "bgp-prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, [u'prefix_length'], name, value)


                                                    class Prefix(Entity):
                                                        """
                                                        Prefix
                                                        
                                                        .. attribute:: l2vpn_vpls_address
                                                        
                                                        	L2VPN VPLS Addr
                                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                        
                                                        .. attribute:: l2vpn_mspw_address
                                                        
                                                        	L2VPN MSPW Addr
                                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                        
                                                        .. attribute:: ipv4_sr_policy_address
                                                        
                                                        	IPV4 Policy Addr
                                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                        
                                                        .. attribute:: ipv6_sr_policy_address
                                                        
                                                        	IPV6 Policy Addr
                                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                        
                                                        .. attribute:: afi
                                                        
                                                        	AFI
                                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                        
                                                        .. attribute:: ipv4_address
                                                        
                                                        	IPv4 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_mcast_address
                                                        
                                                        	IPv4 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_label_address
                                                        
                                                        	IPv4 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4_tunnel_address
                                                        
                                                        	IPv4 Tunnel
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4_mdt_address
                                                        
                                                        	IPv4 MDT Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                        
                                                        .. attribute:: ipv4vpn_address
                                                        
                                                        	IPv4 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv4vpna_mcastddress
                                                        
                                                        	IPv4 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPV6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_mcast_address
                                                        
                                                        	IPV6 Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6_label_address
                                                        
                                                        	IPv6 Label Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_address
                                                        
                                                        	IPv6 VPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: ipv6vpn_mcast_address
                                                        
                                                        	IPv6 VPN Mcast Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: rt_constraint_address
                                                        
                                                        	RT Constrt Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                                        
                                                        .. attribute:: ipv6mvpn_address
                                                        
                                                        	MVPN addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                                        
                                                        .. attribute:: ipv4mvpn_address
                                                        
                                                        	MVPN4 addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                                        
                                                        .. attribute:: l2vpn_evpn_address
                                                        
                                                        	L2VPN EVPN Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                                        
                                                        .. attribute:: ls_ls_address
                                                        
                                                        	LINKSTATE LINKSTATE Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]+
                                                        
                                                        .. attribute:: ipv4_flowspec_address
                                                        
                                                        	IPV4 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6_flowspec_address
                                                        
                                                        	IPV6 Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv4vpn_flowspec_address
                                                        
                                                        	IPV4 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        .. attribute:: ipv6vpn_flowspec_address
                                                        
                                                        	IPV6 VPN Flowspec Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, self).__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "bgp-prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                            self._leafs = OrderedDict([
                                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                            ])
                                                            self.afi = None
                                                            self.ipv4_address = None
                                                            self.ipv4_mcast_address = None
                                                            self.ipv4_label_address = None
                                                            self.ipv4_tunnel_address = None
                                                            self.ipv4_mdt_address = None
                                                            self.ipv4vpn_address = None
                                                            self.ipv4vpna_mcastddress = None
                                                            self.ipv6_address = None
                                                            self.ipv6_mcast_address = None
                                                            self.ipv6_label_address = None
                                                            self.ipv6vpn_address = None
                                                            self.ipv6vpn_mcast_address = None
                                                            self.rt_constraint_address = None
                                                            self.ipv6mvpn_address = None
                                                            self.ipv4mvpn_address = None
                                                            self.l2vpn_evpn_address = None
                                                            self.ls_ls_address = None
                                                            self.ipv4_flowspec_address = None
                                                            self.ipv6_flowspec_address = None
                                                            self.ipv4vpn_flowspec_address = None
                                                            self.ipv6vpn_flowspec_address = None

                                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                            self.l2vpn_vpls_address.parent = self
                                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                            self.l2vpn_mspw_address.parent = self
                                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                            self.ipv4_sr_policy_address.parent = self
                                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                            self.ipv6_sr_policy_address.parent = self
                                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                            self._segment_path = lambda: "prefix"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                        class L2vpnVplsAddress(Entity):
                                                            """
                                                            L2VPN VPLS Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                                self.yang_name = "l2vpn-vpls-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                        class L2vpnMspwAddress(Entity):
                                                            """
                                                            L2VPN MSPW Addr
                                                            
                                                            .. attribute:: l2vpn_address
                                                            
                                                            	l2vpn address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                                self.yang_name = "l2vpn-mspw-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                                ])
                                                                self.l2vpn_address = None
                                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                        class Ipv4SrPolicyAddress(Entity):
                                                            """
                                                            IPV4 Policy Addr
                                                            
                                                            .. attribute:: ipv4_srpolicy_address
                                                            
                                                            	ipv4 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv4-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv4_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                        class Ipv6SrPolicyAddress(Entity):
                                                            """
                                                            IPV6 Policy Addr
                                                            
                                                            .. attribute:: ipv6_srpolicy_address
                                                            
                                                            	ipv6 srpolicy address
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                                self.yang_name = "ipv6-sr-policy-address"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                                ])
                                                                self.ipv6_srpolicy_address = None
                                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class Attributes(Entity):
                                    """
                                    The BGP Attribute table
                                    
                                    .. attribute:: attribute
                                    
                                    	A BGP Attribute table entry
                                    	**type**\: list of  		 :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes, self).__init__()

                                        self.yang_name = "attributes"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("attribute", ("attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute))])
                                        self._leafs = OrderedDict()

                                        self.attribute = YList(self)
                                        self._segment_path = lambda: "attributes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes, [], name, value)


                                    class Attribute(Entity):
                                        """
                                        A BGP Attribute table entry
                                        
                                        .. attribute:: attribute_iid
                                        
                                        	Attribute IID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_cache_bucket
                                        
                                        	Attribute cache bucket
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_cache_id
                                        
                                        	Attribute cache ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_info
                                        
                                        	Attributes
                                        	**type**\:  :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: attribute_instance_id
                                        
                                        	Attribute Instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: attribute_structure_id
                                        
                                        	ID of attribute structure
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_structure_hash_value
                                        
                                        	Hash value for attribute structure
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_count
                                        
                                        	Number of paths which use this attribute structure
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute, self).__init__()

                                            self.yang_name = "attribute"
                                            self.yang_parent_name = "attributes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("attribute-info", ("attribute_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo))])
                                            self._leafs = OrderedDict([
                                                ('attribute_iid', (YLeaf(YType.uint32, 'attribute-iid'), ['int'])),
                                                ('attribute_cache_bucket', (YLeaf(YType.uint32, 'attribute-cache-bucket'), ['int'])),
                                                ('attribute_cache_id', (YLeaf(YType.uint32, 'attribute-cache-id'), ['int'])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('attribute_instance_id', (YLeaf(YType.uint8, 'attribute-instance-id'), ['int'])),
                                                ('attribute_structure_id', (YLeaf(YType.uint32, 'attribute-structure-id'), ['int'])),
                                                ('attribute_structure_hash_value', (YLeaf(YType.uint32, 'attribute-structure-hash-value'), ['int'])),
                                                ('reference_count', (YLeaf(YType.uint32, 'reference-count'), ['int'])),
                                            ])
                                            self.attribute_iid = None
                                            self.attribute_cache_bucket = None
                                            self.attribute_cache_id = None
                                            self.process_instance_id = None
                                            self.attribute_instance_id = None
                                            self.attribute_structure_id = None
                                            self.attribute_structure_hash_value = None
                                            self.reference_count = None

                                            self.attribute_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                            self.attribute_info.parent = self
                                            self._children_name_map["attribute_info"] = "attribute-info"
                                            self._segment_path = lambda: "attribute"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute, ['attribute_iid', 'attribute_cache_bucket', 'attribute_cache_id', u'process_instance_id', u'attribute_instance_id', u'attribute_structure_id', u'attribute_structure_hash_value', u'reference_count'], name, value)


                                        class AttributeInfo(Entity):
                                            """
                                            Attributes
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo, self).__init__()

                                                self.yang_name = "attribute-info"
                                                self.yang_parent_name = "attribute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attribute-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attribute-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class Information(Entity):
                            """
                            Meta data for VRF
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{16}
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information, self).__init__()

                                self.yang_name = "information"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                ])
                                self.route_distinguisher = None
                                self._segment_path = lambda: "information"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Information, [u'route_distinguisher'], name, value)


                        class UpdateInboundFilterVrf(Entity):
                            """
                            Update inbound filtering information for the VRF
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_neighbor_count
                            
                            	Count of neighbors that received filtered messages
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered messages received event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf, self).__init__()

                                self.yang_name = "update-inbound-filter-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("last-update-filtered-timestamp", ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp))])
                                self._leafs = OrderedDict([
                                    ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                    ('update_filtered_message_count', (YLeaf(YType.uint32, 'update-filtered-message-count'), ['int'])),
                                    ('update_filtered_neighbor_count', (YLeaf(YType.uint32, 'update-filtered-neighbor-count'), ['int'])),
                                    ('last_update_filtered_age', (YLeaf(YType.uint32, 'last-update-filtered-age'), ['int'])),
                                ])
                                self.update_vrf_name = None
                                self.update_filtered_message_count = None
                                self.update_filtered_neighbor_count = None
                                self.last_update_filtered_age = None

                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                                self._segment_path = lambda: "update-inbound-filter-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf, [u'update_vrf_name', u'update_filtered_message_count', u'update_filtered_neighbor_count', u'last_update_filtered_age'], name, value)


                            class LastUpdateFilteredTimestamp(Entity):
                                """
                                Last Filtered messages received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "last-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-vrf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-update-filtered-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                        class Postits(Entity):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: postit
                            
                            	A BGP Postit table entry
                            	**type**\: list of  		 :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits, self).__init__()

                                self.yang_name = "postits"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("postit", ("postit", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit))])
                                self._leafs = OrderedDict()

                                self.postit = YList(self)
                                self._segment_path = lambda: "postits"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits, [], name, value)


                            class Postit(Entity):
                                """
                                A BGP Postit table entry
                                
                                .. attribute:: neighbor_address  (key)
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbors_address
                                
                                	Neighbor Addr
                                	**type**\:  :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress>`
                                
                                .. attribute:: vrf_name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: connect_state
                                
                                	State
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: start_time
                                
                                	StartTime
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: neighbor_af
                                
                                	Neighbor Afi
                                	**type**\: list of  		 :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborAf>`
                                
                                .. attribute:: postit_info
                                
                                	Postit Info
                                	**type**\: list of  		 :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit, self).__init__()

                                    self.yang_name = "postit"
                                    self.yang_parent_name = "postits"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_address']
                                    self._child_classes = OrderedDict([("neighbors-address", ("neighbors_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress)), ("neighbor-af", ("neighbor_af", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborAf)), ("postit-info", ("postit_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('connect_state', (YLeaf(YType.uint32, 'connect-state'), ['int'])),
                                        ('start_time', (YLeaf(YType.uint32, 'start-time'), ['int'])),
                                        ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                    ])
                                    self.neighbor_address = None
                                    self.vrf_name = None
                                    self.connect_state = None
                                    self.start_time = None
                                    self.nsr_state = None

                                    self.neighbors_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress()
                                    self.neighbors_address.parent = self
                                    self._children_name_map["neighbors_address"] = "neighbors-address"

                                    self.neighbor_af = YList(self)
                                    self.postit_info = YList(self)
                                    self._segment_path = lambda: "postit" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit, ['neighbor_address', u'vrf_name', u'connect_state', u'start_time', u'nsr_state'], name, value)


                                class NeighborsAddress(Entity):
                                    """
                                    Neighbor Addr
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress, self).__init__()

                                        self.yang_name = "neighbors-address"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "neighbors-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbors-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NeighborAf(Entity):
                                    """
                                    Neighbor Afi
                                    
                                    .. attribute:: entry
                                    
                                    	Array entry
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborAf, self).__init__()

                                        self.yang_name = "neighbor-af"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "neighbor-af"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.NeighborAf, [u'entry'], name, value)


                                class PostitInfo(Entity):
                                    """
                                    Postit Info
                                    
                                    .. attribute:: postit_notification
                                    
                                    	Postit notification
                                    	**type**\:  :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification>`
                                    
                                    .. attribute:: postit_type
                                    
                                    	Postit Type
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_subtype
                                    
                                    	Postit Subtype
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_flags
                                    
                                    	Postit Flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_af_name
                                    
                                    	Postit Afi
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: postit_ts
                                    
                                    	Postit TS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: postit_direction
                                    
                                    	Postit Direction
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: postit_id
                                    
                                    	Postit ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: postit_policy
                                    
                                    	Policy
                                    	**type**\: str
                                    
                                    .. attribute:: postit_reset
                                    
                                    	Reset
                                    	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo, self).__init__()

                                        self.yang_name = "postit-info"
                                        self.yang_parent_name = "postit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("postit-notification", ("postit_notification", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification))])
                                        self._leafs = OrderedDict([
                                            ('postit_type', (YLeaf(YType.uint32, 'postit-type'), ['int'])),
                                            ('postit_subtype', (YLeaf(YType.uint32, 'postit-subtype'), ['int'])),
                                            ('postit_flags', (YLeaf(YType.uint8, 'postit-flags'), ['int'])),
                                            ('postit_af_name', (YLeaf(YType.enumeration, 'postit-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('postit_ts', (YLeaf(YType.uint64, 'postit-ts'), ['int'])),
                                            ('postit_direction', (YLeaf(YType.uint8, 'postit-direction'), ['int'])),
                                            ('postit_id', (YLeaf(YType.uint32, 'postit-id'), ['int'])),
                                            ('peer_id', (YLeaf(YType.uint32, 'peer-id'), ['int'])),
                                            ('postit_policy', (YLeaf(YType.str, 'postit-policy'), ['str'])),
                                            ('postit_reset', (YLeaf(YType.enumeration, 'postit-reset'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                        ])
                                        self.postit_type = None
                                        self.postit_subtype = None
                                        self.postit_flags = None
                                        self.postit_af_name = None
                                        self.postit_ts = None
                                        self.postit_direction = None
                                        self.postit_id = None
                                        self.peer_id = None
                                        self.postit_policy = None
                                        self.postit_reset = None

                                        self.postit_notification = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification()
                                        self.postit_notification.parent = self
                                        self._children_name_map["postit_notification"] = "postit-notification"
                                        self._segment_path = lambda: "postit-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo, [u'postit_type', u'postit_subtype', u'postit_flags', u'postit_af_name', u'postit_ts', u'postit_direction', u'postit_id', u'peer_id', u'postit_policy', u'postit_reset'], name, value)


                                    class PostitNotification(Entity):
                                        """
                                        Postit notification
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification, self).__init__()

                                            self.yang_name = "postit-notification"
                                            self.yang_parent_name = "postit-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData))])
                                            self._leafs = OrderedDict([
                                                ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                                ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                                ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                            ])
                                            self.time_since_last_notification = None
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "postit-notification"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "postit-notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "last-notification-data"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, [u'entry'], name, value)


                        class GlobalProcessInfo(Entity):
                            """
                            The Global Process information table
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf_>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\: str
                            
                            .. attribute:: vrfid
                            
                            	VRF ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo, self).__init__()

                                self.yang_name = "global-process-info"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf_))])
                                self._leafs = OrderedDict([
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('vrfid', (YLeaf(YType.uint32, 'vrfid'), ['int'])),
                                ])
                                self.vrf_name = None
                                self.vrfid = None

                                self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"

                                self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._segment_path = lambda: "global-process-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo, [u'vrf_name', u'vrfid'], name, value)


                            class Global(Entity):
                                """
                                Global information
                                
                                .. attribute:: in_standalone_mode
                                
                                	Standalone or Distributed mode
                                	**type**\: bool
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_name
                                
                                	Name of BGP instance
                                	**type**\: str
                                
                                .. attribute:: restart_count
                                
                                	No of times BGP has started
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_delay
                                
                                	Update delay timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: generic_scan_period
                                
                                	Period (in seconds) of generic scanner runs
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: confederation_id
                                
                                	Confederation ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: cluster_id
                                
                                	Cluster ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_cluster_id
                                
                                	Configured cluster ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_cluster_id_specified_as_ip
                                
                                	Cluster ID specified as an IP address
                                	**type**\: bool
                                
                                .. attribute:: asn_format
                                
                                	BGP AS Number Format
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start_configured
                                
                                	Configured segment\-routing Global Block start value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end_configured
                                
                                	Configured segment\-routing Global Block end value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_start
                                
                                	In use segment\-routing Global Block start value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: srgb_end
                                
                                	In use Segment\-routing Global Block end value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\: bool
                                
                                .. attribute:: graceful_maint_all_nbrs
                                
                                	Graceful Maintenance also for neighbors without GM configuration
                                	**type**\: bool
                                
                                .. attribute:: graceful_maint_retain_routes
                                
                                	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                                	**type**\: bool
                                
                                .. attribute:: process_rlimit
                                
                                	Platform RLIMIT max for the process
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_maximum_buffer_size
                                
                                	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_default_buffer_size
                                
                                	Default value for BMP buffer limit when a value is not configured
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_current_buffer_size
                                
                                	Current value for BMP buffer 
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_cur_maximum_buffer_size
                                
                                	Maximum limit user has configure using max\-buffer\-size command under bmp\-server
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: cluster_id_entry
                                
                                	All configured Cluster IDs
                                	**type**\: list of  		 :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global.ClusterIdEntry>`
                                
                                .. attribute:: color_id
                                
                                	All configured Color IDs
                                	**type**\: list of  		 :py:class:`ColorId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global.ColorId>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "global-process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("cluster-id-entry", ("cluster_id_entry", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global.ClusterIdEntry)), ("color-id", ("color_id", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global.ColorId))])
                                    self._leafs = OrderedDict([
                                        ('in_standalone_mode', (YLeaf(YType.boolean, 'in-standalone-mode'), ['bool'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('instance_name', (YLeaf(YType.str, 'instance-name'), ['str'])),
                                        ('restart_count', (YLeaf(YType.uint32, 'restart-count'), ['int'])),
                                        ('update_delay', (YLeaf(YType.uint32, 'update-delay'), ['int'])),
                                        ('generic_scan_period', (YLeaf(YType.uint16, 'generic-scan-period'), ['int'])),
                                        ('confederation_id', (YLeaf(YType.uint32, 'confederation-id'), ['int'])),
                                        ('cluster_id', (YLeaf(YType.uint32, 'cluster-id'), ['int'])),
                                        ('configured_cluster_id', (YLeaf(YType.uint32, 'configured-cluster-id'), ['int'])),
                                        ('is_cluster_id_specified_as_ip', (YLeaf(YType.boolean, 'is-cluster-id-specified-as-ip'), ['bool'])),
                                        ('asn_format', (YLeaf(YType.uint32, 'asn-format'), ['int'])),
                                        ('srgb_start_configured', (YLeaf(YType.uint32, 'srgb-start-configured'), ['int'])),
                                        ('srgb_end_configured', (YLeaf(YType.uint32, 'srgb-end-configured'), ['int'])),
                                        ('srgb_start', (YLeaf(YType.uint32, 'srgb-start'), ['int'])),
                                        ('srgb_end', (YLeaf(YType.uint32, 'srgb-end'), ['int'])),
                                        ('graceful_maintenance', (YLeaf(YType.boolean, 'graceful-maintenance'), ['bool'])),
                                        ('graceful_maint_all_nbrs', (YLeaf(YType.boolean, 'graceful-maint-all-nbrs'), ['bool'])),
                                        ('graceful_maint_retain_routes', (YLeaf(YType.boolean, 'graceful-maint-retain-routes'), ['bool'])),
                                        ('process_rlimit', (YLeaf(YType.uint64, 'process-rlimit'), ['int'])),
                                        ('bmp_maximum_buffer_size', (YLeaf(YType.uint64, 'bmp-maximum-buffer-size'), ['int'])),
                                        ('bmp_default_buffer_size', (YLeaf(YType.uint64, 'bmp-default-buffer-size'), ['int'])),
                                        ('bmp_current_buffer_size', (YLeaf(YType.uint64, 'bmp-current-buffer-size'), ['int'])),
                                        ('bmp_cur_maximum_buffer_size', (YLeaf(YType.uint64, 'bmp-cur-maximum-buffer-size'), ['int'])),
                                    ])
                                    self.in_standalone_mode = None
                                    self.local_as = None
                                    self.instance_name = None
                                    self.restart_count = None
                                    self.update_delay = None
                                    self.generic_scan_period = None
                                    self.confederation_id = None
                                    self.cluster_id = None
                                    self.configured_cluster_id = None
                                    self.is_cluster_id_specified_as_ip = None
                                    self.asn_format = None
                                    self.srgb_start_configured = None
                                    self.srgb_end_configured = None
                                    self.srgb_start = None
                                    self.srgb_end = None
                                    self.graceful_maintenance = None
                                    self.graceful_maint_all_nbrs = None
                                    self.graceful_maint_retain_routes = None
                                    self.process_rlimit = None
                                    self.bmp_maximum_buffer_size = None
                                    self.bmp_default_buffer_size = None
                                    self.bmp_current_buffer_size = None
                                    self.bmp_cur_maximum_buffer_size = None

                                    self.cluster_id_entry = YList(self)
                                    self.color_id = YList(self)
                                    self._segment_path = lambda: "global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global, [u'in_standalone_mode', u'local_as', u'instance_name', u'restart_count', u'update_delay', u'generic_scan_period', u'confederation_id', u'cluster_id', u'configured_cluster_id', u'is_cluster_id_specified_as_ip', u'asn_format', u'srgb_start_configured', u'srgb_end_configured', u'srgb_start', u'srgb_end', u'graceful_maintenance', u'graceful_maint_all_nbrs', u'graceful_maint_retain_routes', u'process_rlimit', u'bmp_maximum_buffer_size', u'bmp_default_buffer_size', u'bmp_current_buffer_size', u'bmp_cur_maximum_buffer_size'], name, value)


                                class ClusterIdEntry(Entity):
                                    """
                                    All configured Cluster IDs
                                    
                                    .. attribute:: cluster_id_val
                                    
                                    	Cluster ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: cluster_id_type
                                    
                                    	Cluster ID type\: number or IPv4 address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global.ClusterIdEntry, self).__init__()

                                        self.yang_name = "cluster-id-entry"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('cluster_id_val', (YLeaf(YType.uint32, 'cluster-id-val'), ['int'])),
                                            ('cluster_id_type', (YLeaf(YType.uint8, 'cluster-id-type'), ['int'])),
                                        ])
                                        self.cluster_id_val = None
                                        self.cluster_id_type = None
                                        self._segment_path = lambda: "cluster-id-entry"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global.ClusterIdEntry, [u'cluster_id_val', u'cluster_id_type'], name, value)


                                class ColorId(Entity):
                                    """
                                    All configured Color IDs
                                    
                                    .. attribute:: color_id_val
                                    
                                    	Color ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global.ColorId, self).__init__()

                                        self.yang_name = "color-id"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('color_id_val', (YLeaf(YType.uint32, 'color-id-val'), ['int'])),
                                        ])
                                        self.color_id_val = None
                                        self._segment_path = lambda: "color-id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Global.ColorId, [u'color_id_val'], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: vrf_is_active
                                
                                	VRF state
                                	**type**\: bool
                                
                                .. attribute:: route_distinguisher
                                
                                	Route Distinguisher
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: router_id
                                
                                	Router ID for the VRF
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: configured_router_id
                                
                                	Configured router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                                
                                	Redistribute iBGP into IGPs enabled
                                	**type**\: bool
                                
                                .. attribute:: is_fast_external_fallover_enabled
                                
                                	Fast external fallover enabled
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_missing_med_is_worst_enabled
                                
                                	Bestpath\: Treat missing MED as worst
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_always_compare_med_enabled
                                
                                	Bestpath\: Always compare MED
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_ignore_as_path_enabled
                                
                                	Bestpath\: Ignore AS path
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                                
                                	Bestpath\: Relax AS path for mpath
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                                
                                	Bestpath\: Compare MED from confed peer
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                                
                                	Bestpath\: Compare routerID for eBGP peers
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_aigp_ignore_enabled
                                
                                	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                                	**type**\: bool
                                
                                .. attribute:: is_bestpath_igp_metric_ignore_enabled
                                
                                	Bestpath\: Ignore IGP metric
                                	**type**\: bool
                                
                                .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                                
                                	Multipath\: Ignore everything AS path onwards for mpath
                                	**type**\: bool
                                
                                .. attribute:: is_enforce_first_as_enabled
                                
                                	Enforce first AS
                                	**type**\: bool
                                
                                .. attribute:: default_local_preference
                                
                                	Default local preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: keep_alive_time
                                
                                	Default keepalive timer (seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: hold_time
                                
                                	Default hold timer (seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: min_acceptable_hold_time
                                
                                	Default min acceptable hold time from neighbor(seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: is_neighbor_logging
                                
                                	Neighbor logging enabled
                                	**type**\: bool
                                
                                .. attribute:: is_default_metric_configured
                                
                                	Default metric configured
                                	**type**\: bool
                                
                                .. attribute:: default_metric
                                
                                	Default metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_default_originate_configured
                                
                                	Default route originate configured
                                	**type**\: bool
                                
                                .. attribute:: is_graceful_restart
                                
                                	Graceful restart enabled
                                	**type**\: bool
                                
                                .. attribute:: is_nsr
                                
                                	Non\-stop routing enabled
                                	**type**\: bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: stale_path_time
                                
                                	Stale path timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rpki_use_validity
                                
                                	Use RPKI validity for bestpath calculation
                                	**type**\: bool
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Allow invalid paths
                                	**type**\: bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Signal RPKI validity to iBGP peers
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "global-process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('vrf_is_active', (YLeaf(YType.boolean, 'vrf-is-active'), ['bool'])),
                                        ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                        ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                        ('configured_router_id', (YLeaf(YType.str, 'configured-router-id'), ['str'])),
                                        ('is_redistribute_ibgp_to_ig_ps_enabled', (YLeaf(YType.boolean, 'is-redistribute-ibgp-to-ig-ps-enabled'), ['bool'])),
                                        ('is_fast_external_fallover_enabled', (YLeaf(YType.boolean, 'is-fast-external-fallover-enabled'), ['bool'])),
                                        ('is_bestpath_missing_med_is_worst_enabled', (YLeaf(YType.boolean, 'is-bestpath-missing-med-is-worst-enabled'), ['bool'])),
                                        ('is_bestpath_always_compare_med_enabled', (YLeaf(YType.boolean, 'is-bestpath-always-compare-med-enabled'), ['bool'])),
                                        ('is_bestpath_ignore_as_path_enabled', (YLeaf(YType.boolean, 'is-bestpath-ignore-as-path-enabled'), ['bool'])),
                                        ('is_bestpath_as_path_mpath_relax_enabled', (YLeaf(YType.boolean, 'is-bestpath-as-path-mpath-relax-enabled'), ['bool'])),
                                        ('is_bestpath_compare_med_from_confed_peer_enabled', (YLeaf(YType.boolean, 'is-bestpath-compare-med-from-confed-peer-enabled'), ['bool'])),
                                        ('is_bestpath_compare_router_id_for_ebgp_peers_enabled', (YLeaf(YType.boolean, 'is-bestpath-compare-router-id-for-ebgp-peers-enabled'), ['bool'])),
                                        ('is_bestpath_aigp_ignore_enabled', (YLeaf(YType.boolean, 'is-bestpath-aigp-ignore-enabled'), ['bool'])),
                                        ('is_bestpath_igp_metric_ignore_enabled', (YLeaf(YType.boolean, 'is-bestpath-igp-metric-ignore-enabled'), ['bool'])),
                                        ('is_multipath_as_path_ignore_onwards_enabled', (YLeaf(YType.boolean, 'is-multipath-as-path-ignore-onwards-enabled'), ['bool'])),
                                        ('is_enforce_first_as_enabled', (YLeaf(YType.boolean, 'is-enforce-first-as-enabled'), ['bool'])),
                                        ('default_local_preference', (YLeaf(YType.uint32, 'default-local-preference'), ['int'])),
                                        ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                        ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                        ('min_acceptable_hold_time', (YLeaf(YType.uint16, 'min-acceptable-hold-time'), ['int'])),
                                        ('is_neighbor_logging', (YLeaf(YType.boolean, 'is-neighbor-logging'), ['bool'])),
                                        ('is_default_metric_configured', (YLeaf(YType.boolean, 'is-default-metric-configured'), ['bool'])),
                                        ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                        ('is_default_originate_configured', (YLeaf(YType.boolean, 'is-default-originate-configured'), ['bool'])),
                                        ('is_graceful_restart', (YLeaf(YType.boolean, 'is-graceful-restart'), ['bool'])),
                                        ('is_nsr', (YLeaf(YType.boolean, 'is-nsr'), ['bool'])),
                                        ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                        ('stale_path_time', (YLeaf(YType.uint32, 'stale-path-time'), ['int'])),
                                        ('rib_purge_timeout', (YLeaf(YType.uint32, 'rib-purge-timeout'), ['int'])),
                                        ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                        ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                        ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                    ])
                                    self.vrf_is_active = None
                                    self.route_distinguisher = None
                                    self.router_id = None
                                    self.configured_router_id = None
                                    self.is_redistribute_ibgp_to_ig_ps_enabled = None
                                    self.is_fast_external_fallover_enabled = None
                                    self.is_bestpath_missing_med_is_worst_enabled = None
                                    self.is_bestpath_always_compare_med_enabled = None
                                    self.is_bestpath_ignore_as_path_enabled = None
                                    self.is_bestpath_as_path_mpath_relax_enabled = None
                                    self.is_bestpath_compare_med_from_confed_peer_enabled = None
                                    self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = None
                                    self.is_bestpath_aigp_ignore_enabled = None
                                    self.is_bestpath_igp_metric_ignore_enabled = None
                                    self.is_multipath_as_path_ignore_onwards_enabled = None
                                    self.is_enforce_first_as_enabled = None
                                    self.default_local_preference = None
                                    self.keep_alive_time = None
                                    self.hold_time = None
                                    self.min_acceptable_hold_time = None
                                    self.is_neighbor_logging = None
                                    self.is_default_metric_configured = None
                                    self.default_metric = None
                                    self.is_default_originate_configured = None
                                    self.is_graceful_restart = None
                                    self.is_nsr = None
                                    self.restart_time = None
                                    self.stale_path_time = None
                                    self.rib_purge_timeout = None
                                    self.rpki_use_validity = None
                                    self.rpki_allow_invalid = None
                                    self.rpki_signal_ibgp = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.GlobalProcessInfo.Vrf_, [u'vrf_is_active', u'route_distinguisher', u'router_id', u'configured_router_id', u'is_redistribute_ibgp_to_ig_ps_enabled', u'is_fast_external_fallover_enabled', u'is_bestpath_missing_med_is_worst_enabled', u'is_bestpath_always_compare_med_enabled', u'is_bestpath_ignore_as_path_enabled', u'is_bestpath_as_path_mpath_relax_enabled', u'is_bestpath_compare_med_from_confed_peer_enabled', u'is_bestpath_compare_router_id_for_ebgp_peers_enabled', u'is_bestpath_aigp_ignore_enabled', u'is_bestpath_igp_metric_ignore_enabled', u'is_multipath_as_path_ignore_onwards_enabled', u'is_enforce_first_as_enabled', u'default_local_preference', u'keep_alive_time', u'hold_time', u'min_acceptable_hold_time', u'is_neighbor_logging', u'is_default_metric_configured', u'default_metric', u'is_default_originate_configured', u'is_graceful_restart', u'is_nsr', u'restart_time', u'stale_path_time', u'rib_purge_timeout', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp'], name, value)


                        class UpdateInboundErrorNeighbors(Entity):
                            """
                            Update inbound error information for all
                            neighbors
                            
                            .. attribute:: update_inbound_error_neighbor
                            
                            	Update inbound error information for neighbor
                            	**type**\: list of  		 :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors, self).__init__()

                                self.yang_name = "update-inbound-error-neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("update-inbound-error-neighbor", ("update_inbound_error_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor))])
                                self._leafs = OrderedDict()

                                self.update_inbound_error_neighbor = YList(self)
                                self._segment_path = lambda: "update-inbound-error-neighbors"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors, [], name, value)


                            class UpdateInboundErrorNeighbor(Entity):
                                """
                                Update inbound error information for neighbor
                                
                                .. attribute:: neighbor_address  (key)
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: first_update_malformed_timestamp
                                
                                	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                                
                                .. attribute:: last_update_malformed_timestamp
                                
                                	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                                
                                .. attribute:: first_update_memory_allocation_fail_timestamp
                                
                                	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: last_update_memory_allocation_fail_timestamp
                                
                                	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                                
                                .. attribute:: first_update_error_handling_reset_timestamp
                                
                                	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                                
                                .. attribute:: last_error_handling_reset_timestamp
                                
                                	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: update_error_handling_avoid_reset
                                
                                	Configure error\-handling to avoid resets
                                	**type**\: bool
                                
                                .. attribute:: total_update_message_count
                                
                                	Total update messages count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_malformed_message_count
                                
                                	Malformed messages count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_malformed_age
                                
                                	Time since last malformed message received event (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: update_memory_allocation_fail_count
                                
                                	Memory allocation failure count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_memory_allocation_fail_age
                                
                                	Time since last memory allocation failure event (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: update_error_handling_reset_count
                                
                                	Error\-handling reset count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_error_handling_reset_age
                                
                                	Time since last error\-handling reset event (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: update_error_message_list_count
                                
                                	Malformed messages list count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_total_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_action_count
                                
                                	Number of occurence of each action type since  session establishment
                                	**type**\: list of  		 :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                                
                                .. attribute:: update_error_message
                                
                                	List of malformed messages
                                	**type**\: list of  		 :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, self).__init__()

                                    self.yang_name = "update-inbound-error-neighbor"
                                    self.yang_parent_name = "update-inbound-error-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_address']
                                    self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress)), ("first-update-malformed-timestamp", ("first_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp)), ("last-update-malformed-timestamp", ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp)), ("first-update-memory-allocation-fail-timestamp", ("first_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp)), ("first-update-error-handling-reset-timestamp", ("first_update_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp)), ("last-error-handling-reset-timestamp", ("last_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp)), ("establishment-action-count", ("establishment_action_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount)), ("update-error-message", ("update_error_message", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                        ('update_error_handling_avoid_reset', (YLeaf(YType.boolean, 'update-error-handling-avoid-reset'), ['bool'])),
                                        ('total_update_message_count', (YLeaf(YType.uint32, 'total-update-message-count'), ['int'])),
                                        ('update_malformed_message_count', (YLeaf(YType.uint32, 'update-malformed-message-count'), ['int'])),
                                        ('last_update_malformed_age', (YLeaf(YType.uint32, 'last-update-malformed-age'), ['int'])),
                                        ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                        ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                        ('update_error_handling_reset_count', (YLeaf(YType.uint32, 'update-error-handling-reset-count'), ['int'])),
                                        ('last_error_handling_reset_age', (YLeaf(YType.uint32, 'last-error-handling-reset-age'), ['int'])),
                                        ('update_error_message_list_count', (YLeaf(YType.uint32, 'update-error-message-list-count'), ['int'])),
                                        ('update_attribute_discard_count', (YLeaf(YType.uint32, 'update-attribute-discard-count'), ['int'])),
                                        ('establishment_total_update_message_count', (YLeaf(YType.uint32, 'establishment-total-update-message-count'), ['int'])),
                                    ])
                                    self.neighbor_address = None
                                    self.update_vrf_name = None
                                    self.update_error_handling_avoid_reset = None
                                    self.total_update_message_count = None
                                    self.update_malformed_message_count = None
                                    self.last_update_malformed_age = None
                                    self.update_memory_allocation_fail_count = None
                                    self.last_update_memory_allocation_fail_age = None
                                    self.update_error_handling_reset_count = None
                                    self.last_error_handling_reset_age = None
                                    self.update_error_message_list_count = None
                                    self.update_attribute_discard_count = None
                                    self.establishment_total_update_message_count = None

                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                    self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                    self.first_update_malformed_timestamp.parent = self
                                    self._children_name_map["first_update_malformed_timestamp"] = "first-update-malformed-timestamp"

                                    self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                    self.last_update_malformed_timestamp.parent = self
                                    self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"

                                    self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                    self.first_update_memory_allocation_fail_timestamp.parent = self
                                    self._children_name_map["first_update_memory_allocation_fail_timestamp"] = "first-update-memory-allocation-fail-timestamp"

                                    self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                    self.last_update_memory_allocation_fail_timestamp.parent = self
                                    self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"

                                    self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                    self.first_update_error_handling_reset_timestamp.parent = self
                                    self._children_name_map["first_update_error_handling_reset_timestamp"] = "first-update-error-handling-reset-timestamp"

                                    self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                    self.last_error_handling_reset_timestamp.parent = self
                                    self._children_name_map["last_error_handling_reset_timestamp"] = "last-error-handling-reset-timestamp"

                                    self.establishment_action_count = YList(self)
                                    self.update_error_message = YList(self)
                                    self._segment_path = lambda: "update-inbound-error-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, ['neighbor_address', u'update_vrf_name', u'update_error_handling_avoid_reset', u'total_update_message_count', u'update_malformed_message_count', u'last_update_malformed_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age', u'update_error_handling_reset_count', u'last_error_handling_reset_age', u'update_error_message_list_count', u'update_attribute_discard_count', u'establishment_total_update_message_count'], name, value)


                                class UpdateNeighborAddress(Entity):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, self).__init__()

                                        self.yang_name = "update-neighbor-address"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "update-neighbor-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class FirstUpdateMalformedTimestamp(Entity):
                                    """
                                    First malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, self).__init__()

                                        self.yang_name = "first-update-malformed-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "first-update-malformed-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LastUpdateMalformedTimestamp(Entity):
                                    """
                                    Last malformed message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, self).__init__()

                                        self.yang_name = "last-update-malformed-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "last-update-malformed-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class FirstUpdateMemoryAllocationFailTimestamp(Entity):
                                    """
                                    First memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, self).__init__()

                                        self.yang_name = "first-update-memory-allocation-fail-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "first-update-memory-allocation-fail-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                    """
                                    Last memory allocation failure time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                        self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class FirstUpdateErrorHandlingResetTimestamp(Entity):
                                    """
                                    First error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, self).__init__()

                                        self.yang_name = "first-update-error-handling-reset-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "first-update-error-handling-reset-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LastErrorHandlingResetTimestamp(Entity):
                                    """
                                    Last error\-handling reset time\: time elapsed
                                    since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, self).__init__()

                                        self.yang_name = "last-error-handling-reset-timestamp"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "last-error-handling-reset-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class EstablishmentActionCount(Entity):
                                    """
                                    Number of occurence of each action type since
                                    
                                    session establishment
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, self).__init__()

                                        self.yang_name = "establishment-action-count"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "establishment-action-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, [u'entry'], name, value)


                                class UpdateErrorMessage(Entity):
                                    """
                                    List of malformed messages
                                    
                                    .. attribute:: update_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:  :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                    
                                    .. attribute:: update_message_reset_data
                                    
                                    	Reset data
                                    	**type**\:  :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                    
                                    .. attribute:: update_error_final_action
                                    
                                    	Error final action
                                    	**type**\:  :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                    
                                    .. attribute:: update_attribute_discard_count
                                    
                                    	Discarded attribute count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_error_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_error_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\: str
                                    
                                    .. attribute:: update_error_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\: bool
                                    
                                    .. attribute:: update_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of  		 :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                    
                                    .. attribute:: update_error_element
                                    
                                    	Error element list
                                    	**type**\: list of  		 :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, self).__init__()

                                        self.yang_name = "update-error-message"
                                        self.yang_parent_name = "update-inbound-error-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-message-timestamp", ("update_message_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp)), ("update-message-reset-data", ("update_message_reset_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData)), ("update-message-data", ("update_message_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData)), ("update-error-element", ("update_error_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement))])
                                        self._leafs = OrderedDict([
                                            ('update_error_final_action', (YLeaf(YType.enumeration, 'update-error-final-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdErrAction', '')])),
                                            ('update_attribute_discard_count', (YLeaf(YType.uint32, 'update-attribute-discard-count'), ['int'])),
                                            ('update_error_nlri_address_family', (YLeaf(YType.enumeration, 'update-error-nlri-address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('update_error_nlri_string', (YLeaf(YType.str, 'update-error-nlri-string'), ['str'])),
                                            ('update_error_nlri_string_truncated', (YLeaf(YType.boolean, 'update-error-nlri-string-truncated'), ['bool'])),
                                        ])
                                        self.update_error_final_action = None
                                        self.update_attribute_discard_count = None
                                        self.update_error_nlri_address_family = None
                                        self.update_error_nlri_string = None
                                        self.update_error_nlri_string_truncated = None

                                        self.update_message_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                        self.update_message_timestamp.parent = self
                                        self._children_name_map["update_message_timestamp"] = "update-message-timestamp"

                                        self.update_message_reset_data = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                        self.update_message_reset_data.parent = self
                                        self._children_name_map["update_message_reset_data"] = "update-message-reset-data"

                                        self.update_message_data = YList(self)
                                        self.update_error_element = YList(self)
                                        self._segment_path = lambda: "update-error-message"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, [u'update_error_final_action', u'update_attribute_discard_count', u'update_error_nlri_address_family', u'update_error_nlri_string', u'update_error_nlri_string_truncated'], name, value)


                                    class UpdateMessageTimestamp(Entity):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, self).__init__()

                                            self.yang_name = "update-message-timestamp"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "update-message-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateMessageResetData(Entity):
                                        """
                                        Reset data
                                        
                                        .. attribute:: update_error_reset_reason
                                        
                                        	Reset Reason
                                        	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                        
                                        .. attribute:: update_error_reset_notification_code
                                        
                                        	Notification code
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_error_reset_notification_sub_code
                                        
                                        	Notification sub code
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_reset_notification_data
                                        
                                        	Notification data
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_reset_notification_data_length
                                        
                                        	Notification data length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, self).__init__()

                                            self.yang_name = "update-message-reset-data"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update_error_reset_reason', (YLeaf(YType.enumeration, 'update-error-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                                ('update_error_reset_notification_code', (YLeaf(YType.uint8, 'update-error-reset-notification-code'), ['int'])),
                                                ('update_error_reset_notification_sub_code', (YLeaf(YType.uint16, 'update-error-reset-notification-sub-code'), ['int'])),
                                                ('update_error_reset_notification_data', (YLeaf(YType.str, 'update-error-reset-notification-data'), ['str'])),
                                                ('update_error_reset_notification_data_length', (YLeaf(YType.uint16, 'update-error-reset-notification-data-length'), ['int'])),
                                            ])
                                            self.update_error_reset_reason = None
                                            self.update_error_reset_notification_code = None
                                            self.update_error_reset_notification_sub_code = None
                                            self.update_error_reset_notification_data = None
                                            self.update_error_reset_notification_data_length = None
                                            self._segment_path = lambda: "update-message-reset-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, [u'update_error_reset_reason', u'update_error_reset_notification_code', u'update_error_reset_notification_sub_code', u'update_error_reset_notification_data', u'update_error_reset_notification_data_length'], name, value)


                                    class UpdateMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, self).__init__()

                                            self.yang_name = "update-message-data"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "update-message-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, [u'entry'], name, value)


                                    class UpdateErrorElement(Entity):
                                        """
                                        Error element list
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_length
                                        
                                        	Attribute Length [RFC4271\: BGP4]
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_data
                                        
                                        	Error data
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: update_error_data_length
                                        
                                        	Error data length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: update_error_action
                                        
                                        	Error action
                                        	**type**\:  :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, self).__init__()

                                            self.yang_name = "update-error-element"
                                            self.yang_parent_name = "update-error-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update_attribute_flags', (YLeaf(YType.uint8, 'update-attribute-flags'), ['int'])),
                                                ('update_attribute_code', (YLeaf(YType.uint8, 'update-attribute-code'), ['int'])),
                                                ('update_attribute_length', (YLeaf(YType.uint16, 'update-attribute-length'), ['int'])),
                                                ('update_error_data', (YLeaf(YType.str, 'update-error-data'), ['str'])),
                                                ('update_error_data_length', (YLeaf(YType.uint16, 'update-error-data-length'), ['int'])),
                                                ('update_error_action', (YLeaf(YType.enumeration, 'update-error-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdErrAction', '')])),
                                            ])
                                            self.update_attribute_flags = None
                                            self.update_attribute_code = None
                                            self.update_attribute_length = None
                                            self.update_error_data = None
                                            self.update_error_data_length = None
                                            self.update_error_action = None
                                            self._segment_path = lambda: "update-error-element"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, [u'update_attribute_flags', u'update_attribute_code', u'update_attribute_length', u'update_error_data', u'update_error_data_length', u'update_error_action'], name, value)


                        class UpdateInboundFilterNeighbors(Entity):
                            """
                            Update inbound filtering information for all
                            neighbors
                            
                            .. attribute:: update_inbound_filter_neighbor
                            
                            	Update inbound filtering information for neighbor
                            	**type**\: list of  		 :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors, self).__init__()

                                self.yang_name = "update-inbound-filter-neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("update-inbound-filter-neighbor", ("update_inbound_filter_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor))])
                                self._leafs = OrderedDict()

                                self.update_inbound_filter_neighbor = YList(self)
                                self._segment_path = lambda: "update-inbound-filter-neighbors"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors, [], name, value)


                            class UpdateInboundFilterNeighbor(Entity):
                                """
                                Update inbound filtering information for
                                neighbor
                                
                                .. attribute:: neighbor_address  (key)
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: update_neighbor_address
                                
                                	Neighbor address
                                	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                                
                                .. attribute:: first_update_filtered_timestamp
                                
                                	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                                
                                .. attribute:: last_update_filtered_timestamp
                                
                                	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                                
                                .. attribute:: update_vrf_name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: update_filter_logging_enabled
                                
                                	Logging is enabled
                                	**type**\: bool
                                
                                .. attribute:: configured_update_filter_message_buffer_count
                                
                                	Configured Filtered message buffer count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: operational_update_filter_message_buffer_count
                                
                                	Operational Filtered messages buffer count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filter_message_buffer_circular
                                
                                	Indicates if the message buffers are circular
                                	**type**\: bool
                                
                                .. attribute:: update_attribute_filter_group_name
                                
                                	Update attribute\-filter group name
                                	**type**\: str
                                
                                .. attribute:: operational_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled
                                	**type**\: bool
                                
                                .. attribute:: message_update_attribute_filtering_enabled
                                
                                	Attribute filtering is enabled for the current message being parsed
                                	**type**\: bool
                                
                                .. attribute:: total_filter_update_message_count
                                
                                	Total update messages count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_total_filter_update_message_count
                                
                                	Total update messages count since session establishment
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filtered_message_count
                                
                                	Filtered messages count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_update_filtered_message_count
                                
                                	Filtered messages count since session establishment
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_filtered_age
                                
                                	Time since last filtered message received event (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: update_filter_message_list_count
                                
                                	Filtered messages list count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_attribute_filter_attributes
                                
                                	List of attributes that can be filtered
                                	**type**\: list of  		 :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                                
                                .. attribute:: update_filter_message
                                
                                	List of filtered messages
                                	**type**\: list of  		 :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, self).__init__()

                                    self.yang_name = "update-inbound-filter-neighbor"
                                    self.yang_parent_name = "update-inbound-filter-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_address']
                                    self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress)), ("first-update-filtered-timestamp", ("first_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp)), ("last-update-filtered-timestamp", ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp)), ("update-attribute-filter-attributes", ("update_attribute_filter_attributes", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes)), ("update-filter-message", ("update_filter_message", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                        ('update_filter_logging_enabled', (YLeaf(YType.boolean, 'update-filter-logging-enabled'), ['bool'])),
                                        ('configured_update_filter_message_buffer_count', (YLeaf(YType.uint32, 'configured-update-filter-message-buffer-count'), ['int'])),
                                        ('operational_update_filter_message_buffer_count', (YLeaf(YType.uint32, 'operational-update-filter-message-buffer-count'), ['int'])),
                                        ('update_filter_message_buffer_circular', (YLeaf(YType.boolean, 'update-filter-message-buffer-circular'), ['bool'])),
                                        ('update_attribute_filter_group_name', (YLeaf(YType.str, 'update-attribute-filter-group-name'), ['str'])),
                                        ('operational_update_attribute_filtering_enabled', (YLeaf(YType.boolean, 'operational-update-attribute-filtering-enabled'), ['bool'])),
                                        ('message_update_attribute_filtering_enabled', (YLeaf(YType.boolean, 'message-update-attribute-filtering-enabled'), ['bool'])),
                                        ('total_filter_update_message_count', (YLeaf(YType.uint32, 'total-filter-update-message-count'), ['int'])),
                                        ('establishment_total_filter_update_message_count', (YLeaf(YType.uint32, 'establishment-total-filter-update-message-count'), ['int'])),
                                        ('update_filtered_message_count', (YLeaf(YType.uint32, 'update-filtered-message-count'), ['int'])),
                                        ('establishment_update_filtered_message_count', (YLeaf(YType.uint32, 'establishment-update-filtered-message-count'), ['int'])),
                                        ('last_update_filtered_age', (YLeaf(YType.uint32, 'last-update-filtered-age'), ['int'])),
                                        ('update_filter_message_list_count', (YLeaf(YType.uint32, 'update-filter-message-list-count'), ['int'])),
                                    ])
                                    self.neighbor_address = None
                                    self.update_vrf_name = None
                                    self.update_filter_logging_enabled = None
                                    self.configured_update_filter_message_buffer_count = None
                                    self.operational_update_filter_message_buffer_count = None
                                    self.update_filter_message_buffer_circular = None
                                    self.update_attribute_filter_group_name = None
                                    self.operational_update_attribute_filtering_enabled = None
                                    self.message_update_attribute_filtering_enabled = None
                                    self.total_filter_update_message_count = None
                                    self.establishment_total_filter_update_message_count = None
                                    self.update_filtered_message_count = None
                                    self.establishment_update_filtered_message_count = None
                                    self.last_update_filtered_age = None
                                    self.update_filter_message_list_count = None

                                    self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                    self.update_neighbor_address.parent = self
                                    self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                    self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                    self.first_update_filtered_timestamp.parent = self
                                    self._children_name_map["first_update_filtered_timestamp"] = "first-update-filtered-timestamp"

                                    self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                    self.last_update_filtered_timestamp.parent = self
                                    self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"

                                    self.update_attribute_filter_attributes = YList(self)
                                    self.update_filter_message = YList(self)
                                    self._segment_path = lambda: "update-inbound-filter-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, ['neighbor_address', u'update_vrf_name', u'update_filter_logging_enabled', u'configured_update_filter_message_buffer_count', u'operational_update_filter_message_buffer_count', u'update_filter_message_buffer_circular', u'update_attribute_filter_group_name', u'operational_update_attribute_filtering_enabled', u'message_update_attribute_filtering_enabled', u'total_filter_update_message_count', u'establishment_total_filter_update_message_count', u'update_filtered_message_count', u'establishment_update_filtered_message_count', u'last_update_filtered_age', u'update_filter_message_list_count'], name, value)


                                class UpdateNeighborAddress(Entity):
                                    """
                                    Neighbor address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, self).__init__()

                                        self.yang_name = "update-neighbor-address"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "update-neighbor-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class FirstUpdateFilteredTimestamp(Entity):
                                    """
                                    First filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, self).__init__()

                                        self.yang_name = "first-update-filtered-timestamp"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "first-update-filtered-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LastUpdateFilteredTimestamp(Entity):
                                    """
                                    Last filtered message received time\: time
                                    elapsed since 00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, self).__init__()

                                        self.yang_name = "last-update-filtered-timestamp"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "last-update-filtered-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateAttributeFilterAttributes(Entity):
                                    """
                                    List of attributes that can be filtered
                                    
                                    .. attribute:: last_update_filter_match_timestamp
                                    
                                    	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:  :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                    
                                    .. attribute:: update_internal_attribute_code
                                    
                                    	Internal attribute code [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    .. attribute:: update_filter_match_count
                                    
                                    	Filter match counter
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: establishment_update_filter_match_count
                                    
                                    	Filter match counter since last session establishment
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_filter_match_age
                                    
                                    	Time since this attribute was last filtered (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, self).__init__()

                                        self.yang_name = "update-attribute-filter-attributes"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("last-update-filter-match-timestamp", ("last_update_filter_match_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('update_internal_attribute_code', (YLeaf(YType.uint32, 'update-internal-attribute-code'), ['int'])),
                                            ('update_filter_action', (YLeaf(YType.enumeration, 'update-filter-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                            ('update_filter_match_count', (YLeaf(YType.uint32, 'update-filter-match-count'), ['int'])),
                                            ('establishment_update_filter_match_count', (YLeaf(YType.uint32, 'establishment-update-filter-match-count'), ['int'])),
                                            ('last_update_filter_match_age', (YLeaf(YType.uint32, 'last-update-filter-match-age'), ['int'])),
                                        ])
                                        self.update_internal_attribute_code = None
                                        self.update_filter_action = None
                                        self.update_filter_match_count = None
                                        self.establishment_update_filter_match_count = None
                                        self.last_update_filter_match_age = None

                                        self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                        self.last_update_filter_match_timestamp.parent = self
                                        self._children_name_map["last_update_filter_match_timestamp"] = "last-update-filter-match-timestamp"
                                        self._segment_path = lambda: "update-attribute-filter-attributes"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, [u'update_internal_attribute_code', u'update_filter_action', u'update_filter_match_count', u'establishment_update_filter_match_count', u'last_update_filter_match_age'], name, value)


                                    class LastUpdateFilterMatchTimestamp(Entity):
                                        """
                                        Last attribute filtered time\: time elapsed since
                                        00\:00\:00 UTC, January 1, 1970
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, self).__init__()

                                            self.yang_name = "last-update-filter-match-timestamp"
                                            self.yang_parent_name = "update-attribute-filter-attributes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-filter-match-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateFilterMessage(Entity):
                                    """
                                    List of filtered messages
                                    
                                    .. attribute:: update_filter_message_timestamp
                                    
                                    	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                    	**type**\:  :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                    
                                    .. attribute:: update_filtered_attribute_count
                                    
                                    	Filtered attributes count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_final_action
                                    
                                    	Filtering final action
                                    	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    .. attribute:: update_filter_nlri_address_family
                                    
                                    	NLRI address\-family
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_filter_nlri_string
                                    
                                    	List of NLRIs in string format
                                    	**type**\: str
                                    
                                    .. attribute:: update_filter_nlri_string_truncated
                                    
                                    	Indicates whether NLRI string was truncated due to lack of space
                                    	**type**\: bool
                                    
                                    .. attribute:: update_filter_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of  		 :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                    
                                    .. attribute:: update_filter_element
                                    
                                    	Filtering element list
                                    	**type**\: list of  		 :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, self).__init__()

                                        self.yang_name = "update-filter-message"
                                        self.yang_parent_name = "update-inbound-filter-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-filter-message-timestamp", ("update_filter_message_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp)), ("update-filter-message-data", ("update_filter_message_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData)), ("update-filter-element", ("update_filter_element", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement))])
                                        self._leafs = OrderedDict([
                                            ('update_filtered_attribute_count', (YLeaf(YType.uint32, 'update-filtered-attribute-count'), ['int'])),
                                            ('update_filter_final_action', (YLeaf(YType.enumeration, 'update-filter-final-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                            ('update_filter_nlri_address_family', (YLeaf(YType.enumeration, 'update-filter-nlri-address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('update_filter_nlri_string', (YLeaf(YType.str, 'update-filter-nlri-string'), ['str'])),
                                            ('update_filter_nlri_string_truncated', (YLeaf(YType.boolean, 'update-filter-nlri-string-truncated'), ['bool'])),
                                        ])
                                        self.update_filtered_attribute_count = None
                                        self.update_filter_final_action = None
                                        self.update_filter_nlri_address_family = None
                                        self.update_filter_nlri_string = None
                                        self.update_filter_nlri_string_truncated = None

                                        self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                        self.update_filter_message_timestamp.parent = self
                                        self._children_name_map["update_filter_message_timestamp"] = "update-filter-message-timestamp"

                                        self.update_filter_message_data = YList(self)
                                        self.update_filter_element = YList(self)
                                        self._segment_path = lambda: "update-filter-message"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, [u'update_filtered_attribute_count', u'update_filter_final_action', u'update_filter_nlri_address_family', u'update_filter_nlri_string', u'update_filter_nlri_string_truncated'], name, value)


                                    class UpdateFilterMessageTimestamp(Entity):
                                        """
                                        Message timestamp\: time elapsed since 00\:00\:00
                                        UTC, January 1, 1970
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, self).__init__()

                                            self.yang_name = "update-filter-message-timestamp"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "update-filter-message-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateFilterMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, self).__init__()

                                            self.yang_name = "update-filter-message-data"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "update-filter-message-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, [u'entry'], name, value)


                                    class UpdateFilterElement(Entity):
                                        """
                                        Filtering element list
                                        
                                        .. attribute:: update_attribute_flags
                                        
                                        	Attribute Flags [RFC4271\: BGP4]
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_attribute_code
                                        
                                        	Attribute code [RFC4271\: BGP4]
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_filter_action
                                        
                                        	Filtering action
                                        	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, self).__init__()

                                            self.yang_name = "update-filter-element"
                                            self.yang_parent_name = "update-filter-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update_attribute_flags', (YLeaf(YType.uint8, 'update-attribute-flags'), ['int'])),
                                                ('update_attribute_code', (YLeaf(YType.uint8, 'update-attribute-code'), ['int'])),
                                                ('update_filter_action', (YLeaf(YType.enumeration, 'update-filter-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                            ])
                                            self.update_attribute_flags = None
                                            self.update_attribute_code = None
                                            self.update_filter_action = None
                                            self._segment_path = lambda: "update-filter-element"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, [u'update_attribute_flags', u'update_attribute_code', u'update_filter_action'], name, value)


                        class Bmp(Entity):
                            """
                            BMP related Operational Data
                            
                            .. attribute:: server_summaries
                            
                            	Table of BMP Servers
                            	**type**\:  :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries>`
                            
                            .. attribute:: server_neighbors
                            
                            	Table of Neighbors for a BMP Server
                            	**type**\:  :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp, self).__init__()

                                self.yang_name = "bmp"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("server-summaries", ("server_summaries", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries)), ("server-neighbors", ("server_neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors))])
                                self._leafs = OrderedDict()

                                self.server_summaries = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries()
                                self.server_summaries.parent = self
                                self._children_name_map["server_summaries"] = "server-summaries"

                                self.server_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors()
                                self.server_neighbors.parent = self
                                self._children_name_map["server_neighbors"] = "server-neighbors"
                                self._segment_path = lambda: "bmp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp, [], name, value)


                            class ServerSummaries(Entity):
                                """
                                Table of BMP Servers
                                
                                .. attribute:: server_summary
                                
                                	Summary Information about BMP server
                                	**type**\: list of  		 :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries, self).__init__()

                                    self.yang_name = "server-summaries"
                                    self.yang_parent_name = "bmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("server-summary", ("server_summary", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary))])
                                    self._leafs = OrderedDict()

                                    self.server_summary = YList(self)
                                    self._segment_path = lambda: "server-summaries"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries, [], name, value)


                                class ServerSummary(Entity):
                                    """
                                    Summary Information about BMP server
                                    
                                    .. attribute:: server_id  (key)
                                    
                                    	BMP Server ID
                                    	**type**\: int
                                    
                                    	**range:** 1..8
                                    
                                    .. attribute:: bmp_server_state_age
                                    
                                    	Age of current state of BMP Server
                                    	**type**\:  :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                    
                                    .. attribute:: bmp_server_state_time_spec
                                    
                                    	Timespec of current state of BMP Server
                                    	**type**\:  :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                    
                                    .. attribute:: bmp_server_last_discon_time
                                    
                                    	Timespec of Last Disconnect event received from BMP server
                                    	**type**\:  :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                    
                                    .. attribute:: update_source_address
                                    
                                    	Address of Interface configured as Update Source
                                    	**type**\:  :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                    
                                    .. attribute:: bmp_server_id
                                    
                                    	BMP Server ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: bmp_server_host_name
                                    
                                    	BMP Server Hostname
                                    	**type**\: str
                                    
                                    .. attribute:: bmp_server_port
                                    
                                    	BMP Server Port Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_server_state
                                    
                                    	Connection state of the BMP server
                                    	**type**\:  :py:class:`BgpBmpState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpState>`
                                    
                                    .. attribute:: bmp_server_is_flapping
                                    
                                    	Connection to the BMP server Flapping
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_server_nbr_count
                                    
                                    	Neighbor count for the BMP Server
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_init_msg_count
                                    
                                    	Number of Initiation Msgs sent by this BMP Server
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_termination_msg_count
                                    
                                    	Number of Termination Messages sent by this BMP Server
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_status_report_count
                                    
                                    	Number of Status ReportMessages sent by this BMP Server
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_count
                                    
                                    	Total number of per peer messages sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_drop_count
                                    
                                    	Total number of messages dropped
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count
                                    
                                    	Total number of bmpQ msgs pending
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence (0) or DSCP (1) type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_source_interface_name
                                    
                                    	Interface configured as Update Source
                                    	**type**\: str
                                    
                                    .. attribute:: update_source_vrf_id
                                    
                                    	VRF ID of interface configured as Update Source
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_vrf_name
                                    
                                    	VRF Name configured
                                    	**type**\: str
                                    
                                    .. attribute:: bmp_vrf_id
                                    
                                    	VRF ID for the vrf name configured
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_update_mode
                                    
                                    	Update sending mode configured for this BMP server
                                    	**type**\:  :py:class:`BgpBmpUpdMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdMode>`
                                    
                                    .. attribute:: tcp_keep_alive_interval
                                    
                                    	TCP Keep alive interval configured
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_maximum_segment_size
                                    
                                    	TCP Maximum Segments size configured
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_write_cb_pending
                                    
                                    	Are we waiting for TCP write callback ?
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_result
                                    
                                    	Last TCP Socket write status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tcp_last_write_cb_time
                                    
                                    	Last TCP Write CB time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: tcp_last_write_time
                                    
                                    	Last TCP Write time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_all_write_pulse_sent_time
                                    
                                    	Last BMPQ write pulse Sent for all BMP servers 
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmpq_last_write_pulse_cb_time
                                    
                                    	Last BMPQ write pulse callback time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: path_update_count
                                    
                                    	Number of path update sent 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_count
                                    
                                    	Number of path wdraw sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_update_drop
                                    
                                    	Number of path update drop 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_withdraw_drop
                                    
                                    	Number of path wdraw drop 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_max
                                    
                                    	Total bmpQ msgs pending max
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_peer_msg_pending_count_hwts
                                    
                                    	Total bmpQ msgs pending max time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_bytes_written_tcp
                                    
                                    	Total bytes sent to TCP
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: tcp_write_time
                                    
                                    	Time spent processing sending msg to TCP(milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: bmpr_mon_upd_messages
                                    
                                    	Total bmpQ update msgs 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmpr_mon_wdraw_messages
                                    
                                    	Total bmpQ withdraw msgs 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_messages_wdraw_discarded
                                    
                                    	Total bmpQ wdraw msgs discarded because of peer down
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_pfx_wdraw_discarded
                                    
                                    	Total bmpQ wdraw pfxes discarded because of peer down
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_per_peer_msg_route_mon_count
                                    
                                    	Total number of per peer route mon messages sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmpr_mon_update_gen_time
                                    
                                    	Time spent in update generation(milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: bmpr_mon_eo_rmessages
                                    
                                    	Total bmpQ EOR update msgs 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_rmon_cur_buffer_size
                                    
                                    	Current Buffer usage per BMP Route Mon
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_maximum_buffer_size_route_mon
                                    
                                    	Buffer limit used for route mon
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_server_up_count
                                    
                                    	Number of BMP server that are UP
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_in_progress
                                    
                                    	Update generation in progress
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_reset_walk_in_progress
                                    
                                    	Reset walk in progress
                                    	**type**\: bool
                                    
                                    .. attribute:: bmpafi_info
                                    
                                    	AFI specific info for BMP server
                                    	**type**\: list of  		 :py:class:`BmpafiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary, self).__init__()

                                        self.yang_name = "server-summary"
                                        self.yang_parent_name = "server-summaries"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['server_id']
                                        self._child_classes = OrderedDict([("bmp-server-state-age", ("bmp_server_state_age", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge)), ("bmp-server-state-time-spec", ("bmp_server_state_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec)), ("bmp-server-last-discon-time", ("bmp_server_last_discon_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime)), ("update-source-address", ("update_source_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress)), ("bmpafi-info", ("bmpafi_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo))])
                                        self._leafs = OrderedDict([
                                            ('server_id', (YLeaf(YType.uint32, 'server-id'), ['int'])),
                                            ('bmp_server_id', (YLeaf(YType.uint8, 'bmp-server-id'), ['int'])),
                                            ('bmp_server_host_name', (YLeaf(YType.str, 'bmp-server-host-name'), ['str'])),
                                            ('bmp_server_port', (YLeaf(YType.uint32, 'bmp-server-port'), ['int'])),
                                            ('bmp_server_state', (YLeaf(YType.enumeration, 'bmp-server-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBmpState', '')])),
                                            ('bmp_server_is_flapping', (YLeaf(YType.boolean, 'bmp-server-is-flapping'), ['bool'])),
                                            ('bmp_server_nbr_count', (YLeaf(YType.uint32, 'bmp-server-nbr-count'), ['int'])),
                                            ('bmp_init_msg_count', (YLeaf(YType.uint32, 'bmp-init-msg-count'), ['int'])),
                                            ('bmp_termination_msg_count', (YLeaf(YType.uint32, 'bmp-termination-msg-count'), ['int'])),
                                            ('bmp_status_report_count', (YLeaf(YType.uint32, 'bmp-status-report-count'), ['int'])),
                                            ('bmp_per_peer_msg_count', (YLeaf(YType.uint32, 'bmp-per-peer-msg-count'), ['int'])),
                                            ('bmp_peer_msg_drop_count', (YLeaf(YType.uint32, 'bmp-peer-msg-drop-count'), ['int'])),
                                            ('bmp_peer_msg_pending_count', (YLeaf(YType.uint32, 'bmp-peer-msg-pending-count'), ['int'])),
                                            ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                            ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                            ('update_source_interface_name', (YLeaf(YType.str, 'update-source-interface-name'), ['str'])),
                                            ('update_source_vrf_id', (YLeaf(YType.uint32, 'update-source-vrf-id'), ['int'])),
                                            ('bmp_vrf_name', (YLeaf(YType.str, 'bmp-vrf-name'), ['str'])),
                                            ('bmp_vrf_id', (YLeaf(YType.uint32, 'bmp-vrf-id'), ['int'])),
                                            ('bmp_update_mode', (YLeaf(YType.enumeration, 'bmp-update-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBmpUpdMode', '')])),
                                            ('tcp_keep_alive_interval', (YLeaf(YType.uint32, 'tcp-keep-alive-interval'), ['int'])),
                                            ('tcp_maximum_segment_size', (YLeaf(YType.uint32, 'tcp-maximum-segment-size'), ['int'])),
                                            ('tcp_write_cb_pending', (YLeaf(YType.uint32, 'tcp-write-cb-pending'), ['int'])),
                                            ('tcp_last_write_result', (YLeaf(YType.uint32, 'tcp-last-write-result'), ['int'])),
                                            ('tcp_last_write_cb_time', (YLeaf(YType.uint64, 'tcp-last-write-cb-time'), ['int'])),
                                            ('tcp_last_write_time', (YLeaf(YType.uint64, 'tcp-last-write-time'), ['int'])),
                                            ('bmpq_last_write_pulse_sent_time', (YLeaf(YType.uint64, 'bmpq-last-write-pulse-sent-time'), ['int'])),
                                            ('bmpq_last_all_write_pulse_sent_time', (YLeaf(YType.uint64, 'bmpq-last-all-write-pulse-sent-time'), ['int'])),
                                            ('bmpq_last_write_pulse_cb_time', (YLeaf(YType.uint64, 'bmpq-last-write-pulse-cb-time'), ['int'])),
                                            ('path_update_count', (YLeaf(YType.uint32, 'path-update-count'), ['int'])),
                                            ('path_withdraw_count', (YLeaf(YType.uint32, 'path-withdraw-count'), ['int'])),
                                            ('path_update_drop', (YLeaf(YType.uint32, 'path-update-drop'), ['int'])),
                                            ('path_withdraw_drop', (YLeaf(YType.uint32, 'path-withdraw-drop'), ['int'])),
                                            ('bmp_peer_msg_pending_count_max', (YLeaf(YType.uint32, 'bmp-peer-msg-pending-count-max'), ['int'])),
                                            ('bmp_peer_msg_pending_count_hwts', (YLeaf(YType.uint64, 'bmp-peer-msg-pending-count-hwts'), ['int'])),
                                            ('bmp_bytes_written_tcp', (YLeaf(YType.uint64, 'bmp-bytes-written-tcp'), ['int'])),
                                            ('tcp_write_time', (YLeaf(YType.uint32, 'tcp-write-time'), ['int'])),
                                            ('bmpr_mon_upd_messages', (YLeaf(YType.uint32, 'bmpr-mon-upd-messages'), ['int'])),
                                            ('bmpr_mon_wdraw_messages', (YLeaf(YType.uint32, 'bmpr-mon-wdraw-messages'), ['int'])),
                                            ('bmp_messages_wdraw_discarded', (YLeaf(YType.uint32, 'bmp-messages-wdraw-discarded'), ['int'])),
                                            ('bmp_pfx_wdraw_discarded', (YLeaf(YType.uint32, 'bmp-pfx-wdraw-discarded'), ['int'])),
                                            ('bmp_per_peer_msg_route_mon_count', (YLeaf(YType.uint32, 'bmp-per-peer-msg-route-mon-count'), ['int'])),
                                            ('bmpr_mon_update_gen_time', (YLeaf(YType.uint32, 'bmpr-mon-update-gen-time'), ['int'])),
                                            ('bmpr_mon_eo_rmessages', (YLeaf(YType.uint32, 'bmpr-mon-eo-rmessages'), ['int'])),
                                            ('bmp_rmon_cur_buffer_size', (YLeaf(YType.uint64, 'bmp-rmon-cur-buffer-size'), ['int'])),
                                            ('bmp_maximum_buffer_size_route_mon', (YLeaf(YType.uint64, 'bmp-maximum-buffer-size-route-mon'), ['int'])),
                                            ('bmp_server_up_count', (YLeaf(YType.uint32, 'bmp-server-up-count'), ['int'])),
                                            ('bmp_upd_gen_in_progress', (YLeaf(YType.boolean, 'bmp-upd-gen-in-progress'), ['bool'])),
                                            ('bmp_reset_walk_in_progress', (YLeaf(YType.boolean, 'bmp-reset-walk-in-progress'), ['bool'])),
                                        ])
                                        self.server_id = None
                                        self.bmp_server_id = None
                                        self.bmp_server_host_name = None
                                        self.bmp_server_port = None
                                        self.bmp_server_state = None
                                        self.bmp_server_is_flapping = None
                                        self.bmp_server_nbr_count = None
                                        self.bmp_init_msg_count = None
                                        self.bmp_termination_msg_count = None
                                        self.bmp_status_report_count = None
                                        self.bmp_per_peer_msg_count = None
                                        self.bmp_peer_msg_drop_count = None
                                        self.bmp_peer_msg_pending_count = None
                                        self.tos_type = None
                                        self.tos_value = None
                                        self.update_source_interface_name = None
                                        self.update_source_vrf_id = None
                                        self.bmp_vrf_name = None
                                        self.bmp_vrf_id = None
                                        self.bmp_update_mode = None
                                        self.tcp_keep_alive_interval = None
                                        self.tcp_maximum_segment_size = None
                                        self.tcp_write_cb_pending = None
                                        self.tcp_last_write_result = None
                                        self.tcp_last_write_cb_time = None
                                        self.tcp_last_write_time = None
                                        self.bmpq_last_write_pulse_sent_time = None
                                        self.bmpq_last_all_write_pulse_sent_time = None
                                        self.bmpq_last_write_pulse_cb_time = None
                                        self.path_update_count = None
                                        self.path_withdraw_count = None
                                        self.path_update_drop = None
                                        self.path_withdraw_drop = None
                                        self.bmp_peer_msg_pending_count_max = None
                                        self.bmp_peer_msg_pending_count_hwts = None
                                        self.bmp_bytes_written_tcp = None
                                        self.tcp_write_time = None
                                        self.bmpr_mon_upd_messages = None
                                        self.bmpr_mon_wdraw_messages = None
                                        self.bmp_messages_wdraw_discarded = None
                                        self.bmp_pfx_wdraw_discarded = None
                                        self.bmp_per_peer_msg_route_mon_count = None
                                        self.bmpr_mon_update_gen_time = None
                                        self.bmpr_mon_eo_rmessages = None
                                        self.bmp_rmon_cur_buffer_size = None
                                        self.bmp_maximum_buffer_size_route_mon = None
                                        self.bmp_server_up_count = None
                                        self.bmp_upd_gen_in_progress = None
                                        self.bmp_reset_walk_in_progress = None

                                        self.bmp_server_state_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                        self.bmp_server_state_age.parent = self
                                        self._children_name_map["bmp_server_state_age"] = "bmp-server-state-age"

                                        self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                        self.bmp_server_state_time_spec.parent = self
                                        self._children_name_map["bmp_server_state_time_spec"] = "bmp-server-state-time-spec"

                                        self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                        self.bmp_server_last_discon_time.parent = self
                                        self._children_name_map["bmp_server_last_discon_time"] = "bmp-server-last-discon-time"

                                        self.update_source_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                        self.update_source_address.parent = self
                                        self._children_name_map["update_source_address"] = "update-source-address"

                                        self.bmpafi_info = YList(self)
                                        self._segment_path = lambda: "server-summary" + "[server-id='" + str(self.server_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary, ['server_id', u'bmp_server_id', u'bmp_server_host_name', u'bmp_server_port', u'bmp_server_state', u'bmp_server_is_flapping', u'bmp_server_nbr_count', u'bmp_init_msg_count', u'bmp_termination_msg_count', u'bmp_status_report_count', u'bmp_per_peer_msg_count', u'bmp_peer_msg_drop_count', u'bmp_peer_msg_pending_count', u'tos_type', u'tos_value', u'update_source_interface_name', u'update_source_vrf_id', u'bmp_vrf_name', u'bmp_vrf_id', u'bmp_update_mode', u'tcp_keep_alive_interval', u'tcp_maximum_segment_size', u'tcp_write_cb_pending', u'tcp_last_write_result', u'tcp_last_write_cb_time', u'tcp_last_write_time', u'bmpq_last_write_pulse_sent_time', u'bmpq_last_all_write_pulse_sent_time', u'bmpq_last_write_pulse_cb_time', u'path_update_count', u'path_withdraw_count', u'path_update_drop', u'path_withdraw_drop', u'bmp_peer_msg_pending_count_max', u'bmp_peer_msg_pending_count_hwts', u'bmp_bytes_written_tcp', u'tcp_write_time', u'bmpr_mon_upd_messages', u'bmpr_mon_wdraw_messages', u'bmp_messages_wdraw_discarded', u'bmp_pfx_wdraw_discarded', u'bmp_per_peer_msg_route_mon_count', u'bmpr_mon_update_gen_time', u'bmpr_mon_eo_rmessages', u'bmp_rmon_cur_buffer_size', u'bmp_maximum_buffer_size_route_mon', u'bmp_server_up_count', u'bmp_upd_gen_in_progress', u'bmp_reset_walk_in_progress'], name, value)


                                    class BmpServerStateAge(Entity):
                                        """
                                        Age of current state of BMP Server
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, self).__init__()

                                            self.yang_name = "bmp-server-state-age"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-server-state-age"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, [u'seconds', u'nanoseconds'], name, value)


                                    class BmpServerStateTimeSpec(Entity):
                                        """
                                        Timespec of current state of BMP Server
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, self).__init__()

                                            self.yang_name = "bmp-server-state-time-spec"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-server-state-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class BmpServerLastDisconTime(Entity):
                                        """
                                        Timespec of Last Disconnect event received from
                                        BMP server
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, self).__init__()

                                            self.yang_name = "bmp-server-last-discon-time"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "bmp-server-last-discon-time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateSourceAddress(Entity):
                                        """
                                        Address of Interface configured as Update Source
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, self).__init__()

                                            self.yang_name = "update-source-address"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "update-source-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "update-source-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class BmpafiInfo(Entity):
                                        """
                                        AFI specific info for BMP server
                                        
                                        .. attribute:: bmp_resume_prefix
                                        
                                        	BMP Resume prefix
                                        	**type**\:  :py:class:`BmpResumePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix>`
                                        
                                        .. attribute:: bmp_filter_neighbor_address
                                        
                                        	Filter Neighbor Address
                                        	**type**\:  :py:class:`BmpFilterNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress>`
                                        
                                        .. attribute:: bmpaf_name
                                        
                                        	BMP Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: bmp_resume_prefix_len
                                        
                                        	BMP Resume prefix Len
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_resume_start_version
                                        
                                        	Update Gen ResumeWalk start version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_resume_end_version
                                        
                                        	Update Gen ResumeWalk end version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_walk_stopped
                                        
                                        	Update Gen WalkStopped
                                        	**type**\: bool
                                        
                                        .. attribute:: bmp_upd_gen_resume_net_version
                                        
                                        	Update Gen ResumeWalk Net version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_upd_gen_walk_run_time_stamp
                                        
                                        	Last Update Gen Run time stamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_run_count
                                        
                                        	Number of times Update Gen ran
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_stop_time_stamp
                                        
                                        	Last Update Gen Stop time stamp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_upd_gen_walk_stop_count
                                        
                                        	Number of times Update Gen Stopped
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bmp_init_eor_end_version
                                        
                                        	Version to reach to send EOR
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_init_eor_pending_cnt
                                        
                                        	Count for pending EOR
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_filter_neighbor_address_set
                                        
                                        	Filter Neighbor Address Set ?
                                        	**type**\: bool
                                        
                                        .. attribute:: bmp_filter_nbr_cnt
                                        
                                        	Filter nbr Count for this AFI
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_send_version
                                        
                                        	Table Version that this BMP server has caught upto
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, self).__init__()

                                            self.yang_name = "bmpafi-info"
                                            self.yang_parent_name = "server-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bmp-resume-prefix", ("bmp_resume_prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix)), ("bmp-filter-neighbor-address", ("bmp_filter_neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('bmpaf_name', (YLeaf(YType.enumeration, 'bmpaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('bmp_resume_prefix_len', (YLeaf(YType.uint32, 'bmp-resume-prefix-len'), ['int'])),
                                                ('bmp_upd_gen_resume_start_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-start-version'), ['int'])),
                                                ('bmp_upd_gen_resume_end_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-end-version'), ['int'])),
                                                ('bmp_upd_gen_walk_stopped', (YLeaf(YType.boolean, 'bmp-upd-gen-walk-stopped'), ['bool'])),
                                                ('bmp_upd_gen_resume_net_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-net-version'), ['int'])),
                                                ('bmp_upd_gen_walk_run_time_stamp', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-run-time-stamp'), ['int'])),
                                                ('bmp_upd_gen_walk_run_count', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-run-count'), ['int'])),
                                                ('bmp_upd_gen_walk_stop_time_stamp', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-stop-time-stamp'), ['int'])),
                                                ('bmp_upd_gen_walk_stop_count', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-stop-count'), ['int'])),
                                                ('bmp_init_eor_end_version', (YLeaf(YType.uint32, 'bmp-init-eor-end-version'), ['int'])),
                                                ('bmp_init_eor_pending_cnt', (YLeaf(YType.uint32, 'bmp-init-eor-pending-cnt'), ['int'])),
                                                ('bmp_filter_neighbor_address_set', (YLeaf(YType.boolean, 'bmp-filter-neighbor-address-set'), ['bool'])),
                                                ('bmp_filter_nbr_cnt', (YLeaf(YType.uint32, 'bmp-filter-nbr-cnt'), ['int'])),
                                                ('bmp_send_version', (YLeaf(YType.uint32, 'bmp-send-version'), ['int'])),
                                            ])
                                            self.bmpaf_name = None
                                            self.bmp_resume_prefix_len = None
                                            self.bmp_upd_gen_resume_start_version = None
                                            self.bmp_upd_gen_resume_end_version = None
                                            self.bmp_upd_gen_walk_stopped = None
                                            self.bmp_upd_gen_resume_net_version = None
                                            self.bmp_upd_gen_walk_run_time_stamp = None
                                            self.bmp_upd_gen_walk_run_count = None
                                            self.bmp_upd_gen_walk_stop_time_stamp = None
                                            self.bmp_upd_gen_walk_stop_count = None
                                            self.bmp_init_eor_end_version = None
                                            self.bmp_init_eor_pending_cnt = None
                                            self.bmp_filter_neighbor_address_set = None
                                            self.bmp_filter_nbr_cnt = None
                                            self.bmp_send_version = None

                                            self.bmp_resume_prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix()
                                            self.bmp_resume_prefix.parent = self
                                            self._children_name_map["bmp_resume_prefix"] = "bmp-resume-prefix"

                                            self.bmp_filter_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress()
                                            self.bmp_filter_neighbor_address.parent = self
                                            self._children_name_map["bmp_filter_neighbor_address"] = "bmp-filter-neighbor-address"
                                            self._segment_path = lambda: "bmpafi-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, [u'bmpaf_name', u'bmp_resume_prefix_len', u'bmp_upd_gen_resume_start_version', u'bmp_upd_gen_resume_end_version', u'bmp_upd_gen_walk_stopped', u'bmp_upd_gen_resume_net_version', u'bmp_upd_gen_walk_run_time_stamp', u'bmp_upd_gen_walk_run_count', u'bmp_upd_gen_walk_stop_time_stamp', u'bmp_upd_gen_walk_stop_count', u'bmp_init_eor_end_version', u'bmp_init_eor_pending_cnt', u'bmp_filter_neighbor_address_set', u'bmp_filter_nbr_cnt', u'bmp_send_version'], name, value)


                                        class BmpResumePrefix(Entity):
                                            """
                                            BMP Resume prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, self).__init__()

                                                self.yang_name = "bmp-resume-prefix"
                                                self.yang_parent_name = "bmpafi-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bmp-resume-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bmp-resume-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BmpFilterNeighborAddress(Entity):
                                            """
                                            Filter Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, self).__init__()

                                                self.yang_name = "bmp-filter-neighbor-address"
                                                self.yang_parent_name = "bmpafi-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "bmp-filter-neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "bmp-filter-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ServerNeighbors(Entity):
                                """
                                Table of Neighbors for a BMP Server
                                
                                .. attribute:: server_neighbor
                                
                                	BMP Server under which neighbor info are needed
                                	**type**\: list of  		 :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors, self).__init__()

                                    self.yang_name = "server-neighbors"
                                    self.yang_parent_name = "bmp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("server-neighbor", ("server_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.server_neighbor = YList(self)
                                    self._segment_path = lambda: "server-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors, [], name, value)


                                class ServerNeighbor(Entity):
                                    """
                                    BMP Server under which neighbor info are
                                    needed
                                    
                                    .. attribute:: server_id  (key)
                                    
                                    	BMP Server ID
                                    	**type**\: int
                                    
                                    	**range:** 1..8
                                    
                                    .. attribute:: monitored_neighbors
                                    
                                    	List of Neighbors under which BMP Server is confgiured
                                    	**type**\:  :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor, self).__init__()

                                        self.yang_name = "server-neighbor"
                                        self.yang_parent_name = "server-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['server_id']
                                        self._child_classes = OrderedDict([("monitored-neighbors", ("monitored_neighbors", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors))])
                                        self._leafs = OrderedDict([
                                            ('server_id', (YLeaf(YType.uint32, 'server-id'), ['int'])),
                                        ])
                                        self.server_id = None

                                        self.monitored_neighbors = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                        self.monitored_neighbors.parent = self
                                        self._children_name_map["monitored_neighbors"] = "monitored-neighbors"
                                        self._segment_path = lambda: "server-neighbor" + "[server-id='" + str(self.server_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor, ['server_id'], name, value)


                                    class MonitoredNeighbors(Entity):
                                        """
                                        List of Neighbors under which BMP Server is
                                        confgiured
                                        
                                        .. attribute:: monitored_neighbor
                                        
                                        	Information about a neighbor monitored by BMP server
                                        	**type**\: list of  		 :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, self).__init__()

                                            self.yang_name = "monitored-neighbors"
                                            self.yang_parent_name = "server-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("monitored-neighbor", ("monitored_neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor))])
                                            self._leafs = OrderedDict()

                                            self.monitored_neighbor = YList(self)
                                            self._segment_path = lambda: "monitored-neighbors"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, [], name, value)


                                        class MonitoredNeighbor(Entity):
                                            """
                                            Information about a neighbor monitored by
                                            BMP server
                                            
                                            .. attribute:: neighbor_address  (key)
                                            
                                            	Neighbor address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: bmp_neighbor_address
                                            
                                            	Address of Nbr that logs to BMP server
                                            	**type**\:  :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                            
                                            .. attribute:: bmp_neighbor_msg_pending
                                            
                                            	Number of messages pending to be sent to BMP Server from this Neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_msg_dropped
                                            
                                            	Number of messages dropped sent from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_up_sent
                                            
                                            	Number of Peer UP Messages sent from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_peer_down_sent
                                            
                                            	Number of Peer DOWN Messages sent from this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_route_monitor_sent
                                            
                                            	Number of Route Monitor Messages sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_route_monitor_eor_sent
                                            
                                            	Number of Route Monitor EOR Messages sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_sent
                                            
                                            	Number of Path UpdateMessages sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_sent
                                            
                                            	Number of Path WithdrawMessages sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_update_drop
                                            
                                            	Number of path update drop 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_path_withdraw_drop
                                            
                                            	Number of path wdraw drop 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_upd_msg_sent
                                            
                                            	Number of update message sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bmp_neighbor_wdraw_msg_sent
                                            
                                            	Number of withdraw message sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, self).__init__()

                                                self.yang_name = "monitored-neighbor"
                                                self.yang_parent_name = "monitored-neighbors"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['neighbor_address']
                                                self._child_classes = OrderedDict([("bmp-neighbor-address", ("bmp_neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                    ('bmp_neighbor_msg_pending', (YLeaf(YType.uint32, 'bmp-neighbor-msg-pending'), ['int'])),
                                                    ('bmp_neighbor_msg_dropped', (YLeaf(YType.uint32, 'bmp-neighbor-msg-dropped'), ['int'])),
                                                    ('bmp_neighbor_peer_up_sent', (YLeaf(YType.uint32, 'bmp-neighbor-peer-up-sent'), ['int'])),
                                                    ('bmp_neighbor_peer_down_sent', (YLeaf(YType.uint32, 'bmp-neighbor-peer-down-sent'), ['int'])),
                                                    ('bmp_neighbor_route_monitor_sent', (YLeaf(YType.uint32, 'bmp-neighbor-route-monitor-sent'), ['int'])),
                                                    ('bmp_neighbor_route_monitor_eor_sent', (YLeaf(YType.uint32, 'bmp-neighbor-route-monitor-eor-sent'), ['int'])),
                                                    ('bmp_neighbor_path_update_sent', (YLeaf(YType.uint32, 'bmp-neighbor-path-update-sent'), ['int'])),
                                                    ('bmp_neighbor_path_withdraw_sent', (YLeaf(YType.uint32, 'bmp-neighbor-path-withdraw-sent'), ['int'])),
                                                    ('bmp_neighbor_path_update_drop', (YLeaf(YType.uint32, 'bmp-neighbor-path-update-drop'), ['int'])),
                                                    ('bmp_neighbor_path_withdraw_drop', (YLeaf(YType.uint32, 'bmp-neighbor-path-withdraw-drop'), ['int'])),
                                                    ('bmp_neighbor_upd_msg_sent', (YLeaf(YType.uint32, 'bmp-neighbor-upd-msg-sent'), ['int'])),
                                                    ('bmp_neighbor_wdraw_msg_sent', (YLeaf(YType.uint32, 'bmp-neighbor-wdraw-msg-sent'), ['int'])),
                                                ])
                                                self.neighbor_address = None
                                                self.bmp_neighbor_msg_pending = None
                                                self.bmp_neighbor_msg_dropped = None
                                                self.bmp_neighbor_peer_up_sent = None
                                                self.bmp_neighbor_peer_down_sent = None
                                                self.bmp_neighbor_route_monitor_sent = None
                                                self.bmp_neighbor_route_monitor_eor_sent = None
                                                self.bmp_neighbor_path_update_sent = None
                                                self.bmp_neighbor_path_withdraw_sent = None
                                                self.bmp_neighbor_path_update_drop = None
                                                self.bmp_neighbor_path_withdraw_drop = None
                                                self.bmp_neighbor_upd_msg_sent = None
                                                self.bmp_neighbor_wdraw_msg_sent = None

                                                self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                                self.bmp_neighbor_address.parent = self
                                                self._children_name_map["bmp_neighbor_address"] = "bmp-neighbor-address"
                                                self._segment_path = lambda: "monitored-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, ['neighbor_address', u'bmp_neighbor_msg_pending', u'bmp_neighbor_msg_dropped', u'bmp_neighbor_peer_up_sent', u'bmp_neighbor_peer_down_sent', u'bmp_neighbor_route_monitor_sent', u'bmp_neighbor_route_monitor_eor_sent', u'bmp_neighbor_path_update_sent', u'bmp_neighbor_path_withdraw_sent', u'bmp_neighbor_path_update_drop', u'bmp_neighbor_path_withdraw_drop', u'bmp_neighbor_upd_msg_sent', u'bmp_neighbor_wdraw_msg_sent'], name, value)


                                            class BmpNeighborAddress(Entity):
                                                """
                                                Address of Nbr that logs to BMP server
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, self).__init__()

                                                    self.yang_name = "bmp-neighbor-address"
                                                    self.yang_parent_name = "monitored-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "bmp-neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "bmp-neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class ProcessInfo(Entity):
                            """
                            A Process instance table entry
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf_>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics>`
                            
                            .. attribute:: process_instance
                            
                            	ID for the BGP process instance
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\: str
                            
                            .. attribute:: vrf_totals
                            
                            	per VRF counts aggregated across all VRFs
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo, self).__init__()

                                self.yang_name = "process-info"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf_)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics))])
                                self._leafs = OrderedDict([
                                    ('process_instance', (YLeaf(YType.uint8, 'process-instance'), ['int'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('vrf_totals', (YLeaf(YType.boolean, 'vrf-totals'), ['bool'])),
                                ])
                                self.process_instance = None
                                self.vrf_name = None
                                self.vrf_totals = None

                                self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"

                                self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf_()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"

                                self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self._children_name_map["performance_statistics"] = "performance-statistics"
                                self._segment_path = lambda: "process-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo, [u'process_instance', u'vrf_name', u'vrf_totals'], name, value)


                            class Global(Entity):
                                """
                                Global information
                                
                                .. attribute:: process_instance_node
                                
                                	Node the process instance is on
                                	**type**\: str
                                
                                .. attribute:: restart_count
                                
                                	No. of times BGP has started
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_attributes_entry_count
                                
                                	No. of path attribute entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_attribute_memory
                                
                                	Memory (bytes) used by path attribute entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: as_path_entry_count
                                
                                	Number of AS\-path entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_path_entries_memory
                                
                                	Memory (in bytes) used by AS\-path entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: community_entry_count
                                
                                	Number of community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: community_memory
                                
                                	Memory (in bytes) used by community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: extended_community_entry_count
                                
                                	Number of extended community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_memory
                                
                                	Memory (in bytes) used by extended community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: pe_distinguisher_label_entry_count
                                
                                	Number of PE distinguisher label entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pe_distinguisher_label_memory
                                
                                	Memory (in bytes) used by PE distinguisher labels entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: pta_entry_count
                                
                                	Number of PTA entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pta_memory
                                
                                	Memory (in bytes) used by PTA entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: tunnel_encap_entry_count
                                
                                	Number of Tunnel encap entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_encap_memory
                                
                                	Memory (in bytes) used by tunnel encap entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ribrnh_entry_count
                                
                                	Number of RIBRNH entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ribrnh_memory
                                
                                	Memory (in bytes) used by RIBRNH entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: ppmp_entry_count
                                
                                	Number of PPMP entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ppmp_memory
                                
                                	Memory (in bytes) used by PPMP entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: route_reflectors
                                
                                	Number of route reflector info entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_reflector_memory
                                
                                	Memory (in bytes) used by route reflector info entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: nexthop_count
                                
                                	Number of nexthop attribute info entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nexthop_memory
                                
                                	Memory (in bytes) used by nexthop attribute info entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: lsattr_entry_count
                                
                                	Number of LASATTR entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsattr_memory
                                
                                	Memory (in bytes) used by LSATTR entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: attr_set_entry_count
                                
                                	Number of ATTRSET entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attr_set_memory
                                
                                	Memory (in bytes) used by ATTRSET entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: lindex_entry_count
                                
                                	Number of LINDEX entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lindex_memory
                                
                                	Memory (in bytes) used by LINDEX entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: local_as
                                
                                	Local autonomous system number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_vrf_count
                                
                                	total vrf count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbors_count_total
                                
                                	Total number of neighbors
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: established_neighbors_count_total
                                
                                	Total umber of established neighbors
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs
                                
                                	sn num non dflt vrf nbrs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                                
                                	sn num non dflt vrf nbrs estab
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: large_community_entry_count
                                
                                	Number of large community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: large_community_memory
                                
                                	Memory (in bytes) used by large community entries
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: pool_size
                                
                                	pool size
                                	**type**\: list of  		 :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolSize>`
                                
                                .. attribute:: pool_alloc_count
                                
                                	pool alloc count
                                	**type**\: list of  		 :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolAllocCount>`
                                
                                .. attribute:: pool_free_count
                                
                                	pool free count
                                	**type**\: list of  		 :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolFreeCount>`
                                
                                .. attribute:: msg_log_pool_size
                                
                                	msg log pool size
                                	**type**\: list of  		 :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolSize>`
                                
                                .. attribute:: msg_log_pool_alloc_count
                                
                                	msg log pool alloc count
                                	**type**\: list of  		 :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolAllocCount>`
                                
                                .. attribute:: msg_log_pool_free_count
                                
                                	msg log pool free count
                                	**type**\: list of  		 :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolFreeCount>`
                                
                                .. attribute:: bmp_pool_size
                                
                                	bmp pool size
                                	**type**\: list of  		 :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolSize>`
                                
                                .. attribute:: bmp_pool_alloc_count
                                
                                	bmp pool alloc count
                                	**type**\: list of  		 :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolAllocCount>`
                                
                                .. attribute:: bmp_pool_free_count
                                
                                	bmp pool free count
                                	**type**\: list of  		 :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolFreeCount>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pool-size", ("pool_size", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolSize)), ("pool-alloc-count", ("pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolAllocCount)), ("pool-free-count", ("pool_free_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolFreeCount)), ("msg-log-pool-size", ("msg_log_pool_size", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolSize)), ("msg-log-pool-alloc-count", ("msg_log_pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolAllocCount)), ("msg-log-pool-free-count", ("msg_log_pool_free_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolFreeCount)), ("bmp-pool-size", ("bmp_pool_size", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolSize)), ("bmp-pool-alloc-count", ("bmp_pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolAllocCount)), ("bmp-pool-free-count", ("bmp_pool_free_count", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolFreeCount))])
                                    self._leafs = OrderedDict([
                                        ('process_instance_node', (YLeaf(YType.str, 'process-instance-node'), ['str'])),
                                        ('restart_count', (YLeaf(YType.uint32, 'restart-count'), ['int'])),
                                        ('path_attributes_entry_count', (YLeaf(YType.uint32, 'path-attributes-entry-count'), ['int'])),
                                        ('path_attribute_memory', (YLeaf(YType.uint32, 'path-attribute-memory'), ['int'])),
                                        ('as_path_entry_count', (YLeaf(YType.uint32, 'as-path-entry-count'), ['int'])),
                                        ('as_path_entries_memory', (YLeaf(YType.uint32, 'as-path-entries-memory'), ['int'])),
                                        ('community_entry_count', (YLeaf(YType.uint32, 'community-entry-count'), ['int'])),
                                        ('community_memory', (YLeaf(YType.uint32, 'community-memory'), ['int'])),
                                        ('extended_community_entry_count', (YLeaf(YType.uint32, 'extended-community-entry-count'), ['int'])),
                                        ('extended_community_memory', (YLeaf(YType.uint32, 'extended-community-memory'), ['int'])),
                                        ('pe_distinguisher_label_entry_count', (YLeaf(YType.uint32, 'pe-distinguisher-label-entry-count'), ['int'])),
                                        ('pe_distinguisher_label_memory', (YLeaf(YType.uint32, 'pe-distinguisher-label-memory'), ['int'])),
                                        ('pta_entry_count', (YLeaf(YType.uint32, 'pta-entry-count'), ['int'])),
                                        ('pta_memory', (YLeaf(YType.uint32, 'pta-memory'), ['int'])),
                                        ('tunnel_encap_entry_count', (YLeaf(YType.uint32, 'tunnel-encap-entry-count'), ['int'])),
                                        ('tunnel_encap_memory', (YLeaf(YType.uint32, 'tunnel-encap-memory'), ['int'])),
                                        ('ribrnh_entry_count', (YLeaf(YType.uint32, 'ribrnh-entry-count'), ['int'])),
                                        ('ribrnh_memory', (YLeaf(YType.uint32, 'ribrnh-memory'), ['int'])),
                                        ('ppmp_entry_count', (YLeaf(YType.uint32, 'ppmp-entry-count'), ['int'])),
                                        ('ppmp_memory', (YLeaf(YType.uint32, 'ppmp-memory'), ['int'])),
                                        ('route_reflectors', (YLeaf(YType.uint32, 'route-reflectors'), ['int'])),
                                        ('route_reflector_memory', (YLeaf(YType.uint32, 'route-reflector-memory'), ['int'])),
                                        ('nexthop_count', (YLeaf(YType.uint32, 'nexthop-count'), ['int'])),
                                        ('nexthop_memory', (YLeaf(YType.uint32, 'nexthop-memory'), ['int'])),
                                        ('lsattr_entry_count', (YLeaf(YType.uint32, 'lsattr-entry-count'), ['int'])),
                                        ('lsattr_memory', (YLeaf(YType.uint32, 'lsattr-memory'), ['int'])),
                                        ('attr_set_entry_count', (YLeaf(YType.uint32, 'attr-set-entry-count'), ['int'])),
                                        ('attr_set_memory', (YLeaf(YType.uint32, 'attr-set-memory'), ['int'])),
                                        ('lindex_entry_count', (YLeaf(YType.uint32, 'lindex-entry-count'), ['int'])),
                                        ('lindex_memory', (YLeaf(YType.uint32, 'lindex-memory'), ['int'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('total_vrf_count', (YLeaf(YType.uint32, 'total-vrf-count'), ['int'])),
                                        ('neighbors_count_total', (YLeaf(YType.uint32, 'neighbors-count-total'), ['int'])),
                                        ('established_neighbors_count_total', (YLeaf(YType.uint32, 'established-neighbors-count-total'), ['int'])),
                                        ('sn_num_non_dflt_vrf_nbrs', (YLeaf(YType.uint32, 'sn-num-non-dflt-vrf-nbrs'), ['int'])),
                                        ('sn_num_non_dflt_vrf_nbrs_estab', (YLeaf(YType.uint32, 'sn-num-non-dflt-vrf-nbrs-estab'), ['int'])),
                                        ('large_community_entry_count', (YLeaf(YType.uint32, 'large-community-entry-count'), ['int'])),
                                        ('large_community_memory', (YLeaf(YType.uint32, 'large-community-memory'), ['int'])),
                                    ])
                                    self.process_instance_node = None
                                    self.restart_count = None
                                    self.path_attributes_entry_count = None
                                    self.path_attribute_memory = None
                                    self.as_path_entry_count = None
                                    self.as_path_entries_memory = None
                                    self.community_entry_count = None
                                    self.community_memory = None
                                    self.extended_community_entry_count = None
                                    self.extended_community_memory = None
                                    self.pe_distinguisher_label_entry_count = None
                                    self.pe_distinguisher_label_memory = None
                                    self.pta_entry_count = None
                                    self.pta_memory = None
                                    self.tunnel_encap_entry_count = None
                                    self.tunnel_encap_memory = None
                                    self.ribrnh_entry_count = None
                                    self.ribrnh_memory = None
                                    self.ppmp_entry_count = None
                                    self.ppmp_memory = None
                                    self.route_reflectors = None
                                    self.route_reflector_memory = None
                                    self.nexthop_count = None
                                    self.nexthop_memory = None
                                    self.lsattr_entry_count = None
                                    self.lsattr_memory = None
                                    self.attr_set_entry_count = None
                                    self.attr_set_memory = None
                                    self.lindex_entry_count = None
                                    self.lindex_memory = None
                                    self.local_as = None
                                    self.total_vrf_count = None
                                    self.neighbors_count_total = None
                                    self.established_neighbors_count_total = None
                                    self.sn_num_non_dflt_vrf_nbrs = None
                                    self.sn_num_non_dflt_vrf_nbrs_estab = None
                                    self.large_community_entry_count = None
                                    self.large_community_memory = None

                                    self.pool_size = YList(self)
                                    self.pool_alloc_count = YList(self)
                                    self.pool_free_count = YList(self)
                                    self.msg_log_pool_size = YList(self)
                                    self.msg_log_pool_alloc_count = YList(self)
                                    self.msg_log_pool_free_count = YList(self)
                                    self.bmp_pool_size = YList(self)
                                    self.bmp_pool_alloc_count = YList(self)
                                    self.bmp_pool_free_count = YList(self)
                                    self._segment_path = lambda: "global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global, [u'process_instance_node', u'restart_count', u'path_attributes_entry_count', u'path_attribute_memory', u'as_path_entry_count', u'as_path_entries_memory', u'community_entry_count', u'community_memory', u'extended_community_entry_count', u'extended_community_memory', u'pe_distinguisher_label_entry_count', u'pe_distinguisher_label_memory', u'pta_entry_count', u'pta_memory', u'tunnel_encap_entry_count', u'tunnel_encap_memory', u'ribrnh_entry_count', u'ribrnh_memory', u'ppmp_entry_count', u'ppmp_memory', u'route_reflectors', u'route_reflector_memory', u'nexthop_count', u'nexthop_memory', u'lsattr_entry_count', u'lsattr_memory', u'attr_set_entry_count', u'attr_set_memory', u'lindex_entry_count', u'lindex_memory', u'local_as', u'total_vrf_count', u'neighbors_count_total', u'established_neighbors_count_total', u'sn_num_non_dflt_vrf_nbrs', u'sn_num_non_dflt_vrf_nbrs_estab', u'large_community_entry_count', u'large_community_memory'], name, value)


                                class PoolSize(Entity):
                                    """
                                    pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolSize, self).__init__()

                                        self.yang_name = "pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "pool-size"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolSize, [u'entry'], name, value)


                                class PoolAllocCount(Entity):
                                    """
                                    pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolAllocCount, self).__init__()

                                        self.yang_name = "pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "pool-alloc-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolAllocCount, [u'entry'], name, value)


                                class PoolFreeCount(Entity):
                                    """
                                    pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolFreeCount, self).__init__()

                                        self.yang_name = "pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "pool-free-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.PoolFreeCount, [u'entry'], name, value)


                                class MsgLogPoolSize(Entity):
                                    """
                                    msg log pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolSize, self).__init__()

                                        self.yang_name = "msg-log-pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "msg-log-pool-size"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolSize, [u'entry'], name, value)


                                class MsgLogPoolAllocCount(Entity):
                                    """
                                    msg log pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolAllocCount, self).__init__()

                                        self.yang_name = "msg-log-pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "msg-log-pool-alloc-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolAllocCount, [u'entry'], name, value)


                                class MsgLogPoolFreeCount(Entity):
                                    """
                                    msg log pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolFreeCount, self).__init__()

                                        self.yang_name = "msg-log-pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "msg-log-pool-free-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.MsgLogPoolFreeCount, [u'entry'], name, value)


                                class BmpPoolSize(Entity):
                                    """
                                    bmp pool size
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolSize, self).__init__()

                                        self.yang_name = "bmp-pool-size"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "bmp-pool-size"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolSize, [u'entry'], name, value)


                                class BmpPoolAllocCount(Entity):
                                    """
                                    bmp pool alloc count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolAllocCount, self).__init__()

                                        self.yang_name = "bmp-pool-alloc-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "bmp-pool-alloc-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolAllocCount, [u'entry'], name, value)


                                class BmpPoolFreeCount(Entity):
                                    """
                                    bmp pool free count
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolFreeCount, self).__init__()

                                        self.yang_name = "bmp-pool-free-count"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "bmp-pool-free-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Global.BmpPoolFreeCount, [u'entry'], name, value)


                            class Vrf_(Entity):
                                """
                                VRF information
                                
                                .. attribute:: neighbors_count
                                
                                	Number of neighbors
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: established_neighbors_count
                                
                                	Number of established neighbors
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_received
                                
                                	Number of update messages received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_sent
                                
                                	No. of update messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_received
                                
                                	No. of notifications received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: notifications_sent
                                
                                	No. of notifications sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_count
                                
                                	Number of networks
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_count
                                
                                	Number of paths
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf_, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('neighbors_count', (YLeaf(YType.uint32, 'neighbors-count'), ['int'])),
                                        ('established_neighbors_count', (YLeaf(YType.uint32, 'established-neighbors-count'), ['int'])),
                                        ('update_messages_received', (YLeaf(YType.uint32, 'update-messages-received'), ['int'])),
                                        ('update_messages_sent', (YLeaf(YType.uint32, 'update-messages-sent'), ['int'])),
                                        ('notifications_received', (YLeaf(YType.uint32, 'notifications-received'), ['int'])),
                                        ('notifications_sent', (YLeaf(YType.uint32, 'notifications-sent'), ['int'])),
                                        ('network_count', (YLeaf(YType.uint32, 'network-count'), ['int'])),
                                        ('path_count', (YLeaf(YType.uint32, 'path-count'), ['int'])),
                                    ])
                                    self.neighbors_count = None
                                    self.established_neighbors_count = None
                                    self.update_messages_received = None
                                    self.update_messages_sent = None
                                    self.notifications_received = None
                                    self.notifications_sent = None
                                    self.network_count = None
                                    self.path_count = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.Vrf_, [u'neighbors_count', u'established_neighbors_count', u'update_messages_received', u'update_messages_sent', u'notifications_received', u'notifications_sent', u'network_count', u'path_count'], name, value)


                            class PerformanceStatistics(Entity):
                                """
                                Performance statistics
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics, self).__init__()

                                    self.yang_name = "performance-statistics"
                                    self.yang_parent_name = "process-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_))])
                                    self._leafs = OrderedDict()

                                    self.global_ = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"

                                    self.vrf = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._segment_path = lambda: "performance-statistics"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics, [], name, value)


                                class Global(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: ipv4rib_server
                                    
                                    	IPv4 RIB server global info
                                    	**type**\:  :py:class:`Ipv4ribServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer>`
                                    
                                    .. attribute:: ipv6rib_server
                                    
                                    	IPv6 RIB server global info
                                    	**type**\:  :py:class:`Ipv6ribServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer>`
                                    
                                    .. attribute:: te_connection
                                    
                                    	MPLS TE server connection info
                                    	**type**\:  :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection>`
                                    
                                    .. attribute:: lsd_connection
                                    
                                    	MPLS LSD server connection info
                                    	**type**\:  :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection>`
                                    
                                    .. attribute:: ds_npl
                                    
                                    	NSR related DS and NPL information
                                    	**type**\:  :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl>`
                                    
                                    .. attribute:: configuration_items_processed
                                    
                                    	Number of config items processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configuration_processing_time
                                    
                                    	Time spent processing config (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: edm_requests_count
                                    
                                    	Number of EDM requests processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: edm_processing_time
                                    
                                    	Time spent processing EDM requests (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_messages_sent
                                    
                                    	bRIB API output messages sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_bytes_sent
                                    
                                    	bRIB API output bytes sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_bytes_generated
                                    
                                    	bRIB API output bytes generated
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_output_prefixes_advertised
                                    
                                    	bRIB API output prefixes advertised
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_prefixes_withdrawn
                                    
                                    	bRIB API output prefixes withdrawn
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_sending_time
                                    
                                    	Time spent sending output to bRIB API (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_output_generation_time
                                    
                                    	Time spent generating output for bRIB API (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: brib_api_output_calls
                                    
                                    	bRIB API calls to generate output
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_messages
                                    
                                    	bRIB API input messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_bytes
                                    
                                    	bRIB API input bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: brib_api_input_prefixes_received
                                    
                                    	bRIB API input advertised prefixes received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_withdrawn_prefixes
                                    
                                    	bRIB API input withdrawn prefixes received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: brib_api_input_processing_time
                                    
                                    	Time spent processing input from bRIB API (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: instance_node_role
                                    
                                    	Node role \- active/passive
                                    	**type**\: bool
                                    
                                    .. attribute:: active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                    
                                    	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: proc_scoped_sync_state
                                    
                                    	BGP scoped sync state
                                    	**type**\:  :py:class:`BgpScopedSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncState>`
                                    
                                    .. attribute:: initial_sync_sessions_added
                                    
                                    	If true, BGP has at least one established session when NSR initial synchronization is started
                                    	**type**\: bool
                                    
                                    .. attribute:: in_event_attach_calls
                                    
                                    	event\_file\_attach  calls for input
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: out_event_attach_calls
                                    
                                    	event\_file\_attach  calls for output
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: in_out_event_attach_calls
                                    
                                    	event\_file\_attach calls for input
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_timer_id
                                    
                                    	Updgen master timer ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgen_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: current_clock_time
                                    
                                    	Current time
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: updgen_handler_tm
                                    
                                    	Timestamp when updgen timer handler got called
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_timer_id
                                    
                                    	IO master timer ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_tree_timer_left
                                    
                                    	Time left before the QNX timer would expire
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_tree_timer_expiry
                                    
                                    	Time as per tree\->mtexptime
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: io_handler_tm
                                    
                                    	Timestamp when IO timer handler got called
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: qad_messages_sent
                                    
                                    	Messages sent on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadack_sent
                                    
                                    	Acks sent on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_failure
                                    
                                    	Send failure on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_ac_ks_failure
                                    
                                    	Ack failure on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_suspends
                                    
                                    	QAD send suspend
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_resumes
                                    
                                    	QAD send resume 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_send_drops
                                    
                                    	Send packets dropped due to null peer 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_messages_received
                                    
                                    	Messages received on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_processed
                                    
                                    	Messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_ac_ks_received
                                    
                                    	Acks received on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_received
                                    
                                    	Timeouts received on QAD 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_init_drops
                                    
                                    	Packets dropped on standby during initialization
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qadoos_drops
                                    
                                    	Packets dropped due to  out of sequence packetreceived
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_recv_drops
                                    
                                    	Received packet dropped due to null peer 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: qad_timeout_recvd
                                    
                                    	Number of packet send timeouts 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_last_reset_reason
                                    
                                    	Reason for last nsr state  machine reset
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: redcon_nsr_ready
                                    
                                    	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                    	**type**\: bool
                                    
                                    .. attribute:: redcon_state_time
                                    
                                    	Time when nsr state wasconveyed to Redcon last
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: active_nsr_state
                                    
                                    	Current Active BGP nsrstate
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sec_active_nsr_state
                                    
                                    	Current Sec Active BGP nsrstate
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_outstanding_postits
                                    
                                    	Total outstanding postits across all neighbors
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_neighbors_with_pending_postits
                                    
                                    	Total nbrs with pending postits
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tep2p_auto_tunnel_enabled
                                    
                                    	TE support for P2P auto tunnel
                                    	**type**\: bool
                                    
                                    .. attribute:: active_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of  		 :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime>`
                                    
                                    .. attribute:: standby_nsr_mode_enter_time
                                    
                                    	Time that each mode was entered (seconds since  Jan 1 1970)
                                    	**type**\: list of  		 :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime>`
                                    
                                    .. attribute:: active_nsrfo_time
                                    
                                    	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                    	**type**\: list of  		 :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime>`
                                    
                                    .. attribute:: postit_count_info
                                    
                                    	List of neighbors and their postit counts
                                    	**type**\: list of  		 :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo>`
                                    
                                    .. attribute:: issu_milestone
                                    
                                    	ISSU Milestones
                                    	**type**\: list of  		 :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "performance-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ipv4rib-server", ("ipv4rib_server", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer)), ("ipv6rib-server", ("ipv6rib_server", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer)), ("te-connection", ("te_connection", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection)), ("lsd-connection", ("lsd_connection", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection)), ("ds-npl", ("ds_npl", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl)), ("active-nsr-mode-enter-time", ("active_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime)), ("standby-nsr-mode-enter-time", ("standby_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime)), ("active-nsrfo-time", ("active_nsrfo_time", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime)), ("postit-count-info", ("postit_count_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo)), ("issu-milestone", ("issu_milestone", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone))])
                                        self._leafs = OrderedDict([
                                            ('configuration_items_processed', (YLeaf(YType.uint32, 'configuration-items-processed'), ['int'])),
                                            ('configuration_processing_time', (YLeaf(YType.uint32, 'configuration-processing-time'), ['int'])),
                                            ('edm_requests_count', (YLeaf(YType.uint32, 'edm-requests-count'), ['int'])),
                                            ('edm_processing_time', (YLeaf(YType.uint32, 'edm-processing-time'), ['int'])),
                                            ('brib_api_output_messages_sent', (YLeaf(YType.uint32, 'brib-api-output-messages-sent'), ['int'])),
                                            ('brib_api_output_bytes_sent', (YLeaf(YType.uint32, 'brib-api-output-bytes-sent'), ['int'])),
                                            ('brib_api_output_bytes_generated', (YLeaf(YType.uint32, 'brib-api-output-bytes-generated'), ['int'])),
                                            ('brib_api_output_prefixes_advertised', (YLeaf(YType.uint32, 'brib-api-output-prefixes-advertised'), ['int'])),
                                            ('brib_api_output_prefixes_withdrawn', (YLeaf(YType.uint32, 'brib-api-output-prefixes-withdrawn'), ['int'])),
                                            ('brib_api_output_sending_time', (YLeaf(YType.uint32, 'brib-api-output-sending-time'), ['int'])),
                                            ('brib_api_output_generation_time', (YLeaf(YType.uint32, 'brib-api-output-generation-time'), ['int'])),
                                            ('brib_api_output_calls', (YLeaf(YType.uint32, 'brib-api-output-calls'), ['int'])),
                                            ('brib_api_input_messages', (YLeaf(YType.uint32, 'brib-api-input-messages'), ['int'])),
                                            ('brib_api_input_bytes', (YLeaf(YType.uint32, 'brib-api-input-bytes'), ['int'])),
                                            ('brib_api_input_prefixes_received', (YLeaf(YType.uint32, 'brib-api-input-prefixes-received'), ['int'])),
                                            ('brib_api_input_withdrawn_prefixes', (YLeaf(YType.uint32, 'brib-api-input-withdrawn-prefixes'), ['int'])),
                                            ('brib_api_input_processing_time', (YLeaf(YType.uint32, 'brib-api-input-processing-time'), ['int'])),
                                            ('instance_node_role', (YLeaf(YType.boolean, 'instance-node-role'), ['bool'])),
                                            ('active_nsrtcp_phase_two_enter_time', (YLeaf(YType.uint32, 'active-nsrtcp-phase-two-enter-time'), ['int'])),
                                            ('sec_active_nsrtcp_phase_two_enter_time', (YLeaf(YType.uint32, 'sec-active-nsrtcp-phase-two-enter-time'), ['int'])),
                                            ('proc_scoped_sync_state', (YLeaf(YType.enumeration, 'proc-scoped-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpScopedSyncState', '')])),
                                            ('initial_sync_sessions_added', (YLeaf(YType.boolean, 'initial-sync-sessions-added'), ['bool'])),
                                            ('in_event_attach_calls', (YLeaf(YType.uint32, 'in-event-attach-calls'), ['int'])),
                                            ('out_event_attach_calls', (YLeaf(YType.uint32, 'out-event-attach-calls'), ['int'])),
                                            ('in_out_event_attach_calls', (YLeaf(YType.uint32, 'in-out-event-attach-calls'), ['int'])),
                                            ('updgen_timer_id', (YLeaf(YType.uint32, 'updgen-timer-id'), ['int'])),
                                            ('updgen_tree_timer_left', (YLeaf(YType.uint64, 'updgen-tree-timer-left'), ['int'])),
                                            ('updgen_tree_timer_expiry', (YLeaf(YType.uint64, 'updgen-tree-timer-expiry'), ['int'])),
                                            ('current_clock_time', (YLeaf(YType.uint64, 'current-clock-time'), ['int'])),
                                            ('updgen_handler_tm', (YLeaf(YType.uint64, 'updgen-handler-tm'), ['int'])),
                                            ('io_timer_id', (YLeaf(YType.uint32, 'io-timer-id'), ['int'])),
                                            ('io_tree_timer_left', (YLeaf(YType.uint64, 'io-tree-timer-left'), ['int'])),
                                            ('io_tree_timer_expiry', (YLeaf(YType.uint64, 'io-tree-timer-expiry'), ['int'])),
                                            ('io_handler_tm', (YLeaf(YType.uint64, 'io-handler-tm'), ['int'])),
                                            ('qad_messages_sent', (YLeaf(YType.uint32, 'qad-messages-sent'), ['int'])),
                                            ('qadack_sent', (YLeaf(YType.uint32, 'qadack-sent'), ['int'])),
                                            ('qad_send_failure', (YLeaf(YType.uint32, 'qad-send-failure'), ['int'])),
                                            ('qad_ac_ks_failure', (YLeaf(YType.uint32, 'qad-ac-ks-failure'), ['int'])),
                                            ('qad_suspends', (YLeaf(YType.uint32, 'qad-suspends'), ['int'])),
                                            ('qad_resumes', (YLeaf(YType.uint32, 'qad-resumes'), ['int'])),
                                            ('qad_send_drops', (YLeaf(YType.uint32, 'qad-send-drops'), ['int'])),
                                            ('qad_messages_received', (YLeaf(YType.uint32, 'qad-messages-received'), ['int'])),
                                            ('qad_processed', (YLeaf(YType.uint32, 'qad-processed'), ['int'])),
                                            ('qad_ac_ks_received', (YLeaf(YType.uint32, 'qad-ac-ks-received'), ['int'])),
                                            ('qad_timeout_received', (YLeaf(YType.uint32, 'qad-timeout-received'), ['int'])),
                                            ('qad_init_drops', (YLeaf(YType.uint32, 'qad-init-drops'), ['int'])),
                                            ('qadoos_drops', (YLeaf(YType.uint32, 'qadoos-drops'), ['int'])),
                                            ('qad_recv_drops', (YLeaf(YType.uint32, 'qad-recv-drops'), ['int'])),
                                            ('qad_timeout_recvd', (YLeaf(YType.uint32, 'qad-timeout-recvd'), ['int'])),
                                            ('nsr_last_reset_reason', (YLeaf(YType.uint8, 'nsr-last-reset-reason'), ['int'])),
                                            ('redcon_nsr_ready', (YLeaf(YType.boolean, 'redcon-nsr-ready'), ['bool'])),
                                            ('redcon_state_time', (YLeaf(YType.uint32, 'redcon-state-time'), ['int'])),
                                            ('active_nsr_state', (YLeaf(YType.uint32, 'active-nsr-state'), ['int'])),
                                            ('sec_active_nsr_state', (YLeaf(YType.uint32, 'sec-active-nsr-state'), ['int'])),
                                            ('total_outstanding_postits', (YLeaf(YType.uint32, 'total-outstanding-postits'), ['int'])),
                                            ('total_neighbors_with_pending_postits', (YLeaf(YType.uint32, 'total-neighbors-with-pending-postits'), ['int'])),
                                            ('tep2p_auto_tunnel_enabled', (YLeaf(YType.boolean, 'tep2p-auto-tunnel-enabled'), ['bool'])),
                                        ])
                                        self.configuration_items_processed = None
                                        self.configuration_processing_time = None
                                        self.edm_requests_count = None
                                        self.edm_processing_time = None
                                        self.brib_api_output_messages_sent = None
                                        self.brib_api_output_bytes_sent = None
                                        self.brib_api_output_bytes_generated = None
                                        self.brib_api_output_prefixes_advertised = None
                                        self.brib_api_output_prefixes_withdrawn = None
                                        self.brib_api_output_sending_time = None
                                        self.brib_api_output_generation_time = None
                                        self.brib_api_output_calls = None
                                        self.brib_api_input_messages = None
                                        self.brib_api_input_bytes = None
                                        self.brib_api_input_prefixes_received = None
                                        self.brib_api_input_withdrawn_prefixes = None
                                        self.brib_api_input_processing_time = None
                                        self.instance_node_role = None
                                        self.active_nsrtcp_phase_two_enter_time = None
                                        self.sec_active_nsrtcp_phase_two_enter_time = None
                                        self.proc_scoped_sync_state = None
                                        self.initial_sync_sessions_added = None
                                        self.in_event_attach_calls = None
                                        self.out_event_attach_calls = None
                                        self.in_out_event_attach_calls = None
                                        self.updgen_timer_id = None
                                        self.updgen_tree_timer_left = None
                                        self.updgen_tree_timer_expiry = None
                                        self.current_clock_time = None
                                        self.updgen_handler_tm = None
                                        self.io_timer_id = None
                                        self.io_tree_timer_left = None
                                        self.io_tree_timer_expiry = None
                                        self.io_handler_tm = None
                                        self.qad_messages_sent = None
                                        self.qadack_sent = None
                                        self.qad_send_failure = None
                                        self.qad_ac_ks_failure = None
                                        self.qad_suspends = None
                                        self.qad_resumes = None
                                        self.qad_send_drops = None
                                        self.qad_messages_received = None
                                        self.qad_processed = None
                                        self.qad_ac_ks_received = None
                                        self.qad_timeout_received = None
                                        self.qad_init_drops = None
                                        self.qadoos_drops = None
                                        self.qad_recv_drops = None
                                        self.qad_timeout_recvd = None
                                        self.nsr_last_reset_reason = None
                                        self.redcon_nsr_ready = None
                                        self.redcon_state_time = None
                                        self.active_nsr_state = None
                                        self.sec_active_nsr_state = None
                                        self.total_outstanding_postits = None
                                        self.total_neighbors_with_pending_postits = None
                                        self.tep2p_auto_tunnel_enabled = None

                                        self.ipv4rib_server = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer()
                                        self.ipv4rib_server.parent = self
                                        self._children_name_map["ipv4rib_server"] = "ipv4rib-server"

                                        self.ipv6rib_server = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer()
                                        self.ipv6rib_server.parent = self
                                        self._children_name_map["ipv6rib_server"] = "ipv6rib-server"

                                        self.te_connection = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection()
                                        self.te_connection.parent = self
                                        self._children_name_map["te_connection"] = "te-connection"

                                        self.lsd_connection = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection()
                                        self.lsd_connection.parent = self
                                        self._children_name_map["lsd_connection"] = "lsd-connection"

                                        self.ds_npl = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl()
                                        self.ds_npl.parent = self
                                        self._children_name_map["ds_npl"] = "ds-npl"

                                        self.active_nsr_mode_enter_time = YList(self)
                                        self.standby_nsr_mode_enter_time = YList(self)
                                        self.active_nsrfo_time = YList(self)
                                        self.postit_count_info = YList(self)
                                        self.issu_milestone = YList(self)
                                        self._segment_path = lambda: "global"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global, [u'configuration_items_processed', u'configuration_processing_time', u'edm_requests_count', u'edm_processing_time', u'brib_api_output_messages_sent', u'brib_api_output_bytes_sent', u'brib_api_output_bytes_generated', u'brib_api_output_prefixes_advertised', u'brib_api_output_prefixes_withdrawn', u'brib_api_output_sending_time', u'brib_api_output_generation_time', u'brib_api_output_calls', u'brib_api_input_messages', u'brib_api_input_bytes', u'brib_api_input_prefixes_received', u'brib_api_input_withdrawn_prefixes', u'brib_api_input_processing_time', u'instance_node_role', u'active_nsrtcp_phase_two_enter_time', u'sec_active_nsrtcp_phase_two_enter_time', u'proc_scoped_sync_state', u'initial_sync_sessions_added', u'in_event_attach_calls', u'out_event_attach_calls', u'in_out_event_attach_calls', u'updgen_timer_id', u'updgen_tree_timer_left', u'updgen_tree_timer_expiry', u'current_clock_time', u'updgen_handler_tm', u'io_timer_id', u'io_tree_timer_left', u'io_tree_timer_expiry', u'io_handler_tm', u'qad_messages_sent', u'qadack_sent', u'qad_send_failure', u'qad_ac_ks_failure', u'qad_suspends', u'qad_resumes', u'qad_send_drops', u'qad_messages_received', u'qad_processed', u'qad_ac_ks_received', u'qad_timeout_received', u'qad_init_drops', u'qadoos_drops', u'qad_recv_drops', u'qad_timeout_recvd', u'nsr_last_reset_reason', u'redcon_nsr_ready', u'redcon_state_time', u'active_nsr_state', u'sec_active_nsr_state', u'total_outstanding_postits', u'total_neighbors_with_pending_postits', u'tep2p_auto_tunnel_enabled'], name, value)


                                    class Ipv4ribServer(Entity):
                                        """
                                        IPv4 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:  :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:  :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:  :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:  :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer, self).__init__()

                                            self.yang_name = "ipv4rib-server"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("first-rib-connection-up-timestamp", ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp)), ("last-rib-connection-up-timestamp", ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp)), ("first-rib-connection-down-timestamp", ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp)), ("last-rib-connection-down-timestamp", ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('is_rib_connection_up', (YLeaf(YType.boolean, 'is-rib-connection-up'), ['bool'])),
                                                ('rib_connection_up_count', (YLeaf(YType.uint32, 'rib-connection-up-count'), ['int'])),
                                                ('last_rib_connection_up_age', (YLeaf(YType.uint32, 'last-rib-connection-up-age'), ['int'])),
                                                ('rib_connection_down_count', (YLeaf(YType.uint32, 'rib-connection-down-count'), ['int'])),
                                                ('last_rib_connection_down_age', (YLeaf(YType.uint32, 'last-rib-connection-down-age'), ['int'])),
                                            ])
                                            self.is_rib_connection_up = None
                                            self.rib_connection_up_count = None
                                            self.last_rib_connection_up_age = None
                                            self.rib_connection_down_count = None
                                            self.last_rib_connection_down_age = None

                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"

                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"

                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"

                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                            self._segment_path = lambda: "ipv4rib-server"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer, [u'is_rib_connection_up', u'rib_connection_up_count', u'last_rib_connection_up_age', u'rib_connection_down_count', u'last_rib_connection_down_age'], name, value)


                                        class FirstRibConnectionUpTimestamp(Entity):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibConnectionUpTimestamp(Entity):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstRibConnectionDownTimestamp(Entity):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibConnectionDownTimestamp(Entity):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv4rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class Ipv6ribServer(Entity):
                                        """
                                        IPv6 RIB server global info
                                        
                                        .. attribute:: first_rib_connection_up_timestamp
                                        
                                        	First RIB connection Up event timestamp
                                        	**type**\:  :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_up_timestamp
                                        
                                        	Last RIB connection Up event timestamp
                                        	**type**\:  :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp>`
                                        
                                        .. attribute:: first_rib_connection_down_timestamp
                                        
                                        	First RIB connection Down event timestamp
                                        	**type**\:  :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_rib_connection_down_timestamp
                                        
                                        	Last RIB connection Down event timestamp
                                        	**type**\:  :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp>`
                                        
                                        .. attribute:: is_rib_connection_up
                                        
                                        	Is RIB Connection Up?
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_connection_up_count
                                        
                                        	Number of RIB connection Up events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_connection_up_age
                                        
                                        	Time since last RIB connection Up event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_connection_down_count
                                        
                                        	Number of RIB connection Down events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_connection_down_age
                                        
                                        	Time since last RIB connection Down event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer, self).__init__()

                                            self.yang_name = "ipv6rib-server"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("first-rib-connection-up-timestamp", ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp)), ("last-rib-connection-up-timestamp", ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp)), ("first-rib-connection-down-timestamp", ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp)), ("last-rib-connection-down-timestamp", ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('is_rib_connection_up', (YLeaf(YType.boolean, 'is-rib-connection-up'), ['bool'])),
                                                ('rib_connection_up_count', (YLeaf(YType.uint32, 'rib-connection-up-count'), ['int'])),
                                                ('last_rib_connection_up_age', (YLeaf(YType.uint32, 'last-rib-connection-up-age'), ['int'])),
                                                ('rib_connection_down_count', (YLeaf(YType.uint32, 'rib-connection-down-count'), ['int'])),
                                                ('last_rib_connection_down_age', (YLeaf(YType.uint32, 'last-rib-connection-down-age'), ['int'])),
                                            ])
                                            self.is_rib_connection_up = None
                                            self.rib_connection_up_count = None
                                            self.last_rib_connection_up_age = None
                                            self.rib_connection_down_count = None
                                            self.last_rib_connection_down_age = None

                                            self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp()
                                            self.first_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"

                                            self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp()
                                            self.last_rib_connection_up_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"

                                            self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp()
                                            self.first_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"

                                            self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp()
                                            self.last_rib_connection_down_timestamp.parent = self
                                            self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                            self._segment_path = lambda: "ipv6rib-server"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer, [u'is_rib_connection_up', u'rib_connection_up_count', u'last_rib_connection_up_age', u'rib_connection_down_count', u'last_rib_connection_down_age'], name, value)


                                        class FirstRibConnectionUpTimestamp(Entity):
                                            """
                                            First RIB connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibConnectionUpTimestamp(Entity):
                                            """
                                            Last RIB connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-up-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstRibConnectionDownTimestamp(Entity):
                                            """
                                            First RIB connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibConnectionDownTimestamp(Entity):
                                            """
                                            Last RIB connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-rib-connection-down-timestamp"
                                                self.yang_parent_name = "ipv6rib-server"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class TeConnection(Entity):
                                        """
                                        MPLS TE server connection info
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:  :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:  :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp>`
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:  :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:  :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\: bool
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection, self).__init__()

                                            self.yang_name = "te-connection"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("first-connection-up-timestamp", ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp)), ("last-connection-up-timestamp", ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp)), ("first-connection-down-timestamp", ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp)), ("last-connection-down-timestamp", ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('is_connection_up', (YLeaf(YType.boolean, 'is-connection-up'), ['bool'])),
                                                ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                                ('last_connection_up_age', (YLeaf(YType.uint32, 'last-connection-up-age'), ['int'])),
                                                ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                                ('last_connection_down_age', (YLeaf(YType.uint32, 'last-connection-down-age'), ['int'])),
                                            ])
                                            self.is_connection_up = None
                                            self.connection_up_count = None
                                            self.last_connection_up_age = None
                                            self.connection_down_count = None
                                            self.last_connection_down_age = None

                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"

                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self
                                            self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"

                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"

                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                            self._segment_path = lambda: "te-connection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection, [u'is_connection_up', u'connection_up_count', u'last_connection_up_age', u'connection_down_count', u'last_connection_down_age'], name, value)


                                        class FirstConnectionUpTimestamp(Entity):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-connection-up-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastConnectionUpTimestamp(Entity):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-connection-up-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstConnectionDownTimestamp(Entity):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-connection-down-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastConnectionDownTimestamp(Entity):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-connection-down-timestamp"
                                                self.yang_parent_name = "te-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LsdConnection(Entity):
                                        """
                                        MPLS LSD server connection info
                                        
                                        .. attribute:: first_connection_up_timestamp
                                        
                                        	First connection Up event timestamp
                                        	**type**\:  :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp>`
                                        
                                        .. attribute:: last_connection_up_timestamp
                                        
                                        	Last connection Up event timestamp
                                        	**type**\:  :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp>`
                                        
                                        .. attribute:: first_connection_down_timestamp
                                        
                                        	First connection Down event timestamp
                                        	**type**\:  :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp>`
                                        
                                        .. attribute:: last_connection_down_timestamp
                                        
                                        	Last connection Down event timestamp
                                        	**type**\:  :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp>`
                                        
                                        .. attribute:: is_connection_up
                                        
                                        	Is Connection Up?
                                        	**type**\: bool
                                        
                                        .. attribute:: connection_up_count
                                        
                                        	Number of connection Up events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_connection_up_age
                                        
                                        	Time since last connection Up event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: connection_down_count
                                        
                                        	Number of connection down events
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_connection_down_age
                                        
                                        	Time since last connection Down event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection, self).__init__()

                                            self.yang_name = "lsd-connection"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("first-connection-up-timestamp", ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp)), ("last-connection-up-timestamp", ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp)), ("first-connection-down-timestamp", ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp)), ("last-connection-down-timestamp", ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('is_connection_up', (YLeaf(YType.boolean, 'is-connection-up'), ['bool'])),
                                                ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                                ('last_connection_up_age', (YLeaf(YType.uint32, 'last-connection-up-age'), ['int'])),
                                                ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                                ('last_connection_down_age', (YLeaf(YType.uint32, 'last-connection-down-age'), ['int'])),
                                            ])
                                            self.is_connection_up = None
                                            self.connection_up_count = None
                                            self.last_connection_up_age = None
                                            self.connection_down_count = None
                                            self.last_connection_down_age = None

                                            self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp()
                                            self.first_connection_up_timestamp.parent = self
                                            self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"

                                            self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp()
                                            self.last_connection_up_timestamp.parent = self
                                            self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"

                                            self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp()
                                            self.first_connection_down_timestamp.parent = self
                                            self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"

                                            self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp()
                                            self.last_connection_down_timestamp.parent = self
                                            self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                            self._segment_path = lambda: "lsd-connection"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection, [u'is_connection_up', u'connection_up_count', u'last_connection_up_age', u'connection_down_count', u'last_connection_down_age'], name, value)


                                        class FirstConnectionUpTimestamp(Entity):
                                            """
                                            First connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "first-connection-up-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastConnectionUpTimestamp(Entity):
                                            """
                                            Last connection Up event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp, self).__init__()

                                                self.yang_name = "last-connection-up-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-connection-up-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstConnectionDownTimestamp(Entity):
                                            """
                                            First connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "first-connection-down-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastConnectionDownTimestamp(Entity):
                                            """
                                            Last connection Down event timestamp
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp, self).__init__()

                                                self.yang_name = "last-connection-down-timestamp"
                                                self.yang_parent_name = "lsd-connection"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-connection-down-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class DsNpl(Entity):
                                        """
                                        NSR related DS and NPL information
                                        
                                        .. attribute:: dir_service_conn_state
                                        
                                        	Current Directory Service connectionstate
                                        	**type**\:  :py:class:`BgpDsConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnState>`
                                        
                                        .. attribute:: issu_mgr_conn_state
                                        
                                        	Current ISSU Mgr connection state
                                        	**type**\:  :py:class:`BgpIsmConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnState>`
                                        
                                        .. attribute:: issu_phase
                                        
                                        	Current ISSU Phase
                                        	**type**\: str
                                        
                                        .. attribute:: issu_type_ng
                                        
                                        	ISSU type is Next Gen
                                        	**type**\: bool
                                        
                                        .. attribute:: issuha_option
                                        
                                        	Current ISSU HA option
                                        	**type**\: str
                                        
                                        .. attribute:: local_ds_handle
                                        
                                        	Local Directory Service handle
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: service_name
                                        
                                        	Local DS service name
                                        	**type**\: str
                                        
                                        .. attribute:: dsissu_status_flag
                                        
                                        	DS ISSU status flag
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: npl_priority_statistic
                                        
                                        	NPL priority statistics
                                        	**type**\: list of  		 :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic>`
                                        
                                        .. attribute:: npl_endpoint
                                        
                                        	NPL endpoint information
                                        	**type**\: list of  		 :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl, self).__init__()

                                            self.yang_name = "ds-npl"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("npl-priority-statistic", ("npl_priority_statistic", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic)), ("npl-endpoint", ("npl_endpoint", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint))])
                                            self._leafs = OrderedDict([
                                                ('dir_service_conn_state', (YLeaf(YType.enumeration, 'dir-service-conn-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpDsConnState', '')])),
                                                ('issu_mgr_conn_state', (YLeaf(YType.enumeration, 'issu-mgr-conn-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpIsmConnState', '')])),
                                                ('issu_phase', (YLeaf(YType.str, 'issu-phase'), ['str'])),
                                                ('issu_type_ng', (YLeaf(YType.boolean, 'issu-type-ng'), ['bool'])),
                                                ('issuha_option', (YLeaf(YType.str, 'issuha-option'), ['str'])),
                                                ('local_ds_handle', (YLeaf(YType.uint64, 'local-ds-handle'), ['int'])),
                                                ('service_name', (YLeaf(YType.str, 'service-name'), ['str'])),
                                                ('dsissu_status_flag', (YLeaf(YType.uint32, 'dsissu-status-flag'), ['int'])),
                                            ])
                                            self.dir_service_conn_state = None
                                            self.issu_mgr_conn_state = None
                                            self.issu_phase = None
                                            self.issu_type_ng = None
                                            self.issuha_option = None
                                            self.local_ds_handle = None
                                            self.service_name = None
                                            self.dsissu_status_flag = None

                                            self.npl_priority_statistic = YList(self)
                                            self.npl_endpoint = YList(self)
                                            self._segment_path = lambda: "ds-npl"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl, [u'dir_service_conn_state', u'issu_mgr_conn_state', u'issu_phase', u'issu_type_ng', u'issuha_option', u'local_ds_handle', u'service_name', u'dsissu_status_flag'], name, value)


                                        class NplPriorityStatistic(Entity):
                                            """
                                            NPL priority statistics
                                            
                                            .. attribute:: num_sent
                                            
                                            	Total sent
                                            	**type**\: list of  		 :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent>`
                                            
                                            .. attribute:: num_recv
                                            
                                            	Total recvd
                                            	**type**\: list of  		 :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv>`
                                            
                                            .. attribute:: num_sent_drop
                                            
                                            	Sent Error/drops
                                            	**type**\: list of  		 :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                            
                                            .. attribute:: num_recv_drop
                                            
                                            	Recv Errors/drops
                                            	**type**\: list of  		 :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic, self).__init__()

                                                self.yang_name = "npl-priority-statistic"
                                                self.yang_parent_name = "ds-npl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("num-sent", ("num_sent", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent)), ("num-recv", ("num_recv", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv)), ("num-sent-drop", ("num_sent_drop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop)), ("num-recv-drop", ("num_recv_drop", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop))])
                                                self._leafs = OrderedDict()

                                                self.num_sent = YList(self)
                                                self.num_recv = YList(self)
                                                self.num_sent_drop = YList(self)
                                                self.num_recv_drop = YList(self)
                                                self._segment_path = lambda: "npl-priority-statistic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic, [], name, value)


                                            class NumSent(Entity):
                                                """
                                                Total sent
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent, self).__init__()

                                                    self.yang_name = "num-sent"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint64, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "num-sent"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent, [u'entry'], name, value)


                                            class NumRecv(Entity):
                                                """
                                                Total recvd
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv, self).__init__()

                                                    self.yang_name = "num-recv"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint64, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "num-recv"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv, [u'entry'], name, value)


                                            class NumSentDrop(Entity):
                                                """
                                                Sent Error/drops
                                                
                                                .. attribute:: nsr_pl_send_drop_array
                                                
                                                	nsr pl send drop array
                                                	**type**\: list of  		 :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop, self).__init__()

                                                    self.yang_name = "num-sent-drop"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nsr-pl-send-drop-array", ("nsr_pl_send_drop_array", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray))])
                                                    self._leafs = OrderedDict()

                                                    self.nsr_pl_send_drop_array = YList(self)
                                                    self._segment_path = lambda: "num-sent-drop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop, [], name, value)


                                                class NsrPlSendDropArray(Entity):
                                                    """
                                                    nsr pl send drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                                        self.yang_name = "nsr-pl-send-drop-array"
                                                        self.yang_parent_name = "num-sent-drop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "nsr-pl-send-drop-array"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, [u'entry'], name, value)


                                            class NumRecvDrop(Entity):
                                                """
                                                Recv Errors/drops
                                                
                                                .. attribute:: nsr_pl_recv_drop_array
                                                
                                                	nsr pl recv drop array
                                                	**type**\: list of  		 :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop, self).__init__()

                                                    self.yang_name = "num-recv-drop"
                                                    self.yang_parent_name = "npl-priority-statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nsr-pl-recv-drop-array", ("nsr_pl_recv_drop_array", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray))])
                                                    self._leafs = OrderedDict()

                                                    self.nsr_pl_recv_drop_array = YList(self)
                                                    self._segment_path = lambda: "num-recv-drop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop, [], name, value)


                                                class NsrPlRecvDropArray(Entity):
                                                    """
                                                    nsr pl recv drop array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                                        self.yang_name = "nsr-pl-recv-drop-array"
                                                        self.yang_parent_name = "num-recv-drop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "nsr-pl-recv-drop-array"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, [u'entry'], name, value)


                                        class NplEndpoint(Entity):
                                            """
                                            NPL endpoint information
                                            
                                            .. attribute:: endpoint_name
                                            
                                            	Endpoint name
                                            	**type**\: str
                                            
                                            .. attribute:: sync_group_name
                                            
                                            	Syncgroup associated with this endpoint
                                            	**type**\: str
                                            
                                            .. attribute:: node_id
                                            
                                            	Node ID
                                            	**type**\: str
                                            
                                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                            
                                            .. attribute:: endpoint_handle
                                            
                                            	NCD endpoint handle
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: endpoint_stale_flag
                                            
                                            	Endpoint stale flag
                                            	**type**\: bool
                                            
                                            .. attribute:: endpoint_issu_role
                                            
                                            	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                            	**type**\: str
                                            
                                            .. attribute:: endpoint_active_flag
                                            
                                            	Endpoint active flag
                                            	**type**\: bool
                                            
                                            .. attribute:: msg_size
                                            
                                            	Message size for this entity
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: wheel_id
                                            
                                            	Wheel ID for this endpoint
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: expected_sequence_num
                                            
                                            	Expected sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: endpoint
                                            
                                            	NCD endpoint bytestream
                                            	**type**\: list of  		 :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint, self).__init__()

                                                self.yang_name = "npl-endpoint"
                                                self.yang_parent_name = "ds-npl"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("endpoint", ("endpoint", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint))])
                                                self._leafs = OrderedDict([
                                                    ('endpoint_name', (YLeaf(YType.str, 'endpoint-name'), ['str'])),
                                                    ('sync_group_name', (YLeaf(YType.str, 'sync-group-name'), ['str'])),
                                                    ('node_id', (YLeaf(YType.str, 'node-id'), ['str'])),
                                                    ('endpoint_handle', (YLeaf(YType.uint64, 'endpoint-handle'), ['int'])),
                                                    ('endpoint_stale_flag', (YLeaf(YType.boolean, 'endpoint-stale-flag'), ['bool'])),
                                                    ('endpoint_issu_role', (YLeaf(YType.str, 'endpoint-issu-role'), ['str'])),
                                                    ('endpoint_active_flag', (YLeaf(YType.boolean, 'endpoint-active-flag'), ['bool'])),
                                                    ('msg_size', (YLeaf(YType.uint32, 'msg-size'), ['int'])),
                                                    ('wheel_id', (YLeaf(YType.uint32, 'wheel-id'), ['int'])),
                                                    ('expected_sequence_num', (YLeaf(YType.uint32, 'expected-sequence-num'), ['int'])),
                                                ])
                                                self.endpoint_name = None
                                                self.sync_group_name = None
                                                self.node_id = None
                                                self.endpoint_handle = None
                                                self.endpoint_stale_flag = None
                                                self.endpoint_issu_role = None
                                                self.endpoint_active_flag = None
                                                self.msg_size = None
                                                self.wheel_id = None
                                                self.expected_sequence_num = None

                                                self.endpoint = YList(self)
                                                self._segment_path = lambda: "npl-endpoint"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint, [u'endpoint_name', u'sync_group_name', u'node_id', u'endpoint_handle', u'endpoint_stale_flag', u'endpoint_issu_role', u'endpoint_active_flag', u'msg_size', u'wheel_id', u'expected_sequence_num'], name, value)


                                            class Endpoint(Entity):
                                                """
                                                NCD endpoint bytestream
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint, self).__init__()

                                                    self.yang_name = "endpoint"
                                                    self.yang_parent_name = "npl-endpoint"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "endpoint"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint, [u'entry'], name, value)


                                    class ActiveNsrModeEnterTime(Entity):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime, self).__init__()

                                            self.yang_name = "active-nsr-mode-enter-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "active-nsr-mode-enter-time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime, [u'entry'], name, value)


                                    class StandbyNsrModeEnterTime(Entity):
                                        """
                                        Time that each mode was entered (seconds since
                                        
                                        Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime, self).__init__()

                                            self.yang_name = "standby-nsr-mode-enter-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "standby-nsr-mode-enter-time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime, [u'entry'], name, value)


                                    class ActiveNsrfoTime(Entity):
                                        """
                                        Time that each thread isdone with its
                                        
                                        go\-activeprocessing (seconds since Jan 1 1970)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime, self).__init__()

                                            self.yang_name = "active-nsrfo-time"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "active-nsrfo-time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime, [u'entry'], name, value)


                                    class PostitCountInfo(Entity):
                                        """
                                        List of neighbors and their postit counts
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress>`
                                        
                                        .. attribute:: postit_count
                                        
                                        	Count of the number of postits for this nbr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo, self).__init__()

                                            self.yang_name = "postit-count-info"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('postit_count', (YLeaf(YType.uint32, 'postit-count'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.postit_count = None
                                            self.vrf_name = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "postit-count-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo, [u'postit_count', u'vrf_name'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "postit-count-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class IssuMilestone(Entity):
                                        """
                                        ISSU Milestones
                                        
                                        .. attribute:: milestone_name
                                        
                                        	Milestone name
                                        	**type**\: str
                                        
                                        .. attribute:: milestone_start_timestamp
                                        
                                        	Milestone start timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: milestone_met_timestamp
                                        
                                        	Milestone met timestamp
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone, self).__init__()

                                            self.yang_name = "issu-milestone"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('milestone_name', (YLeaf(YType.str, 'milestone-name'), ['str'])),
                                                ('milestone_start_timestamp', (YLeaf(YType.uint32, 'milestone-start-timestamp'), ['int'])),
                                                ('milestone_met_timestamp', (YLeaf(YType.uint32, 'milestone-met-timestamp'), ['int'])),
                                            ])
                                            self.milestone_name = None
                                            self.milestone_start_timestamp = None
                                            self.milestone_met_timestamp = None
                                            self._segment_path = lambda: "issu-milestone"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone, [u'milestone_name', u'milestone_start_timestamp', u'milestone_met_timestamp'], name, value)


                                class Vrf_(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: lpts_set_up_time
                                    
                                    	Time spent setting up LPTS socket opt (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lpts_calls
                                    
                                    	Number of times LPTS socket opt set up
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_throttles_count
                                    
                                    	Number of partial read throttles
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above low threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: high_throttled_read_count
                                    
                                    	Number of socket reads for nbrs above high threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	Number of bytes of data written
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to to funvction to process sub\-group message list
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of Calls to function to process write queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing imbound update messages (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "performance-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lpts_set_up_time', (YLeaf(YType.uint32, 'lpts-set-up-time'), ['int'])),
                                            ('lpts_calls', (YLeaf(YType.uint32, 'lpts-calls'), ['int'])),
                                            ('read_throttles_count', (YLeaf(YType.uint32, 'read-throttles-count'), ['int'])),
                                            ('low_throttled_read_count', (YLeaf(YType.uint32, 'low-throttled-read-count'), ['int'])),
                                            ('high_throttled_read_count', (YLeaf(YType.uint32, 'high-throttled-read-count'), ['int'])),
                                            ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                            ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                            ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                            ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                            ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                            ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                            ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                            ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                            ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                            ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                            ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                            ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                            ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                            ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                            ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                        ])
                                        self.lpts_set_up_time = None
                                        self.lpts_calls = None
                                        self.read_throttles_count = None
                                        self.low_throttled_read_count = None
                                        self.high_throttled_read_count = None
                                        self.read_calls_count = None
                                        self.read_messages_count = None
                                        self.data_bytes_read = None
                                        self.io_read_time = None
                                        self.write_calls_count = None
                                        self.data_bytes_written = None
                                        self.io_write_time = None
                                        self.write_subgroup_calls_count = None
                                        self.write_subgroup_messages_count = None
                                        self.subgroup_list_time = None
                                        self.write_queue_calls_count = None
                                        self.write_queue_messages_count = None
                                        self.write_queue_time = None
                                        self.inbound_update_messages = None
                                        self.inbound_update_messages_time = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.ProcessInfo.PerformanceStatistics.Vrf_, [u'lpts_set_up_time', u'lpts_calls', u'read_throttles_count', u'low_throttled_read_count', u'high_throttled_read_count', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time'], name, value)


                        class Sessions(Entity):
                            """
                            The BGP session table
                            
                            .. attribute:: session
                            
                            	A BGP session table entry
                            	**type**\: list of  		 :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions, self).__init__()

                                self.yang_name = "sessions"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("session", ("session", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session))])
                                self._leafs = OrderedDict()

                                self.session = YList(self)
                                self._segment_path = lambda: "sessions"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions, [], name, value)


                            class Session(Entity):
                                """
                                A BGP session table entry
                                
                                .. attribute:: neighbor_address  (key)
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress>`
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\: str
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\: bool
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\: str
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\: bool
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: postit_pending
                                
                                	Nbr has postits pending
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session, self).__init__()

                                    self.yang_name = "session"
                                    self.yang_parent_name = "sessions"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_address']
                                    self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                        ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                        ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                        ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                        ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                        ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                        ('postit_pending', (YLeaf(YType.boolean, 'postit-pending'), ['bool'])),
                                    ])
                                    self.neighbor_address = None
                                    self.speaker_id = None
                                    self.description = None
                                    self.local_as = None
                                    self.remote_as = None
                                    self.messages_queued_in = None
                                    self.messages_queued_out = None
                                    self.connection_state = None
                                    self.is_local_address_configured = None
                                    self.vrf_name = None
                                    self.nsr_enabled = None
                                    self.nsr_state = None
                                    self.postit_pending = None

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                    self._segment_path = lambda: "session" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'messages_queued_in', u'messages_queued_out', u'connection_state', u'is_local_address_configured', u'vrf_name', u'nsr_enabled', u'nsr_state', u'postit_pending'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "session"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-local-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "session"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-remote-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class Neighbors(Entity):
                            """
                            The BGP Neighbor table
                            
                            .. attribute:: neighbor
                            
                            	A BGP Neighbor table entry
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors, self).__init__()

                                self.yang_name = "neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor))])
                                self._leafs = OrderedDict()

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "neighbors"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors, [], name, value)


                            class Neighbor(Entity):
                                """
                                A BGP Neighbor table entry
                                
                                .. attribute:: neighbor_address  (key)
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                                
                                .. attribute:: send_notification_info
                                
                                	Information on the last notification sent
                                	**type**\:  :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo>`
                                
                                .. attribute:: received_notification_info
                                
                                	Information on the last notification received
                                	**type**\:  :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics>`
                                
                                .. attribute:: message_statistics
                                
                                	Message statistics
                                	**type**\:  :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics>`
                                
                                .. attribute:: tcp_init_sync_time_spec
                                
                                	Time When neighbor entered TCP Init Sync
                                	**type**\:  :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_phase_two_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Phase Two
                                	**type**\:  :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                
                                .. attribute:: tcp_init_sync_done_time_spec
                                
                                	Time when neighbor entered TCP Init Sync Done
                                	**type**\:  :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance>`
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\: str
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_external_neighbor_not_directly_connected
                                
                                	External neighbor not directly connected
                                	**type**\: bool
                                
                                .. attribute:: messages_received
                                
                                	Number of messages received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_sent
                                
                                	Number of messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_in
                                
                                	No. of update msgs received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_messages_out
                                
                                	No. of update messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_in
                                
                                	No. of msgs on receive queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: messages_queued_out
                                
                                	No. of messages on send queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_established_time
                                
                                	Time (in secs) that the connection has been established
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                .. attribute:: previous_connection_state
                                
                                	Previous state of connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_admin_status
                                
                                	Administrative status of connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: open_check_error_code
                                
                                	Open check error code
                                	**type**\:  :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\: bool
                                
                                .. attribute:: connection_local_port
                                
                                	Local port for the connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_remote_port
                                
                                	Remote port for the connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_interface_handle
                                
                                	Interface Handle of Neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_notification_sent
                                
                                	Notification was sent during last reset
                                	**type**\: bool
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\: bool
                                
                                .. attribute:: is_out_of_memory_shutdown
                                
                                	Neighbor shut down during a SEVERE low memory condition
                                	**type**\: bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\: bool
                                
                                .. attribute:: is_ebgp_peer_as_league
                                
                                	EBGP peer belongs to AS League
                                	**type**\: bool
                                
                                .. attribute:: is_ebgp_peer_common_admin
                                
                                	EBGP peer with common administation
                                	**type**\: bool
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\: bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\: bool
                                
                                .. attribute:: bfd_session_state
                                
                                	BFD state for this peer
                                	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                
                                .. attribute:: bfd_session_created_state
                                
                                	BFD state for this peer
                                	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_state_ts
                                
                                	Timestamp since when nbr is in this bfd state
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: router_id
                                
                                	Router ID for the neighbor
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: negotiated_protocol_version
                                
                                	Negotiated protocol version
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\: bool
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\: bool
                                
                                .. attribute:: is_capability_negotiation_suppressed
                                
                                	Capability negotiation suppressed
                                	**type**\: bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\: bool
                                
                                .. attribute:: is_route_refresh_capability_received
                                
                                	Route refresh capability received
                                	**type**\: bool
                                
                                .. attribute:: is_route_refresh_old_capability_received
                                
                                	Route refresh old capability received
                                	**type**\: bool
                                
                                .. attribute:: is_gr_aware
                                
                                	GR awareness received
                                	**type**\: bool
                                
                                .. attribute:: is4_byte_as_capability_received
                                
                                	4\-byte AScapability received
                                	**type**\: bool
                                
                                .. attribute:: is4_byte_as_capability_sent
                                
                                	4\-byte AScapability Snt
                                	**type**\: bool
                                
                                .. attribute:: multi_protocol_capability_received
                                
                                	Multi\-protocol capability has been received
                                	**type**\: bool
                                
                                .. attribute:: hold_time
                                
                                	Hold time (in secs) negotiated for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: keep_alive_time
                                
                                	Keepalive time (in secs) negotiated for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: connect_retry_interval
                                
                                	Time (in secs) for connect retry timer
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_update
                                
                                	Time (in secs) since last update message was received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read
                                
                                	Time (in secs) since last read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_since_last_read_reset
                                
                                	Time (in secs) since last read before last reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: time_last_cb
                                
                                	CB
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: time_last_cb_reset
                                
                                	Last CB before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_last_fb
                                
                                	FB
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: count_last_write
                                
                                	Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_last_write
                                
                                	Time (in secs) since last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: attempted_last_write_bytes
                                
                                	Attempted size of last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_last_write_bytes
                                
                                	Actual size of last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_second_last_write
                                
                                	Time (in secs) since second  last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: attempted_second_last_write_bytes
                                
                                	Attempted size of second last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_bytes
                                
                                	Actual size of second last write
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: attempted_last_write_reset_bytes
                                
                                	Attempted size of last write before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_last_write_reset_bytes
                                
                                	Actual size of last write before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_second_last_write_reset
                                
                                	Time (in secs) since last write before last reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: attempted_second_last_write_reset_bytes
                                
                                	Attempted size of second last write before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: actual_second_last_write_reset_bytes
                                
                                	Actual size of second last write before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_write_event
                                
                                	Time (in secs) since last write thread event
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_write_event
                                
                                	Time (in secs) since second last write thread event
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_aexpiry_reset
                                
                                	Time (in secs) since last KA timer expiry before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_k_aexpiry_reset
                                
                                	Time (in secs) since second last KA timer expiry before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_anotsent_reset
                                
                                	Duration (in secs) since last time that KA was not sent before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_aerror_reset
                                
                                	Duration (in secs) since last time that an error was encountered after KA expiry
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: last_k_astart_reset
                                
                                	Time (in secs) since the last KA timer start before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: second_last_k_astart_reset
                                
                                	Time (in secs) since the second last KA timer start before reset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: connection_up_count
                                
                                	Number of times the connection was established
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connection_down_count
                                
                                	Number of times connection was dropped
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_connection_last_dropped
                                
                                	Time since the connection last went down (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: reset_reason
                                
                                	Reason for last connection reset
                                	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                
                                .. attribute:: peer_reset_reason
                                
                                	Reason for last peer close event
                                	**type**\:  :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                
                                .. attribute:: peer_error_code
                                
                                	If peer closed, error received from transport
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_notify_error_code
                                
                                	Code for the last error notification seen on the connection
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_notify_error_subcode
                                
                                	Error subcode of the last error notification seen on the connection
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: error_notifies_received
                                
                                	Number of error notifications received on the connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: error_notifies_sent
                                
                                	Number of error notifications sent on the connection
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\: bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\: str
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\: bool
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\: bool
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\: bool
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: fssn_offset
                                
                                	First standby SeqNo offset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fpbsn_offset
                                
                                	First standby PDU boundary SeqNo offset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_ackd_seq_no
                                
                                	SeqNo of the last Ackd byte
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bytes_written
                                
                                	Total bytes written by write thread
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: bytes_read
                                
                                	Total bytes read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: socket_read_bytes
                                
                                	Total read bytes value insocket\-lib
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: is_read_disabled
                                
                                	If true, socket read isdisabled
                                	**type**\: bool
                                
                                .. attribute:: update_bytes_read
                                
                                	Total update bytes read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: nsr_state
                                
                                	NSR state
                                	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\: bool
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\: bool
                                
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\: bool
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\: bool
                                
                                .. attribute:: io_armed
                                
                                	If true, socket has beenauto\-armed for io control
                                	**type**\: bool
                                
                                .. attribute:: read_armed
                                
                                	If true, socket has beenauto\-armed for read
                                	**type**\: bool
                                
                                .. attribute:: write_armed
                                
                                	If true, socket has beenauto\-armed for write
                                	**type**\: bool
                                
                                .. attribute:: discard_data_bytes
                                
                                	Remaining discard data (bytes) on Standby
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\: bool
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\: bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\: bool
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\: bool
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\: bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\: bool
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\: bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\: bool
                                
                                .. attribute:: dynamic_neighbor
                                
                                	Dynamic neighbor
                                	**type**\: bool
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_address']
                                    self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress)), ("send-notification-info", ("send_notification_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo)), ("received-notification-info", ("received_notification_info", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics)), ("message-statistics", ("message_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics)), ("tcp-init-sync-time-spec", ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec)), ("tcp-init-sync-phase-two-time-spec", ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec)), ("tcp-init-sync-done-time-spec", ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                        ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                        ('is_external_neighbor_not_directly_connected', (YLeaf(YType.boolean, 'is-external-neighbor-not-directly-connected'), ['bool'])),
                                        ('messages_received', (YLeaf(YType.uint32, 'messages-received'), ['int'])),
                                        ('messages_sent', (YLeaf(YType.uint32, 'messages-sent'), ['int'])),
                                        ('update_messages_in', (YLeaf(YType.uint32, 'update-messages-in'), ['int'])),
                                        ('update_messages_out', (YLeaf(YType.uint32, 'update-messages-out'), ['int'])),
                                        ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                        ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                        ('connection_established_time', (YLeaf(YType.uint32, 'connection-established-time'), ['int'])),
                                        ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                        ('previous_connection_state', (YLeaf(YType.uint32, 'previous-connection-state'), ['int'])),
                                        ('connection_admin_status', (YLeaf(YType.uint32, 'connection-admin-status'), ['int'])),
                                        ('open_check_error_code', (YLeaf(YType.enumeration, 'open-check-error-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpOpenCheckErr', '')])),
                                        ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                        ('connection_local_port', (YLeaf(YType.uint32, 'connection-local-port'), ['int'])),
                                        ('connection_remote_port', (YLeaf(YType.uint32, 'connection-remote-port'), ['int'])),
                                        ('neighbor_interface_handle', (YLeaf(YType.uint32, 'neighbor-interface-handle'), ['int'])),
                                        ('reset_notification_sent', (YLeaf(YType.boolean, 'reset-notification-sent'), ['bool'])),
                                        ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                        ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                        ('is_out_of_memory_shutdown', (YLeaf(YType.boolean, 'is-out-of-memory-shutdown'), ['bool'])),
                                        ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                        ('is_ebgp_peer_as_league', (YLeaf(YType.boolean, 'is-ebgp-peer-as-league'), ['bool'])),
                                        ('is_ebgp_peer_common_admin', (YLeaf(YType.boolean, 'is-ebgp-peer-common-admin'), ['bool'])),
                                        ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                        ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                        ('bfd_session_state', (YLeaf(YType.enumeration, 'bfd-session-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                        ('bfd_session_created_state', (YLeaf(YType.enumeration, 'bfd-session-created-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                        ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                        ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                        ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                        ('bfd_state_ts', (YLeaf(YType.uint64, 'bfd-state-ts'), ['int'])),
                                        ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                        ('negotiated_protocol_version', (YLeaf(YType.uint16, 'negotiated-protocol-version'), ['int'])),
                                        ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                        ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                        ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                        ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                        ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                        ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                        ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                        ('is_capability_negotiation_suppressed', (YLeaf(YType.boolean, 'is-capability-negotiation-suppressed'), ['bool'])),
                                        ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                        ('is_route_refresh_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-capability-received'), ['bool'])),
                                        ('is_route_refresh_old_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-old-capability-received'), ['bool'])),
                                        ('is_gr_aware', (YLeaf(YType.boolean, 'is-gr-aware'), ['bool'])),
                                        ('is4_byte_as_capability_received', (YLeaf(YType.boolean, 'is4-byte-as-capability-received'), ['bool'])),
                                        ('is4_byte_as_capability_sent', (YLeaf(YType.boolean, 'is4-byte-as-capability-sent'), ['bool'])),
                                        ('multi_protocol_capability_received', (YLeaf(YType.boolean, 'multi-protocol-capability-received'), ['bool'])),
                                        ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                        ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                        ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                        ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                        ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                        ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                        ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                        ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                        ('connect_retry_interval', (YLeaf(YType.uint16, 'connect-retry-interval'), ['int'])),
                                        ('time_since_last_update', (YLeaf(YType.uint32, 'time-since-last-update'), ['int'])),
                                        ('time_since_last_read', (YLeaf(YType.uint32, 'time-since-last-read'), ['int'])),
                                        ('time_since_last_read_reset', (YLeaf(YType.uint32, 'time-since-last-read-reset'), ['int'])),
                                        ('time_last_cb', (YLeaf(YType.uint64, 'time-last-cb'), ['int'])),
                                        ('time_last_cb_reset', (YLeaf(YType.uint32, 'time-last-cb-reset'), ['int'])),
                                        ('time_last_fb', (YLeaf(YType.uint64, 'time-last-fb'), ['int'])),
                                        ('count_last_write', (YLeaf(YType.uint32, 'count-last-write'), ['int'])),
                                        ('time_since_last_write', (YLeaf(YType.uint32, 'time-since-last-write'), ['int'])),
                                        ('attempted_last_write_bytes', (YLeaf(YType.uint32, 'attempted-last-write-bytes'), ['int'])),
                                        ('actual_last_write_bytes', (YLeaf(YType.uint32, 'actual-last-write-bytes'), ['int'])),
                                        ('time_since_second_last_write', (YLeaf(YType.uint32, 'time-since-second-last-write'), ['int'])),
                                        ('attempted_second_last_write_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-bytes'), ['int'])),
                                        ('actual_second_last_write_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-bytes'), ['int'])),
                                        ('time_since_last_write_reset', (YLeaf(YType.uint32, 'time-since-last-write-reset'), ['int'])),
                                        ('attempted_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-last-write-reset-bytes'), ['int'])),
                                        ('actual_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-last-write-reset-bytes'), ['int'])),
                                        ('time_since_second_last_write_reset', (YLeaf(YType.uint32, 'time-since-second-last-write-reset'), ['int'])),
                                        ('attempted_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-reset-bytes'), ['int'])),
                                        ('actual_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-reset-bytes'), ['int'])),
                                        ('last_write_event', (YLeaf(YType.uint32, 'last-write-event'), ['int'])),
                                        ('second_last_write_event', (YLeaf(YType.uint32, 'second-last-write-event'), ['int'])),
                                        ('last_k_aexpiry_reset', (YLeaf(YType.uint32, 'last-k-aexpiry-reset'), ['int'])),
                                        ('second_last_k_aexpiry_reset', (YLeaf(YType.uint32, 'second-last-k-aexpiry-reset'), ['int'])),
                                        ('last_k_anotsent_reset', (YLeaf(YType.uint32, 'last-k-anotsent-reset'), ['int'])),
                                        ('last_k_aerror_reset', (YLeaf(YType.uint32, 'last-k-aerror-reset'), ['int'])),
                                        ('last_k_astart_reset', (YLeaf(YType.uint32, 'last-k-astart-reset'), ['int'])),
                                        ('second_last_k_astart_reset', (YLeaf(YType.uint32, 'second-last-k-astart-reset'), ['int'])),
                                        ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                        ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                        ('time_since_connection_last_dropped', (YLeaf(YType.uint32, 'time-since-connection-last-dropped'), ['int'])),
                                        ('reset_reason', (YLeaf(YType.enumeration, 'reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                        ('peer_reset_reason', (YLeaf(YType.enumeration, 'peer-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPeerResetReasonIndex', '')])),
                                        ('peer_error_code', (YLeaf(YType.uint32, 'peer-error-code'), ['int'])),
                                        ('last_notify_error_code', (YLeaf(YType.uint8, 'last-notify-error-code'), ['int'])),
                                        ('last_notify_error_subcode', (YLeaf(YType.uint8, 'last-notify-error-subcode'), ['int'])),
                                        ('error_notifies_received', (YLeaf(YType.uint32, 'error-notifies-received'), ['int'])),
                                        ('error_notifies_sent', (YLeaf(YType.uint32, 'error-notifies-sent'), ['int'])),
                                        ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                        ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                        ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                        ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                        ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                        ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                        ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                        ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                        ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                        ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                        ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                        ('fssn_offset', (YLeaf(YType.uint32, 'fssn-offset'), ['int'])),
                                        ('fpbsn_offset', (YLeaf(YType.uint32, 'fpbsn-offset'), ['int'])),
                                        ('last_ackd_seq_no', (YLeaf(YType.uint32, 'last-ackd-seq-no'), ['int'])),
                                        ('bytes_written', (YLeaf(YType.uint32, 'bytes-written'), ['int'])),
                                        ('bytes_read', (YLeaf(YType.uint32, 'bytes-read'), ['int'])),
                                        ('socket_read_bytes', (YLeaf(YType.uint32, 'socket-read-bytes'), ['int'])),
                                        ('is_read_disabled', (YLeaf(YType.boolean, 'is-read-disabled'), ['bool'])),
                                        ('update_bytes_read', (YLeaf(YType.uint32, 'update-bytes-read'), ['int'])),
                                        ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                        ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                        ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                        ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                        ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                        ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                        ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                        ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                        ('io_armed', (YLeaf(YType.boolean, 'io-armed'), ['bool'])),
                                        ('read_armed', (YLeaf(YType.boolean, 'read-armed'), ['bool'])),
                                        ('write_armed', (YLeaf(YType.boolean, 'write-armed'), ['bool'])),
                                        ('discard_data_bytes', (YLeaf(YType.uint32, 'discard-data-bytes'), ['int'])),
                                        ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                        ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                        ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                        ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                        ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                        ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                        ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                        ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                        ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                        ('dynamic_neighbor', (YLeaf(YType.boolean, 'dynamic-neighbor'), ['bool'])),
                                    ])
                                    self.neighbor_address = None
                                    self.speaker_id = None
                                    self.description = None
                                    self.local_as = None
                                    self.remote_as = None
                                    self.has_internal_link = None
                                    self.is_external_neighbor_not_directly_connected = None
                                    self.messages_received = None
                                    self.messages_sent = None
                                    self.update_messages_in = None
                                    self.update_messages_out = None
                                    self.messages_queued_in = None
                                    self.messages_queued_out = None
                                    self.connection_established_time = None
                                    self.connection_state = None
                                    self.previous_connection_state = None
                                    self.connection_admin_status = None
                                    self.open_check_error_code = None
                                    self.is_local_address_configured = None
                                    self.connection_local_port = None
                                    self.connection_remote_port = None
                                    self.neighbor_interface_handle = None
                                    self.reset_notification_sent = None
                                    self.is_administratively_shut_down = None
                                    self.is_neighbor_max_prefix_shutdown = None
                                    self.is_out_of_memory_shutdown = None
                                    self.is_out_of_memory_forced_up = None
                                    self.is_ebgp_peer_as_league = None
                                    self.is_ebgp_peer_common_admin = None
                                    self.ttl_security_enabled = None
                                    self.suppress4_byte_as = None
                                    self.bfd_session_state = None
                                    self.bfd_session_created_state = None
                                    self.bfd_session_enable_mode = None
                                    self.bfd_minintervalval = None
                                    self.bfd_multiplierval = None
                                    self.bfd_state_ts = None
                                    self.router_id = None
                                    self.negotiated_protocol_version = None
                                    self.ebgp_time_to_live = None
                                    self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                    self.tcpmss = None
                                    self.msg_log_in = None
                                    self.msg_log_out = None
                                    self.neighbor_local_as = None
                                    self.local_as_no_prepend = None
                                    self.is_capability_negotiation_suppressed = None
                                    self.is_capability_negotiation_performed = None
                                    self.is_route_refresh_capability_received = None
                                    self.is_route_refresh_old_capability_received = None
                                    self.is_gr_aware = None
                                    self.is4_byte_as_capability_received = None
                                    self.is4_byte_as_capability_sent = None
                                    self.multi_protocol_capability_received = None
                                    self.hold_time = None
                                    self.keep_alive_time = None
                                    self.configured_hold_time = None
                                    self.configured_keepalive = None
                                    self.configured_min_acc_hold_time = None
                                    self.min_advertise_interval = None
                                    self.min_advertise_interval_msecs = None
                                    self.min_origination_interval = None
                                    self.connect_retry_interval = None
                                    self.time_since_last_update = None
                                    self.time_since_last_read = None
                                    self.time_since_last_read_reset = None
                                    self.time_last_cb = None
                                    self.time_last_cb_reset = None
                                    self.time_last_fb = None
                                    self.count_last_write = None
                                    self.time_since_last_write = None
                                    self.attempted_last_write_bytes = None
                                    self.actual_last_write_bytes = None
                                    self.time_since_second_last_write = None
                                    self.attempted_second_last_write_bytes = None
                                    self.actual_second_last_write_bytes = None
                                    self.time_since_last_write_reset = None
                                    self.attempted_last_write_reset_bytes = None
                                    self.actual_last_write_reset_bytes = None
                                    self.time_since_second_last_write_reset = None
                                    self.attempted_second_last_write_reset_bytes = None
                                    self.actual_second_last_write_reset_bytes = None
                                    self.last_write_event = None
                                    self.second_last_write_event = None
                                    self.last_k_aexpiry_reset = None
                                    self.second_last_k_aexpiry_reset = None
                                    self.last_k_anotsent_reset = None
                                    self.last_k_aerror_reset = None
                                    self.last_k_astart_reset = None
                                    self.second_last_k_astart_reset = None
                                    self.connection_up_count = None
                                    self.connection_down_count = None
                                    self.time_since_connection_last_dropped = None
                                    self.reset_reason = None
                                    self.peer_reset_reason = None
                                    self.peer_error_code = None
                                    self.last_notify_error_code = None
                                    self.last_notify_error_subcode = None
                                    self.error_notifies_received = None
                                    self.error_notifies_sent = None
                                    self.remote_as_number = None
                                    self.dmz_link_bandwidth = None
                                    self.ebgp_recv_dmz = None
                                    self.ebgp_send_dmz_mode = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.tcp_session_open_mode = None
                                    self.vrf_name = None
                                    self.standby_rp = None
                                    self.nsr_enabled = None
                                    self.graceful_restart_enabled_nbr = None
                                    self.gr_restart_time = None
                                    self.gr_stale_path_time = None
                                    self.fssn_offset = None
                                    self.fpbsn_offset = None
                                    self.last_ackd_seq_no = None
                                    self.bytes_written = None
                                    self.bytes_read = None
                                    self.socket_read_bytes = None
                                    self.is_read_disabled = None
                                    self.update_bytes_read = None
                                    self.nsr_state = None
                                    self.is_passive_close = None
                                    self.nbr_enforce_first_as = None
                                    self.active_bmp_servers = None
                                    self.nbr_cluster_id = None
                                    self.nbr_in_cluster = None
                                    self.ignore_connected = None
                                    self.internal_vpn_client = None
                                    self.io_armed = None
                                    self.read_armed = None
                                    self.write_armed = None
                                    self.discard_data_bytes = None
                                    self.local_as_replace_as = None
                                    self.local_as_dual_as = None
                                    self.local_as_dual_as_mode_native = None
                                    self.egress_peer_engineering_enabled = None
                                    self.discard_as4_path = None
                                    self.rpki_disable = None
                                    self.rpki_use_validity = None
                                    self.rpki_allow_invalid = None
                                    self.rpki_signal_ibgp = None
                                    self.dynamic_neighbor = None

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                    self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo()
                                    self.send_notification_info.parent = self
                                    self._children_name_map["send_notification_info"] = "send-notification-info"

                                    self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                    self.received_notification_info.parent = self
                                    self._children_name_map["received_notification_info"] = "received-notification-info"

                                    self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self._children_name_map["performance_statistics"] = "performance-statistics"

                                    self.message_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics()
                                    self.message_statistics.parent = self
                                    self._children_name_map["message_statistics"] = "message-statistics"

                                    self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                    self.tcp_init_sync_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"

                                    self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                    self.tcp_init_sync_phase_two_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"

                                    self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                    self.tcp_init_sync_done_time_spec.parent = self
                                    self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"

                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                    self.af_data = YList(self)
                                    self._segment_path = lambda: "neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_external_neighbor_not_directly_connected', u'messages_received', u'messages_sent', u'update_messages_in', u'update_messages_out', u'messages_queued_in', u'messages_queued_out', u'connection_established_time', u'connection_state', u'previous_connection_state', u'connection_admin_status', u'open_check_error_code', u'is_local_address_configured', u'connection_local_port', u'connection_remote_port', u'neighbor_interface_handle', u'reset_notification_sent', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_shutdown', u'is_out_of_memory_forced_up', u'is_ebgp_peer_as_league', u'is_ebgp_peer_common_admin', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_state', u'bfd_session_created_state', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'bfd_state_ts', u'router_id', u'negotiated_protocol_version', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_suppressed', u'is_capability_negotiation_performed', u'is_route_refresh_capability_received', u'is_route_refresh_old_capability_received', u'is_gr_aware', u'is4_byte_as_capability_received', u'is4_byte_as_capability_sent', u'multi_protocol_capability_received', u'hold_time', u'keep_alive_time', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'connect_retry_interval', u'time_since_last_update', u'time_since_last_read', u'time_since_last_read_reset', u'time_last_cb', u'time_last_cb_reset', u'time_last_fb', u'count_last_write', u'time_since_last_write', u'attempted_last_write_bytes', u'actual_last_write_bytes', u'time_since_second_last_write', u'attempted_second_last_write_bytes', u'actual_second_last_write_bytes', u'time_since_last_write_reset', u'attempted_last_write_reset_bytes', u'actual_last_write_reset_bytes', u'time_since_second_last_write_reset', u'attempted_second_last_write_reset_bytes', u'actual_second_last_write_reset_bytes', u'last_write_event', u'second_last_write_event', u'last_k_aexpiry_reset', u'second_last_k_aexpiry_reset', u'last_k_anotsent_reset', u'last_k_aerror_reset', u'last_k_astart_reset', u'second_last_k_astart_reset', u'connection_up_count', u'connection_down_count', u'time_since_connection_last_dropped', u'reset_reason', u'peer_reset_reason', u'peer_error_code', u'last_notify_error_code', u'last_notify_error_subcode', u'error_notifies_received', u'error_notifies_sent', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'fssn_offset', u'fpbsn_offset', u'last_ackd_seq_no', u'bytes_written', u'bytes_read', u'socket_read_bytes', u'is_read_disabled', u'update_bytes_read', u'nsr_state', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'io_armed', u'read_armed', u'write_armed', u'discard_data_bytes', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'dynamic_neighbor'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-local-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-remote-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class SendNotificationInfo(Entity):
                                    """
                                    Information on the last notification sent
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo, self).__init__()

                                        self.yang_name = "send-notification-info"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData))])
                                        self._leafs = OrderedDict([
                                            ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                            ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                            ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                        ])
                                        self.time_since_last_notification = None
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "send-notification-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "send-notification-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "last-notification-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                class ReceivedNotificationInfo(Entity):
                                    """
                                    Information on the last notification received
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo, self).__init__()

                                        self.yang_name = "received-notification-info"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData))])
                                        self._leafs = OrderedDict([
                                            ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                            ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                            ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                        ])
                                        self.time_since_last_notification = None
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "received-notification-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "received-notification-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "last-notification-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                class PerformanceStatistics(Entity):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: read_throttles
                                    
                                    	Number of partial read throttles
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_throttled_read
                                    
                                    	Num socket reads after nbrs crossed low threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: high_throttled_read
                                    
                                    	Num of socket reads after nbr crossed high threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_last_throttled_read
                                    
                                    	Time (in secs) since last read after being throttled
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: read_calls_count
                                    
                                    	No. of calls to function to read inbound data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: read_messages_count
                                    
                                    	Number of BGP messages read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_read
                                    
                                    	No. of bytes of data read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: io_read_time
                                    
                                    	Time spent reading inbound data (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_calls_count
                                    
                                    	No. of calls to function to write outbound data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: data_bytes_written
                                    
                                    	No. of data bytes written
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: io_write_time
                                    
                                    	Time spent writing outbound data (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: last_sent_seq_no
                                    
                                    	Seq No of the last sent byte
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_calls_count
                                    
                                    	No. of calls to function to process sub\-group message list
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_subgroup_messages_count
                                    
                                    	Number of sub\-group msgs processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subgroup_list_time
                                    
                                    	Time spent processing sub\-group message list  (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: write_queue_calls_count
                                    
                                    	No. of calls to function to process write queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_messages_count
                                    
                                    	Number of write queue messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: write_queue_time
                                    
                                    	Time spent processing write queue (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: inbound_update_messages
                                    
                                    	Number of inbound update messages processed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_update_messages_time
                                    
                                    	Time spent processing inbound update messages (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: maximum_read_size
                                    
                                    	Size of largest socket (milliseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: actives
                                    
                                    	Number of retried Active opens for this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: failed_post_actives
                                    
                                    	Number of Active Opens that failed in the Post Active State for this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passives
                                    
                                    	Number of retried Passive opens for this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rejected_passives
                                    
                                    	Number of rejected Passive opens for this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: active_collision
                                    
                                    	Number of Closed Active connections for this neighbor due to collision 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: passive_collision
                                    
                                    	Number of Closed Remote opens for this neighborneighbor due to collision 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_read_thread_trigger
                                    
                                    	Number of times io\-control thread trigger read thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: control_to_write_thread_trigger
                                    
                                    	Number of times io\-control thread trigger write thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: network_status
                                    
                                    	Socket status, TRUE if socket closed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_flags
                                    
                                    	Reset flags, per thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nbr_flags
                                    
                                    	Nbr flags, per thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nbr_fd
                                    
                                    	Primary FD, per nbr
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: reset_retries
                                    
                                    	Reset Retries, per nbr
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: sync_flags
                                    
                                    	Sync flags, per nbr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_oper_down_count
                                    
                                    	Number of times NSR scoped sync has been done
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_nsr_scoped_sync
                                    
                                    	Last time NSR scoped syncwas done for the neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics, self).__init__()

                                        self.yang_name = "performance-statistics"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('read_throttles', (YLeaf(YType.uint32, 'read-throttles'), ['int'])),
                                            ('low_throttled_read', (YLeaf(YType.uint32, 'low-throttled-read'), ['int'])),
                                            ('high_throttled_read', (YLeaf(YType.uint32, 'high-throttled-read'), ['int'])),
                                            ('time_since_last_throttled_read', (YLeaf(YType.uint32, 'time-since-last-throttled-read'), ['int'])),
                                            ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                            ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                            ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                            ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                            ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                            ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                            ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                            ('last_sent_seq_no', (YLeaf(YType.uint32, 'last-sent-seq-no'), ['int'])),
                                            ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                            ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                            ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                            ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                            ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                            ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                            ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                            ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                            ('maximum_read_size', (YLeaf(YType.uint32, 'maximum-read-size'), ['int'])),
                                            ('actives', (YLeaf(YType.uint32, 'actives'), ['int'])),
                                            ('failed_post_actives', (YLeaf(YType.uint32, 'failed-post-actives'), ['int'])),
                                            ('passives', (YLeaf(YType.uint32, 'passives'), ['int'])),
                                            ('rejected_passives', (YLeaf(YType.uint32, 'rejected-passives'), ['int'])),
                                            ('active_collision', (YLeaf(YType.uint32, 'active-collision'), ['int'])),
                                            ('passive_collision', (YLeaf(YType.uint32, 'passive-collision'), ['int'])),
                                            ('control_to_read_thread_trigger', (YLeaf(YType.uint32, 'control-to-read-thread-trigger'), ['int'])),
                                            ('control_to_write_thread_trigger', (YLeaf(YType.uint32, 'control-to-write-thread-trigger'), ['int'])),
                                            ('network_status', (YLeaf(YType.uint32, 'network-status'), ['int'])),
                                            ('reset_flags', (YLeaf(YType.uint32, 'reset-flags'), ['int'])),
                                            ('nbr_flags', (YLeaf(YType.uint32, 'nbr-flags'), ['int'])),
                                            ('nbr_fd', (YLeaf(YType.int32, 'nbr-fd'), ['int'])),
                                            ('reset_retries', (YLeaf(YType.uint8, 'reset-retries'), ['int'])),
                                            ('sync_flags', (YLeaf(YType.uint32, 'sync-flags'), ['int'])),
                                            ('nsr_oper_down_count', (YLeaf(YType.uint32, 'nsr-oper-down-count'), ['int'])),
                                            ('last_nsr_scoped_sync', (YLeaf(YType.uint32, 'last-nsr-scoped-sync'), ['int'])),
                                        ])
                                        self.read_throttles = None
                                        self.low_throttled_read = None
                                        self.high_throttled_read = None
                                        self.time_since_last_throttled_read = None
                                        self.read_calls_count = None
                                        self.read_messages_count = None
                                        self.data_bytes_read = None
                                        self.io_read_time = None
                                        self.write_calls_count = None
                                        self.data_bytes_written = None
                                        self.io_write_time = None
                                        self.last_sent_seq_no = None
                                        self.write_subgroup_calls_count = None
                                        self.write_subgroup_messages_count = None
                                        self.subgroup_list_time = None
                                        self.write_queue_calls_count = None
                                        self.write_queue_messages_count = None
                                        self.write_queue_time = None
                                        self.inbound_update_messages = None
                                        self.inbound_update_messages_time = None
                                        self.maximum_read_size = None
                                        self.actives = None
                                        self.failed_post_actives = None
                                        self.passives = None
                                        self.rejected_passives = None
                                        self.active_collision = None
                                        self.passive_collision = None
                                        self.control_to_read_thread_trigger = None
                                        self.control_to_write_thread_trigger = None
                                        self.network_status = None
                                        self.reset_flags = None
                                        self.nbr_flags = None
                                        self.nbr_fd = None
                                        self.reset_retries = None
                                        self.sync_flags = None
                                        self.nsr_oper_down_count = None
                                        self.last_nsr_scoped_sync = None
                                        self._segment_path = lambda: "performance-statistics"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.PerformanceStatistics, [u'read_throttles', u'low_throttled_read', u'high_throttled_read', u'time_since_last_throttled_read', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'last_sent_seq_no', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time', u'maximum_read_size', u'actives', u'failed_post_actives', u'passives', u'rejected_passives', u'active_collision', u'passive_collision', u'control_to_read_thread_trigger', u'control_to_write_thread_trigger', u'network_status', u'reset_flags', u'nbr_flags', u'nbr_fd', u'reset_retries', u'sync_flags', u'nsr_oper_down_count', u'last_nsr_scoped_sync'], name, value)


                                class MessageStatistics(Entity):
                                    """
                                    Message statistics
                                    
                                    .. attribute:: open
                                    
                                    	Open
                                    	**type**\:  :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                    
                                    .. attribute:: notification
                                    
                                    	Notification
                                    	**type**\:  :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                    
                                    .. attribute:: update
                                    
                                    	Update
                                    	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                    
                                    .. attribute:: keepalive
                                    
                                    	Keepalive
                                    	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                    
                                    .. attribute:: route_refresh
                                    
                                    	Route refresh
                                    	**type**\:  :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                    
                                    .. attribute:: total
                                    
                                    	Total
                                    	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics, self).__init__()

                                        self.yang_name = "message-statistics"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("open", ("open", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open)), ("notification", ("notification", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification)), ("update", ("update", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update)), ("keepalive", ("keepalive", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive)), ("route-refresh", ("route_refresh", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh)), ("total", ("total", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total))])
                                        self._leafs = OrderedDict()

                                        self.open = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open()
                                        self.open.parent = self
                                        self._children_name_map["open"] = "open"

                                        self.notification = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                        self.notification.parent = self
                                        self._children_name_map["notification"] = "notification"

                                        self.update = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update()
                                        self.update.parent = self
                                        self._children_name_map["update"] = "update"

                                        self.keepalive = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                        self.keepalive.parent = self
                                        self._children_name_map["keepalive"] = "keepalive"

                                        self.route_refresh = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                        self.route_refresh.parent = self
                                        self._children_name_map["route_refresh"] = "route-refresh"

                                        self.total = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total()
                                        self.total.parent = self
                                        self._children_name_map["total"] = "total"
                                        self._segment_path = lambda: "message-statistics"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics, [], name, value)


                                    class Open(Entity):
                                        """
                                        Open
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open, self).__init__()

                                            self.yang_name = "open"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "open"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "open"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "open"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Notification(Entity):
                                        """
                                        Notification
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification, self).__init__()

                                            self.yang_name = "notification"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "notification"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "notification"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Update(Entity):
                                        """
                                        Update
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update, self).__init__()

                                            self.yang_name = "update"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "update"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Keepalive(Entity):
                                        """
                                        Keepalive
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                            self.yang_name = "keepalive"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "keepalive"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "keepalive"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "keepalive"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class RouteRefresh(Entity):
                                        """
                                        Route refresh
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                            self.yang_name = "route-refresh"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "route-refresh"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "route-refresh"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "route-refresh"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Total(Entity):
                                        """
                                        Total
                                        
                                        .. attribute:: tx
                                        
                                        	Transmit
                                        	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                        
                                        .. attribute:: rx
                                        
                                        	Receive
                                        	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total, self).__init__()

                                            self.yang_name = "total"
                                            self.yang_parent_name = "message-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx))])
                                            self._leafs = OrderedDict()

                                            self.tx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                            self.tx.parent = self
                                            self._children_name_map["tx"] = "tx"

                                            self.rx = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                            self.rx.parent = self
                                            self._children_name_map["rx"] = "rx"
                                            self._segment_path = lambda: "total"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total, [], name, value)


                                        class Tx(Entity):
                                            """
                                            Transmit
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                self.yang_name = "tx"
                                                self.yang_parent_name = "total"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "tx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "tx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Rx(Entity):
                                            """
                                            Receive
                                            
                                            .. attribute:: last_time_spec
                                            
                                            	Last timespec
                                            	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                            
                                            .. attribute:: count
                                            
                                            	Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                self.yang_name = "rx"
                                                self.yang_parent_name = "total"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                ])
                                                self.count = None

                                                self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                self.last_time_spec.parent = self
                                                self._children_name_map["last_time_spec"] = "last-time-spec"
                                                self._segment_path = lambda: "rx"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, [u'count'], name, value)


                                            class LastTimeSpec(Entity):
                                                """
                                                Last timespec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                    self.yang_name = "last-time-spec"
                                                    self.yang_parent_name = "rx"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "last-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class TcpInitSyncTimeSpec(Entity):
                                    """
                                    Time When neighbor entered TCP Init Sync
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "tcp-init-sync-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                    """
                                    Time when neighbor entered TCP Init Sync Phase
                                    Two
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class TcpInitSyncDoneTimeSpec(Entity):
                                    """
                                    Time when neighbor entered TCP Init Sync Done
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                        self.yang_name = "tcp-init-sync-done-time-spec"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "tcp-init-sync-done-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                            ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                            ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                            ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                            ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                            ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                        ])
                                        self.gshut_exists = None
                                        self.gshut_local_active = None
                                        self.gshut_active = None
                                        self.gshut_locpref_set = None
                                        self.gshut_locpref = None
                                        self.gshut_prepends = None
                                        self._segment_path = lambda: "graceful-maintenance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                                class AfData(Entity):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: neighbor_af_performance_statistics
                                    
                                    	Neighbor AF statistics
                                    	**type**\:  :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\: bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\: bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\: str
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: advertise_afi_def_vrf_imp_disable
                                    
                                    	Advertise of default VRF import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                    
                                    	Advertise of v4 default VRF import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                    
                                    	Advertise of v6 default VRF import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_vrf_re_imp_disable
                                    
                                    	Advertise of VRF re\-import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                    
                                    	Advertise of v4 VRF re\-import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                    
                                    	Advertise of v6 VRF re\-import disable
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_eo_r_ready
                                    
                                    	EoR Can be sent for Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\: bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\: bool
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_update_throttled
                                    
                                    	Updates Throttled becausewrite limit is reached
                                    	**type**\: bool
                                    
                                    .. attribute:: is_update_leaving
                                    
                                    	Nbr leaving update\-groupto another
                                    	**type**\: bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\: bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\: bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\: bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_version
                                    
                                    	Neighbor version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: prefixes_accepted
                                    
                                    	No. of prefixes accepted
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_synced
                                    
                                    	Number of prefixes synced to standby
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn_not_found
                                    
                                    	No. of prefixes withdrawn but not found
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied
                                    
                                    	No. of prefixes denied
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_no_policy
                                    
                                    	No. of prefixes denied because there was no inbound policy
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_rt_permit
                                    
                                    	No. of prefixes denied because RT extended community is not imported
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_orf_policy
                                    
                                    	No. of prefixes denied by prefix based ORF policy
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_denied_policy
                                    
                                    	No. of prefixes denied by inbound policy
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_bestpaths
                                    
                                    	No. of bestpaths from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_best_externalpaths
                                    
                                    	No. of best\-external paths from this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_advertised
                                    
                                    	No. of prefixes advertised
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_be_advertised
                                    
                                    	No BE prefixes advertised
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_suppressed
                                    
                                    	No. of prefixes suppressed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefixes_withdrawn
                                    
                                    	No. of prefixes withdrawn
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_received
                                    
                                    	Extended nexthop encoding capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ext_nh_encoding_capability_sent
                                    
                                    	Extended nexhop encoding capability Sent
                                    	**type**\: bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_refreshes_received
                                    
                                    	Number of route refresh requests received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_refreshes_sent
                                    
                                    	Number of route refresh requests sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_target_version
                                    
                                    	Target version for refresh update generation
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_version
                                    
                                    	Version till which refresh updates have been generated
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_acked_version
                                    
                                    	Version acked by the peer for refresh updates sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\: bool
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_default_originate_sent
                                    
                                    	Default origination update sent
                                    	**type**\: bool
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\: bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\: bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\: bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_received_in_read_only
                                    
                                    	An EoR was received while in read\-only mode
                                    	**type**\: bool
                                    
                                    .. attribute:: acked_version
                                    
                                    	Version mapped from acked seqNo
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: synced_acked_version
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version
                                    
                                    	No. of all outstanding version objects waiting for ack from the peer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_refresh_version
                                    
                                    	No. of only refresh version objects waiting for ack from the peer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_max
                                    
                                    	Version mapped from acked seqNo that was synced last
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\: bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\: bool
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\: bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\: bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with 
                                    	**type**\: bool
                                    
                                    .. attribute:: prefixes_denied_non_cumulative
                                    
                                    	No. of prefixes exactly denied (non cumulative)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: enable_label_stack
                                    
                                    	Enable label stack
                                    	**type**\: bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData, self).__init__()

                                        self.yang_name = "af-data"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-af-performance-statistics", ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby))])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                            ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                            ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                            ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                            ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                            ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                            ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                            ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                            ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                            ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                            ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                            ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                            ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                            ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                            ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                            ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                            ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                            ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                            ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                            ('advertise_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-def-vrf-imp-disable'), ['bool'])),
                                            ('advertise_evpnv4_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-def-vrf-imp-disable'), ['bool'])),
                                            ('advertise_evpnv6_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-def-vrf-imp-disable'), ['bool'])),
                                            ('advertise_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-vrf-re-imp-disable'), ['bool'])),
                                            ('advertise_evpnv4_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-vrf-re-imp-disable'), ['bool'])),
                                            ('advertise_evpnv6_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-vrf-re-imp-disable'), ['bool'])),
                                            ('advertise_afi_eo_r_ready', (YLeaf(YType.boolean, 'advertise-afi-eo-r-ready'), ['bool'])),
                                            ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                            ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                            ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                            ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                            ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                            ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                            ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                            ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                            ('is_update_throttled', (YLeaf(YType.boolean, 'is-update-throttled'), ['bool'])),
                                            ('is_update_leaving', (YLeaf(YType.boolean, 'is-update-leaving'), ['bool'])),
                                            ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                            ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                            ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                            ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                            ('neighbor_version', (YLeaf(YType.uint32, 'neighbor-version'), ['int'])),
                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                            ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                            ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                            ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                            ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                            ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                            ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                            ('prefixes_accepted', (YLeaf(YType.uint32, 'prefixes-accepted'), ['int'])),
                                            ('prefixes_synced', (YLeaf(YType.uint32, 'prefixes-synced'), ['int'])),
                                            ('prefixes_withdrawn_not_found', (YLeaf(YType.uint32, 'prefixes-withdrawn-not-found'), ['int'])),
                                            ('prefixes_denied', (YLeaf(YType.uint32, 'prefixes-denied'), ['int'])),
                                            ('prefixes_denied_no_policy', (YLeaf(YType.uint32, 'prefixes-denied-no-policy'), ['int'])),
                                            ('prefixes_denied_rt_permit', (YLeaf(YType.uint32, 'prefixes-denied-rt-permit'), ['int'])),
                                            ('prefixes_denied_orf_policy', (YLeaf(YType.uint32, 'prefixes-denied-orf-policy'), ['int'])),
                                            ('prefixes_denied_policy', (YLeaf(YType.uint32, 'prefixes-denied-policy'), ['int'])),
                                            ('number_of_bestpaths', (YLeaf(YType.uint32, 'number-of-bestpaths'), ['int'])),
                                            ('number_of_best_externalpaths', (YLeaf(YType.uint32, 'number-of-best-externalpaths'), ['int'])),
                                            ('prefixes_advertised', (YLeaf(YType.uint32, 'prefixes-advertised'), ['int'])),
                                            ('prefixes_be_advertised', (YLeaf(YType.uint32, 'prefixes-be-advertised'), ['int'])),
                                            ('prefixes_suppressed', (YLeaf(YType.uint32, 'prefixes-suppressed'), ['int'])),
                                            ('prefixes_withdrawn', (YLeaf(YType.uint32, 'prefixes-withdrawn'), ['int'])),
                                            ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                            ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                            ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                            ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                            ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                            ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                            ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                            ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                            ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                            ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                            ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                            ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                            ('is_ext_nh_encoding_capability_received', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-received'), ['bool'])),
                                            ('is_ext_nh_encoding_capability_sent', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-sent'), ['bool'])),
                                            ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                            ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                            ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                            ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                            ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                            ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                            ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                            ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                            ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                            ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                            ('route_refreshes_received', (YLeaf(YType.uint32, 'route-refreshes-received'), ['int'])),
                                            ('route_refreshes_sent', (YLeaf(YType.uint32, 'route-refreshes-sent'), ['int'])),
                                            ('refresh_target_version', (YLeaf(YType.uint32, 'refresh-target-version'), ['int'])),
                                            ('refresh_version', (YLeaf(YType.uint32, 'refresh-version'), ['int'])),
                                            ('refresh_acked_version', (YLeaf(YType.uint32, 'refresh-acked-version'), ['int'])),
                                            ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                            ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                            ('is_default_originate_sent', (YLeaf(YType.boolean, 'is-default-originate-sent'), ['bool'])),
                                            ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                            ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                            ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                            ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                            ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                            ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                            ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                            ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                            ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                            ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                            ('eo_r_received_in_read_only', (YLeaf(YType.boolean, 'eo-r-received-in-read-only'), ['bool'])),
                                            ('acked_version', (YLeaf(YType.uint32, 'acked-version'), ['int'])),
                                            ('synced_acked_version', (YLeaf(YType.uint32, 'synced-acked-version'), ['int'])),
                                            ('outstanding_version', (YLeaf(YType.uint32, 'outstanding-version'), ['int'])),
                                            ('outstanding_refresh_version', (YLeaf(YType.uint32, 'outstanding-refresh-version'), ['int'])),
                                            ('outstanding_version_max', (YLeaf(YType.uint32, 'outstanding-version-max'), ['int'])),
                                            ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                            ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                            ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                            ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                            ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                            ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                            ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                            ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                            ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                            ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                            ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                            ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                            ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                            ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                            ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                            ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                            ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                            ('prefixes_denied_non_cumulative', (YLeaf(YType.uint32, 'prefixes-denied-non-cumulative'), ['int'])),
                                            ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                        ])
                                        self.af_name = None
                                        self.is_neighbor_route_reflector_client = None
                                        self.is_legacy_pe_rt = None
                                        self.is_neighbor_af_capable = None
                                        self.is_soft_reconfiguration_inbound_allowed = None
                                        self.is_use_soft_reconfiguration_always_on = None
                                        self.remove_private_as_from_updates = None
                                        self.remove_private_as_entire_aspath_from_updates = None
                                        self.remove_private_as_from_inbound_updates = None
                                        self.remove_private_as_entire_aspath_from_inbound_updates = None
                                        self.flowspec_validation_d_isable = None
                                        self.flowspec_redirect_validation_d_isable = None
                                        self.orr_group_name = None
                                        self.orr_group_index = None
                                        self.is_orr_root_address_configured = None
                                        self.advertise_afi = None
                                        self.advertise_afi_reorg = None
                                        self.advertise_afi_disable = None
                                        self.encapsulation_type = None
                                        self.advertise_rt_type = None
                                        self.advertise_afi_def_vrf_imp_disable = None
                                        self.advertise_evpnv4_afi_def_vrf_imp_disable = None
                                        self.advertise_evpnv6_afi_def_vrf_imp_disable = None
                                        self.advertise_afi_vrf_re_imp_disable = None
                                        self.advertise_evpnv4_afi_vrf_re_imp_disable = None
                                        self.advertise_evpnv6_afi_vrf_re_imp_disable = None
                                        self.advertise_afi_eo_r_ready = None
                                        self.always_use_next_hop_local = None
                                        self.sent_community_to_neighbor = None
                                        self.sent_gshut_community_to_neighbor = None
                                        self.sent_extended_community_to_neighbor = None
                                        self.neighbor_default_originate = None
                                        self.is_orf_sent = None
                                        self.is_update_deferred = None
                                        self.is_orf_send_scheduled = None
                                        self.update_group_number = None
                                        self.filter_group_index = None
                                        self.is_update_throttled = None
                                        self.is_update_leaving = None
                                        self.vpn_update_gen_enabled = None
                                        self.vpn_update_gen_trigger_enabled = None
                                        self.is_addpath_send_operational = None
                                        self.is_addpath_receive_operational = None
                                        self.neighbor_version = None
                                        self.weight = None
                                        self.max_prefix_limit = None
                                        self.use_max_prefix_warning_only = None
                                        self.max_prefix_discard_extra_paths = None
                                        self.max_prefix_exceed_discard_paths = None
                                        self.max_prefix_threshold_percent = None
                                        self.max_prefix_restart_time = None
                                        self.prefixes_accepted = None
                                        self.prefixes_synced = None
                                        self.prefixes_withdrawn_not_found = None
                                        self.prefixes_denied = None
                                        self.prefixes_denied_no_policy = None
                                        self.prefixes_denied_rt_permit = None
                                        self.prefixes_denied_orf_policy = None
                                        self.prefixes_denied_policy = None
                                        self.number_of_bestpaths = None
                                        self.number_of_best_externalpaths = None
                                        self.prefixes_advertised = None
                                        self.prefixes_be_advertised = None
                                        self.prefixes_suppressed = None
                                        self.prefixes_withdrawn = None
                                        self.is_peer_orf_capable = None
                                        self.is_advertised_orf_send = None
                                        self.is_received_orf_send_capable = None
                                        self.is_advertised_orf_receive = None
                                        self.is_received_orf_receive_capable = None
                                        self.is_advertised_graceful_restart = None
                                        self.is_graceful_restart_state_flag = None
                                        self.is_received_graceful_restart_capable = None
                                        self.is_add_path_send_capability_advertised = None
                                        self.is_add_path_send_capability_received = None
                                        self.is_add_path_receive_capability_advertised = None
                                        self.is_add_path_receive_capability_received = None
                                        self.is_ext_nh_encoding_capability_received = None
                                        self.is_ext_nh_encoding_capability_sent = None
                                        self.restart_time = None
                                        self.local_restart_time = None
                                        self.stale_path_timeout = None
                                        self.rib_purge_timeout_value = None
                                        self.neighbor_preserved_forwarding_state = None
                                        self.long_lived_graceful_restart_stale_time_configured = None
                                        self.long_lived_graceful_restart_stale_time_sent = None
                                        self.long_lived_graceful_restart_stale_time_accept = None
                                        self.long_lived_graceful_restart_capability_received = None
                                        self.long_lived_graceful_restart_stale_time_received = None
                                        self.neighbor_preserved_long_lived_forwarding_state = None
                                        self.neighbor_long_lived_graceful_restart_capable = None
                                        self.neighbor_long_lived_graceful_restart_time_remaining = None
                                        self.route_refreshes_received = None
                                        self.route_refreshes_sent = None
                                        self.refresh_target_version = None
                                        self.refresh_version = None
                                        self.refresh_acked_version = None
                                        self.is_prefix_orf_present = None
                                        self.orf_entries_received = None
                                        self.is_default_originate_sent = None
                                        self.route_policy_prefix_orf = None
                                        self.route_policy_in = None
                                        self.route_policy_out = None
                                        self.route_policy_default_originate = None
                                        self.is_neighbor_ebgp_without_inbound_policy = None
                                        self.is_neighbor_ebgp_without_outbound_policy = None
                                        self.is_as_override_set = None
                                        self.is_allow_as_in_set = None
                                        self.allow_as_in_count = None
                                        self.address_family_long_lived_time = None
                                        self.eo_r_received_in_read_only = None
                                        self.acked_version = None
                                        self.synced_acked_version = None
                                        self.outstanding_version = None
                                        self.outstanding_refresh_version = None
                                        self.outstanding_version_max = None
                                        self.is_aigp_set = None
                                        self.is_rt_present = None
                                        self.is_rt_present_standby = None
                                        self.accept_own_enabled = None
                                        self.selective_multipath_eligible = None
                                        self.afrpki_disable = None
                                        self.afrpki_use_validity = None
                                        self.afrpki_allow_invalid = None
                                        self.afrpki_signal_ibgp = None
                                        self.is_advertise_permanent_network = None
                                        self.is_send_mcast_attr = None
                                        self.import_stitching = None
                                        self.import_reoriginate = None
                                        self.import_reoriginate_stitching = None
                                        self.advertise_v4_flags = None
                                        self.advertise_v6_flags = None
                                        self.advertise_local_labeled_route_unicast = None
                                        self.prefixes_denied_non_cumulative = None
                                        self.enable_label_stack = None

                                        self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                        self.neighbor_af_performance_statistics.parent = self
                                        self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"

                                        self.extended_community = YList(self)
                                        self.extended_community_standby = YList(self)
                                        self._segment_path = lambda: "af-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_disable', u'encapsulation_type', u'advertise_rt_type', u'advertise_afi_def_vrf_imp_disable', u'advertise_evpnv4_afi_def_vrf_imp_disable', u'advertise_evpnv6_afi_def_vrf_imp_disable', u'advertise_afi_vrf_re_imp_disable', u'advertise_evpnv4_afi_vrf_re_imp_disable', u'advertise_evpnv6_afi_vrf_re_imp_disable', u'advertise_afi_eo_r_ready', u'always_use_next_hop_local', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'update_group_number', u'filter_group_index', u'is_update_throttled', u'is_update_leaving', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'neighbor_version', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'prefixes_accepted', u'prefixes_synced', u'prefixes_withdrawn_not_found', u'prefixes_denied', u'prefixes_denied_no_policy', u'prefixes_denied_rt_permit', u'prefixes_denied_orf_policy', u'prefixes_denied_policy', u'number_of_bestpaths', u'number_of_best_externalpaths', u'prefixes_advertised', u'prefixes_be_advertised', u'prefixes_suppressed', u'prefixes_withdrawn', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'is_ext_nh_encoding_capability_received', u'is_ext_nh_encoding_capability_sent', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'route_refreshes_received', u'route_refreshes_sent', u'refresh_target_version', u'refresh_version', u'refresh_acked_version', u'is_prefix_orf_present', u'orf_entries_received', u'is_default_originate_sent', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'eo_r_received_in_read_only', u'acked_version', u'synced_acked_version', u'outstanding_version', u'outstanding_refresh_version', u'outstanding_version_max', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'advertise_local_labeled_route_unicast', u'prefixes_denied_non_cumulative', u'enable_label_stack'], name, value)


                                    class NeighborAfPerformanceStatistics(Entity):
                                        """
                                        Neighbor AF statistics
                                        
                                        .. attribute:: sub_group_pending_message_count
                                        
                                        	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: processed_messages
                                        
                                        	Number of messages processed from the neighbor's write queue
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sent_messages
                                        
                                        	Number of messages sent from the neighbor's write queue
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_transmit
                                        
                                        	No. of update messages with split\-horizon flag that were sent out
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_update_blocked
                                        
                                        	No. of update messages with split\-horizon flag that were blocked
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_transmit
                                        
                                        	No. of withdraw messages with split\-horizon flag that were sent out
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: split_horizon_withdraw_blocked
                                        
                                        	No. of withdraw messages with split\-horizon flag that were blocked
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                            self.yang_name = "neighbor-af-performance-statistics"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sub_group_pending_message_count', (YLeaf(YType.uint32, 'sub-group-pending-message-count'), ['int'])),
                                                ('processed_messages', (YLeaf(YType.uint32, 'processed-messages'), ['int'])),
                                                ('sent_messages', (YLeaf(YType.uint32, 'sent-messages'), ['int'])),
                                                ('split_horizon_update_transmit', (YLeaf(YType.uint32, 'split-horizon-update-transmit'), ['int'])),
                                                ('split_horizon_update_blocked', (YLeaf(YType.uint32, 'split-horizon-update-blocked'), ['int'])),
                                                ('split_horizon_withdraw_transmit', (YLeaf(YType.uint32, 'split-horizon-withdraw-transmit'), ['int'])),
                                                ('split_horizon_withdraw_blocked', (YLeaf(YType.uint32, 'split-horizon-withdraw-blocked'), ['int'])),
                                            ])
                                            self.sub_group_pending_message_count = None
                                            self.processed_messages = None
                                            self.sent_messages = None
                                            self.split_horizon_update_transmit = None
                                            self.split_horizon_update_blocked = None
                                            self.split_horizon_withdraw_transmit = None
                                            self.split_horizon_withdraw_blocked = None
                                            self._segment_path = lambda: "neighbor-af-performance-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, [u'sub_group_pending_message_count', u'processed_messages', u'sent_messages', u'split_horizon_update_transmit', u'split_horizon_update_blocked', u'split_horizon_withdraw_transmit', u'split_horizon_withdraw_blocked'], name, value)


                                    class ExtendedCommunity(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                            self.yang_name = "extended-community"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "extended-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunity, [u'entry'], name, value)


                                    class ExtendedCommunityStandby(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                            self.yang_name = "extended-community-standby"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "extended-community-standby"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                        class NextHopVrf(Entity):
                            """
                            A BGP Next\-hop VRF table entry
                            
                            .. attribute:: total_processing_time
                            
                            	Total time spent in processing
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_proc_notification_time
                            
                            	How long since the maximum processing time notifcation was received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_deletes
                            
                            	Number of bestpath deletes caused by notification which resulted in maximum processing
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_notification_bestpath_changes
                            
                            	Number of bestpath changes caused by notification which resulted in maximum processing
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_processing_time
                            
                            	Maximum time spent procesing a single batch notification
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_notificationication_time
                            
                            	Time since the last notification was received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_notification_processing_time
                            
                            	Processing time for the last notification
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf, self).__init__()

                                self.yang_name = "next-hop-vrf"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('total_processing_time', (YLeaf(YType.uint32, 'total-processing-time'), ['int'])),
                                    ('max_proc_notification_time', (YLeaf(YType.uint32, 'max-proc-notification-time'), ['int'])),
                                    ('max_notification_bestpath_deletes', (YLeaf(YType.uint32, 'max-notification-bestpath-deletes'), ['int'])),
                                    ('max_notification_bestpath_changes', (YLeaf(YType.uint32, 'max-notification-bestpath-changes'), ['int'])),
                                    ('maximum_processing_time', (YLeaf(YType.uint32, 'maximum-processing-time'), ['int'])),
                                    ('last_notificationication_time', (YLeaf(YType.uint32, 'last-notificationication-time'), ['int'])),
                                    ('last_notification_processing_time', (YLeaf(YType.uint32, 'last-notification-processing-time'), ['int'])),
                                ])
                                self.total_processing_time = None
                                self.max_proc_notification_time = None
                                self.max_notification_bestpath_deletes = None
                                self.max_notification_bestpath_changes = None
                                self.maximum_processing_time = None
                                self.last_notificationication_time = None
                                self.last_notification_processing_time = None
                                self._segment_path = lambda: "next-hop-vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NextHopVrf, [u'total_processing_time', u'max_proc_notification_time', u'max_notification_bestpath_deletes', u'max_notification_bestpath_changes', u'maximum_processing_time', u'last_notificationication_time', u'last_notification_processing_time'], name, value)


                        class NeighborRanges(Entity):
                            """
                            The BGP Dynamic Neighbor Range table
                            
                            .. attribute:: neighbor_range
                            
                            	A BGP Neighbor Range table entry
                            	**type**\: list of  		 :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges, self).__init__()

                                self.yang_name = "neighbor-ranges"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-range", ("neighbor_range", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange))])
                                self._leafs = OrderedDict()

                                self.neighbor_range = YList(self)
                                self._segment_path = lambda: "neighbor-ranges"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges, [], name, value)


                            class NeighborRange(Entity):
                                """
                                A BGP Neighbor Range table entry
                                
                                .. attribute:: neighbor_range_address  (key)
                                
                                	Neighbor Range prefix
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                
                                .. attribute:: connection_local_address
                                
                                	Local address for the connection
                                	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                                
                                .. attribute:: connection_remote_address
                                
                                	Remote address for the connection
                                	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance
                                	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                                
                                .. attribute:: cfg_local_address
                                
                                	Configured local address
                                	**type**\:  :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                                
                                .. attribute:: speaker_id
                                
                                	Speaker this neighbor is allocated to
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: description
                                
                                	Description
                                	**type**\: str
                                
                                .. attribute:: local_as
                                
                                	Local AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_as
                                
                                	Remote AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: has_internal_link
                                
                                	Internal link to neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_local_address_configured
                                
                                	Local address configured for the neighbor connection
                                	**type**\: bool
                                
                                .. attribute:: neighbor_range_prefix_length
                                
                                	Neighbor Range Prefix Length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_administratively_shut_down
                                
                                	Neighbor is administratively shut down
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_max_prefix_shutdown
                                
                                	Neighbor shut down because it exceeded max prfx count
                                	**type**\: bool
                                
                                .. attribute:: is_out_of_memory_forced_up
                                
                                	Neighbor forced up during a low memory condition
                                	**type**\: bool
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL Security enabled
                                	**type**\: bool
                                
                                .. attribute:: suppress4_byte_as
                                
                                	Suppress 4byteas capability
                                	**type**\: bool
                                
                                .. attribute:: bfd_session_enable_mode
                                
                                	BFD enable mode for this peer
                                	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minintervalval
                                
                                	BFD Mininterval for this peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_multiplierval
                                
                                	BFD Multiplier for this peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_time_to_live
                                
                                	Maximum number of hops for external BGP neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                
                                	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                	**type**\: bool
                                
                                .. attribute:: tcpmss
                                
                                	Neighbor TCP Maximum Segment                     size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_in
                                
                                	Message in log count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_log_out
                                
                                	Message out log count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_local_as
                                
                                	Local AS configured on the neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_as_no_prepend
                                
                                	Option to not prepend the Local AS to announcements
                                	**type**\: bool
                                
                                .. attribute:: is_capability_negotiation_performed
                                
                                	Capability negotiation performed
                                	**type**\: bool
                                
                                .. attribute:: configured_hold_time
                                
                                	Hold time (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_keepalive
                                
                                	Keepalive time (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: configured_min_acc_hold_time
                                
                                	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval
                                
                                	Minimum advertisement interval, secs part
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: min_advertise_interval_msecs
                                
                                	Minimum advertisement interval, msecs part
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: min_origination_interval
                                
                                	Minimum origination interval (in secs)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: remote_as_number
                                
                                	Remote AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dmz_link_bandwidth
                                
                                	Bandwidth of link to single\-hop eBGP peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	Receive Bandwidth of link to single\-hop eBGP peer
                                	**type**\: bool
                                
                                .. attribute:: ebgp_send_dmz_mode
                                
                                	Ebgp send dmz link bw mode
                                	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: tos_type
                                
                                	Precedence or DSCP type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tcp_session_open_mode
                                
                                	The TCP mode to be used to set up BGP session with the neighbor
                                	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\: str
                                
                                .. attribute:: standby_rp
                                
                                	Standby RP socket inited for Active Open
                                	**type**\: bool
                                
                                .. attribute:: nsr_enabled
                                
                                	Neighbor supports NSR
                                	**type**\: bool
                                
                                .. attribute:: graceful_restart_enabled_nbr
                                
                                	Neighbor supports graceful\-restart
                                	**type**\: bool
                                
                                .. attribute:: gr_restart_time
                                
                                	Neighbor restart time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: gr_stale_path_time
                                
                                	Neighbor stale\-path time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: is_passive_close
                                
                                	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                	**type**\: bool
                                
                                .. attribute:: nbr_enforce_first_as
                                
                                	Neighbor enforce first AS
                                	**type**\: bool
                                
                                .. attribute:: active_bmp_servers
                                
                                	BMP Servers to which the neighbor sends logs
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nbr_cluster_id
                                
                                	Cluster id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_in_cluster
                                
                                	Type of cluster\_id\:undefined/number/Ip address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ignore_connected
                                
                                	If true, the VPN client isan IBGP CE peer
                                	**type**\: bool
                                
                                .. attribute:: internal_vpn_client
                                
                                	If true, don't do NHconnected check for nbr
                                	**type**\: bool
                                
                                .. attribute:: local_as_replace_as
                                
                                	Local AS Replace\-AS option
                                	**type**\: bool
                                
                                .. attribute:: local_as_dual_as
                                
                                	Local AS Dual\-AS option
                                	**type**\: bool
                                
                                .. attribute:: local_as_dual_as_mode_native
                                
                                	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                	**type**\: bool
                                
                                .. attribute:: egress_peer_engineering_enabled
                                
                                	Indicates if Egress Peer Engineering is enabled
                                	**type**\: bool
                                
                                .. attribute:: discard_as4_path
                                
                                	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rpki_disable
                                
                                	Prefix validation disabled
                                	**type**\: bool
                                
                                .. attribute:: rpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\: bool
                                
                                .. attribute:: rpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\: bool
                                
                                .. attribute:: rpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\: bool
                                
                                .. attribute:: remote_as_list_name
                                
                                	Remote AS List Name
                                	**type**\: str
                                
                                .. attribute:: nbr_rcv_size
                                
                                	Nbr Receive Size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_send_size
                                
                                	Nbr Send Size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: islocal_address_cfg
                                
                                	Local address configured
                                	**type**\: bool
                                
                                .. attribute:: update_source
                                
                                	Update Source
                                	**type**\: str
                                
                                .. attribute:: addpath_send_enable
                                
                                	Addpath Send enabled
                                	**type**\: bool
                                
                                .. attribute:: addpath_receive_enable
                                
                                	Addpath Receive enable
                                	**type**\: bool
                                
                                .. attribute:: addpath_send_disable
                                
                                	Addpath Send Disabled
                                	**type**\: bool
                                
                                .. attribute:: addpath_receive_disable
                                
                                	Addpath Receive Disabled
                                	**type**\: bool
                                
                                .. attribute:: upd_errh_noreset
                                
                                	Update errh noreset
                                	**type**\: bool
                                
                                .. attribute:: msg_buf_count
                                
                                	Message Buf Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msg_bug_circular
                                
                                	Message Buf Circular
                                	**type**\: bool
                                
                                .. attribute:: syslog_enable
                                
                                	syslog enable
                                	**type**\: bool
                                
                                .. attribute:: oper_attrf_enable
                                
                                	Oper attrf Enable
                                	**type**\: bool
                                
                                .. attribute:: attrf_group_name
                                
                                	Attrf Group Name
                                	**type**\: str
                                
                                .. attribute:: max_peers
                                
                                	Max Dynamic nbrs in range
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: idle_watch_time
                                
                                	Dynamic Neighbor idle\-watch time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: current_peers
                                
                                	Current Dynamic nbrs in range
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_match
                                
                                	Passive open matching range
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_open_accepted
                                
                                	open accepted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_max_drop
                                
                                	open drop due to max peers
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_inst_error
                                
                                	Error during instance creation
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: af_data
                                
                                	Address family specific neighbor data
                                	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData>`
                                
                                .. attribute:: instance
                                
                                	Dynamic Neighbor Instance List
                                	**type**\: list of  		 :py:class:`Instance_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange, self).__init__()

                                    self.yang_name = "neighbor-range"
                                    self.yang_parent_name = "neighbor-ranges"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['neighbor_range_address']
                                    self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance)), ("cfg-local-address", ("cfg_local_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData)), ("instance", ("instance", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_range_address', (YLeaf(YType.str, 'neighbor-range-address'), ['str','str'])),
                                        ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                        ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                        ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                        ('neighbor_range_prefix_length', (YLeaf(YType.uint8, 'neighbor-range-prefix-length'), ['int'])),
                                        ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                        ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                        ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                        ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                        ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                        ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                        ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                        ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                        ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                        ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                        ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                        ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                        ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                        ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                        ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                        ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                        ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                        ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                        ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                        ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                        ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                        ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                        ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                        ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                        ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                        ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                        ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                        ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                        ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                        ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                        ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                        ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                        ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                        ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                        ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                        ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                        ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                        ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                        ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                        ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                        ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                        ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                        ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                        ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                        ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                        ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                        ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                        ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                        ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                        ('remote_as_list_name', (YLeaf(YType.str, 'remote-as-list-name'), ['str'])),
                                        ('nbr_rcv_size', (YLeaf(YType.uint32, 'nbr-rcv-size'), ['int'])),
                                        ('nbr_send_size', (YLeaf(YType.uint32, 'nbr-send-size'), ['int'])),
                                        ('islocal_address_cfg', (YLeaf(YType.boolean, 'islocal-address-cfg'), ['bool'])),
                                        ('update_source', (YLeaf(YType.str, 'update-source'), ['str'])),
                                        ('addpath_send_enable', (YLeaf(YType.boolean, 'addpath-send-enable'), ['bool'])),
                                        ('addpath_receive_enable', (YLeaf(YType.boolean, 'addpath-receive-enable'), ['bool'])),
                                        ('addpath_send_disable', (YLeaf(YType.boolean, 'addpath-send-disable'), ['bool'])),
                                        ('addpath_receive_disable', (YLeaf(YType.boolean, 'addpath-receive-disable'), ['bool'])),
                                        ('upd_errh_noreset', (YLeaf(YType.boolean, 'upd-errh-noreset'), ['bool'])),
                                        ('msg_buf_count', (YLeaf(YType.uint32, 'msg-buf-count'), ['int'])),
                                        ('msg_bug_circular', (YLeaf(YType.boolean, 'msg-bug-circular'), ['bool'])),
                                        ('syslog_enable', (YLeaf(YType.boolean, 'syslog-enable'), ['bool'])),
                                        ('oper_attrf_enable', (YLeaf(YType.boolean, 'oper-attrf-enable'), ['bool'])),
                                        ('attrf_group_name', (YLeaf(YType.str, 'attrf-group-name'), ['str'])),
                                        ('max_peers', (YLeaf(YType.uint32, 'max-peers'), ['int'])),
                                        ('idle_watch_time', (YLeaf(YType.uint32, 'idle-watch-time'), ['int'])),
                                        ('current_peers', (YLeaf(YType.uint32, 'current-peers'), ['int'])),
                                        ('range_open_match', (YLeaf(YType.uint32, 'range-open-match'), ['int'])),
                                        ('range_open_accepted', (YLeaf(YType.uint32, 'range-open-accepted'), ['int'])),
                                        ('range_max_drop', (YLeaf(YType.uint32, 'range-max-drop'), ['int'])),
                                        ('range_inst_error', (YLeaf(YType.uint32, 'range-inst-error'), ['int'])),
                                    ])
                                    self.neighbor_range_address = None
                                    self.speaker_id = None
                                    self.description = None
                                    self.local_as = None
                                    self.remote_as = None
                                    self.has_internal_link = None
                                    self.is_local_address_configured = None
                                    self.neighbor_range_prefix_length = None
                                    self.is_administratively_shut_down = None
                                    self.is_neighbor_max_prefix_shutdown = None
                                    self.is_out_of_memory_forced_up = None
                                    self.ttl_security_enabled = None
                                    self.suppress4_byte_as = None
                                    self.bfd_session_enable_mode = None
                                    self.bfd_minintervalval = None
                                    self.bfd_multiplierval = None
                                    self.ebgp_time_to_live = None
                                    self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                    self.tcpmss = None
                                    self.msg_log_in = None
                                    self.msg_log_out = None
                                    self.neighbor_local_as = None
                                    self.local_as_no_prepend = None
                                    self.is_capability_negotiation_performed = None
                                    self.configured_hold_time = None
                                    self.configured_keepalive = None
                                    self.configured_min_acc_hold_time = None
                                    self.min_advertise_interval = None
                                    self.min_advertise_interval_msecs = None
                                    self.min_origination_interval = None
                                    self.remote_as_number = None
                                    self.dmz_link_bandwidth = None
                                    self.ebgp_recv_dmz = None
                                    self.ebgp_send_dmz_mode = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.tcp_session_open_mode = None
                                    self.vrf_name = None
                                    self.standby_rp = None
                                    self.nsr_enabled = None
                                    self.graceful_restart_enabled_nbr = None
                                    self.gr_restart_time = None
                                    self.gr_stale_path_time = None
                                    self.is_passive_close = None
                                    self.nbr_enforce_first_as = None
                                    self.active_bmp_servers = None
                                    self.nbr_cluster_id = None
                                    self.nbr_in_cluster = None
                                    self.ignore_connected = None
                                    self.internal_vpn_client = None
                                    self.local_as_replace_as = None
                                    self.local_as_dual_as = None
                                    self.local_as_dual_as_mode_native = None
                                    self.egress_peer_engineering_enabled = None
                                    self.discard_as4_path = None
                                    self.rpki_disable = None
                                    self.rpki_use_validity = None
                                    self.rpki_allow_invalid = None
                                    self.rpki_signal_ibgp = None
                                    self.remote_as_list_name = None
                                    self.nbr_rcv_size = None
                                    self.nbr_send_size = None
                                    self.islocal_address_cfg = None
                                    self.update_source = None
                                    self.addpath_send_enable = None
                                    self.addpath_receive_enable = None
                                    self.addpath_send_disable = None
                                    self.addpath_receive_disable = None
                                    self.upd_errh_noreset = None
                                    self.msg_buf_count = None
                                    self.msg_bug_circular = None
                                    self.syslog_enable = None
                                    self.oper_attrf_enable = None
                                    self.attrf_group_name = None
                                    self.max_peers = None
                                    self.idle_watch_time = None
                                    self.current_peers = None
                                    self.range_open_match = None
                                    self.range_open_accepted = None
                                    self.range_max_drop = None
                                    self.range_inst_error = None

                                    self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                    self.connection_local_address.parent = self
                                    self._children_name_map["connection_local_address"] = "connection-local-address"

                                    self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                    self.connection_remote_address.parent = self
                                    self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                    self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                    self.cfg_local_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                    self.cfg_local_address.parent = self
                                    self._children_name_map["cfg_local_address"] = "cfg-local-address"

                                    self.af_data = YList(self)
                                    self.instance = YList(self)
                                    self._segment_path = lambda: "neighbor-range" + "[neighbor-range-address='" + str(self.neighbor_range_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange, ['neighbor_range_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_local_address_configured', u'neighbor_range_prefix_length', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_forced_up', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_performed', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'remote_as_list_name', u'nbr_rcv_size', u'nbr_send_size', u'islocal_address_cfg', u'update_source', u'addpath_send_enable', u'addpath_receive_enable', u'addpath_send_disable', u'addpath_receive_disable', u'upd_errh_noreset', u'msg_buf_count', u'msg_bug_circular', u'syslog_enable', u'oper_attrf_enable', u'attrf_group_name', u'max_peers', u'idle_watch_time', u'current_peers', u'range_open_match', u'range_open_accepted', u'range_max_drop', u'range_inst_error'], name, value)


                                class ConnectionLocalAddress(Entity):
                                    """
                                    Local address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, self).__init__()

                                        self.yang_name = "connection-local-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-local-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class ConnectionRemoteAddress(Entity):
                                    """
                                    Remote address for the connection
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, self).__init__()

                                        self.yang_name = "connection-remote-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "connection-remote-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "connection-remote-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance
                                    
                                    .. attribute:: gshut_exists
                                    
                                    	Graceful Maintenance enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_local_active
                                    
                                    	Graceful Maintenance locally activated
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_active
                                    
                                    	Graceful Maintenance activated
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	Graceful Maintenance Local Preference set
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	Graceful Maintenance Local Preference
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	Graceful Maintenance number of AS prepends
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                            ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                            ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                            ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                            ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                            ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                        ])
                                        self.gshut_exists = None
                                        self.gshut_local_active = None
                                        self.gshut_active = None
                                        self.gshut_locpref_set = None
                                        self.gshut_locpref = None
                                        self.gshut_prepends = None
                                        self._segment_path = lambda: "graceful-maintenance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                                class CfgLocalAddress(Entity):
                                    """
                                    Configured local address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress, self).__init__()

                                        self.yang_name = "cfg-local-address"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "cfg-local-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "cfg-local-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class AfData(Entity):
                                    """
                                    Address family specific neighbor data
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: is_neighbor_route_reflector_client
                                    
                                    	Nbr is a route reflector client
                                    	**type**\: bool
                                    
                                    .. attribute:: is_legacy_pe_rt
                                    
                                    	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_neighbor_af_capable
                                    
                                    	Address family capability received from neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: is_soft_reconfiguration_inbound_allowed
                                    
                                    	Inbound soft reconfiguration allowed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_use_soft_reconfiguration_always_on
                                    
                                    	Soft reconf overrides route refresh
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_from_updates
                                    
                                    	Private AS numbers removed from updates to this nbr
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_updates
                                    
                                    	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr
                                    	**type**\: bool
                                    
                                    .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                    
                                    	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                    	**type**\: bool
                                    
                                    .. attribute:: flowspec_validation_d_isable
                                    
                                    	Flowspec Validation Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flowspec_redirect_validation_d_isable
                                    
                                    	Flowspec Redirect Validation Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\: str
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_reorg
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_local
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_afi_disable
                                    
                                    	Encode in Advertise AFI
                                    	**type**\: bool
                                    
                                    .. attribute:: always_use_next_hop_local
                                    
                                    	Local router always used for next\-hop
                                    	**type**\: bool
                                    
                                    .. attribute:: next_hop_unchanged
                                    
                                    	router does not change next\-hop
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_community_to_neighbor
                                    
                                    	Community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_gshut_community_to_neighbor
                                    
                                    	GSHUT Community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: sent_extended_community_to_neighbor
                                    
                                    	Extended community attribute sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_default_originate
                                    
                                    	Neighbor originates default
                                    	**type**\: bool
                                    
                                    .. attribute:: is_orf_sent
                                    
                                    	Outbound route filter sent to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: is_update_deferred
                                    
                                    	Update deferred until ORF/route refresh received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_orf_send_scheduled
                                    
                                    	Scheduled to send prefix based ORF
                                    	**type**\: bool
                                    
                                    .. attribute:: vpn_update_gen_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\: bool
                                    
                                    .. attribute:: vpn_update_gen_trigger_enabled
                                    
                                    	RT Nbr enabled for updategento another
                                    	**type**\: bool
                                    
                                    .. attribute:: is_addpath_send_operational
                                    
                                    	Addpath is operational on send\-side
                                    	**type**\: bool
                                    
                                    .. attribute:: is_addpath_receive_operational
                                    
                                    	Addpath is operational on receive\-side
                                    	**type**\: bool
                                    
                                    .. attribute:: weight
                                    
                                    	Weight for this AF
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_prefix_limit
                                    
                                    	Max limit for # of prefixes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: use_max_prefix_warning_only
                                    
                                    	Warning only when maximum prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_discard_extra_paths
                                    
                                    	Discard extra paths when prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_exceed_discard_paths
                                    
                                    	Did we discard extra paths when prefix limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: max_prefix_threshold_percent
                                    
                                    	Percentage of maximum no. of prefixes at which to generate warning
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: max_prefix_restart_time
                                    
                                    	Time interval (in minutes) after which peering session will be reestablished
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: is_peer_orf_capable
                                    
                                    	Peer has outbound route filter capability
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_orf_send
                                    
                                    	Prefix based ORF send mode capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_orf_send_capable
                                    
                                    	Prefix based ORF send mode capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_orf_receive
                                    
                                    	Prefix based ORF receive mode capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_orf_receive_capable
                                    
                                    	Prefix based ORF receive mode capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertised_graceful_restart
                                    
                                    	Graceful Restart Capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_graceful_restart_state_flag
                                    
                                    	Restart state flag enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_received_graceful_restart_capable
                                    
                                    	Graceful Restart Capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_send_capability_advertised
                                    
                                    	Addpath Send capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_send_capability_received
                                    
                                    	Addpath Send capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_receive_capability_advertised
                                    
                                    	Addpath Receive capability advertised
                                    	**type**\: bool
                                    
                                    .. attribute:: is_add_path_receive_capability_received
                                    
                                    	Addpath Receive capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: restart_time
                                    
                                    	Restart time advertised (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: local_restart_time
                                    
                                    	Local Restart time (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: stale_path_timeout
                                    
                                    	Stale path timeout time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_purge_timeout_value
                                    
                                    	RIB purge timeout time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_preserved_forwarding_state
                                    
                                    	Neighbor preserved forwarding state
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_configured
                                    
                                    	Long\-lived graceful\-restart stale time is configured
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_sent
                                    
                                    	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_accept
                                    
                                    	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: long_lived_graceful_restart_capability_received
                                    
                                    	Long\-lived graceful\-restart capability received from the neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: long_lived_graceful_restart_stale_time_received
                                    
                                    	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                    
                                    	Neighbor preserved long\-lived forwarding state
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_capable
                                    
                                    	Treat neighbor as long\-lived graceful\-restart capable
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                    
                                    	Remaining long\-lived graceful\-restart time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_prefix_orf_present
                                    
                                    	Outbound route filter prefix ORF present
                                    	**type**\: bool
                                    
                                    .. attribute:: orf_entries_received
                                    
                                    	Number of outbound route filter entries received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_policy_prefix_orf
                                    
                                    	Prefix based ORF for incoming updates
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_in
                                    
                                    	Incoming route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outgoing route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: route_policy_default_originate
                                    
                                    	Default\-originate route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                    
                                    	eBGP neighbor with no configured inbound policy
                                    	**type**\: bool
                                    
                                    .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                    
                                    	eBGP neighbor with no configured outbound policy
                                    	**type**\: bool
                                    
                                    .. attribute:: is_as_override_set
                                    
                                    	As override set 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_allow_as_in_set
                                    
                                    	Allowas\-in set 
                                    	**type**\: bool
                                    
                                    .. attribute:: allow_as_in_count
                                    
                                    	Allowas\-in count config
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: address_family_long_lived_time
                                    
                                    	AF specific Long\-lived\-time config
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_aigp_set
                                    
                                    	AIGP set 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_rt_present
                                    
                                    	RT attribute list present
                                    	**type**\: bool
                                    
                                    .. attribute:: is_rt_present_standby
                                    
                                    	RT attribute list present
                                    	**type**\: bool
                                    
                                    .. attribute:: accept_own_enabled
                                    
                                    	Accept\-Own enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: selective_multipath_eligible
                                    
                                    	Selective multipath eligible
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: afrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\: bool
                                    
                                    .. attribute:: is_advertise_permanent_network
                                    
                                    	Advertise Permanent Network
                                    	**type**\: bool
                                    
                                    .. attribute:: is_send_mcast_attr
                                    
                                    	Send Mcast Attr
                                    	**type**\: bool
                                    
                                    .. attribute:: import_stitching
                                    
                                    	Import Stitching enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: import_reoriginate
                                    
                                    	Import Reoriginate enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: import_reoriginate_stitching
                                    
                                    	Import Reoriginate Stitching enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: advertise_v4_flags
                                    
                                    	Advertise options for VPNV4
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_v6_flags
                                    
                                    	Advertise options for VPNV6
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: enable_label_stack
                                    
                                    	Enable label stack
                                    	**type**\: bool
                                    
                                    .. attribute:: extended_community
                                    
                                    	Extended community attribute
                                    	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                    
                                    .. attribute:: extended_community_standby
                                    
                                    	Extended community attribute
                                    	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData, self).__init__()

                                        self.yang_name = "af-data"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby))])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                            ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                            ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                            ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                            ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                            ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                            ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                            ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                            ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                            ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                            ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                            ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                            ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                            ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                            ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                            ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                            ('advertise_afi_local', (YLeaf(YType.boolean, 'advertise-afi-local'), ['bool'])),
                                            ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                            ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                            ('next_hop_unchanged', (YLeaf(YType.boolean, 'next-hop-unchanged'), ['bool'])),
                                            ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                            ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                            ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                            ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                            ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                            ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                            ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                            ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                            ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                            ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                            ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                            ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                            ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                            ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                            ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                            ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                            ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                            ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                            ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                            ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                            ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                            ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                            ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                            ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                            ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                            ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                            ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                            ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                            ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                            ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                            ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                            ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                            ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                            ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                            ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                            ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                            ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                            ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                            ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                            ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                            ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                            ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                            ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                            ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                            ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                            ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                            ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                            ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                            ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                            ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                            ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                            ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                            ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                            ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                            ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                            ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                            ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                            ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                            ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                            ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                            ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                            ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                            ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                            ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                            ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                            ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                            ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                            ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                            ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                        ])
                                        self.af_name = None
                                        self.is_neighbor_route_reflector_client = None
                                        self.is_legacy_pe_rt = None
                                        self.is_neighbor_af_capable = None
                                        self.is_soft_reconfiguration_inbound_allowed = None
                                        self.is_use_soft_reconfiguration_always_on = None
                                        self.remove_private_as_from_updates = None
                                        self.remove_private_as_entire_aspath_from_updates = None
                                        self.remove_private_as_from_inbound_updates = None
                                        self.remove_private_as_entire_aspath_from_inbound_updates = None
                                        self.flowspec_validation_d_isable = None
                                        self.flowspec_redirect_validation_d_isable = None
                                        self.orr_group_name = None
                                        self.orr_group_index = None
                                        self.is_orr_root_address_configured = None
                                        self.advertise_afi = None
                                        self.advertise_afi_reorg = None
                                        self.advertise_afi_local = None
                                        self.advertise_afi_disable = None
                                        self.always_use_next_hop_local = None
                                        self.next_hop_unchanged = None
                                        self.sent_community_to_neighbor = None
                                        self.sent_gshut_community_to_neighbor = None
                                        self.sent_extended_community_to_neighbor = None
                                        self.neighbor_default_originate = None
                                        self.is_orf_sent = None
                                        self.is_update_deferred = None
                                        self.is_orf_send_scheduled = None
                                        self.vpn_update_gen_enabled = None
                                        self.vpn_update_gen_trigger_enabled = None
                                        self.is_addpath_send_operational = None
                                        self.is_addpath_receive_operational = None
                                        self.weight = None
                                        self.max_prefix_limit = None
                                        self.use_max_prefix_warning_only = None
                                        self.max_prefix_discard_extra_paths = None
                                        self.max_prefix_exceed_discard_paths = None
                                        self.max_prefix_threshold_percent = None
                                        self.max_prefix_restart_time = None
                                        self.is_peer_orf_capable = None
                                        self.is_advertised_orf_send = None
                                        self.is_received_orf_send_capable = None
                                        self.is_advertised_orf_receive = None
                                        self.is_received_orf_receive_capable = None
                                        self.is_advertised_graceful_restart = None
                                        self.is_graceful_restart_state_flag = None
                                        self.is_received_graceful_restart_capable = None
                                        self.is_add_path_send_capability_advertised = None
                                        self.is_add_path_send_capability_received = None
                                        self.is_add_path_receive_capability_advertised = None
                                        self.is_add_path_receive_capability_received = None
                                        self.restart_time = None
                                        self.local_restart_time = None
                                        self.stale_path_timeout = None
                                        self.rib_purge_timeout_value = None
                                        self.neighbor_preserved_forwarding_state = None
                                        self.long_lived_graceful_restart_stale_time_configured = None
                                        self.long_lived_graceful_restart_stale_time_sent = None
                                        self.long_lived_graceful_restart_stale_time_accept = None
                                        self.long_lived_graceful_restart_capability_received = None
                                        self.long_lived_graceful_restart_stale_time_received = None
                                        self.neighbor_preserved_long_lived_forwarding_state = None
                                        self.neighbor_long_lived_graceful_restart_capable = None
                                        self.neighbor_long_lived_graceful_restart_time_remaining = None
                                        self.is_prefix_orf_present = None
                                        self.orf_entries_received = None
                                        self.route_policy_prefix_orf = None
                                        self.route_policy_in = None
                                        self.route_policy_out = None
                                        self.route_policy_default_originate = None
                                        self.is_neighbor_ebgp_without_inbound_policy = None
                                        self.is_neighbor_ebgp_without_outbound_policy = None
                                        self.is_as_override_set = None
                                        self.is_allow_as_in_set = None
                                        self.allow_as_in_count = None
                                        self.address_family_long_lived_time = None
                                        self.is_aigp_set = None
                                        self.is_rt_present = None
                                        self.is_rt_present_standby = None
                                        self.accept_own_enabled = None
                                        self.selective_multipath_eligible = None
                                        self.afrpki_disable = None
                                        self.afrpki_use_validity = None
                                        self.afrpki_allow_invalid = None
                                        self.afrpki_signal_ibgp = None
                                        self.is_advertise_permanent_network = None
                                        self.is_send_mcast_attr = None
                                        self.import_stitching = None
                                        self.import_reoriginate = None
                                        self.import_reoriginate_stitching = None
                                        self.advertise_v4_flags = None
                                        self.advertise_v6_flags = None
                                        self.enable_label_stack = None

                                        self.extended_community = YList(self)
                                        self.extended_community_standby = YList(self)
                                        self._segment_path = lambda: "af-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_local', u'advertise_afi_disable', u'always_use_next_hop_local', u'next_hop_unchanged', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'is_prefix_orf_present', u'orf_entries_received', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'enable_label_stack'], name, value)


                                    class ExtendedCommunity(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, self).__init__()

                                            self.yang_name = "extended-community"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "extended-community"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, [u'entry'], name, value)


                                    class ExtendedCommunityStandby(Entity):
                                        """
                                        Extended community attribute
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, self).__init__()

                                            self.yang_name = "extended-community-standby"
                                            self.yang_parent_name = "af-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "extended-community-standby"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                                class Instance_(Entity):
                                    """
                                    Dynamic Neighbor Instance List
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Dynamic Neighbor address
                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress>`
                                    
                                    .. attribute:: neighbor_age
                                    
                                    	Neighbor age
                                    	**type**\:  :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge>`
                                    
                                    .. attribute:: idle_watch_timer_remaining_value
                                    
                                    	Idle watch timer remaining time
                                    	**type**\:  :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue>`
                                    
                                    .. attribute:: is_idle_watch_timer_running
                                    
                                    	Is idle watch timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_, self).__init__()

                                        self.yang_name = "instance"
                                        self.yang_parent_name = "neighbor-range"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress)), ("neighbor-age", ("neighbor_age", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge)), ("idle-watch-timer-remaining-value", ("idle_watch_timer_remaining_value", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue))])
                                        self._leafs = OrderedDict([
                                            ('is_idle_watch_timer_running', (YLeaf(YType.boolean, 'is-idle-watch-timer-running'), ['bool'])),
                                            ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                        ])
                                        self.is_idle_watch_timer_running = None
                                        self.connection_state = None

                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"

                                        self.neighbor_age = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge()
                                        self.neighbor_age.parent = self
                                        self._children_name_map["neighbor_age"] = "neighbor-age"

                                        self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue()
                                        self.idle_watch_timer_remaining_value.parent = self
                                        self._children_name_map["idle_watch_timer_remaining_value"] = "idle-watch-timer-remaining-value"
                                        self._segment_path = lambda: "instance"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_, [u'is_idle_watch_timer_running', u'connection_state'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Dynamic Neighbor address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class NeighborAge(Entity):
                                        """
                                        Neighbor age
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge, self).__init__()

                                            self.yang_name = "neighbor-age"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "neighbor-age"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.NeighborAge, [u'seconds', u'nanoseconds'], name, value)


                                    class IdleWatchTimerRemainingValue(Entity):
                                        """
                                        Idle watch timer remaining time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue, self).__init__()

                                            self.yang_name = "idle-watch-timer-remaining-value"
                                            self.yang_parent_name = "instance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "idle-watch-timer-remaining-value"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue, [u'seconds', u'nanoseconds'], name, value)


                        class MessageLogs(Entity):
                            """
                            The BGP Neighbor Message table
                            
                            .. attribute:: message_log
                            
                            	A BGP Message log entry
                            	**type**\: list of  		 :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs, self).__init__()

                                self.yang_name = "message-logs"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("message-log", ("message_log", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog))])
                                self._leafs = OrderedDict()

                                self.message_log = YList(self)
                                self._segment_path = lambda: "message-logs"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs, [], name, value)


                            class MessageLog(Entity):
                                """
                                A BGP Message log entry
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\: union of the below types:
                                
                                		**type**\: str
                                
                                			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                		**type**\: str
                                
                                			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: direction
                                
                                	Direction
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_message
                                
                                	Array of Neighbor Messages in one direction
                                	**type**\: list of  		 :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog, self).__init__()

                                    self.yang_name = "message-log"
                                    self.yang_parent_name = "message-logs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-message", ("neighbor_message", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage))])
                                    self._leafs = OrderedDict([
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('direction', (YLeaf(YType.uint32, 'direction'), ['int'])),
                                    ])
                                    self.neighbor_address = None
                                    self.direction = None

                                    self.neighbor_message = YList(self)
                                    self._segment_path = lambda: "message-log"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog, ['neighbor_address', 'direction'], name, value)


                                class NeighborMessage(Entity):
                                    """
                                    Array of Neighbor Messages in one direction
                                    
                                    .. attribute:: message_timestamp
                                    
                                    	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                    	**type**\:  :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                    
                                    .. attribute:: message_type_received
                                    
                                    	Type of messages Received
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: total_logged_message_count
                                    
                                    	Total logged messages count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: message_data_length
                                    
                                    	Message data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: logged_message_data
                                    
                                    	Raw Message data in binary format
                                    	**type**\: list of  		 :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage, self).__init__()

                                        self.yang_name = "neighbor-message"
                                        self.yang_parent_name = "message-log"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("message-timestamp", ("message_timestamp", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp)), ("logged-message-data", ("logged_message_data", Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData))])
                                        self._leafs = OrderedDict([
                                            ('message_type_received', (YLeaf(YType.uint8, 'message-type-received'), ['int'])),
                                            ('total_logged_message_count', (YLeaf(YType.uint32, 'total-logged-message-count'), ['int'])),
                                            ('message_data_length', (YLeaf(YType.uint16, 'message-data-length'), ['int'])),
                                        ])
                                        self.message_type_received = None
                                        self.total_logged_message_count = None
                                        self.message_data_length = None

                                        self.message_timestamp = Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                        self.message_timestamp.parent = self
                                        self._children_name_map["message_timestamp"] = "message-timestamp"

                                        self.logged_message_data = YList(self)
                                        self._segment_path = lambda: "neighbor-message"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage, [u'message_type_received', u'total_logged_message_count', u'message_data_length'], name, value)


                                    class MessageTimestamp(Entity):
                                        """
                                        message received time\: time elapsed since 00\:00
                                        \:00 UTC, January 1, 1970
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, self).__init__()

                                            self.yang_name = "message-timestamp"
                                            self.yang_parent_name = "neighbor-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "message-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LoggedMessageData(Entity):
                                        """
                                        Raw Message data in binary format
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, self).__init__()

                                            self.yang_name = "logged-message-data"
                                            self.yang_parent_name = "neighbor-message"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "logged-message-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Vrfs.Vrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, [u'entry'], name, value)


                class DefaultVrf(Entity):
                    """
                    Default VRF related operational data
                    
                    .. attribute:: update_inbound_error_vrf
                    
                    	Update inbound error information for the VRF
                    	**type**\:  :py:class:`UpdateInboundErrorVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf>`
                    
                    .. attribute:: afs
                    
                    	BGP address family table
                    	**type**\:  :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs>`
                    
                    .. attribute:: information
                    
                    	Meta data for VRF
                    	**type**\:  :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information>`
                    
                    .. attribute:: update_inbound_filter_vrf
                    
                    	Update inbound filtering information for the VRF
                    	**type**\:  :py:class:`UpdateInboundFilterVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf>`
                    
                    .. attribute:: postits
                    
                    	The BGP Neighbor table
                    	**type**\:  :py:class:`Postits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits>`
                    
                    .. attribute:: global_process_info
                    
                    	The Global Process information table
                    	**type**\:  :py:class:`GlobalProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo>`
                    
                    .. attribute:: update_inbound_error_neighbors
                    
                    	Update inbound error information for all neighbors
                    	**type**\:  :py:class:`UpdateInboundErrorNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors>`
                    
                    .. attribute:: update_inbound_filter_neighbors
                    
                    	Update inbound filtering information for all neighbors
                    	**type**\:  :py:class:`UpdateInboundFilterNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors>`
                    
                    .. attribute:: bmp
                    
                    	BMP related Operational Data
                    	**type**\:  :py:class:`Bmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp>`
                    
                    .. attribute:: process_info
                    
                    	A Process instance table entry
                    	**type**\:  :py:class:`ProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo>`
                    
                    .. attribute:: sessions
                    
                    	The BGP session table
                    	**type**\:  :py:class:`Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions>`
                    
                    .. attribute:: neighbors
                    
                    	The BGP Neighbor table
                    	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors>`
                    
                    .. attribute:: next_hop_vrf
                    
                    	A BGP Next\-hop VRF table entry
                    	**type**\:  :py:class:`NextHopVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf>`
                    
                    .. attribute:: neighbor_ranges
                    
                    	The BGP Dynamic Neighbor Range table
                    	**type**\:  :py:class:`NeighborRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges>`
                    
                    .. attribute:: message_logs
                    
                    	The BGP Neighbor Message table
                    	**type**\:  :py:class:`MessageLogs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf, self).__init__()

                        self.yang_name = "default-vrf"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("update-inbound-error-vrf", ("update_inbound_error_vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf)), ("afs", ("afs", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs)), ("information", ("information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information)), ("update-inbound-filter-vrf", ("update_inbound_filter_vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf)), ("postits", ("postits", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits)), ("global-process-info", ("global_process_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo)), ("update-inbound-error-neighbors", ("update_inbound_error_neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors)), ("update-inbound-filter-neighbors", ("update_inbound_filter_neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors)), ("bmp", ("bmp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp)), ("process-info", ("process_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo)), ("sessions", ("sessions", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions)), ("neighbors", ("neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors)), ("next-hop-vrf", ("next_hop_vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf)), ("neighbor-ranges", ("neighbor_ranges", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges)), ("message-logs", ("message_logs", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs))])
                        self._leafs = OrderedDict()

                        self.update_inbound_error_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf()
                        self.update_inbound_error_vrf.parent = self
                        self._children_name_map["update_inbound_error_vrf"] = "update-inbound-error-vrf"

                        self.afs = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs()
                        self.afs.parent = self
                        self._children_name_map["afs"] = "afs"

                        self.information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information()
                        self.information.parent = self
                        self._children_name_map["information"] = "information"

                        self.update_inbound_filter_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf()
                        self.update_inbound_filter_vrf.parent = self
                        self._children_name_map["update_inbound_filter_vrf"] = "update-inbound-filter-vrf"

                        self.postits = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits()
                        self.postits.parent = self
                        self._children_name_map["postits"] = "postits"

                        self.global_process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo()
                        self.global_process_info.parent = self
                        self._children_name_map["global_process_info"] = "global-process-info"

                        self.update_inbound_error_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors()
                        self.update_inbound_error_neighbors.parent = self
                        self._children_name_map["update_inbound_error_neighbors"] = "update-inbound-error-neighbors"

                        self.update_inbound_filter_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors()
                        self.update_inbound_filter_neighbors.parent = self
                        self._children_name_map["update_inbound_filter_neighbors"] = "update-inbound-filter-neighbors"

                        self.bmp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp()
                        self.bmp.parent = self
                        self._children_name_map["bmp"] = "bmp"

                        self.process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo()
                        self.process_info.parent = self
                        self._children_name_map["process_info"] = "process-info"

                        self.sessions = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions()
                        self.sessions.parent = self
                        self._children_name_map["sessions"] = "sessions"

                        self.neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"

                        self.next_hop_vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf()
                        self.next_hop_vrf.parent = self
                        self._children_name_map["next_hop_vrf"] = "next-hop-vrf"

                        self.neighbor_ranges = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges()
                        self.neighbor_ranges.parent = self
                        self._children_name_map["neighbor_ranges"] = "neighbor-ranges"

                        self.message_logs = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs()
                        self.message_logs.parent = self
                        self._children_name_map["message_logs"] = "message-logs"
                        self._segment_path = lambda: "default-vrf"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf, [], name, value)


                    class UpdateInboundErrorVrf(Entity):
                        """
                        Update inbound error information for the VRF
                        
                        .. attribute:: last_update_malformed_timestamp
                        
                        	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:  :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp>`
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: update_malformed_message_count
                        
                        	Malformed messages count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_malformed_neighbor_count
                        
                        	Count of neighbors that received malformed messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_update_malformed_age
                        
                        	Time since last malformed messages received event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf, self).__init__()

                            self.yang_name = "update-inbound-error-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("last-update-malformed-timestamp", ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp))])
                            self._leafs = OrderedDict([
                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                ('update_malformed_message_count', (YLeaf(YType.uint32, 'update-malformed-message-count'), ['int'])),
                                ('update_malformed_neighbor_count', (YLeaf(YType.uint32, 'update-malformed-neighbor-count'), ['int'])),
                                ('last_update_malformed_age', (YLeaf(YType.uint32, 'last-update-malformed-age'), ['int'])),
                            ])
                            self.update_vrf_name = None
                            self.update_malformed_message_count = None
                            self.update_malformed_neighbor_count = None
                            self.last_update_malformed_age = None

                            self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp()
                            self.last_update_malformed_timestamp.parent = self
                            self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                            self._segment_path = lambda: "update-inbound-error-vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf, [u'update_vrf_name', u'update_malformed_message_count', u'update_malformed_neighbor_count', u'last_update_malformed_age'], name, value)


                        class LastUpdateMalformedTimestamp(Entity):
                            """
                            Last malformed messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, self).__init__()

                                self.yang_name = "last-update-malformed-timestamp"
                                self.yang_parent_name = "update-inbound-error-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-malformed-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorVrf.LastUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                    class Afs(Entity):
                        """
                        BGP address family table
                        
                        .. attribute:: af
                        
                        	A particular address family
                        	**type**\: list of  		 :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs, self).__init__()

                            self.yang_name = "afs"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("af", ("af", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af))])
                            self._leafs = OrderedDict()

                            self.af = YList(self)
                            self._segment_path = lambda: "afs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs, [], name, value)


                        class Af(Entity):
                            """
                            A particular address family
                            
                            .. attribute:: af_name  (key)
                            
                            	Address family
                            	**type**\:  :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                            
                            .. attribute:: rpki_refresh_af_table
                            
                            	RPKI Refresh Table (per AF)
                            	**type**\:  :py:class:`RpkiRefreshAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable>`
                            
                            .. attribute:: policies
                            
                            	The BGP Policy Table
                            	**type**\:  :py:class:`Policies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies>`
                            
                            .. attribute:: convergence
                            
                            	A BGP Convergence table entry
                            	**type**\:  :py:class:`Convergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence>`
                            
                            .. attribute:: af_process_info
                            
                            	A BGP Process address family table entry
                            	**type**\:  :py:class:`AfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo>`
                            
                            .. attribute:: path_used_table
                            
                            	The BGP Path Used Table
                            	**type**\:  :py:class:`PathUsedTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable>`
                            
                            .. attribute:: bmp_path_table_generic
                            
                            	Summary Info about BMP Table
                            	**type**\:  :py:class:`BmpPathTableGeneric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric>`
                            
                            .. attribute:: rpc_sets
                            
                            	BGP next\-hop set table
                            	**type**\:  :py:class:`RpcSets <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets>`
                            
                            .. attribute:: global_af_process_info
                            
                            	The Global Address Family Process information table
                            	**type**\:  :py:class:`GlobalAfProcessInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo>`
                            
                            .. attribute:: advertised_path_xr
                            
                            	The BGP Advertised path table (bestpath)
                            	**type**\:  :py:class:`AdvertisedPathXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr>`
                            
                            .. attribute:: sourced_networks
                            
                            	The BGP Convergence table
                            	**type**\:  :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks>`
                            
                            .. attribute:: update_groups
                            
                            	The BGP Update group table
                            	**type**\:  :py:class:`UpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups>`
                            
                            .. attribute:: update_generation_sub_groups
                            
                            	Update generation for all sub\-groups
                            	**type**\:  :py:class:`UpdateGenerationSubGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups>`
                            
                            .. attribute:: next_hop_address_families
                            
                            	Address family of nexthop table
                            	**type**\:  :py:class:`NextHopAddressFamilies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies>`
                            
                            .. attribute:: rt_set_counters
                            
                            	The RT\-set counter table
                            	**type**\:  :py:class:`RtSetCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters>`
                            
                            .. attribute:: bmp_paths
                            
                            	The paths in BMP Table
                            	**type**\:  :py:class:`BmpPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths>`
                            
                            .. attribute:: update_generation_update_groups
                            
                            	Update generation for all update\-groups
                            	**type**\:  :py:class:`UpdateGenerationUpdateGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups>`
                            
                            .. attribute:: update_generation_filter_groups
                            
                            	Update generation for all filter\-groups under a sub\-group
                            	**type**\:  :py:class:`UpdateGenerationFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups>`
                            
                            .. attribute:: networks
                            
                            	The BGP Network Table
                            	**type**\:  :py:class:`Networks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks>`
                            
                            .. attribute:: path_table
                            
                            	The BGP Path Table
                            	**type**\:  :py:class:`PathTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable>`
                            
                            .. attribute:: epes
                            
                            	The BGP Egress Engineering table
                            	**type**\:  :py:class:`Epes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes>`
                            
                            .. attribute:: advertised_path_counts
                            
                            	The BGP Advertised paths table (bestpath)
                            	**type**\:  :py:class:`AdvertisedPathCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts>`
                            
                            .. attribute:: path_labeled_table
                            
                            	The BGP Path Labeled Table
                            	**type**\:  :py:class:`PathLabeledTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable>`
                            
                            .. attribute:: advertised_paths
                            
                            	The BGP Advertised paths table (add\-paths)
                            	**type**\:  :py:class:`AdvertisedPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths>`
                            
                            .. attribute:: neighbor_af_table
                            
                            	The BGP Neighbor AF table
                            	**type**\:  :py:class:`NeighborAfTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable>`
                            
                            .. attribute:: update_generation_neighbors
                            
                            	Update generation for all neighbors
                            	**type**\:  :py:class:`UpdateGenerationNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors>`
                            
                            .. attribute:: update_generation_address_family
                            
                            	Update generation for address\-family
                            	**type**\:  :py:class:`UpdateGenerationAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily>`
                            
                            .. attribute:: dampenings
                            
                            	The BGP Dampening table
                            	**type**\:  :py:class:`Dampenings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings>`
                            
                            .. attribute:: prefix_filters
                            
                            	The BGP Prefix Filter table
                            	**type**\:  :py:class:`PrefixFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters>`
                            
                            .. attribute:: attributes
                            
                            	The BGP Attribute table
                            	**type**\:  :py:class:`Attributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af, self).__init__()

                                self.yang_name = "af"
                                self.yang_parent_name = "afs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['af_name']
                                self._child_classes = OrderedDict([("rpki-refresh-af-table", ("rpki_refresh_af_table", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable)), ("policies", ("policies", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies)), ("convergence", ("convergence", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence)), ("af-process-info", ("af_process_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo)), ("path-used-table", ("path_used_table", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable)), ("bmp-path-table-generic", ("bmp_path_table_generic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric)), ("rpc-sets", ("rpc_sets", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets)), ("global-af-process-info", ("global_af_process_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo)), ("advertised-path-xr", ("advertised_path_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr)), ("sourced-networks", ("sourced_networks", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks)), ("update-groups", ("update_groups", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups)), ("update-generation-sub-groups", ("update_generation_sub_groups", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups)), ("next-hop-address-families", ("next_hop_address_families", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies)), ("rt-set-counters", ("rt_set_counters", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters)), ("bmp-paths", ("bmp_paths", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths)), ("update-generation-update-groups", ("update_generation_update_groups", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups)), ("update-generation-filter-groups", ("update_generation_filter_groups", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups)), ("networks", ("networks", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks)), ("path-table", ("path_table", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable)), ("epes", ("epes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes)), ("advertised-path-counts", ("advertised_path_counts", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts)), ("path-labeled-table", ("path_labeled_table", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable)), ("advertised-paths", ("advertised_paths", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths)), ("neighbor-af-table", ("neighbor_af_table", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable)), ("update-generation-neighbors", ("update_generation_neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors)), ("update-generation-address-family", ("update_generation_address_family", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily)), ("dampenings", ("dampenings", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings)), ("prefix-filters", ("prefix_filters", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters)), ("attributes", ("attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes))])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes', 'BgpAddressFamily', '')])),
                                ])
                                self.af_name = None

                                self.rpki_refresh_af_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable()
                                self.rpki_refresh_af_table.parent = self
                                self._children_name_map["rpki_refresh_af_table"] = "rpki-refresh-af-table"

                                self.policies = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies()
                                self.policies.parent = self
                                self._children_name_map["policies"] = "policies"

                                self.convergence = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence()
                                self.convergence.parent = self
                                self._children_name_map["convergence"] = "convergence"

                                self.af_process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo()
                                self.af_process_info.parent = self
                                self._children_name_map["af_process_info"] = "af-process-info"

                                self.path_used_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable()
                                self.path_used_table.parent = self
                                self._children_name_map["path_used_table"] = "path-used-table"

                                self.bmp_path_table_generic = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric()
                                self.bmp_path_table_generic.parent = self
                                self._children_name_map["bmp_path_table_generic"] = "bmp-path-table-generic"

                                self.rpc_sets = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets()
                                self.rpc_sets.parent = self
                                self._children_name_map["rpc_sets"] = "rpc-sets"

                                self.global_af_process_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo()
                                self.global_af_process_info.parent = self
                                self._children_name_map["global_af_process_info"] = "global-af-process-info"

                                self.advertised_path_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr()
                                self.advertised_path_xr.parent = self
                                self._children_name_map["advertised_path_xr"] = "advertised-path-xr"

                                self.sourced_networks = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks()
                                self.sourced_networks.parent = self
                                self._children_name_map["sourced_networks"] = "sourced-networks"

                                self.update_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups()
                                self.update_groups.parent = self
                                self._children_name_map["update_groups"] = "update-groups"

                                self.update_generation_sub_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups()
                                self.update_generation_sub_groups.parent = self
                                self._children_name_map["update_generation_sub_groups"] = "update-generation-sub-groups"

                                self.next_hop_address_families = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies()
                                self.next_hop_address_families.parent = self
                                self._children_name_map["next_hop_address_families"] = "next-hop-address-families"

                                self.rt_set_counters = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters()
                                self.rt_set_counters.parent = self
                                self._children_name_map["rt_set_counters"] = "rt-set-counters"

                                self.bmp_paths = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths()
                                self.bmp_paths.parent = self
                                self._children_name_map["bmp_paths"] = "bmp-paths"

                                self.update_generation_update_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups()
                                self.update_generation_update_groups.parent = self
                                self._children_name_map["update_generation_update_groups"] = "update-generation-update-groups"

                                self.update_generation_filter_groups = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups()
                                self.update_generation_filter_groups.parent = self
                                self._children_name_map["update_generation_filter_groups"] = "update-generation-filter-groups"

                                self.networks = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks()
                                self.networks.parent = self
                                self._children_name_map["networks"] = "networks"

                                self.path_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable()
                                self.path_table.parent = self
                                self._children_name_map["path_table"] = "path-table"

                                self.epes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes()
                                self.epes.parent = self
                                self._children_name_map["epes"] = "epes"

                                self.advertised_path_counts = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts()
                                self.advertised_path_counts.parent = self
                                self._children_name_map["advertised_path_counts"] = "advertised-path-counts"

                                self.path_labeled_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable()
                                self.path_labeled_table.parent = self
                                self._children_name_map["path_labeled_table"] = "path-labeled-table"

                                self.advertised_paths = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths()
                                self.advertised_paths.parent = self
                                self._children_name_map["advertised_paths"] = "advertised-paths"

                                self.neighbor_af_table = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable()
                                self.neighbor_af_table.parent = self
                                self._children_name_map["neighbor_af_table"] = "neighbor-af-table"

                                self.update_generation_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors()
                                self.update_generation_neighbors.parent = self
                                self._children_name_map["update_generation_neighbors"] = "update-generation-neighbors"

                                self.update_generation_address_family = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily()
                                self.update_generation_address_family.parent = self
                                self._children_name_map["update_generation_address_family"] = "update-generation-address-family"

                                self.dampenings = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings()
                                self.dampenings.parent = self
                                self._children_name_map["dampenings"] = "dampenings"

                                self.prefix_filters = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters()
                                self.prefix_filters.parent = self
                                self._children_name_map["prefix_filters"] = "prefix-filters"

                                self.attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes()
                                self.attributes.parent = self
                                self._children_name_map["attributes"] = "attributes"
                                self._segment_path = lambda: "af" + "[af-name='" + str(self.af_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af, ['af_name'], name, value)


                            class RpkiRefreshAfTable(Entity):
                                """
                                RPKI Refresh Table (per AF)
                                
                                .. attribute:: rpki_refresh_af
                                
                                	RPKI Refresh List
                                	**type**\:  :py:class:`RpkiRefreshAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable, self).__init__()

                                    self.yang_name = "rpki-refresh-af-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpki-refresh-af", ("rpki_refresh_af", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf))])
                                    self._leafs = OrderedDict()

                                    self.rpki_refresh_af = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf()
                                    self.rpki_refresh_af.parent = self
                                    self._children_name_map["rpki_refresh_af"] = "rpki-refresh-af"
                                    self._segment_path = lambda: "rpki-refresh-af-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable, [], name, value)


                                class RpkiRefreshAf(Entity):
                                    """
                                    RPKI Refresh List
                                    
                                    .. attribute:: refresh_entry
                                    
                                    	Array of refresh entries
                                    	**type**\: list of  		 :py:class:`RefreshEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf, self).__init__()

                                        self.yang_name = "rpki-refresh-af"
                                        self.yang_parent_name = "rpki-refresh-af-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("refresh-entry", ("refresh_entry", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry))])
                                        self._leafs = OrderedDict()

                                        self.refresh_entry = YList(self)
                                        self._segment_path = lambda: "rpki-refresh-af"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf, [], name, value)


                                    class RefreshEntry(Entity):
                                        """
                                        Array of refresh entries
                                        
                                        .. attribute:: af_name
                                        
                                        	Address Family
                                        	**type**\:  :py:class:`BgpRpkiAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAf>`
                                        
                                        .. attribute:: neighbor
                                        
                                        	BGP neighbor
                                        	**type**\: str
                                        
                                        .. attribute:: policy
                                        
                                        	Route Policy
                                        	**type**\: str
                                        
                                        .. attribute:: paths
                                        
                                        	Number of BGP paths modified or dropped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: drop
                                        
                                        	BGP paths were dropped
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry, self).__init__()

                                            self.yang_name = "refresh-entry"
                                            self.yang_parent_name = "rpki-refresh-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiAf', '')])),
                                                ('neighbor', (YLeaf(YType.str, 'neighbor'), ['str'])),
                                                ('policy', (YLeaf(YType.str, 'policy'), ['str'])),
                                                ('paths', (YLeaf(YType.uint32, 'paths'), ['int'])),
                                                ('drop', (YLeaf(YType.boolean, 'drop'), ['bool'])),
                                            ])
                                            self.af_name = None
                                            self.neighbor = None
                                            self.policy = None
                                            self.paths = None
                                            self.drop = None
                                            self._segment_path = lambda: "refresh-entry"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpkiRefreshAfTable.RpkiRefreshAf.RefreshEntry, [u'af_name', u'neighbor', u'policy', u'paths', u'drop'], name, value)


                            class Policies(Entity):
                                """
                                The BGP Policy Table
                                
                                .. attribute:: policy
                                
                                	A BGP Policy table entry
                                	**type**\: list of  		 :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies, self).__init__()

                                    self.yang_name = "policies"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("policy", ("policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy))])
                                    self._leafs = OrderedDict()

                                    self.policy = YList(self)
                                    self._segment_path = lambda: "policies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies, [], name, value)


                                class Policy(Entity):
                                    """
                                    A BGP Policy table entry
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr>`
                                    
                                    .. attribute:: path_info_after_policy_in
                                    
                                    	Path information after inbound policy
                                    	**type**\:  :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn>`
                                    
                                    .. attribute:: path_info_after_policy_out
                                    
                                    	Path information after outbound policy
                                    	**type**\:  :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: attributes_after_policy_out
                                    
                                    	Attributes after outbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy, self).__init__()

                                        self.yang_name = "policy"
                                        self.yang_parent_name = "policies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr)), ("path-info-after-policy-in", ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn)), ("path-info-after-policy-out", ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn)), ("attributes-after-policy-out", ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.vrf_name = None

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                        self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn()
                                        self.path_info_after_policy_in.parent = self
                                        self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"

                                        self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut()
                                        self.path_info_after_policy_out.parent = self
                                        self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"

                                        self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut()
                                        self.attributes_after_policy_out.parent = self
                                        self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                        self._segment_path = lambda: "policy"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy, ['rd', 'network', 'prefix_length', 'neighbor_address', u'no_path', u'af_name', u'route_distinguisher', u'source_route_distinguisher', u'vrf_name'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address-xr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInfoAfterPolicyIn(Entity):
                                        """
                                        Path information after inbound policy
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, self).__init__()

                                            self.yang_name = "path-info-after-policy-in"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-info-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInfoAfterPolicyOut(Entity):
                                        """
                                        Path information after outbound policy
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, self).__init__()

                                            self.yang_name = "path-info-after-policy-out"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-info-after-policy-out"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-info-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyOut(Entity):
                                        """
                                        Attributes after outbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, self).__init__()

                                            self.yang_name = "attributes-after-policy-out"
                                            self.yang_parent_name = "policy"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-out"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-out"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Policies.Policy.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class Convergence(Entity):
                                """
                                A BGP Convergence table entry
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: has_converged
                                
                                	Convergence has been reached
                                	**type**\: bool
                                
                                .. attribute:: are_write_queues_empty
                                
                                	All neighbor write queues are empty
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence, self).__init__()

                                    self.yang_name = "convergence"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('has_converged', (YLeaf(YType.boolean, 'has-converged'), ['bool'])),
                                        ('are_write_queues_empty', (YLeaf(YType.boolean, 'are-write-queues-empty'), ['bool'])),
                                    ])
                                    self.af_name = None
                                    self.has_converged = None
                                    self.are_write_queues_empty = None
                                    self._segment_path = lambda: "convergence"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Convergence, [u'af_name', u'has_converged', u'are_write_queues_empty'], name, value)


                            class AfProcessInfo(Entity):
                                """
                                A BGP Process address family table entry
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf>`
                                
                                .. attribute:: performance_statistics
                                
                                	Performance statistics
                                	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics>`
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: process_instance
                                
                                	ID for the BGP process instance
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\: str
                                
                                .. attribute:: vrf_totals
                                
                                	per VRF information aggregated across all VRFs
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo, self).__init__()

                                    self.yang_name = "af-process-info"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('process_instance', (YLeaf(YType.uint8, 'process-instance'), ['int'])),
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('vrf_totals', (YLeaf(YType.boolean, 'vrf-totals'), ['bool'])),
                                    ])
                                    self.af_name = None
                                    self.process_instance = None
                                    self.vrf_name = None
                                    self.vrf_totals = None

                                    self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"

                                    self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"

                                    self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics()
                                    self.performance_statistics.parent = self
                                    self._children_name_map["performance_statistics"] = "performance-statistics"
                                    self._segment_path = lambda: "af-process-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo, [u'af_name', u'process_instance', u'vrf_name', u'vrf_totals'], name, value)


                                class Global(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: version_wrap_time_spec
                                    
                                    	Version Wrap timestamp
                                    	**type**\:  :py:class:`VersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec>`
                                    
                                    .. attribute:: version_wrap_start_time_spec
                                    
                                    	Version Wrap handle start timestamp
                                    	**type**\:  :py:class:`VersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec>`
                                    
                                    .. attribute:: version_wrap_done_time_spec
                                    
                                    	Version Wrap handle Done timestamp
                                    	**type**\:  :py:class:`VersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec>`
                                    
                                    .. attribute:: trigger_rib
                                    
                                    	Trigger RIB
                                    	**type**\:  :py:class:`TriggerRib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib>`
                                    
                                    .. attribute:: trigger_import
                                    
                                    	Trigger import
                                    	**type**\:  :py:class:`TriggerImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport>`
                                    
                                    .. attribute:: trigger_update
                                    
                                    	Trigger update
                                    	**type**\:  :py:class:`TriggerUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate>`
                                    
                                    .. attribute:: trigger_label
                                    
                                    	Trigger label
                                    	**type**\:  :py:class:`TriggerLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel>`
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:  :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall>`
                                    
                                    .. attribute:: router_state
                                    
                                    	Router state
                                    	**type**\:  :py:class:`BgpRtrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRtrState>`
                                    
                                    .. attribute:: table_version
                                    
                                    	BGP table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrapped
                                    
                                    	Number of times Version Wrap happened
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version_wrapped_tid
                                    
                                    	Version Wrapped trigger tid
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_active_pelem_version
                                    
                                    	Maximum Active Pelem Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: merged_table_version
                                    
                                    	Merged Table Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_download_go_active_done_pending
                                    
                                    	Route Download Go Active Done Pending
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_brib_received_version
                                    
                                    	Version received from 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Version sent to RIB/bRIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_version
                                    
                                    	Version updated by label thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_version
                                    
                                    	Version updated by import thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: standby_version
                                    
                                    	Version updated by sync thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: send_version
                                    
                                    	Version for sending updates to peers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_init_sync_pfx
                                    
                                    	Num of prefix synced during Initsync
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_label_stack_depth_v4_next_hop
                                    
                                    	Max supported label stack depth for IPv4 Nexthop
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_label_stack_depth_v6_next_hop
                                    
                                    	Max supported label stack depth for IPv6 Nexthop
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_num
                                    
                                    	Total local networks
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_memory
                                    
                                    	Total local networks memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_malloced_num
                                    
                                    	Total local networks malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_networks_freed_num
                                    
                                    	Total local networks freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_num
                                    
                                    	Total local paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_memory
                                    
                                    	Total local paths memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_malloced_num
                                    
                                    	Total local paths malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths_freed_num
                                    
                                    	Total local paths freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_num
                                    
                                    	Total impoorted paths 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths_memory
                                    
                                    	Total imported paths memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_num
                                    
                                    	Total Num of networks
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_memory
                                    
                                    	Total networks memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_malloced_num
                                    
                                    	Total networks malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: networks_freed_num
                                    
                                    	Total networks freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_num
                                    
                                    	Total Num of paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_memory
                                    
                                    	Total paths memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_malloced_num
                                    
                                    	Total paths malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_freed_num
                                    
                                    	Total paths freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_num
                                    
                                    	Total Num of path\-elems
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_memory
                                    
                                    	Total path\-elems memory
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_malloced_num
                                    
                                    	Total path\-elems malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_freed_num
                                    
                                    	Total path\-elems freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_last_trigger
                                    
                                    	Timestamp when Label thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_label_version
                                    
                                    	Label thread version when last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_bgp_version
                                    
                                    	BGP version when label thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_triggers
                                    
                                    	Label thread triggers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_last_trigger
                                    
                                    	Timestamp when RIB thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_rib_version
                                    
                                    	RIB thread version when last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_bgp_version
                                    
                                    	BGP version when RIB thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_triggers
                                    
                                    	RIB thread triggers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_last_trigger
                                    
                                    	Timestamp when Import thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_import_version
                                    
                                    	Import thread version when last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_bgp_version
                                    
                                    	BGP version when Import thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: import_triggers
                                    
                                    	Import thread triggers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_gen_last_trigger
                                    
                                    	Timestamp when Update generation thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_gen_bgp_version
                                    
                                    	BGP version when Update generation thread is last triggered
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_triggers
                                    
                                    	Update thread triggers
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_r_ds_num
                                    
                                    	Total Num of RDs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_remote_r_ds_num
                                    
                                    	Total Num of remote RDs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total_same_r_ds_num
                                    
                                    	Total Num of same RDs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_rd_count
                                    
                                    	Activity\: Number of RDs malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_rd_count
                                    
                                    	Activity\: Number of RDs freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rd_memory
                                    
                                    	Memory (in bytes) used by RD data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: multipath_network_entry_count
                                    
                                    	Number of multipath network entries
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_network_entry_memory
                                    
                                    	Memory (in bytes) used bymultipath network entries
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: multipath_paths_count
                                    
                                    	Number of multipath paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: multipath_paths_memory
                                    
                                    	Memory (in bytes) used bymultimpath paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("version-wrap-time-spec", ("version_wrap_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec)), ("version-wrap-start-time-spec", ("version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec)), ("version-wrap-done-time-spec", ("version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec)), ("trigger-rib", ("trigger_rib", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib)), ("trigger-import", ("trigger_import", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport)), ("trigger-update", ("trigger_update", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate)), ("trigger-label", ("trigger_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel)), ("rib-install", ("rib_install", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall))])
                                        self._leafs = OrderedDict([
                                            ('router_state', (YLeaf(YType.enumeration, 'router-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRtrState', '')])),
                                            ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                            ('version_wrapped', (YLeaf(YType.uint32, 'version-wrapped'), ['int'])),
                                            ('version_wrapped_tid', (YLeaf(YType.uint32, 'version-wrapped-tid'), ['int'])),
                                            ('max_active_pelem_version', (YLeaf(YType.uint32, 'max-active-pelem-version'), ['int'])),
                                            ('merged_table_version', (YLeaf(YType.uint32, 'merged-table-version'), ['int'])),
                                            ('route_download_go_active_done_pending', (YLeaf(YType.uint32, 'route-download-go-active-done-pending'), ['int'])),
                                            ('rib_brib_received_version', (YLeaf(YType.uint32, 'rib-brib-received-version'), ['int'])),
                                            ('table_brib_version', (YLeaf(YType.uint32, 'table-brib-version'), ['int'])),
                                            ('label_version', (YLeaf(YType.uint32, 'label-version'), ['int'])),
                                            ('import_version', (YLeaf(YType.uint32, 'import-version'), ['int'])),
                                            ('standby_version', (YLeaf(YType.uint32, 'standby-version'), ['int'])),
                                            ('send_version', (YLeaf(YType.uint32, 'send-version'), ['int'])),
                                            ('num_init_sync_pfx', (YLeaf(YType.uint32, 'num-init-sync-pfx'), ['int'])),
                                            ('max_label_stack_depth_v4_next_hop', (YLeaf(YType.uint32, 'max-label-stack-depth-v4-next-hop'), ['int'])),
                                            ('max_label_stack_depth_v6_next_hop', (YLeaf(YType.uint32, 'max-label-stack-depth-v6-next-hop'), ['int'])),
                                            ('local_networks_num', (YLeaf(YType.uint32, 'local-networks-num'), ['int'])),
                                            ('local_networks_memory', (YLeaf(YType.uint32, 'local-networks-memory'), ['int'])),
                                            ('local_networks_malloced_num', (YLeaf(YType.uint32, 'local-networks-malloced-num'), ['int'])),
                                            ('local_networks_freed_num', (YLeaf(YType.uint32, 'local-networks-freed-num'), ['int'])),
                                            ('local_paths_num', (YLeaf(YType.uint32, 'local-paths-num'), ['int'])),
                                            ('local_paths_memory', (YLeaf(YType.uint32, 'local-paths-memory'), ['int'])),
                                            ('local_paths_malloced_num', (YLeaf(YType.uint32, 'local-paths-malloced-num'), ['int'])),
                                            ('local_paths_freed_num', (YLeaf(YType.uint32, 'local-paths-freed-num'), ['int'])),
                                            ('imported_paths_num', (YLeaf(YType.uint32, 'imported-paths-num'), ['int'])),
                                            ('imported_paths_memory', (YLeaf(YType.uint32, 'imported-paths-memory'), ['int'])),
                                            ('networks_num', (YLeaf(YType.uint32, 'networks-num'), ['int'])),
                                            ('networks_memory', (YLeaf(YType.uint32, 'networks-memory'), ['int'])),
                                            ('networks_malloced_num', (YLeaf(YType.uint32, 'networks-malloced-num'), ['int'])),
                                            ('networks_freed_num', (YLeaf(YType.uint32, 'networks-freed-num'), ['int'])),
                                            ('paths_num', (YLeaf(YType.uint32, 'paths-num'), ['int'])),
                                            ('paths_memory', (YLeaf(YType.uint32, 'paths-memory'), ['int'])),
                                            ('paths_malloced_num', (YLeaf(YType.uint32, 'paths-malloced-num'), ['int'])),
                                            ('paths_freed_num', (YLeaf(YType.uint32, 'paths-freed-num'), ['int'])),
                                            ('path_elems_num', (YLeaf(YType.uint32, 'path-elems-num'), ['int'])),
                                            ('path_elems_memory', (YLeaf(YType.uint32, 'path-elems-memory'), ['int'])),
                                            ('path_elems_malloced_num', (YLeaf(YType.uint32, 'path-elems-malloced-num'), ['int'])),
                                            ('path_elems_freed_num', (YLeaf(YType.uint32, 'path-elems-freed-num'), ['int'])),
                                            ('label_last_trigger', (YLeaf(YType.uint64, 'label-last-trigger'), ['int'])),
                                            ('last_label_version', (YLeaf(YType.uint32, 'last-label-version'), ['int'])),
                                            ('label_bgp_version', (YLeaf(YType.uint32, 'label-bgp-version'), ['int'])),
                                            ('label_triggers', (YLeaf(YType.uint32, 'label-triggers'), ['int'])),
                                            ('rib_last_trigger', (YLeaf(YType.uint64, 'rib-last-trigger'), ['int'])),
                                            ('last_rib_version', (YLeaf(YType.uint32, 'last-rib-version'), ['int'])),
                                            ('rib_bgp_version', (YLeaf(YType.uint32, 'rib-bgp-version'), ['int'])),
                                            ('rib_triggers', (YLeaf(YType.uint32, 'rib-triggers'), ['int'])),
                                            ('import_last_trigger', (YLeaf(YType.uint64, 'import-last-trigger'), ['int'])),
                                            ('last_import_version', (YLeaf(YType.uint32, 'last-import-version'), ['int'])),
                                            ('import_bgp_version', (YLeaf(YType.uint32, 'import-bgp-version'), ['int'])),
                                            ('import_triggers', (YLeaf(YType.uint32, 'import-triggers'), ['int'])),
                                            ('update_gen_last_trigger', (YLeaf(YType.uint64, 'update-gen-last-trigger'), ['int'])),
                                            ('update_gen_bgp_version', (YLeaf(YType.uint32, 'update-gen-bgp-version'), ['int'])),
                                            ('update_triggers', (YLeaf(YType.uint32, 'update-triggers'), ['int'])),
                                            ('total_r_ds_num', (YLeaf(YType.uint32, 'total-r-ds-num'), ['int'])),
                                            ('total_remote_r_ds_num', (YLeaf(YType.uint32, 'total-remote-r-ds-num'), ['int'])),
                                            ('total_same_r_ds_num', (YLeaf(YType.uint32, 'total-same-r-ds-num'), ['int'])),
                                            ('malloced_rd_count', (YLeaf(YType.uint32, 'malloced-rd-count'), ['int'])),
                                            ('freed_rd_count', (YLeaf(YType.uint32, 'freed-rd-count'), ['int'])),
                                            ('rd_memory', (YLeaf(YType.uint32, 'rd-memory'), ['int'])),
                                            ('multipath_network_entry_count', (YLeaf(YType.uint32, 'multipath-network-entry-count'), ['int'])),
                                            ('multipath_network_entry_memory', (YLeaf(YType.uint32, 'multipath-network-entry-memory'), ['int'])),
                                            ('multipath_paths_count', (YLeaf(YType.uint32, 'multipath-paths-count'), ['int'])),
                                            ('multipath_paths_memory', (YLeaf(YType.uint32, 'multipath-paths-memory'), ['int'])),
                                            ('update_wait_install_enabled', (YLeaf(YType.uint32, 'update-wait-install-enabled'), ['int'])),
                                            ('rib_acked_table_version', (YLeaf(YType.uint32, 'rib-acked-table-version'), ['int'])),
                                            ('rib_ack_requests', (YLeaf(YType.uint32, 'rib-ack-requests'), ['int'])),
                                            ('rib_acks_received', (YLeaf(YType.uint32, 'rib-acks-received'), ['int'])),
                                            ('rib_slow_acks', (YLeaf(YType.uint32, 'rib-slow-acks'), ['int'])),
                                        ])
                                        self.router_state = None
                                        self.table_version = None
                                        self.version_wrapped = None
                                        self.version_wrapped_tid = None
                                        self.max_active_pelem_version = None
                                        self.merged_table_version = None
                                        self.route_download_go_active_done_pending = None
                                        self.rib_brib_received_version = None
                                        self.table_brib_version = None
                                        self.label_version = None
                                        self.import_version = None
                                        self.standby_version = None
                                        self.send_version = None
                                        self.num_init_sync_pfx = None
                                        self.max_label_stack_depth_v4_next_hop = None
                                        self.max_label_stack_depth_v6_next_hop = None
                                        self.local_networks_num = None
                                        self.local_networks_memory = None
                                        self.local_networks_malloced_num = None
                                        self.local_networks_freed_num = None
                                        self.local_paths_num = None
                                        self.local_paths_memory = None
                                        self.local_paths_malloced_num = None
                                        self.local_paths_freed_num = None
                                        self.imported_paths_num = None
                                        self.imported_paths_memory = None
                                        self.networks_num = None
                                        self.networks_memory = None
                                        self.networks_malloced_num = None
                                        self.networks_freed_num = None
                                        self.paths_num = None
                                        self.paths_memory = None
                                        self.paths_malloced_num = None
                                        self.paths_freed_num = None
                                        self.path_elems_num = None
                                        self.path_elems_memory = None
                                        self.path_elems_malloced_num = None
                                        self.path_elems_freed_num = None
                                        self.label_last_trigger = None
                                        self.last_label_version = None
                                        self.label_bgp_version = None
                                        self.label_triggers = None
                                        self.rib_last_trigger = None
                                        self.last_rib_version = None
                                        self.rib_bgp_version = None
                                        self.rib_triggers = None
                                        self.import_last_trigger = None
                                        self.last_import_version = None
                                        self.import_bgp_version = None
                                        self.import_triggers = None
                                        self.update_gen_last_trigger = None
                                        self.update_gen_bgp_version = None
                                        self.update_triggers = None
                                        self.total_r_ds_num = None
                                        self.total_remote_r_ds_num = None
                                        self.total_same_r_ds_num = None
                                        self.malloced_rd_count = None
                                        self.freed_rd_count = None
                                        self.rd_memory = None
                                        self.multipath_network_entry_count = None
                                        self.multipath_network_entry_memory = None
                                        self.multipath_paths_count = None
                                        self.multipath_paths_memory = None
                                        self.update_wait_install_enabled = None
                                        self.rib_acked_table_version = None
                                        self.rib_ack_requests = None
                                        self.rib_acks_received = None
                                        self.rib_slow_acks = None

                                        self.version_wrap_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec()
                                        self.version_wrap_time_spec.parent = self
                                        self._children_name_map["version_wrap_time_spec"] = "version-wrap-time-spec"

                                        self.version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec()
                                        self.version_wrap_start_time_spec.parent = self
                                        self._children_name_map["version_wrap_start_time_spec"] = "version-wrap-start-time-spec"

                                        self.version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec()
                                        self.version_wrap_done_time_spec.parent = self
                                        self._children_name_map["version_wrap_done_time_spec"] = "version-wrap-done-time-spec"

                                        self.trigger_rib = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib()
                                        self.trigger_rib.parent = self
                                        self._children_name_map["trigger_rib"] = "trigger-rib"

                                        self.trigger_import = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport()
                                        self.trigger_import.parent = self
                                        self._children_name_map["trigger_import"] = "trigger-import"

                                        self.trigger_update = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate()
                                        self.trigger_update.parent = self
                                        self._children_name_map["trigger_update"] = "trigger-update"

                                        self.trigger_label = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel()
                                        self.trigger_label.parent = self
                                        self._children_name_map["trigger_label"] = "trigger-label"

                                        self.rib_install = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall()
                                        self.rib_install.parent = self
                                        self._children_name_map["rib_install"] = "rib-install"
                                        self._segment_path = lambda: "global"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global, [u'router_state', u'table_version', u'version_wrapped', u'version_wrapped_tid', u'max_active_pelem_version', u'merged_table_version', u'route_download_go_active_done_pending', u'rib_brib_received_version', u'table_brib_version', u'label_version', u'import_version', u'standby_version', u'send_version', u'num_init_sync_pfx', u'max_label_stack_depth_v4_next_hop', u'max_label_stack_depth_v6_next_hop', u'local_networks_num', u'local_networks_memory', u'local_networks_malloced_num', u'local_networks_freed_num', u'local_paths_num', u'local_paths_memory', u'local_paths_malloced_num', u'local_paths_freed_num', u'imported_paths_num', u'imported_paths_memory', u'networks_num', u'networks_memory', u'networks_malloced_num', u'networks_freed_num', u'paths_num', u'paths_memory', u'paths_malloced_num', u'paths_freed_num', u'path_elems_num', u'path_elems_memory', u'path_elems_malloced_num', u'path_elems_freed_num', u'label_last_trigger', u'last_label_version', u'label_bgp_version', u'label_triggers', u'rib_last_trigger', u'last_rib_version', u'rib_bgp_version', u'rib_triggers', u'import_last_trigger', u'last_import_version', u'import_bgp_version', u'import_triggers', u'update_gen_last_trigger', u'update_gen_bgp_version', u'update_triggers', u'total_r_ds_num', u'total_remote_r_ds_num', u'total_same_r_ds_num', u'malloced_rd_count', u'freed_rd_count', u'rd_memory', u'multipath_network_entry_count', u'multipath_network_entry_memory', u'multipath_paths_count', u'multipath_paths_memory', u'update_wait_install_enabled', u'rib_acked_table_version', u'rib_ack_requests', u'rib_acks_received', u'rib_slow_acks'], name, value)


                                    class VersionWrapTimeSpec(Entity):
                                        """
                                        Version Wrap timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-wrap-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class VersionWrapStartTimeSpec(Entity):
                                        """
                                        Version Wrap handle start timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-start-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-wrap-start-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapStartTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class VersionWrapDoneTimeSpec(Entity):
                                        """
                                        Version Wrap handle Done timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec, self).__init__()

                                            self.yang_name = "version-wrap-done-time-spec"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-wrap-done-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.VersionWrapDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TriggerRib(Entity):
                                        """
                                        Trigger RIB
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib, self).__init__()

                                            self.yang_name = "trigger-rib"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic))])
                                            self._leafs = OrderedDict([
                                                ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                            ])
                                            self.triggers = None

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-rib"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib, [u'triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-rib"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                    ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                ])
                                                self.trigger_version = None
                                                self.trigger_table_version = None

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._segment_path = lambda: "statistic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "trigger-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerRib.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TriggerImport(Entity):
                                        """
                                        Trigger import
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport, self).__init__()

                                            self.yang_name = "trigger-import"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic))])
                                            self._leafs = OrderedDict([
                                                ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                            ])
                                            self.triggers = None

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-import"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport, [u'triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-import"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                    ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                ])
                                                self.trigger_version = None
                                                self.trigger_table_version = None

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._segment_path = lambda: "statistic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "trigger-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerImport.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TriggerUpdate(Entity):
                                        """
                                        Trigger update
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate, self).__init__()

                                            self.yang_name = "trigger-update"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic))])
                                            self._leafs = OrderedDict([
                                                ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                            ])
                                            self.triggers = None

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-update"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate, [u'triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-update"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                    ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                ])
                                                self.trigger_version = None
                                                self.trigger_table_version = None

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._segment_path = lambda: "statistic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "trigger-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerUpdate.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TriggerLabel(Entity):
                                        """
                                        Trigger label
                                        
                                        .. attribute:: triggers
                                        
                                        	Triggers
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: statistic
                                        
                                        	statistic
                                        	**type**\: list of  		 :py:class:`Statistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel, self).__init__()

                                            self.yang_name = "trigger-label"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("statistic", ("statistic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic))])
                                            self._leafs = OrderedDict([
                                                ('triggers', (YLeaf(YType.uint32, 'triggers'), ['int'])),
                                            ])
                                            self.triggers = None

                                            self.statistic = YList(self)
                                            self._segment_path = lambda: "trigger-label"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel, [u'triggers'], name, value)


                                        class Statistic(Entity):
                                            """
                                            statistic
                                            
                                            .. attribute:: trigger_time_spec
                                            
                                            	trigger time spec
                                            	**type**\:  :py:class:`TriggerTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec>`
                                            
                                            .. attribute:: trigger_version
                                            
                                            	TriggerVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: trigger_table_version
                                            
                                            	TriggerTableVersion
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic, self).__init__()

                                                self.yang_name = "statistic"
                                                self.yang_parent_name = "trigger-label"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("trigger-time-spec", ("trigger_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec))])
                                                self._leafs = OrderedDict([
                                                    ('trigger_version', (YLeaf(YType.uint32, 'trigger-version'), ['int'])),
                                                    ('trigger_table_version', (YLeaf(YType.uint32, 'trigger-table-version'), ['int'])),
                                                ])
                                                self.trigger_version = None
                                                self.trigger_table_version = None

                                                self.trigger_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec()
                                                self.trigger_time_spec.parent = self
                                                self._children_name_map["trigger_time_spec"] = "trigger-time-spec"
                                                self._segment_path = lambda: "statistic"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic, [u'trigger_version', u'trigger_table_version'], name, value)


                                            class TriggerTimeSpec(Entity):
                                                """
                                                trigger time spec
                                                
                                                .. attribute:: seconds
                                                
                                                	Seconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: nanoseconds
                                                
                                                	Nanoseconds part of time value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: nanosecond
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec, self).__init__()

                                                    self.yang_name = "trigger-time-spec"
                                                    self.yang_parent_name = "statistic"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                    ])
                                                    self.seconds = None
                                                    self.nanoseconds = None
                                                    self._segment_path = lambda: "trigger-time-spec"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.TriggerLabel.Statistic.TriggerTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class RibInstall(Entity):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:  :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:  :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: skipped_count
                                        
                                        	Skipped routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall, self).__init__()

                                            self.yang_name = "rib-install"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("update-time", ("update_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime)), ("install-time", ("install_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime))])
                                            self._leafs = OrderedDict([
                                                ('installed_count', (YLeaf(YType.uint32, 'installed-count'), ['int'])),
                                                ('modified_count', (YLeaf(YType.uint32, 'modified-count'), ['int'])),
                                                ('skipped_count', (YLeaf(YType.uint32, 'skipped-count'), ['int'])),
                                                ('withdrawn_count', (YLeaf(YType.uint32, 'withdrawn-count'), ['int'])),
                                                ('start_version', (YLeaf(YType.uint32, 'start-version'), ['int'])),
                                                ('target_version', (YLeaf(YType.uint32, 'target-version'), ['int'])),
                                            ])
                                            self.installed_count = None
                                            self.modified_count = None
                                            self.skipped_count = None
                                            self.withdrawn_count = None
                                            self.start_version = None
                                            self.target_version = None

                                            self.update_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self._children_name_map["update_time"] = "update-time"

                                            self.install_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self._children_name_map["install_time"] = "install-time"
                                            self._segment_path = lambda: "rib-install"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall, [u'installed_count', u'modified_count', u'skipped_count', u'withdrawn_count', u'start_version', u'target_version'], name, value)


                                        class UpdateTime(Entity):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime, self).__init__()

                                                self.yang_name = "update-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "update-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.UpdateTime, [u'seconds', u'nanoseconds'], name, value)


                                        class InstallTime(Entity):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime, self).__init__()

                                                self.yang_name = "install-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "install-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Global.RibInstall.InstallTime, [u'seconds', u'nanoseconds'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: network_entry_count
                                    
                                    	Number of network entries
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: paths_count
                                    
                                    	Number of paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: imported_paths
                                    
                                    	Number of imported paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_paths
                                    
                                    	Number of local paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_elems_count
                                    
                                    	Number of path elems
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: imported_path_memory
                                    
                                    	Memory (in bytes) used by imported paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: local_path_memory
                                    
                                    	Memory (in bytes) used by local paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: path_elem_memory
                                    
                                    	Memory (in bytes) used by pathelem data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_path_count
                                    
                                    	Number of (unused) received paths for inbound soft reconfiguration
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: history_path_count
                                    
                                    	Number of history paths (for dampening)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: damped_path_count
                                    
                                    	Number of dampened paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_prefix_count
                                    
                                    	Activity\: Number of prefixes malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_prefix_count
                                    
                                    	Activity\: Number of prefixes freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_count
                                    
                                    	Activity\: Number of paths malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_count
                                    
                                    	Activity\: Number of paths freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: malloced_path_elem_count
                                    
                                    	Activity\: Number of path elems malloced
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: freed_path_elem_count
                                    
                                    	Activity\: Number of pathelems freed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: any_ebgp_neighbor_missing_policy
                                    
                                    	Is there any neighbor which is missing either inbound or outbound or both routing policy for this address family?
                                    	**type**\: bool
                                    
                                    .. attribute:: attribute_download
                                    
                                    	Attribute download is 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_target_download
                                    
                                    	Route Target download is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: srms_prefix_sid
                                    
                                    	SRMS Prefix SID is 
                                    	**type**\: bool
                                    
                                    .. attribute:: add_path_install_enable
                                    
                                    	Additional paths installation is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: add_path_install_disable
                                    
                                    	Additional paths installation is disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: best_external
                                    
                                    	Best External is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: best_external_disable
                                    
                                    	Best External is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: label_retain
                                    
                                    	Label retention is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: label_retainvalue
                                    
                                    	Label retention value enabled
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tbl_bitf_size
                                    
                                    	Bitfield size on table
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: tbl_chunk_bitf_size
                                    
                                    	Chunk Bitfield size on table
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: is_route_reflector
                                    
                                    	Router is an RR for this AF
                                    	**type**\: bool
                                    
                                    .. attribute:: asbr
                                    
                                    	Router is an ASBR for this AF
                                    	**type**\: bool
                                    
                                    .. attribute:: retain_rt_all
                                    
                                    	Retain\-RT\-All enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: ibgp_nexthop_self_count
                                    
                                    	Number of iBGP sessions configured with nh\-self
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: use_igpsr_label
                                    
                                    	Use IGP SR label for resolution
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_network_entry_count
                                    
                                    	Number of BMP net entries
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_paths_count
                                    
                                    	Total Number of BMP paths
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_prefix_memory
                                    
                                    	Memory (in bytes) used by prefix data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bmp_path_memory
                                    
                                    	Memory (in bytes) used by path data
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('network_entry_count', (YLeaf(YType.uint32, 'network-entry-count'), ['int'])),
                                            ('paths_count', (YLeaf(YType.uint32, 'paths-count'), ['int'])),
                                            ('imported_paths', (YLeaf(YType.uint32, 'imported-paths'), ['int'])),
                                            ('local_paths', (YLeaf(YType.uint32, 'local-paths'), ['int'])),
                                            ('path_elems_count', (YLeaf(YType.uint32, 'path-elems-count'), ['int'])),
                                            ('path_memory', (YLeaf(YType.uint32, 'path-memory'), ['int'])),
                                            ('imported_path_memory', (YLeaf(YType.uint32, 'imported-path-memory'), ['int'])),
                                            ('local_path_memory', (YLeaf(YType.uint32, 'local-path-memory'), ['int'])),
                                            ('prefix_memory', (YLeaf(YType.uint32, 'prefix-memory'), ['int'])),
                                            ('path_elem_memory', (YLeaf(YType.uint32, 'path-elem-memory'), ['int'])),
                                            ('received_path_count', (YLeaf(YType.uint32, 'received-path-count'), ['int'])),
                                            ('history_path_count', (YLeaf(YType.uint32, 'history-path-count'), ['int'])),
                                            ('damped_path_count', (YLeaf(YType.uint32, 'damped-path-count'), ['int'])),
                                            ('malloced_prefix_count', (YLeaf(YType.uint32, 'malloced-prefix-count'), ['int'])),
                                            ('freed_prefix_count', (YLeaf(YType.uint32, 'freed-prefix-count'), ['int'])),
                                            ('malloced_path_count', (YLeaf(YType.uint32, 'malloced-path-count'), ['int'])),
                                            ('freed_path_count', (YLeaf(YType.uint32, 'freed-path-count'), ['int'])),
                                            ('malloced_path_elem_count', (YLeaf(YType.uint32, 'malloced-path-elem-count'), ['int'])),
                                            ('freed_path_elem_count', (YLeaf(YType.uint32, 'freed-path-elem-count'), ['int'])),
                                            ('any_ebgp_neighbor_missing_policy', (YLeaf(YType.boolean, 'any-ebgp-neighbor-missing-policy'), ['bool'])),
                                            ('attribute_download', (YLeaf(YType.boolean, 'attribute-download'), ['bool'])),
                                            ('route_target_download', (YLeaf(YType.boolean, 'route-target-download'), ['bool'])),
                                            ('srms_prefix_sid', (YLeaf(YType.boolean, 'srms-prefix-sid'), ['bool'])),
                                            ('add_path_install_enable', (YLeaf(YType.boolean, 'add-path-install-enable'), ['bool'])),
                                            ('add_path_install_disable', (YLeaf(YType.boolean, 'add-path-install-disable'), ['bool'])),
                                            ('best_external', (YLeaf(YType.boolean, 'best-external'), ['bool'])),
                                            ('best_external_disable', (YLeaf(YType.boolean, 'best-external-disable'), ['bool'])),
                                            ('label_retain', (YLeaf(YType.boolean, 'label-retain'), ['bool'])),
                                            ('label_retainvalue', (YLeaf(YType.uint32, 'label-retainvalue'), ['int'])),
                                            ('tbl_bitf_size', (YLeaf(YType.uint16, 'tbl-bitf-size'), ['int'])),
                                            ('tbl_chunk_bitf_size', (YLeaf(YType.uint16, 'tbl-chunk-bitf-size'), ['int'])),
                                            ('is_route_reflector', (YLeaf(YType.boolean, 'is-route-reflector'), ['bool'])),
                                            ('asbr', (YLeaf(YType.boolean, 'asbr'), ['bool'])),
                                            ('retain_rt_all', (YLeaf(YType.boolean, 'retain-rt-all'), ['bool'])),
                                            ('ibgp_nexthop_self_count', (YLeaf(YType.uint32, 'ibgp-nexthop-self-count'), ['int'])),
                                            ('use_igpsr_label', (YLeaf(YType.boolean, 'use-igpsr-label'), ['bool'])),
                                            ('bmp_network_entry_count', (YLeaf(YType.uint32, 'bmp-network-entry-count'), ['int'])),
                                            ('bmp_paths_count', (YLeaf(YType.uint32, 'bmp-paths-count'), ['int'])),
                                            ('bmp_prefix_memory', (YLeaf(YType.uint32, 'bmp-prefix-memory'), ['int'])),
                                            ('bmp_path_memory', (YLeaf(YType.uint32, 'bmp-path-memory'), ['int'])),
                                        ])
                                        self.network_entry_count = None
                                        self.paths_count = None
                                        self.imported_paths = None
                                        self.local_paths = None
                                        self.path_elems_count = None
                                        self.path_memory = None
                                        self.imported_path_memory = None
                                        self.local_path_memory = None
                                        self.prefix_memory = None
                                        self.path_elem_memory = None
                                        self.received_path_count = None
                                        self.history_path_count = None
                                        self.damped_path_count = None
                                        self.malloced_prefix_count = None
                                        self.freed_prefix_count = None
                                        self.malloced_path_count = None
                                        self.freed_path_count = None
                                        self.malloced_path_elem_count = None
                                        self.freed_path_elem_count = None
                                        self.any_ebgp_neighbor_missing_policy = None
                                        self.attribute_download = None
                                        self.route_target_download = None
                                        self.srms_prefix_sid = None
                                        self.add_path_install_enable = None
                                        self.add_path_install_disable = None
                                        self.best_external = None
                                        self.best_external_disable = None
                                        self.label_retain = None
                                        self.label_retainvalue = None
                                        self.tbl_bitf_size = None
                                        self.tbl_chunk_bitf_size = None
                                        self.is_route_reflector = None
                                        self.asbr = None
                                        self.retain_rt_all = None
                                        self.ibgp_nexthop_self_count = None
                                        self.use_igpsr_label = None
                                        self.bmp_network_entry_count = None
                                        self.bmp_paths_count = None
                                        self.bmp_prefix_memory = None
                                        self.bmp_path_memory = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.Vrf, [u'network_entry_count', u'paths_count', u'imported_paths', u'local_paths', u'path_elems_count', u'path_memory', u'imported_path_memory', u'local_path_memory', u'prefix_memory', u'path_elem_memory', u'received_path_count', u'history_path_count', u'damped_path_count', u'malloced_prefix_count', u'freed_prefix_count', u'malloced_path_count', u'freed_path_count', u'malloced_path_elem_count', u'freed_path_elem_count', u'any_ebgp_neighbor_missing_policy', u'attribute_download', u'route_target_download', u'srms_prefix_sid', u'add_path_install_enable', u'add_path_install_disable', u'best_external', u'best_external_disable', u'label_retain', u'label_retainvalue', u'tbl_bitf_size', u'tbl_chunk_bitf_size', u'is_route_reflector', u'asbr', u'retain_rt_all', u'ibgp_nexthop_self_count', u'use_igpsr_label', u'bmp_network_entry_count', u'bmp_paths_count', u'bmp_prefix_memory', u'bmp_path_memory'], name, value)


                                class PerformanceStatistics(Entity):
                                    """
                                    Performance statistics
                                    
                                    .. attribute:: global_
                                    
                                    	Global information
                                    	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global>`
                                    
                                    .. attribute:: vrf
                                    
                                    	VRF information
                                    	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics, self).__init__()

                                        self.yang_name = "performance-statistics"
                                        self.yang_parent_name = "af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf))])
                                        self._leafs = OrderedDict()

                                        self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global()
                                        self.global_.parent = self
                                        self._children_name_map["global_"] = "global"

                                        self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf()
                                        self.vrf.parent = self
                                        self._children_name_map["vrf"] = "vrf"
                                        self._segment_path = lambda: "performance-statistics"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics, [], name, value)


                                    class Global(Entity):
                                        """
                                        Global information
                                        
                                        .. attribute:: has_converged
                                        
                                        	TRUE if process has converged
                                        	**type**\: bool
                                        
                                        .. attribute:: first_nbr_up_time
                                        
                                        	Time when first peer came up (seconds since Jan 1 1970)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: total_pim_install
                                        
                                        	Total number of install to PIM
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_callbacks
                                        
                                        	Total number of PIM callbacks
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total_pim_callback_batch
                                        
                                        	Total number of Pim callback batches
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mode_enter_time
                                        
                                        	Time that each mode was entered (seconds since  Jan 1 1970)
                                        	**type**\: list of  		 :py:class:`ModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime>`
                                        
                                        .. attribute:: total_pim_install_add
                                        
                                        	Total number of install to PIM for add
                                        	**type**\: list of  		 :py:class:`TotalPimInstallAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd>`
                                        
                                        .. attribute:: total_pim_install_del
                                        
                                        	Total number of install to PIM for del
                                        	**type**\: list of  		 :py:class:`TotalPimInstallDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel>`
                                        
                                        .. attribute:: total_pim_callback_add
                                        
                                        	Total number of Pim callbacks for add
                                        	**type**\: list of  		 :py:class:`TotalPimCallbackAdd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd>`
                                        
                                        .. attribute:: total_pim_callback_del
                                        
                                        	Total number of Pim callbacks for del
                                        	**type**\: list of  		 :py:class:`TotalPimCallbackDel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel>`
                                        
                                        .. attribute:: total_pim_callback_add_local
                                        
                                        	Total number of Pim callbacks for local add
                                        	**type**\: list of  		 :py:class:`TotalPimCallbackAddLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal>`
                                        
                                        .. attribute:: total_pim_callback_del_local
                                        
                                        	Total number of Pim callbacks for Local del
                                        	**type**\: list of  		 :py:class:`TotalPimCallbackDelLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global, self).__init__()

                                            self.yang_name = "global"
                                            self.yang_parent_name = "performance-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("mode-enter-time", ("mode_enter_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime)), ("total-pim-install-add", ("total_pim_install_add", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd)), ("total-pim-install-del", ("total_pim_install_del", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel)), ("total-pim-callback-add", ("total_pim_callback_add", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd)), ("total-pim-callback-del", ("total_pim_callback_del", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel)), ("total-pim-callback-add-local", ("total_pim_callback_add_local", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal)), ("total-pim-callback-del-local", ("total_pim_callback_del_local", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal))])
                                            self._leafs = OrderedDict([
                                                ('has_converged', (YLeaf(YType.boolean, 'has-converged'), ['bool'])),
                                                ('first_nbr_up_time', (YLeaf(YType.uint32, 'first-nbr-up-time'), ['int'])),
                                                ('total_pim_install', (YLeaf(YType.uint32, 'total-pim-install'), ['int'])),
                                                ('total_pim_callbacks', (YLeaf(YType.uint32, 'total-pim-callbacks'), ['int'])),
                                                ('total_pim_callback_batch', (YLeaf(YType.uint32, 'total-pim-callback-batch'), ['int'])),
                                            ])
                                            self.has_converged = None
                                            self.first_nbr_up_time = None
                                            self.total_pim_install = None
                                            self.total_pim_callbacks = None
                                            self.total_pim_callback_batch = None

                                            self.mode_enter_time = YList(self)
                                            self.total_pim_install_add = YList(self)
                                            self.total_pim_install_del = YList(self)
                                            self.total_pim_callback_add = YList(self)
                                            self.total_pim_callback_del = YList(self)
                                            self.total_pim_callback_add_local = YList(self)
                                            self.total_pim_callback_del_local = YList(self)
                                            self._segment_path = lambda: "global"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global, [u'has_converged', u'first_nbr_up_time', u'total_pim_install', u'total_pim_callbacks', u'total_pim_callback_batch'], name, value)


                                        class ModeEnterTime(Entity):
                                            """
                                            Time that each mode was entered (seconds since
                                            
                                            Jan 1 1970)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime, self).__init__()

                                                self.yang_name = "mode-enter-time"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mode-enter-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.ModeEnterTime, [u'entry'], name, value)


                                        class TotalPimInstallAdd(Entity):
                                            """
                                            Total number of install to PIM for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd, self).__init__()

                                                self.yang_name = "total-pim-install-add"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-install-add"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallAdd, [u'entry'], name, value)


                                        class TotalPimInstallDel(Entity):
                                            """
                                            Total number of install to PIM for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel, self).__init__()

                                                self.yang_name = "total-pim-install-del"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-install-del"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimInstallDel, [u'entry'], name, value)


                                        class TotalPimCallbackAdd(Entity):
                                            """
                                            Total number of Pim callbacks for add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd, self).__init__()

                                                self.yang_name = "total-pim-callback-add"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-callback-add"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAdd, [u'entry'], name, value)


                                        class TotalPimCallbackDel(Entity):
                                            """
                                            Total number of Pim callbacks for del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel, self).__init__()

                                                self.yang_name = "total-pim-callback-del"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-callback-del"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDel, [u'entry'], name, value)


                                        class TotalPimCallbackAddLocal(Entity):
                                            """
                                            Total number of Pim callbacks for local add
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal, self).__init__()

                                                self.yang_name = "total-pim-callback-add-local"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-callback-add-local"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackAddLocal, [u'entry'], name, value)


                                        class TotalPimCallbackDelLocal(Entity):
                                            """
                                            Total number of Pim callbacks for Local del
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal, self).__init__()

                                                self.yang_name = "total-pim-callback-del-local"
                                                self.yang_parent_name = "global"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "total-pim-callback-del-local"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Global.TotalPimCallbackDelLocal, [u'entry'], name, value)


                                    class Vrf(Entity):
                                        """
                                        VRF information
                                        
                                        .. attribute:: time_rib_coverged
                                        
                                        	Time last RIB ack was sent 
                                        	**type**\:  :py:class:`TimeRibCoverged <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged>`
                                        
                                        .. attribute:: time_rib_down
                                        
                                        	Time last RIB down wassent. This field is deprecated
                                        	**type**\:  :py:class:`TimeRibDown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown>`
                                        
                                        .. attribute:: first_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the first time
                                        	**type**\:  :py:class:`FirstRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp>`
                                        
                                        .. attribute:: last_rib_table_full_timestamp
                                        
                                        	Timestamp when RIB table was full for the last time
                                        	**type**\:  :py:class:`LastRibTableFullTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp>`
                                        
                                        .. attribute:: first_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the first time
                                        	**type**\:  :py:class:`FirstRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: last_rib_table_has_space_timestamp
                                        
                                        	Timestamp when RIB table had space for the last time
                                        	**type**\:  :py:class:`LastRibTableHasSpaceTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp>`
                                        
                                        .. attribute:: time_label_retain
                                        
                                        	Time last label retentiontriggered 
                                        	**type**\:  :py:class:`TimeLabelRetain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain>`
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: rib_update_calls
                                        
                                        	No. of calls to RIB update function
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_update_time
                                        
                                        	Time spent sending RIB updates (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: prefixes_sent_to_rib
                                        
                                        	No. of prefixes sent to RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_resent_to_rib
                                        
                                        	No. of prefixes re\-sent to RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_not_sent_to_rib
                                        
                                        	No. of prefixes not sent to RIB due to unsupported label stack size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_removed_from_rib
                                        
                                        	No. of prefixes withdrawn from RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_sent_to_rib
                                        
                                        	No. of attributes sent to RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_removed_from_rib
                                        
                                        	No. of attributes withdrawn from RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attributes_recover_from_rib
                                        
                                        	No. of attributes recovered from RIB
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scanner_runs
                                        
                                        	# of times scanner has run
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: scanner_time
                                        
                                        	Time spent running scanner (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: rib_tbl_del_calls
                                        
                                        	No. of rib update skipped on account of table delete
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_invalid_calls
                                        
                                        	No. of  rib update skipped due to table invalid
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_skip_calls
                                        
                                        	No. of rib update skipped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_local_label
                                        
                                        	No. of rib update skipped. due to no local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_tbl_retry
                                        
                                        	No. of table rib retires
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_last_update_sent
                                        
                                        	Time last update was sent (seconds since Jan 1 1970)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: is_rib_table_full
                                        
                                        	Indicates if RIB table is in prefix\-limit state
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_table_full_version
                                        
                                        	Version when RIB table became full (from non\-full)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_rib_table_full_version
                                        
                                        	Version when RIB table was full for the first time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_full_version
                                        
                                        	Version when RIB table was full for the last time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_full_age
                                        
                                        	Time since RIB table was full for the last time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: first_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the first time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_has_space_version
                                        
                                        	Version when RIB table had space for the last time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_rib_table_has_space_age
                                        
                                        	Times since RIB table had space for the last time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_trigger
                                        
                                        	Rib trigger enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: vrf_flags
                                        
                                        	VRF flags for debug display
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_calls
                                        
                                        	No. of calls to label allocation processing function
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_time
                                        
                                        	Time spent running label processing (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: label_rewrite_count
                                        
                                        	Number of label rewrites created
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_release_count
                                        
                                        	Number of labels released
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_added_count
                                        
                                        	Number of labels requested
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_calls
                                        
                                        	Number of calls to import processing function
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_time
                                        
                                        	Time spent in import processing (milliseconds) Note time accounted against source nets
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: import_src_net_processed_count
                                        
                                        	Number of source nets processed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_dest_net_processed_count
                                        
                                        	Number of destination nets processed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_added_path_count
                                        
                                        	Number of imported paths added
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_removed_path_count
                                        
                                        	Number of imported paths removed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: import_replaced_path_count
                                        
                                        	Number of imported paths 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_group_count
                                        
                                        	No. of update group
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: subgroup_count
                                        
                                        	No. of update subgroup
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                            self.yang_name = "vrf"
                                            self.yang_parent_name = "performance-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("time-rib-coverged", ("time_rib_coverged", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged)), ("time-rib-down", ("time_rib_down", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown)), ("first-rib-table-full-timestamp", ("first_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp)), ("last-rib-table-full-timestamp", ("last_rib_table_full_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp)), ("first-rib-table-has-space-timestamp", ("first_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp)), ("last-rib-table-has-space-timestamp", ("last_rib_table_has_space_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp)), ("time-label-retain", ("time_label_retain", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain))])
                                            self._leafs = OrderedDict([
                                                ('update_generation_calls', (YLeaf(YType.uint32, 'update-generation-calls'), ['int'])),
                                                ('update_generation_prefixes_count', (YLeaf(YType.uint32, 'update-generation-prefixes-count'), ['int'])),
                                                ('update_generation_be_prefixes_count', (YLeaf(YType.uint32, 'update-generation-be-prefixes-count'), ['int'])),
                                                ('update_generation_messages_count', (YLeaf(YType.uint32, 'update-generation-messages-count'), ['int'])),
                                                ('update_generation_time', (YLeaf(YType.uint32, 'update-generation-time'), ['int'])),
                                                ('rib_update_calls', (YLeaf(YType.uint32, 'rib-update-calls'), ['int'])),
                                                ('rib_update_time', (YLeaf(YType.uint32, 'rib-update-time'), ['int'])),
                                                ('prefixes_sent_to_rib', (YLeaf(YType.uint32, 'prefixes-sent-to-rib'), ['int'])),
                                                ('prefixes_resent_to_rib', (YLeaf(YType.uint32, 'prefixes-resent-to-rib'), ['int'])),
                                                ('prefixes_not_sent_to_rib', (YLeaf(YType.uint32, 'prefixes-not-sent-to-rib'), ['int'])),
                                                ('prefixes_removed_from_rib', (YLeaf(YType.uint32, 'prefixes-removed-from-rib'), ['int'])),
                                                ('attributes_sent_to_rib', (YLeaf(YType.uint32, 'attributes-sent-to-rib'), ['int'])),
                                                ('attributes_removed_from_rib', (YLeaf(YType.uint32, 'attributes-removed-from-rib'), ['int'])),
                                                ('attributes_recover_from_rib', (YLeaf(YType.uint32, 'attributes-recover-from-rib'), ['int'])),
                                                ('scanner_runs', (YLeaf(YType.uint32, 'scanner-runs'), ['int'])),
                                                ('scanner_time', (YLeaf(YType.uint32, 'scanner-time'), ['int'])),
                                                ('rib_tbl_del_calls', (YLeaf(YType.uint32, 'rib-tbl-del-calls'), ['int'])),
                                                ('rib_tbl_invalid_calls', (YLeaf(YType.uint32, 'rib-tbl-invalid-calls'), ['int'])),
                                                ('rib_tbl_skip_calls', (YLeaf(YType.uint32, 'rib-tbl-skip-calls'), ['int'])),
                                                ('rib_tbl_local_label', (YLeaf(YType.uint32, 'rib-tbl-local-label'), ['int'])),
                                                ('rib_tbl_retry', (YLeaf(YType.uint32, 'rib-tbl-retry'), ['int'])),
                                                ('time_last_update_sent', (YLeaf(YType.uint32, 'time-last-update-sent'), ['int'])),
                                                ('is_rib_table_full', (YLeaf(YType.boolean, 'is-rib-table-full'), ['bool'])),
                                                ('rib_table_full_version', (YLeaf(YType.uint32, 'rib-table-full-version'), ['int'])),
                                                ('first_rib_table_full_version', (YLeaf(YType.uint32, 'first-rib-table-full-version'), ['int'])),
                                                ('last_rib_table_full_version', (YLeaf(YType.uint32, 'last-rib-table-full-version'), ['int'])),
                                                ('last_rib_table_full_age', (YLeaf(YType.uint32, 'last-rib-table-full-age'), ['int'])),
                                                ('first_rib_table_has_space_version', (YLeaf(YType.uint32, 'first-rib-table-has-space-version'), ['int'])),
                                                ('last_rib_table_has_space_version', (YLeaf(YType.uint32, 'last-rib-table-has-space-version'), ['int'])),
                                                ('last_rib_table_has_space_age', (YLeaf(YType.uint32, 'last-rib-table-has-space-age'), ['int'])),
                                                ('rib_trigger', (YLeaf(YType.boolean, 'rib-trigger'), ['bool'])),
                                                ('vrf_flags', (YLeaf(YType.uint32, 'vrf-flags'), ['int'])),
                                                ('label_calls', (YLeaf(YType.uint32, 'label-calls'), ['int'])),
                                                ('label_time', (YLeaf(YType.uint32, 'label-time'), ['int'])),
                                                ('label_rewrite_count', (YLeaf(YType.uint32, 'label-rewrite-count'), ['int'])),
                                                ('label_release_count', (YLeaf(YType.uint32, 'label-release-count'), ['int'])),
                                                ('label_added_count', (YLeaf(YType.uint32, 'label-added-count'), ['int'])),
                                                ('import_calls', (YLeaf(YType.uint32, 'import-calls'), ['int'])),
                                                ('import_time', (YLeaf(YType.uint32, 'import-time'), ['int'])),
                                                ('import_src_net_processed_count', (YLeaf(YType.uint32, 'import-src-net-processed-count'), ['int'])),
                                                ('import_dest_net_processed_count', (YLeaf(YType.uint32, 'import-dest-net-processed-count'), ['int'])),
                                                ('import_added_path_count', (YLeaf(YType.uint32, 'import-added-path-count'), ['int'])),
                                                ('import_removed_path_count', (YLeaf(YType.uint32, 'import-removed-path-count'), ['int'])),
                                                ('import_replaced_path_count', (YLeaf(YType.uint32, 'import-replaced-path-count'), ['int'])),
                                                ('update_group_count', (YLeaf(YType.uint32, 'update-group-count'), ['int'])),
                                                ('subgroup_count', (YLeaf(YType.uint32, 'subgroup-count'), ['int'])),
                                            ])
                                            self.update_generation_calls = None
                                            self.update_generation_prefixes_count = None
                                            self.update_generation_be_prefixes_count = None
                                            self.update_generation_messages_count = None
                                            self.update_generation_time = None
                                            self.rib_update_calls = None
                                            self.rib_update_time = None
                                            self.prefixes_sent_to_rib = None
                                            self.prefixes_resent_to_rib = None
                                            self.prefixes_not_sent_to_rib = None
                                            self.prefixes_removed_from_rib = None
                                            self.attributes_sent_to_rib = None
                                            self.attributes_removed_from_rib = None
                                            self.attributes_recover_from_rib = None
                                            self.scanner_runs = None
                                            self.scanner_time = None
                                            self.rib_tbl_del_calls = None
                                            self.rib_tbl_invalid_calls = None
                                            self.rib_tbl_skip_calls = None
                                            self.rib_tbl_local_label = None
                                            self.rib_tbl_retry = None
                                            self.time_last_update_sent = None
                                            self.is_rib_table_full = None
                                            self.rib_table_full_version = None
                                            self.first_rib_table_full_version = None
                                            self.last_rib_table_full_version = None
                                            self.last_rib_table_full_age = None
                                            self.first_rib_table_has_space_version = None
                                            self.last_rib_table_has_space_version = None
                                            self.last_rib_table_has_space_age = None
                                            self.rib_trigger = None
                                            self.vrf_flags = None
                                            self.label_calls = None
                                            self.label_time = None
                                            self.label_rewrite_count = None
                                            self.label_release_count = None
                                            self.label_added_count = None
                                            self.import_calls = None
                                            self.import_time = None
                                            self.import_src_net_processed_count = None
                                            self.import_dest_net_processed_count = None
                                            self.import_added_path_count = None
                                            self.import_removed_path_count = None
                                            self.import_replaced_path_count = None
                                            self.update_group_count = None
                                            self.subgroup_count = None

                                            self.time_rib_coverged = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged()
                                            self.time_rib_coverged.parent = self
                                            self._children_name_map["time_rib_coverged"] = "time-rib-coverged"

                                            self.time_rib_down = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown()
                                            self.time_rib_down.parent = self
                                            self._children_name_map["time_rib_down"] = "time-rib-down"

                                            self.first_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp()
                                            self.first_rib_table_full_timestamp.parent = self
                                            self._children_name_map["first_rib_table_full_timestamp"] = "first-rib-table-full-timestamp"

                                            self.last_rib_table_full_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp()
                                            self.last_rib_table_full_timestamp.parent = self
                                            self._children_name_map["last_rib_table_full_timestamp"] = "last-rib-table-full-timestamp"

                                            self.first_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp()
                                            self.first_rib_table_has_space_timestamp.parent = self
                                            self._children_name_map["first_rib_table_has_space_timestamp"] = "first-rib-table-has-space-timestamp"

                                            self.last_rib_table_has_space_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp()
                                            self.last_rib_table_has_space_timestamp.parent = self
                                            self._children_name_map["last_rib_table_has_space_timestamp"] = "last-rib-table-has-space-timestamp"

                                            self.time_label_retain = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain()
                                            self.time_label_retain.parent = self
                                            self._children_name_map["time_label_retain"] = "time-label-retain"
                                            self._segment_path = lambda: "vrf"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf, [u'update_generation_calls', u'update_generation_prefixes_count', u'update_generation_be_prefixes_count', u'update_generation_messages_count', u'update_generation_time', u'rib_update_calls', u'rib_update_time', u'prefixes_sent_to_rib', u'prefixes_resent_to_rib', u'prefixes_not_sent_to_rib', u'prefixes_removed_from_rib', u'attributes_sent_to_rib', u'attributes_removed_from_rib', u'attributes_recover_from_rib', u'scanner_runs', u'scanner_time', u'rib_tbl_del_calls', u'rib_tbl_invalid_calls', u'rib_tbl_skip_calls', u'rib_tbl_local_label', u'rib_tbl_retry', u'time_last_update_sent', u'is_rib_table_full', u'rib_table_full_version', u'first_rib_table_full_version', u'last_rib_table_full_version', u'last_rib_table_full_age', u'first_rib_table_has_space_version', u'last_rib_table_has_space_version', u'last_rib_table_has_space_age', u'rib_trigger', u'vrf_flags', u'label_calls', u'label_time', u'label_rewrite_count', u'label_release_count', u'label_added_count', u'import_calls', u'import_time', u'import_src_net_processed_count', u'import_dest_net_processed_count', u'import_added_path_count', u'import_removed_path_count', u'import_replaced_path_count', u'update_group_count', u'subgroup_count'], name, value)


                                        class TimeRibCoverged(Entity):
                                            """
                                            Time last RIB ack was sent 
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, self).__init__()

                                                self.yang_name = "time-rib-coverged"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "time-rib-coverged"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibCoverged, [u'seconds', u'nanoseconds'], name, value)


                                        class TimeRibDown(Entity):
                                            """
                                            Time last RIB down wassent. This field is
                                            deprecated
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, self).__init__()

                                                self.yang_name = "time-rib-down"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "time-rib-down"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeRibDown, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstRibTableFullTimestamp(Entity):
                                            """
                                            Timestamp when RIB table was full for the first
                                            time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, self).__init__()

                                                self.yang_name = "first-rib-table-full-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-table-full-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableFullTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibTableFullTimestamp(Entity):
                                            """
                                            Timestamp when RIB table was full for the last
                                            time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, self).__init__()

                                                self.yang_name = "last-rib-table-full-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-table-full-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableFullTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class FirstRibTableHasSpaceTimestamp(Entity):
                                            """
                                            Timestamp when RIB table had space for the first
                                            time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, self).__init__()

                                                self.yang_name = "first-rib-table-has-space-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "first-rib-table-has-space-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.FirstRibTableHasSpaceTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastRibTableHasSpaceTimestamp(Entity):
                                            """
                                            Timestamp when RIB table had space for the last
                                            time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, self).__init__()

                                                self.yang_name = "last-rib-table-has-space-timestamp"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-rib-table-has-space-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.LastRibTableHasSpaceTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class TimeLabelRetain(Entity):
                                            """
                                            Time last label retentiontriggered 
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, self).__init__()

                                                self.yang_name = "time-label-retain"
                                                self.yang_parent_name = "vrf"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "time-label-retain"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AfProcessInfo.PerformanceStatistics.Vrf.TimeLabelRetain, [u'seconds', u'nanoseconds'], name, value)


                            class PathUsedTable(Entity):
                                """
                                The BGP Path Used Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable, self).__init__()

                                    self.yang_name = "path-used-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path))])
                                    self._leafs = OrderedDict()

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-used-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: orig_source_rd
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertised_neighbor
                                    
                                    	Advertised Neighbor Address. Valid in the case of Advertised table
                                    	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor>`
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: original_source_route_distinguisher
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\: str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-used-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                            ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                            ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                            ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                            ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                            ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                            ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.orig_source_rd = None
                                        self.path_id = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.label_oor = None
                                        self.label_oor_version = None
                                        self.label_fail = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.original_source_route_distinguisher = None
                                        self.prefix_version = None
                                        self.vrf_name = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None

                                        self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor()
                                        self.advertised_neighbor.parent = self
                                        self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                    class AdvertisedNeighbor(Entity):
                                        """
                                        Advertised Neighbor Address. Valid in the case
                                        of Advertised table
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor, self).__init__()

                                            self.yang_name = "advertised-neighbor"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "advertised-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied. In the
                                        case of path type received\-only this will be
                                        attributes before inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathUsedTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class BmpPathTableGeneric(Entity):
                                """
                                Summary Info about BMP Table
                                
                                .. attribute:: bmp_version_wrap_time_spec
                                
                                	Version Wrap timestamp
                                	**type**\:  :py:class:`BmpVersionWrapTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec>`
                                
                                .. attribute:: bmp_version_wrap_start_time_spec
                                
                                	Version Wrap handle start timestamp
                                	**type**\:  :py:class:`BmpVersionWrapStartTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec>`
                                
                                .. attribute:: bmp_version_wrap_done_time_spec
                                
                                	Version Wrap handle Done timestamp
                                	**type**\:  :py:class:`BmpVersionWrapDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec>`
                                
                                .. attribute:: bmp_route_monitoringe_enabled
                                
                                	Is Route Monitoring mode enabled
                                	**type**\: bool
                                
                                .. attribute:: bmp_table_version
                                
                                	Table version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_count
                                
                                	Number of nets in the table
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_count
                                
                                	Number of paths in the table
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_version_wrapped
                                
                                	Number of times Table Version Wrapped
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_version_wrapped_tid
                                
                                	Version Wrapped trigger thread id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_version_inprogress
                                
                                	Is Version wrap in progress
                                	**type**\: bool
                                
                                .. attribute:: bmp_version_incremented
                                
                                	Is Version being incremented
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric, self).__init__()

                                    self.yang_name = "bmp-path-table-generic"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bmp-version-wrap-time-spec", ("bmp_version_wrap_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec)), ("bmp-version-wrap-start-time-spec", ("bmp_version_wrap_start_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec)), ("bmp-version-wrap-done-time-spec", ("bmp_version_wrap_done_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec))])
                                    self._leafs = OrderedDict([
                                        ('bmp_route_monitoringe_enabled', (YLeaf(YType.boolean, 'bmp-route-monitoringe-enabled'), ['bool'])),
                                        ('bmp_table_version', (YLeaf(YType.uint32, 'bmp-table-version'), ['int'])),
                                        ('network_count', (YLeaf(YType.uint32, 'network-count'), ['int'])),
                                        ('path_count', (YLeaf(YType.uint32, 'path-count'), ['int'])),
                                        ('bmp_version_wrapped', (YLeaf(YType.uint32, 'bmp-version-wrapped'), ['int'])),
                                        ('bmp_version_wrapped_tid', (YLeaf(YType.uint32, 'bmp-version-wrapped-tid'), ['int'])),
                                        ('bmp_version_inprogress', (YLeaf(YType.boolean, 'bmp-version-inprogress'), ['bool'])),
                                        ('bmp_version_incremented', (YLeaf(YType.boolean, 'bmp-version-incremented'), ['bool'])),
                                    ])
                                    self.bmp_route_monitoringe_enabled = None
                                    self.bmp_table_version = None
                                    self.network_count = None
                                    self.path_count = None
                                    self.bmp_version_wrapped = None
                                    self.bmp_version_wrapped_tid = None
                                    self.bmp_version_inprogress = None
                                    self.bmp_version_incremented = None

                                    self.bmp_version_wrap_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec()
                                    self.bmp_version_wrap_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_time_spec"] = "bmp-version-wrap-time-spec"

                                    self.bmp_version_wrap_start_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec()
                                    self.bmp_version_wrap_start_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_start_time_spec"] = "bmp-version-wrap-start-time-spec"

                                    self.bmp_version_wrap_done_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec()
                                    self.bmp_version_wrap_done_time_spec.parent = self
                                    self._children_name_map["bmp_version_wrap_done_time_spec"] = "bmp-version-wrap-done-time-spec"
                                    self._segment_path = lambda: "bmp-path-table-generic"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric, [u'bmp_route_monitoringe_enabled', u'bmp_table_version', u'network_count', u'path_count', u'bmp_version_wrapped', u'bmp_version_wrapped_tid', u'bmp_version_inprogress', u'bmp_version_incremented'], name, value)


                                class BmpVersionWrapTimeSpec(Entity):
                                    """
                                    Version Wrap timestamp
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-version-wrap-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class BmpVersionWrapStartTimeSpec(Entity):
                                    """
                                    Version Wrap handle start timestamp
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-start-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-version-wrap-start-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapStartTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class BmpVersionWrapDoneTimeSpec(Entity):
                                    """
                                    Version Wrap handle Done timestamp
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, self).__init__()

                                        self.yang_name = "bmp-version-wrap-done-time-spec"
                                        self.yang_parent_name = "bmp-path-table-generic"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-version-wrap-done-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPathTableGeneric.BmpVersionWrapDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                            class RpcSets(Entity):
                                """
                                BGP next\-hop set table
                                
                                .. attribute:: rpc_set
                                
                                	A BGP next\-hop set
                                	**type**\: list of  		 :py:class:`RpcSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets, self).__init__()

                                    self.yang_name = "rpc-sets"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rpc-set", ("rpc_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet))])
                                    self._leafs = OrderedDict()

                                    self.rpc_set = YList(self)
                                    self._segment_path = lambda: "rpc-sets"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets, [], name, value)


                                class RpcSet(Entity):
                                    """
                                    A BGP next\-hop set
                                    
                                    .. attribute:: rpc_set_index  (key)
                                    
                                    	Nexthop set index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_xr
                                    
                                    	Number of multipath next\-hops
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: srv6sid_address
                                    
                                    	SRv6 SID address value
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: srv6sid_address_len
                                    
                                    	SRv6 SID address Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	List of multipath next\-hops
                                    	**type**\: list of  		 :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet, self).__init__()

                                        self.yang_name = "rpc-set"
                                        self.yang_parent_name = "rpc-sets"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['rpc_set_index']
                                        self._child_classes = OrderedDict([("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop))])
                                        self._leafs = OrderedDict([
                                            ('rpc_set_index', (YLeaf(YType.uint32, 'rpc-set-index'), ['int'])),
                                            ('next_hop_xr', (YLeaf(YType.uint32, 'next-hop-xr'), ['int'])),
                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                            ('ref_count', (YLeaf(YType.uint32, 'ref-count'), ['int'])),
                                            ('srv6sid_address', (YLeaf(YType.str, 'srv6sid-address'), ['str'])),
                                            ('srv6sid_address_len', (YLeaf(YType.uint32, 'srv6sid-address-len'), ['int'])),
                                        ])
                                        self.rpc_set_index = None
                                        self.next_hop_xr = None
                                        self.label = None
                                        self.ref_count = None
                                        self.srv6sid_address = None
                                        self.srv6sid_address_len = None

                                        self.next_hop = YList(self)
                                        self._segment_path = lambda: "rpc-set" + "[rpc-set-index='" + str(self.rpc_set_index) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet, ['rpc_set_index', u'next_hop_xr', u'label', u'ref_count', u'srv6sid_address', u'srv6sid_address_len'], name, value)


                                    class NextHop(Entity):
                                        """
                                        List of multipath next\-hops
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop, self).__init__()

                                            self.yang_name = "next-hop"
                                            self.yang_parent_name = "rpc-set"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "next-hop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RpcSets.RpcSet.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class GlobalAfProcessInfo(Entity):
                                """
                                The Global Address Family Process information
                                table
                                
                                .. attribute:: global_
                                
                                	Global information
                                	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global>`
                                
                                .. attribute:: vrf
                                
                                	VRF information
                                	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf>`
                                
                                .. attribute:: vrf_name
                                
                                	Name of the VRF
                                	**type**\: str
                                
                                .. attribute:: af_name
                                
                                	Address family id
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: is_nsr_enabled
                                
                                	Non\-stop routing enabled
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo, self).__init__()

                                    self.yang_name = "global-af-process-info"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf))])
                                    self._leafs = OrderedDict([
                                        ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('is_nsr_enabled', (YLeaf(YType.boolean, 'is-nsr-enabled'), ['bool'])),
                                    ])
                                    self.vrf_name = None
                                    self.af_name = None
                                    self.is_nsr_enabled = None

                                    self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global()
                                    self.global_.parent = self
                                    self._children_name_map["global_"] = "global"

                                    self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf()
                                    self.vrf.parent = self
                                    self._children_name_map["vrf"] = "vrf"
                                    self._segment_path = lambda: "global-af-process-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo, [u'vrf_name', u'af_name', u'is_nsr_enabled'], name, value)


                                class Global(Entity):
                                    """
                                    Global information
                                    
                                    .. attribute:: rib_install
                                    
                                    	RIB install info
                                    	**type**\:  :py:class:`RibInstall <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall>`
                                    
                                    .. attribute:: scanner_period
                                    
                                    	Period (in seconds) of address\-family scanner runs
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nh_tunnel_version
                                    
                                    	NH Tunnel Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_prefixes
                                    
                                    	Total prefixes of address\-family scanned
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segment_prefixes
                                    
                                    	Number of prefixes scanned in a segment of address\-family
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: scan_segments
                                    
                                    	Number of segments to scan all prefixes of address\-family
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: inter_as_install_enabled
                                    
                                    	Is inter\-AS install to pim on ASBR enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: global_mcast_enabled
                                    
                                    	Is global table mcast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: segmented_mcast_enabled
                                    
                                    	Is segmented mcast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: gblafrpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: gblafrpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\: bool
                                    
                                    .. attribute:: gblafrpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: gblafrpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\: bool
                                    
                                    .. attribute:: update_wait_install_enabled
                                    
                                    	Update wait\-install enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_ack_requests
                                    
                                    	Counter for RIB ack requests
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_acks_received
                                    
                                    	Counter for RIB ack received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_slow_acks
                                    
                                    	Counter for slow RIB acks
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_perm_net_cfg
                                    
                                    	Permanent Network Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: perm_net_del_count
                                    
                                    	Count of removed perm paths
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_del_count
                                    
                                    	Count of stale perm paths
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_stale_mark_count
                                    
                                    	Count of stale marked perm paths
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_insert_count
                                    
                                    	Count of inserted perm paths
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_existing_count
                                    
                                    	Count of existing perm paths
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_query_count
                                    
                                    	Count of perm nets given by RPL
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_net_rpl_process_count
                                    
                                    	Count of perm nets processed in RPL
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_nbr_count
                                    
                                    	Count of neighbors configured with perm net
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_not_found_count
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_path_not_found_count
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_pelem_found_count
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_reg_path_found_count
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rib_perm_path_found_count
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_free_count
                                    
                                    	Count of freed perm pelems
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_path_refresh_count
                                    
                                    	Count of perm paths refreshed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: perm_pelem_all_bump_count
                                    
                                    	Count of bumped perm pelems
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: syncgrp_version
                                    
                                    	Sync\-group Version
                                    	**type**\: list of  		 :py:class:`SyncgrpVersion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global, self).__init__()

                                        self.yang_name = "global"
                                        self.yang_parent_name = "global-af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rib-install", ("rib_install", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall)), ("syncgrp-version", ("syncgrp_version", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion))])
                                        self._leafs = OrderedDict([
                                            ('scanner_period', (YLeaf(YType.uint16, 'scanner-period'), ['int'])),
                                            ('nh_tunnel_version', (YLeaf(YType.uint32, 'nh-tunnel-version'), ['int'])),
                                            ('scan_prefixes', (YLeaf(YType.uint32, 'scan-prefixes'), ['int'])),
                                            ('scan_segment_prefixes', (YLeaf(YType.uint32, 'scan-segment-prefixes'), ['int'])),
                                            ('scan_segments', (YLeaf(YType.uint8, 'scan-segments'), ['int'])),
                                            ('inter_as_install_enabled', (YLeaf(YType.boolean, 'inter-as-install-enabled'), ['bool'])),
                                            ('global_mcast_enabled', (YLeaf(YType.boolean, 'global-mcast-enabled'), ['bool'])),
                                            ('segmented_mcast_enabled', (YLeaf(YType.boolean, 'segmented-mcast-enabled'), ['bool'])),
                                            ('gblafrpki_disable', (YLeaf(YType.boolean, 'gblafrpki-disable'), ['bool'])),
                                            ('gblafrpki_use_validity', (YLeaf(YType.boolean, 'gblafrpki-use-validity'), ['bool'])),
                                            ('gblafrpki_allow_invalid', (YLeaf(YType.boolean, 'gblafrpki-allow-invalid'), ['bool'])),
                                            ('gblafrpki_signal_ibgp', (YLeaf(YType.boolean, 'gblafrpki-signal-ibgp'), ['bool'])),
                                            ('update_wait_install_enabled', (YLeaf(YType.boolean, 'update-wait-install-enabled'), ['bool'])),
                                            ('rib_ack_requests', (YLeaf(YType.uint32, 'rib-ack-requests'), ['int'])),
                                            ('rib_acks_received', (YLeaf(YType.uint32, 'rib-acks-received'), ['int'])),
                                            ('rib_slow_acks', (YLeaf(YType.uint32, 'rib-slow-acks'), ['int'])),
                                            ('is_perm_net_cfg', (YLeaf(YType.boolean, 'is-perm-net-cfg'), ['bool'])),
                                            ('perm_net_del_count', (YLeaf(YType.uint16, 'perm-net-del-count'), ['int'])),
                                            ('perm_net_stale_del_count', (YLeaf(YType.uint16, 'perm-net-stale-del-count'), ['int'])),
                                            ('perm_net_stale_mark_count', (YLeaf(YType.uint16, 'perm-net-stale-mark-count'), ['int'])),
                                            ('perm_net_insert_count', (YLeaf(YType.uint16, 'perm-net-insert-count'), ['int'])),
                                            ('perm_net_existing_count', (YLeaf(YType.uint16, 'perm-net-existing-count'), ['int'])),
                                            ('perm_net_rpl_query_count', (YLeaf(YType.uint16, 'perm-net-rpl-query-count'), ['int'])),
                                            ('perm_net_rpl_process_count', (YLeaf(YType.uint16, 'perm-net-rpl-process-count'), ['int'])),
                                            ('perm_nbr_count', (YLeaf(YType.uint16, 'perm-nbr-count'), ['int'])),
                                            ('rib_perm_pelem_not_found_count', (YLeaf(YType.uint16, 'rib-perm-pelem-not-found-count'), ['int'])),
                                            ('rib_perm_path_not_found_count', (YLeaf(YType.uint16, 'rib-perm-path-not-found-count'), ['int'])),
                                            ('rib_perm_pelem_found_count', (YLeaf(YType.uint16, 'rib-perm-pelem-found-count'), ['int'])),
                                            ('rib_reg_path_found_count', (YLeaf(YType.uint16, 'rib-reg-path-found-count'), ['int'])),
                                            ('rib_perm_path_found_count', (YLeaf(YType.uint16, 'rib-perm-path-found-count'), ['int'])),
                                            ('perm_pelem_free_count', (YLeaf(YType.uint16, 'perm-pelem-free-count'), ['int'])),
                                            ('perm_path_refresh_count', (YLeaf(YType.uint16, 'perm-path-refresh-count'), ['int'])),
                                            ('perm_pelem_bump_count', (YLeaf(YType.uint16, 'perm-pelem-bump-count'), ['int'])),
                                            ('perm_pelem_all_bump_count', (YLeaf(YType.uint16, 'perm-pelem-all-bump-count'), ['int'])),
                                        ])
                                        self.scanner_period = None
                                        self.nh_tunnel_version = None
                                        self.scan_prefixes = None
                                        self.scan_segment_prefixes = None
                                        self.scan_segments = None
                                        self.inter_as_install_enabled = None
                                        self.global_mcast_enabled = None
                                        self.segmented_mcast_enabled = None
                                        self.gblafrpki_disable = None
                                        self.gblafrpki_use_validity = None
                                        self.gblafrpki_allow_invalid = None
                                        self.gblafrpki_signal_ibgp = None
                                        self.update_wait_install_enabled = None
                                        self.rib_ack_requests = None
                                        self.rib_acks_received = None
                                        self.rib_slow_acks = None
                                        self.is_perm_net_cfg = None
                                        self.perm_net_del_count = None
                                        self.perm_net_stale_del_count = None
                                        self.perm_net_stale_mark_count = None
                                        self.perm_net_insert_count = None
                                        self.perm_net_existing_count = None
                                        self.perm_net_rpl_query_count = None
                                        self.perm_net_rpl_process_count = None
                                        self.perm_nbr_count = None
                                        self.rib_perm_pelem_not_found_count = None
                                        self.rib_perm_path_not_found_count = None
                                        self.rib_perm_pelem_found_count = None
                                        self.rib_reg_path_found_count = None
                                        self.rib_perm_path_found_count = None
                                        self.perm_pelem_free_count = None
                                        self.perm_path_refresh_count = None
                                        self.perm_pelem_bump_count = None
                                        self.perm_pelem_all_bump_count = None

                                        self.rib_install = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall()
                                        self.rib_install.parent = self
                                        self._children_name_map["rib_install"] = "rib-install"

                                        self.syncgrp_version = YList(self)
                                        self._segment_path = lambda: "global"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global, [u'scanner_period', u'nh_tunnel_version', u'scan_prefixes', u'scan_segment_prefixes', u'scan_segments', u'inter_as_install_enabled', u'global_mcast_enabled', u'segmented_mcast_enabled', u'gblafrpki_disable', u'gblafrpki_use_validity', u'gblafrpki_allow_invalid', u'gblafrpki_signal_ibgp', u'update_wait_install_enabled', u'rib_ack_requests', u'rib_acks_received', u'rib_slow_acks', u'is_perm_net_cfg', u'perm_net_del_count', u'perm_net_stale_del_count', u'perm_net_stale_mark_count', u'perm_net_insert_count', u'perm_net_existing_count', u'perm_net_rpl_query_count', u'perm_net_rpl_process_count', u'perm_nbr_count', u'rib_perm_pelem_not_found_count', u'rib_perm_path_not_found_count', u'rib_perm_pelem_found_count', u'rib_reg_path_found_count', u'rib_perm_path_found_count', u'perm_pelem_free_count', u'perm_path_refresh_count', u'perm_pelem_bump_count', u'perm_pelem_all_bump_count'], name, value)


                                    class RibInstall(Entity):
                                        """
                                        RIB install info
                                        
                                        .. attribute:: update_time
                                        
                                        	RIB update time
                                        	**type**\:  :py:class:`UpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime>`
                                        
                                        .. attribute:: install_time
                                        
                                        	RIB install time
                                        	**type**\:  :py:class:`InstallTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime>`
                                        
                                        .. attribute:: installed_count
                                        
                                        	Installed routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: modified_count
                                        
                                        	Modified routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: skipped_count
                                        
                                        	Skipped routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: withdrawn_count
                                        
                                        	Withdrawn routes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: start_version
                                        
                                        	Start version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: target_version
                                        
                                        	Target version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall, self).__init__()

                                            self.yang_name = "rib-install"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("update-time", ("update_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime)), ("install-time", ("install_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime))])
                                            self._leafs = OrderedDict([
                                                ('installed_count', (YLeaf(YType.uint32, 'installed-count'), ['int'])),
                                                ('modified_count', (YLeaf(YType.uint32, 'modified-count'), ['int'])),
                                                ('skipped_count', (YLeaf(YType.uint32, 'skipped-count'), ['int'])),
                                                ('withdrawn_count', (YLeaf(YType.uint32, 'withdrawn-count'), ['int'])),
                                                ('start_version', (YLeaf(YType.uint32, 'start-version'), ['int'])),
                                                ('target_version', (YLeaf(YType.uint32, 'target-version'), ['int'])),
                                            ])
                                            self.installed_count = None
                                            self.modified_count = None
                                            self.skipped_count = None
                                            self.withdrawn_count = None
                                            self.start_version = None
                                            self.target_version = None

                                            self.update_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime()
                                            self.update_time.parent = self
                                            self._children_name_map["update_time"] = "update-time"

                                            self.install_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime()
                                            self.install_time.parent = self
                                            self._children_name_map["install_time"] = "install-time"
                                            self._segment_path = lambda: "rib-install"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall, [u'installed_count', u'modified_count', u'skipped_count', u'withdrawn_count', u'start_version', u'target_version'], name, value)


                                        class UpdateTime(Entity):
                                            """
                                            RIB update time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime, self).__init__()

                                                self.yang_name = "update-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "update-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.UpdateTime, [u'seconds', u'nanoseconds'], name, value)


                                        class InstallTime(Entity):
                                            """
                                            RIB install time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime, self).__init__()

                                                self.yang_name = "install-time"
                                                self.yang_parent_name = "rib-install"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "install-time"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.RibInstall.InstallTime, [u'seconds', u'nanoseconds'], name, value)


                                    class SyncgrpVersion(Entity):
                                        """
                                        Sync\-group Version
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion, self).__init__()

                                            self.yang_name = "syncgrp-version"
                                            self.yang_parent_name = "global"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "syncgrp-version"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Global.SyncgrpVersion, [u'entry'], name, value)


                                class Vrf(Entity):
                                    """
                                    VRF information
                                    
                                    .. attribute:: table_is_active
                                    
                                    	Table state is active
                                    	**type**\: bool
                                    
                                    .. attribute:: table_id
                                    
                                    	Table ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rd_version
                                    
                                    	RD version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_version
                                    
                                    	Table version synced to RIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_conv_version
                                    
                                    	NSR conv version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_is_conv
                                    
                                    	NSR is converged
                                    	**type**\: bool
                                    
                                    .. attribute:: client_reflection_enabled
                                    
                                    	Client reflection enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dampening_enabled
                                    
                                    	Dampening enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: ebgp_distance
                                    
                                    	Distance for eBGP routes (external)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ibgp_distance
                                    
                                    	Distance for iBGP routes (internal)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: aggregates_distance
                                    
                                    	Dist for aggregate routes (local)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dynamic_med_enabled
                                    
                                    	Update generation enabled for MED change
                                    	**type**\: bool
                                    
                                    .. attribute:: dynamic_med_interval
                                    
                                    	Delay in update generation after a MED change (in minutes)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: dynamic_med_timer_running
                                    
                                    	Dynamic MED timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: dynamic_med_timer_value
                                    
                                    	Dynamic MED timer value (in seconds) left on the timer
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: dynamic_med_periodic_timer_running
                                    
                                    	Dynamic MED periodic timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: dynamic_med_periodic_timer_value
                                    
                                    	Dynamic MED periodic timer value (in seconds) left on the timer
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_has_converged
                                    
                                    	Received convergence notification from RIB
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_convergence_version
                                    
                                    	Last convergence version received from RIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_rib_table_full
                                    
                                    	Indicates if RIB table is in prefix\-limit state
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_table_full_version
                                    
                                    	Version when RIB table became full (from non\-full)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length_configured
                                    
                                    	Is nexthop resoultion minimum prefix\-length configured ?
                                    	**type**\: bool
                                    
                                    .. attribute:: nexthop_resolution_minimum_prefix_length
                                    
                                    	Nexthop resoultion minimum prefix\-length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: selective_ebgp_multipath_enabled
                                    
                                    	Selective eBGP multipath isenabled
                                    	**type**\: bool
                                    
                                    .. attribute:: selective_ibgp_multipath_enabled
                                    
                                    	Selective iBGP multipath isenabled
                                    	**type**\: bool
                                    
                                    .. attribute:: selective_eibgp_multipath_enabled
                                    
                                    	Selective eiBGP multipath isenabled
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_acked_table_version
                                    
                                    	Table version acked by RIB
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf, self).__init__()

                                        self.yang_name = "vrf"
                                        self.yang_parent_name = "global-af-process-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('table_is_active', (YLeaf(YType.boolean, 'table-is-active'), ['bool'])),
                                            ('table_id', (YLeaf(YType.uint32, 'table-id'), ['int'])),
                                            ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                            ('rd_version', (YLeaf(YType.uint32, 'rd-version'), ['int'])),
                                            ('rib_version', (YLeaf(YType.uint32, 'rib-version'), ['int'])),
                                            ('nsr_conv_version', (YLeaf(YType.uint32, 'nsr-conv-version'), ['int'])),
                                            ('nsr_is_conv', (YLeaf(YType.boolean, 'nsr-is-conv'), ['bool'])),
                                            ('client_reflection_enabled', (YLeaf(YType.boolean, 'client-reflection-enabled'), ['bool'])),
                                            ('dampening_enabled', (YLeaf(YType.boolean, 'dampening-enabled'), ['bool'])),
                                            ('ebgp_distance', (YLeaf(YType.uint16, 'ebgp-distance'), ['int'])),
                                            ('ibgp_distance', (YLeaf(YType.uint16, 'ibgp-distance'), ['int'])),
                                            ('aggregates_distance', (YLeaf(YType.uint16, 'aggregates-distance'), ['int'])),
                                            ('dynamic_med_enabled', (YLeaf(YType.boolean, 'dynamic-med-enabled'), ['bool'])),
                                            ('dynamic_med_interval', (YLeaf(YType.uint16, 'dynamic-med-interval'), ['int'])),
                                            ('dynamic_med_timer_running', (YLeaf(YType.boolean, 'dynamic-med-timer-running'), ['bool'])),
                                            ('dynamic_med_timer_value', (YLeaf(YType.uint16, 'dynamic-med-timer-value'), ['int'])),
                                            ('dynamic_med_periodic_timer_running', (YLeaf(YType.boolean, 'dynamic-med-periodic-timer-running'), ['bool'])),
                                            ('dynamic_med_periodic_timer_value', (YLeaf(YType.uint16, 'dynamic-med-periodic-timer-value'), ['int'])),
                                            ('rib_has_converged', (YLeaf(YType.boolean, 'rib-has-converged'), ['bool'])),
                                            ('rib_convergence_version', (YLeaf(YType.uint32, 'rib-convergence-version'), ['int'])),
                                            ('is_rib_table_full', (YLeaf(YType.boolean, 'is-rib-table-full'), ['bool'])),
                                            ('rib_table_full_version', (YLeaf(YType.uint32, 'rib-table-full-version'), ['int'])),
                                            ('nexthop_resolution_minimum_prefix_length_configured', (YLeaf(YType.boolean, 'nexthop-resolution-minimum-prefix-length-configured'), ['bool'])),
                                            ('nexthop_resolution_minimum_prefix_length', (YLeaf(YType.uint32, 'nexthop-resolution-minimum-prefix-length'), ['int'])),
                                            ('selective_ebgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-ebgp-multipath-enabled'), ['bool'])),
                                            ('selective_ibgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-ibgp-multipath-enabled'), ['bool'])),
                                            ('selective_eibgp_multipath_enabled', (YLeaf(YType.boolean, 'selective-eibgp-multipath-enabled'), ['bool'])),
                                            ('rib_acked_table_version', (YLeaf(YType.uint32, 'rib-acked-table-version'), ['int'])),
                                        ])
                                        self.table_is_active = None
                                        self.table_id = None
                                        self.table_version = None
                                        self.rd_version = None
                                        self.rib_version = None
                                        self.nsr_conv_version = None
                                        self.nsr_is_conv = None
                                        self.client_reflection_enabled = None
                                        self.dampening_enabled = None
                                        self.ebgp_distance = None
                                        self.ibgp_distance = None
                                        self.aggregates_distance = None
                                        self.dynamic_med_enabled = None
                                        self.dynamic_med_interval = None
                                        self.dynamic_med_timer_running = None
                                        self.dynamic_med_timer_value = None
                                        self.dynamic_med_periodic_timer_running = None
                                        self.dynamic_med_periodic_timer_value = None
                                        self.rib_has_converged = None
                                        self.rib_convergence_version = None
                                        self.is_rib_table_full = None
                                        self.rib_table_full_version = None
                                        self.nexthop_resolution_minimum_prefix_length_configured = None
                                        self.nexthop_resolution_minimum_prefix_length = None
                                        self.selective_ebgp_multipath_enabled = None
                                        self.selective_ibgp_multipath_enabled = None
                                        self.selective_eibgp_multipath_enabled = None
                                        self.rib_acked_table_version = None
                                        self._segment_path = lambda: "vrf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.GlobalAfProcessInfo.Vrf, [u'table_is_active', u'table_id', u'table_version', u'rd_version', u'rib_version', u'nsr_conv_version', u'nsr_is_conv', u'client_reflection_enabled', u'dampening_enabled', u'ebgp_distance', u'ibgp_distance', u'aggregates_distance', u'dynamic_med_enabled', u'dynamic_med_interval', u'dynamic_med_timer_running', u'dynamic_med_timer_value', u'dynamic_med_periodic_timer_running', u'dynamic_med_periodic_timer_value', u'rib_has_converged', u'rib_convergence_version', u'is_rib_table_full', u'rib_table_full_version', u'nexthop_resolution_minimum_prefix_length_configured', u'nexthop_resolution_minimum_prefix_length', u'selective_ebgp_multipath_enabled', u'selective_ibgp_multipath_enabled', u'selective_eibgp_multipath_enabled', u'rib_acked_table_version'], name, value)


                            class AdvertisedPathXr(Entity):
                                """
                                The BGP Advertised path table (bestpath)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised path table entry (bestpath)
                                	**type**\: list of  		 :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr, self).__init__()

                                    self.yang_name = "advertised-path-xr"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("advertised-path", ("advertised_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath))])
                                    self._leafs = OrderedDict()

                                    self.advertised_path = YList(self)
                                    self._segment_path = lambda: "advertised-path-xr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr, [], name, value)


                                class AdvertisedPath(Entity):
                                    """
                                    A BGP Advertised path table entry (bestpath)
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: advertised_neighbor
                                    
                                    	Advertised Neighbor Address. Valid in the case of Advertised table
                                    	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor>`
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: original_source_route_distinguisher
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\: str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, self).__init__()

                                        self.yang_name = "advertised-path"
                                        self.yang_parent_name = "advertised-path-xr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                            ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                            ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                            ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.label_oor = None
                                        self.label_oor_version = None
                                        self.label_fail = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.original_source_route_distinguisher = None
                                        self.prefix_version = None
                                        self.vrf_name = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None

                                        self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor()
                                        self.advertised_neighbor.parent = self
                                        self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._segment_path = lambda: "advertised-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath, ['rd', 'network', 'prefix_length', 'neighbor_address', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                    class AdvertisedNeighbor(Entity):
                                        """
                                        Advertised Neighbor Address. Valid in the case
                                        of Advertised table
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor, self).__init__()

                                            self.yang_name = "advertised-neighbor"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "advertised-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied. In the
                                        case of path type received\-only this will be
                                        attributes before inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathXr.AdvertisedPath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SourcedNetworks(Entity):
                                """
                                The BGP Convergence table
                                
                                .. attribute:: sourced_network
                                
                                	A BGP network command table entry
                                	**type**\: list of  		 :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks, self).__init__()

                                    self.yang_name = "sourced-networks"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sourced-network", ("sourced_network", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork))])
                                    self._leafs = OrderedDict()

                                    self.sourced_network = YList(self)
                                    self._segment_path = lambda: "sourced-networks"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks, [], name, value)


                                class SourcedNetwork(Entity):
                                    """
                                    A BGP network command table entry
                                    
                                    .. attribute:: network  (key)
                                    
                                    	Network in prefix/length format
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                    
                                    .. attribute:: sourced_prefix
                                    
                                    	Prefix length
                                    	**type**\:  :py:class:`SourcedPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: is_backdoor
                                    
                                    	TRUE if net is a backdoor route
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork, self).__init__()

                                        self.yang_name = "sourced-network"
                                        self.yang_parent_name = "sourced-networks"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['network']
                                        self._child_classes = OrderedDict([("sourced-prefix", ("sourced_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix))])
                                        self._leafs = OrderedDict([
                                            ('network', (YLeaf(YType.str, 'network'), ['str','str'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('is_backdoor', (YLeaf(YType.boolean, 'is-backdoor'), ['bool'])),
                                        ])
                                        self.network = None
                                        self.af_name = None
                                        self.is_backdoor = None

                                        self.sourced_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix()
                                        self.sourced_prefix.parent = self
                                        self._children_name_map["sourced_prefix"] = "sourced-prefix"
                                        self._segment_path = lambda: "sourced-network" + "[network='" + str(self.network) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork, ['network', u'af_name', u'is_backdoor'], name, value)


                                    class SourcedPrefix(Entity):
                                        """
                                        Prefix length
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, self).__init__()

                                            self.yang_name = "sourced-prefix"
                                            self.yang_parent_name = "sourced-network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix_length = None

                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._segment_path = lambda: "sourced-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix, [u'prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "sourced-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.SourcedNetworks.SourcedNetwork.SourcedPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class UpdateGroups(Entity):
                                """
                                The BGP Update group table
                                
                                .. attribute:: update_group
                                
                                	A BGP Update group table entry
                                	**type**\: list of  		 :py:class:`UpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups, self).__init__()

                                    self.yang_name = "update-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-group", ("update_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup))])
                                    self._leafs = OrderedDict()

                                    self.update_group = YList(self)
                                    self._segment_path = lambda: "update-groups"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups, [], name, value)


                                class UpdateGroup(Entity):
                                    """
                                    A BGP Update group table entry
                                    
                                    .. attribute:: update_group_id
                                    
                                    	Update group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_id
                                    
                                    	Filter group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: session_af_name
                                    
                                    	Neighbor session Address family
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_group_number
                                    
                                    	Update group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family for update group
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: should_send_communities
                                    
                                    	Send communities
                                    	**type**\: bool
                                    
                                    .. attribute:: should_send_ext_communities
                                    
                                    	Send Extended communities
                                    	**type**\: bool
                                    
                                    .. attribute:: should_send_stitching_rt
                                    
                                    	Send Stitching RT
                                    	**type**\: bool
                                    
                                    .. attribute:: has_orf_receive_capability
                                    
                                    	ORF receive capability
                                    	**type**\: bool
                                    
                                    .. attribute:: is_route_reflector_client
                                    
                                    	Route\-reflector client
                                    	**type**\: bool
                                    
                                    .. attribute:: is_client_reflection_disabled
                                    
                                    	True if client\-to\-client reflection is disabled 
                                    	**type**\: bool
                                    
                                    .. attribute:: accepts_legacy_pe_rt_route
                                    
                                    	accept\-legacy\-pe\-RT route
                                    	**type**\: bool
                                    
                                    .. attribute:: updgrp_cluster_id
                                    
                                    	Cluster ID (populated ifclient\-to\-client reflectionis disabled)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updgrp_cluster_type
                                    
                                    	Cluster ID type\:undefined/number/Ip address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: orr_group_name
                                    
                                    	ORR Group Name
                                    	**type**\: str
                                    
                                    .. attribute:: orr_group_index
                                    
                                    	ORR Group Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_orr_root_address_configured
                                    
                                    	ORR Root address configuredfor the neighbor connection
                                    	**type**\: bool
                                    
                                    .. attribute:: should_remove_private_a_ss
                                    
                                    	Remove private AS numbers
                                    	**type**\: bool
                                    
                                    .. attribute:: should_remove_private_as_ent_path
                                    
                                    	Remove private AS numbersif the entire path consistsof private ASes
                                    	**type**\: bool
                                    
                                    .. attribute:: use_next_hop_self
                                    
                                    	Next hop self
                                    	**type**\: bool
                                    
                                    .. attribute:: use_next_hop_unchanged_mpath
                                    
                                    	Next\-hop\-unchanged multipath
                                    	**type**\: bool
                                    
                                    .. attribute:: is_internal_peers
                                    
                                    	Internal peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is_common_admin_peers
                                    
                                    	Common admin peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is4_byte_as_peer
                                    
                                    	4\-byte AS capable peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is_addpath_capable
                                    
                                    	Add\-path capable peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is_send_mcast_attr_enabled
                                    
                                    	Send mcast attribute enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_aigp_capable
                                    
                                    	AIGP capable peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is_aigp_cost_community_capable
                                    
                                    	Send AIGP cost community to peers
                                    	**type**\: bool
                                    
                                    .. attribute:: is_aigp_med_capable
                                    
                                    	Send AIGP cost in MED
                                    	**type**\: bool
                                    
                                    .. attribute:: is_llgr_capable
                                    
                                    	Send Long\-lived Stale paths
                                    	**type**\: bool
                                    
                                    .. attribute:: is_adv_capable
                                    
                                    	Send tranlsated paths
                                    	**type**\: bool
                                    
                                    .. attribute:: is_adv_reorg_capable
                                    
                                    	Send Re\-orig paths
                                    	**type**\: bool
                                    
                                    .. attribute:: disable_native_advertisement
                                    
                                    	Disable advertising native routes
                                    	**type**\: bool
                                    
                                    .. attribute:: disable_def_vrf_imp_advertisement
                                    
                                    	Disable advertising default VRF  imported routes
                                    	**type**\: bool
                                    
                                    .. attribute:: disable_vrf_re_imp_advertisement
                                    
                                    	Disable advertising VRF re\-imported routes
                                    	**type**\: bool
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation type
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertise_rt_type
                                    
                                    	Advertise RT type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: is_directly_connected_ebgp_v6_peers
                                    
                                    	Directly connected EBGP v6 peers
                                    	**type**\: bool
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_advertisement_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_policy_out
                                    
                                    	Outbound route policy name
                                    	**type**\: str
                                    
                                    .. attribute:: desync_count
                                    
                                    	Number of times the update has been desynchronized
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: subgrp_merge_count
                                    
                                    	Number of times sub\-groups have been merged
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_subgrp_count
                                    
                                    	Current count of refresh subgroups
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updates_formatted
                                    
                                    	Number of updates formatted
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: updates_replicated
                                    
                                    	No. of updates replicated
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\: bool
                                    
                                    .. attribute:: as_override
                                    
                                    	AS Override option
                                    	**type**\: bool
                                    
                                    .. attribute:: soo_value
                                    
                                    	Site\-of\-origin value
                                    	**type**\: str
                                    
                                    .. attribute:: split_horizon
                                    
                                    	Split horizon check
                                    	**type**\: bool
                                    
                                    .. attribute:: is_labeled_afi_enabled
                                    
                                    	Update group has labeled AFI enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_unlabeled_afi_enabled
                                    
                                    	Update group has unlabeled AFI enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: ext_nh_encoding
                                    
                                    	Extended nexthop encoding cap received
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_adv_perm_net_capable
                                    
                                    	Advertise Permanent\-Net capable peers
                                    	**type**\: bool
                                    
                                    .. attribute:: should_send_gshut_community
                                    
                                    	Send GSHUT community
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_active
                                    
                                    	GSHUT active
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref_set
                                    
                                    	GSHUT local preference set
                                    	**type**\: bool
                                    
                                    .. attribute:: gshut_locpref
                                    
                                    	GSHUT local preference
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: gshut_prepends
                                    
                                    	GSHUT AS prepends
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: advertise_local_labeled_route_unicast
                                    
                                    	Advertise routes with local\-label via Unicast SAFI
                                    	**type**\: bool
                                    
                                    .. attribute:: enable_label_stack
                                    
                                    	Enable label stack
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor
                                    
                                    	Neighbors in this update group which are not in any sub\-group
                                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor>`
                                    
                                    .. attribute:: update_sub_group
                                    
                                    	Update sub\-group list
                                    	**type**\: list of  		 :py:class:`UpdateSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup, self).__init__()

                                        self.yang_name = "update-group"
                                        self.yang_parent_name = "update-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor)), ("update-sub-group", ("update_sub_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup))])
                                        self._leafs = OrderedDict([
                                            ('update_group_id', (YLeaf(YType.uint32, 'update-group-id'), ['int'])),
                                            ('filter_group_id', (YLeaf(YType.uint32, 'filter-group-id'), ['int'])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('session_af_name', (YLeaf(YType.uint8, 'session-af-name'), ['int'])),
                                            ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('should_send_communities', (YLeaf(YType.boolean, 'should-send-communities'), ['bool'])),
                                            ('should_send_ext_communities', (YLeaf(YType.boolean, 'should-send-ext-communities'), ['bool'])),
                                            ('should_send_stitching_rt', (YLeaf(YType.boolean, 'should-send-stitching-rt'), ['bool'])),
                                            ('has_orf_receive_capability', (YLeaf(YType.boolean, 'has-orf-receive-capability'), ['bool'])),
                                            ('is_route_reflector_client', (YLeaf(YType.boolean, 'is-route-reflector-client'), ['bool'])),
                                            ('is_client_reflection_disabled', (YLeaf(YType.boolean, 'is-client-reflection-disabled'), ['bool'])),
                                            ('accepts_legacy_pe_rt_route', (YLeaf(YType.boolean, 'accepts-legacy-pe-rt-route'), ['bool'])),
                                            ('updgrp_cluster_id', (YLeaf(YType.uint32, 'updgrp-cluster-id'), ['int'])),
                                            ('updgrp_cluster_type', (YLeaf(YType.uint8, 'updgrp-cluster-type'), ['int'])),
                                            ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                            ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                            ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                            ('should_remove_private_a_ss', (YLeaf(YType.boolean, 'should-remove-private-a-ss'), ['bool'])),
                                            ('should_remove_private_as_ent_path', (YLeaf(YType.boolean, 'should-remove-private-as-ent-path'), ['bool'])),
                                            ('use_next_hop_self', (YLeaf(YType.boolean, 'use-next-hop-self'), ['bool'])),
                                            ('use_next_hop_unchanged_mpath', (YLeaf(YType.boolean, 'use-next-hop-unchanged-mpath'), ['bool'])),
                                            ('is_internal_peers', (YLeaf(YType.boolean, 'is-internal-peers'), ['bool'])),
                                            ('is_common_admin_peers', (YLeaf(YType.boolean, 'is-common-admin-peers'), ['bool'])),
                                            ('is4_byte_as_peer', (YLeaf(YType.boolean, 'is4-byte-as-peer'), ['bool'])),
                                            ('is_addpath_capable', (YLeaf(YType.boolean, 'is-addpath-capable'), ['bool'])),
                                            ('is_send_mcast_attr_enabled', (YLeaf(YType.boolean, 'is-send-mcast-attr-enabled'), ['bool'])),
                                            ('is_aigp_capable', (YLeaf(YType.boolean, 'is-aigp-capable'), ['bool'])),
                                            ('is_aigp_cost_community_capable', (YLeaf(YType.boolean, 'is-aigp-cost-community-capable'), ['bool'])),
                                            ('is_aigp_med_capable', (YLeaf(YType.boolean, 'is-aigp-med-capable'), ['bool'])),
                                            ('is_llgr_capable', (YLeaf(YType.boolean, 'is-llgr-capable'), ['bool'])),
                                            ('is_adv_capable', (YLeaf(YType.boolean, 'is-adv-capable'), ['bool'])),
                                            ('is_adv_reorg_capable', (YLeaf(YType.boolean, 'is-adv-reorg-capable'), ['bool'])),
                                            ('disable_native_advertisement', (YLeaf(YType.boolean, 'disable-native-advertisement'), ['bool'])),
                                            ('disable_def_vrf_imp_advertisement', (YLeaf(YType.boolean, 'disable-def-vrf-imp-advertisement'), ['bool'])),
                                            ('disable_vrf_re_imp_advertisement', (YLeaf(YType.boolean, 'disable-vrf-re-imp-advertisement'), ['bool'])),
                                            ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                            ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                            ('is_directly_connected_ebgp_v6_peers', (YLeaf(YType.boolean, 'is-directly-connected-ebgp-v6-peers'), ['bool'])),
                                            ('minimum_advertisement_interval', (YLeaf(YType.uint32, 'minimum-advertisement-interval'), ['int'])),
                                            ('minimum_advertisement_interval_msecs', (YLeaf(YType.uint32, 'minimum-advertisement-interval-msecs'), ['int'])),
                                            ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                            ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                            ('desync_count', (YLeaf(YType.uint32, 'desync-count'), ['int'])),
                                            ('subgrp_merge_count', (YLeaf(YType.uint32, 'subgrp-merge-count'), ['int'])),
                                            ('refresh_subgrp_count', (YLeaf(YType.uint32, 'refresh-subgrp-count'), ['int'])),
                                            ('updates_formatted', (YLeaf(YType.uint32, 'updates-formatted'), ['int'])),
                                            ('updates_replicated', (YLeaf(YType.uint32, 'updates-replicated'), ['int'])),
                                            ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                            ('as_override', (YLeaf(YType.boolean, 'as-override'), ['bool'])),
                                            ('soo_value', (YLeaf(YType.str, 'soo-value'), ['str'])),
                                            ('split_horizon', (YLeaf(YType.boolean, 'split-horizon'), ['bool'])),
                                            ('is_labeled_afi_enabled', (YLeaf(YType.boolean, 'is-labeled-afi-enabled'), ['bool'])),
                                            ('is_unlabeled_afi_enabled', (YLeaf(YType.boolean, 'is-unlabeled-afi-enabled'), ['bool'])),
                                            ('ext_nh_encoding', (YLeaf(YType.boolean, 'ext-nh-encoding'), ['bool'])),
                                            ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                            ('is_adv_perm_net_capable', (YLeaf(YType.boolean, 'is-adv-perm-net-capable'), ['bool'])),
                                            ('should_send_gshut_community', (YLeaf(YType.boolean, 'should-send-gshut-community'), ['bool'])),
                                            ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                            ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                            ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                            ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                            ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                            ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                        ])
                                        self.update_group_id = None
                                        self.filter_group_id = None
                                        self.process_instance_id = None
                                        self.session_af_name = None
                                        self.update_group_number = None
                                        self.update_group_af_name = None
                                        self.should_send_communities = None
                                        self.should_send_ext_communities = None
                                        self.should_send_stitching_rt = None
                                        self.has_orf_receive_capability = None
                                        self.is_route_reflector_client = None
                                        self.is_client_reflection_disabled = None
                                        self.accepts_legacy_pe_rt_route = None
                                        self.updgrp_cluster_id = None
                                        self.updgrp_cluster_type = None
                                        self.orr_group_name = None
                                        self.orr_group_index = None
                                        self.is_orr_root_address_configured = None
                                        self.should_remove_private_a_ss = None
                                        self.should_remove_private_as_ent_path = None
                                        self.use_next_hop_self = None
                                        self.use_next_hop_unchanged_mpath = None
                                        self.is_internal_peers = None
                                        self.is_common_admin_peers = None
                                        self.is4_byte_as_peer = None
                                        self.is_addpath_capable = None
                                        self.is_send_mcast_attr_enabled = None
                                        self.is_aigp_capable = None
                                        self.is_aigp_cost_community_capable = None
                                        self.is_aigp_med_capable = None
                                        self.is_llgr_capable = None
                                        self.is_adv_capable = None
                                        self.is_adv_reorg_capable = None
                                        self.disable_native_advertisement = None
                                        self.disable_def_vrf_imp_advertisement = None
                                        self.disable_vrf_re_imp_advertisement = None
                                        self.encapsulation_type = None
                                        self.advertise_rt_type = None
                                        self.is_directly_connected_ebgp_v6_peers = None
                                        self.minimum_advertisement_interval = None
                                        self.minimum_advertisement_interval_msecs = None
                                        self.local_as = None
                                        self.route_policy_out = None
                                        self.desync_count = None
                                        self.subgrp_merge_count = None
                                        self.refresh_subgrp_count = None
                                        self.updates_formatted = None
                                        self.updates_replicated = None
                                        self.local_as_replace_as = None
                                        self.as_override = None
                                        self.soo_value = None
                                        self.split_horizon = None
                                        self.is_labeled_afi_enabled = None
                                        self.is_unlabeled_afi_enabled = None
                                        self.ext_nh_encoding = None
                                        self.remote_as = None
                                        self.is_adv_perm_net_capable = None
                                        self.should_send_gshut_community = None
                                        self.gshut_active = None
                                        self.gshut_locpref_set = None
                                        self.gshut_locpref = None
                                        self.gshut_prepends = None
                                        self.advertise_local_labeled_route_unicast = None
                                        self.enable_label_stack = None

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"

                                        self.neighbor = YList(self)
                                        self.update_sub_group = YList(self)
                                        self._segment_path = lambda: "update-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup, ['update_group_id', 'filter_group_id', u'process_instance_id', u'session_af_name', u'update_group_number', u'update_group_af_name', u'should_send_communities', u'should_send_ext_communities', u'should_send_stitching_rt', u'has_orf_receive_capability', u'is_route_reflector_client', u'is_client_reflection_disabled', u'accepts_legacy_pe_rt_route', u'updgrp_cluster_id', u'updgrp_cluster_type', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'should_remove_private_a_ss', u'should_remove_private_as_ent_path', u'use_next_hop_self', u'use_next_hop_unchanged_mpath', u'is_internal_peers', u'is_common_admin_peers', u'is4_byte_as_peer', u'is_addpath_capable', u'is_send_mcast_attr_enabled', u'is_aigp_capable', u'is_aigp_cost_community_capable', u'is_aigp_med_capable', u'is_llgr_capable', u'is_adv_capable', u'is_adv_reorg_capable', u'disable_native_advertisement', u'disable_def_vrf_imp_advertisement', u'disable_vrf_re_imp_advertisement', u'encapsulation_type', u'advertise_rt_type', u'is_directly_connected_ebgp_v6_peers', u'minimum_advertisement_interval', u'minimum_advertisement_interval_msecs', u'local_as', u'route_policy_out', u'desync_count', u'subgrp_merge_count', u'refresh_subgrp_count', u'updates_formatted', u'updates_replicated', u'local_as_replace_as', u'as_override', u'soo_value', u'split_horizon', u'is_labeled_afi_enabled', u'is_unlabeled_afi_enabled', u'ext_nh_encoding', u'remote_as', u'is_adv_perm_net_capable', u'should_send_gshut_community', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends', u'advertise_local_labeled_route_unicast', u'enable_label_stack'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: update_generation_calls
                                        
                                        	No. of calls to update generation function
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_prefixes_count
                                        
                                        	No. of prefixes updates generated for
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_be_prefixes_count
                                        
                                        	No. of be prefixes updates generated for
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_messages_count
                                        
                                        	No. of update messages generated
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_generation_time
                                        
                                        	Time spent generating updates (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: updgen_timer_start_time
                                        
                                        	Timestamp when update timer started for updgrp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_stop_time
                                        
                                        	Timestamp when update timer stopped for updgrp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: updgen_timer_process_time
                                        
                                        	Timestamp when update timer processed for updgrp
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update_generation_calls', (YLeaf(YType.uint32, 'update-generation-calls'), ['int'])),
                                                ('update_generation_prefixes_count', (YLeaf(YType.uint32, 'update-generation-prefixes-count'), ['int'])),
                                                ('update_generation_be_prefixes_count', (YLeaf(YType.uint32, 'update-generation-be-prefixes-count'), ['int'])),
                                                ('update_generation_messages_count', (YLeaf(YType.uint32, 'update-generation-messages-count'), ['int'])),
                                                ('update_generation_time', (YLeaf(YType.uint32, 'update-generation-time'), ['int'])),
                                                ('updgen_timer_start_time', (YLeaf(YType.uint64, 'updgen-timer-start-time'), ['int'])),
                                                ('updgen_timer_stop_time', (YLeaf(YType.uint64, 'updgen-timer-stop-time'), ['int'])),
                                                ('updgen_timer_process_time', (YLeaf(YType.uint64, 'updgen-timer-process-time'), ['int'])),
                                            ])
                                            self.update_generation_calls = None
                                            self.update_generation_prefixes_count = None
                                            self.update_generation_be_prefixes_count = None
                                            self.update_generation_messages_count = None
                                            self.update_generation_time = None
                                            self.updgen_timer_start_time = None
                                            self.updgen_timer_stop_time = None
                                            self.updgen_timer_process_time = None
                                            self._segment_path = lambda: "performance-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.PerformanceStatistics, [u'update_generation_calls', u'update_generation_prefixes_count', u'update_generation_be_prefixes_count', u'update_generation_messages_count', u'update_generation_time', u'updgen_timer_start_time', u'updgen_timer_stop_time', u'updgen_timer_process_time'], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Neighbors in this update group which are not in
                                        any sub\-group
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class UpdateSubGroup(Entity):
                                        """
                                        Update sub\-group list
                                        
                                        .. attribute:: update_sub_group_number
                                        
                                        	Update sub\-group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group
                                        
                                        	Update sub\-group fgrp\-num
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: wait_for_eo_rs
                                        
                                        	Wait for  RT Nbr EoRs
                                        	**type**\: bool
                                        
                                        .. attribute:: update_filter_group
                                        
                                        	Update f\-group list
                                        	**type**\: list of  		 :py:class:`UpdateFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup>`
                                        
                                        .. attribute:: neighbor
                                        
                                        	Neighbors in this subgrp not in any filtergrp
                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, self).__init__()

                                            self.yang_name = "update-sub-group"
                                            self.yang_parent_name = "update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("update-filter-group", ("update_filter_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor))])
                                            self._leafs = OrderedDict([
                                                ('update_sub_group_number', (YLeaf(YType.uint32, 'update-sub-group-number'), ['int'])),
                                                ('filter_group', (YLeaf(YType.uint16, 'filter-group'), ['int'])),
                                                ('wait_for_eo_rs', (YLeaf(YType.boolean, 'wait-for-eo-rs'), ['bool'])),
                                            ])
                                            self.update_sub_group_number = None
                                            self.filter_group = None
                                            self.wait_for_eo_rs = None

                                            self.update_filter_group = YList(self)
                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "update-sub-group"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup, [u'update_sub_group_number', u'filter_group', u'wait_for_eo_rs'], name, value)


                                        class UpdateFilterGroup(Entity):
                                            """
                                            Update f\-group list
                                            
                                            .. attribute:: update_filter_group_number
                                            
                                            	Update sub\-group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rts
                                            
                                            	RT count per filter group
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_flags
                                            
                                            	Flags per filter group
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fgroup_neighbors
                                            
                                            	Nbrs per filter group
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: fgroup_created_message_elements
                                            
                                            	Number of message elems created for filtergroup
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_deleted_message_elements
                                            
                                            	Number of message elems deleted
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_queued_message_elements
                                            
                                            	Number of message elems queued
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in last update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_advertised_prefixes
                                            
                                            	Number of prefixes advertised to filtergroup in all update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin last update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_withdrawn_prefixes
                                            
                                            	Number of prefixes withdrawn f`rom filtergroupin all update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_total_non_optimised_prefixes
                                            
                                            	Number of prefixes  non\-optm from filtergroupin all update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_skipped_prefixes
                                            
                                            	Number of prefixes skipped for filtergroup in last update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fgroup_suppressed_prefixes
                                            
                                            	Number of prefixes suppressed for filtergroup in last update walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_rt_present
                                            
                                            	RT attribute list present
                                            	**type**\: bool
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity>`
                                            
                                            .. attribute:: neighbor
                                            
                                            	Neighbors in this update sub\-group
                                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, self).__init__()

                                                self.yang_name = "update-filter-group"
                                                self.yang_parent_name = "update-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity)), ("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor))])
                                                self._leafs = OrderedDict([
                                                    ('update_filter_group_number', (YLeaf(YType.uint32, 'update-filter-group-number'), ['int'])),
                                                    ('rts', (YLeaf(YType.uint32, 'rts'), ['int'])),
                                                    ('fgroup_flags', (YLeaf(YType.uint8, 'fgroup-flags'), ['int'])),
                                                    ('fgroup_neighbors', (YLeaf(YType.uint16, 'fgroup-neighbors'), ['int'])),
                                                    ('fgroup_created_message_elements', (YLeaf(YType.uint32, 'fgroup-created-message-elements'), ['int'])),
                                                    ('fgroup_deleted_message_elements', (YLeaf(YType.uint32, 'fgroup-deleted-message-elements'), ['int'])),
                                                    ('fgroup_queued_message_elements', (YLeaf(YType.uint32, 'fgroup-queued-message-elements'), ['int'])),
                                                    ('fgroup_advertised_prefixes', (YLeaf(YType.uint32, 'fgroup-advertised-prefixes'), ['int'])),
                                                    ('fgroup_total_advertised_prefixes', (YLeaf(YType.uint32, 'fgroup-total-advertised-prefixes'), ['int'])),
                                                    ('fgroup_withdrawn_prefixes', (YLeaf(YType.uint32, 'fgroup-withdrawn-prefixes'), ['int'])),
                                                    ('fgroup_total_withdrawn_prefixes', (YLeaf(YType.uint32, 'fgroup-total-withdrawn-prefixes'), ['int'])),
                                                    ('fgroup_total_non_optimised_prefixes', (YLeaf(YType.uint32, 'fgroup-total-non-optimised-prefixes'), ['int'])),
                                                    ('fgroup_skipped_prefixes', (YLeaf(YType.uint32, 'fgroup-skipped-prefixes'), ['int'])),
                                                    ('fgroup_suppressed_prefixes', (YLeaf(YType.uint32, 'fgroup-suppressed-prefixes'), ['int'])),
                                                    ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                                ])
                                                self.update_filter_group_number = None
                                                self.rts = None
                                                self.fgroup_flags = None
                                                self.fgroup_neighbors = None
                                                self.fgroup_created_message_elements = None
                                                self.fgroup_deleted_message_elements = None
                                                self.fgroup_queued_message_elements = None
                                                self.fgroup_advertised_prefixes = None
                                                self.fgroup_total_advertised_prefixes = None
                                                self.fgroup_withdrawn_prefixes = None
                                                self.fgroup_total_withdrawn_prefixes = None
                                                self.fgroup_total_non_optimised_prefixes = None
                                                self.fgroup_skipped_prefixes = None
                                                self.fgroup_suppressed_prefixes = None
                                                self.is_rt_present = None

                                                self.extended_community = YList(self)
                                                self.neighbor = YList(self)
                                                self._segment_path = lambda: "update-filter-group"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup, [u'update_filter_group_number', u'rts', u'fgroup_flags', u'fgroup_neighbors', u'fgroup_created_message_elements', u'fgroup_deleted_message_elements', u'fgroup_queued_message_elements', u'fgroup_advertised_prefixes', u'fgroup_total_advertised_prefixes', u'fgroup_withdrawn_prefixes', u'fgroup_total_withdrawn_prefixes', u'fgroup_total_non_optimised_prefixes', u'fgroup_skipped_prefixes', u'fgroup_suppressed_prefixes', u'is_rt_present'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "update-filter-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.ExtendedCommunity, [u'entry'], name, value)


                                            class Neighbor(Entity):
                                                """
                                                Neighbors in this update sub\-group
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, self).__init__()

                                                    self.yang_name = "neighbor"
                                                    self.yang_parent_name = "update-filter-group"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.UpdateFilterGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Neighbors in this subgrp not in any filtergrp
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "update-sub-group"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGroups.UpdateGroup.UpdateSubGroup.Neighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class UpdateGenerationSubGroups(Entity):
                                """
                                Update generation for all sub\-groups
                                
                                .. attribute:: update_generation_sub_group
                                
                                	Update generation for sub\-group
                                	**type**\: list of  		 :py:class:`UpdateGenerationSubGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups, self).__init__()

                                    self.yang_name = "update-generation-sub-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-generation-sub-group", ("update_generation_sub_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup))])
                                    self._leafs = OrderedDict()

                                    self.update_generation_sub_group = YList(self)
                                    self._segment_path = lambda: "update-generation-sub-groups"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups, [], name, value)


                                class UpdateGenerationSubGroup(Entity):
                                    """
                                    Update generation for sub\-group
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: creation_timestamp
                                    
                                    	Creation time
                                    	**type**\:  :py:class:`CreationTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp>`
                                    
                                    .. attribute:: last_merge_timestamp
                                    
                                    	Last merge time
                                    	**type**\:  :py:class:`LastMergeTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp>`
                                    
                                    .. attribute:: first_update_walk_start_timestamp
                                    
                                    	First update walk start time
                                    	**type**\:  :py:class:`FirstUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: first_update_walk_end_timestamp
                                    
                                    	First update walk end time
                                    	**type**\:  :py:class:`FirstUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: last_update_walk_start_timestamp
                                    
                                    	Last update walk start time
                                    	**type**\:  :py:class:`LastUpdateWalkStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp>`
                                    
                                    .. attribute:: last_update_walk_end_timestamp
                                    
                                    	Last update walk end time
                                    	**type**\:  :py:class:`LastUpdateWalkEndTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp>`
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:  :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics>`
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: current_update_limit_sub_group
                                    
                                    	Current update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_update_limit_sub_group
                                    
                                    	Configured update limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_throttled
                                    
                                    	Is update throttled
                                    	**type**\: bool
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_version
                                    
                                    	NSR version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_resume_version
                                    
                                    	Next resume version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: io_write_event_pending
                                    
                                    	Is IO write event pending
                                    	**type**\: bool
                                    
                                    .. attribute:: update_default_route_sent
                                    
                                    	Is default route sent
                                    	**type**\: bool
                                    
                                    .. attribute:: merge_count
                                    
                                    	Merge count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_merged_sub_group_index
                                    
                                    	Last merged sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: eo_r_attempted
                                    
                                    	Sending EoR has been attempted
                                    	**type**\: bool
                                    
                                    .. attribute:: last_update_walk_end_age
                                    
                                    	Time since last update walk end event
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, self).__init__()

                                        self.yang_name = "update-generation-sub-group"
                                        self.yang_parent_name = "update-generation-sub-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("creation-timestamp", ("creation_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp)), ("last-merge-timestamp", ("last_merge_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp)), ("first-update-walk-start-timestamp", ("first_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp)), ("first-update-walk-end-timestamp", ("first_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp)), ("last-update-walk-start-timestamp", ("last_update_walk_start_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp)), ("last-update-walk-end-timestamp", ("last_update_walk_end_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp)), ("last-update-queued-timestamp", ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics))])
                                        self._leafs = OrderedDict([
                                            ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                            ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                            ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                            ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                            ('sub_group_id_xr', (YLeaf(YType.uint32, 'sub-group-id-xr'), ['int'])),
                                            ('parent_sub_group_index', (YLeaf(YType.uint32, 'parent-sub-group-index'), ['int'])),
                                            ('parent_sub_group_id', (YLeaf(YType.uint32, 'parent-sub-group-id'), ['int'])),
                                            ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                            ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                            ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                            ('current_update_limit_sub_group', (YLeaf(YType.uint32, 'current-update-limit-sub-group'), ['int'])),
                                            ('configured_update_limit_sub_group', (YLeaf(YType.uint32, 'configured-update-limit-sub-group'), ['int'])),
                                            ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                            ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                            ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                                            ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                            ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                            ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                            ('nsr_version', (YLeaf(YType.uint32, 'nsr-version'), ['int'])),
                                            ('pending_target_version', (YLeaf(YType.uint32, 'pending-target-version'), ['int'])),
                                            ('next_resume_version', (YLeaf(YType.uint32, 'next-resume-version'), ['int'])),
                                            ('update_refresh_target_version', (YLeaf(YType.uint32, 'update-refresh-target-version'), ['int'])),
                                            ('io_write_event_pending', (YLeaf(YType.boolean, 'io-write-event-pending'), ['bool'])),
                                            ('update_default_route_sent', (YLeaf(YType.boolean, 'update-default-route-sent'), ['bool'])),
                                            ('merge_count', (YLeaf(YType.uint32, 'merge-count'), ['int'])),
                                            ('last_merged_sub_group_index', (YLeaf(YType.uint32, 'last-merged-sub-group-index'), ['int'])),
                                            ('eo_r_attempted', (YLeaf(YType.boolean, 'eo-r-attempted'), ['bool'])),
                                            ('last_update_walk_end_age', (YLeaf(YType.uint32, 'last-update-walk-end-age'), ['int'])),
                                            ('last_update_queued_age', (YLeaf(YType.uint32, 'last-update-queued-age'), ['int'])),
                                        ])
                                        self.update_group_index = None
                                        self.sub_group_index = None
                                        self.sub_group_id = None
                                        self.process_id = None
                                        self.update_vrf_name = None
                                        self.update_group_af_name = None
                                        self.sub_group_index_xr = None
                                        self.sub_group_id_xr = None
                                        self.parent_sub_group_index = None
                                        self.parent_sub_group_id = None
                                        self.update_group_index_xr = None
                                        self.update_main_table_version = None
                                        self.update_vrf_table_rib_version = None
                                        self.current_update_limit_sub_group = None
                                        self.configured_update_limit_sub_group = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_throttled = None
                                        self.refresh_sub_group_count = None
                                        self.filter_group_count = None
                                        self.neighbor_count = None
                                        self.version = None
                                        self.nsr_version = None
                                        self.pending_target_version = None
                                        self.next_resume_version = None
                                        self.update_refresh_target_version = None
                                        self.io_write_event_pending = None
                                        self.update_default_route_sent = None
                                        self.merge_count = None
                                        self.last_merged_sub_group_index = None
                                        self.eo_r_attempted = None
                                        self.last_update_walk_end_age = None
                                        self.last_update_queued_age = None

                                        self.creation_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp()
                                        self.creation_timestamp.parent = self
                                        self._children_name_map["creation_timestamp"] = "creation-timestamp"

                                        self.last_merge_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp()
                                        self.last_merge_timestamp.parent = self
                                        self._children_name_map["last_merge_timestamp"] = "last-merge-timestamp"

                                        self.first_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp()
                                        self.first_update_walk_start_timestamp.parent = self
                                        self._children_name_map["first_update_walk_start_timestamp"] = "first-update-walk-start-timestamp"

                                        self.first_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp()
                                        self.first_update_walk_end_timestamp.parent = self
                                        self._children_name_map["first_update_walk_end_timestamp"] = "first-update-walk-end-timestamp"

                                        self.last_update_walk_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp()
                                        self.last_update_walk_start_timestamp.parent = self
                                        self._children_name_map["last_update_walk_start_timestamp"] = "last-update-walk-start-timestamp"

                                        self.last_update_walk_end_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp()
                                        self.last_update_walk_end_timestamp.parent = self
                                        self._children_name_map["last_update_walk_end_timestamp"] = "last-update-walk-end-timestamp"

                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"

                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._segment_path = lambda: "update-generation-sub-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup, ['update_group_index', 'sub_group_index', 'sub_group_id', u'process_id', u'update_vrf_name', u'update_group_af_name', u'sub_group_index_xr', u'sub_group_id_xr', u'parent_sub_group_index', u'parent_sub_group_id', u'update_group_index_xr', u'update_main_table_version', u'update_vrf_table_rib_version', u'current_update_limit_sub_group', u'configured_update_limit_sub_group', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled', u'refresh_sub_group_count', u'filter_group_count', u'neighbor_count', u'version', u'nsr_version', u'pending_target_version', u'next_resume_version', u'update_refresh_target_version', u'io_write_event_pending', u'update_default_route_sent', u'merge_count', u'last_merged_sub_group_index', u'eo_r_attempted', u'last_update_walk_end_age', u'last_update_queued_age'], name, value)


                                    class CreationTimestamp(Entity):
                                        """
                                        Creation time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, self).__init__()

                                            self.yang_name = "creation-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "creation-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.CreationTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastMergeTimestamp(Entity):
                                        """
                                        Last merge time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, self).__init__()

                                            self.yang_name = "last-merge-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-merge-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastMergeTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstUpdateWalkStartTimestamp(Entity):
                                        """
                                        First update walk start time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, self).__init__()

                                            self.yang_name = "first-update-walk-start-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-update-walk-start-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstUpdateWalkEndTimestamp(Entity):
                                        """
                                        First update walk end time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, self).__init__()

                                            self.yang_name = "first-update-walk-end-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-update-walk-end-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.FirstUpdateWalkEndTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateWalkStartTimestamp(Entity):
                                        """
                                        Last update walk start time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-walk-start-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-walk-start-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateWalkEndTimestamp(Entity):
                                        """
                                        Last update walk end time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, self).__init__()

                                            self.yang_name = "last-update-walk-end-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-walk-end-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateWalkEndTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateQueuedTimestamp(Entity):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-queued-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.LastUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-sub-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                            ])
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_size_high = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_cleared = None
                                            self.last_update_discard_age = None
                                            self.last_update_cleard_age = None
                                            self.update_throttle_count = None
                                            self.last_update_throttle_age = None
                                            self.update_recovery_count = None
                                            self.last_update_recovery_age = None
                                            self.update_memory_allocation_fail_count = None
                                            self.last_update_memory_allocation_fail_age = None

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._segment_path = lambda: "update-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-discard-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-cleared-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-throttle-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-recovery-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationSubGroups.UpdateGenerationSubGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class NextHopAddressFamilies(Entity):
                                """
                                Address family of nexthop table
                                
                                .. attribute:: next_hop_address_family
                                
                                	Nexthop Address family
                                	**type**\: list of  		 :py:class:`NextHopAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies, self).__init__()

                                    self.yang_name = "next-hop-address-families"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("next-hop-address-family", ("next_hop_address_family", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily))])
                                    self._leafs = OrderedDict()

                                    self.next_hop_address_family = YList(self)
                                    self._segment_path = lambda: "next-hop-address-families"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies, [], name, value)


                                class NextHopAddressFamily(Entity):
                                    """
                                    Nexthop Address family
                                    
                                    .. attribute:: next_hop_af_name  (key)
                                    
                                    	Address family
                                    	**type**\:  :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                    
                                    .. attribute:: next_hop_af_vrf_af
                                    
                                    	A BGP Next\-hop VRF AF table entry
                                    	**type**\:  :py:class:`NextHopAfVrfAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf>`
                                    
                                    .. attribute:: next_hop_afs
                                    
                                    	The BGP Next\-hop table
                                    	**type**\:  :py:class:`NextHopAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, self).__init__()

                                        self.yang_name = "next-hop-address-family"
                                        self.yang_parent_name = "next-hop-address-families"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['next_hop_af_name']
                                        self._child_classes = OrderedDict([("next-hop-af-vrf-af", ("next_hop_af_vrf_af", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf)), ("next-hop-afs", ("next_hop_afs", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs))])
                                        self._leafs = OrderedDict([
                                            ('next_hop_af_name', (YLeaf(YType.enumeration, 'next-hop-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes', 'BgpAddressFamily', '')])),
                                        ])
                                        self.next_hop_af_name = None

                                        self.next_hop_af_vrf_af = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf()
                                        self.next_hop_af_vrf_af.parent = self
                                        self._children_name_map["next_hop_af_vrf_af"] = "next-hop-af-vrf-af"

                                        self.next_hop_afs = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs()
                                        self.next_hop_afs.parent = self
                                        self._children_name_map["next_hop_afs"] = "next-hop-afs"
                                        self._segment_path = lambda: "next-hop-address-family" + "[next-hop-af-name='" + str(self.next_hop_af_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily, ['next_hop_af_name'], name, value)


                                    class NextHopAfVrfAf(Entity):
                                        """
                                        A BGP Next\-hop VRF AF table entry
                                        
                                        .. attribute:: performance_statistics
                                        
                                        	Performance statistics
                                        	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: gwaf_name
                                        
                                        	GW Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: total_nexthops
                                        
                                        	Total number of nexthops
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: critical_trigger_delay
                                        
                                        	Trigger delay for critical event processing
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: non_critical_trigger_delay
                                        
                                        	Trigger delay for non\-critical event processing
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: table_active
                                        
                                        	Whether the VRF is active
                                        	**type**\: bool
                                        
                                        .. attribute:: nh_rib_up
                                        
                                        	Whether the VRF is active
                                        	**type**\: bool
                                        
                                        .. attribute:: nh_rib_version
                                        
                                        	RIB version for gw\_ctx
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_nexthop_version
                                        
                                        	NH version for gw\_ctx
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nh_table_id
                                        
                                        	Gateway context table id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_table_version
                                        
                                        	Version of the EPE table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_label_version
                                        
                                        	Version of the EPE label walk
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_downloaded_version
                                        
                                        	Version of the EPE table downloaded
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: epe_standby_version
                                        
                                        	Version of the EPE table processed by sync thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, self).__init__()

                                            self.yang_name = "next-hop-af-vrf-af"
                                            self.yang_parent_name = "next-hop-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics))])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('gwaf_name', (YLeaf(YType.enumeration, 'gwaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('total_nexthops', (YLeaf(YType.uint32, 'total-nexthops'), ['int'])),
                                                ('critical_trigger_delay', (YLeaf(YType.uint32, 'critical-trigger-delay'), ['int'])),
                                                ('non_critical_trigger_delay', (YLeaf(YType.uint32, 'non-critical-trigger-delay'), ['int'])),
                                                ('table_active', (YLeaf(YType.boolean, 'table-active'), ['bool'])),
                                                ('nh_rib_up', (YLeaf(YType.boolean, 'nh-rib-up'), ['bool'])),
                                                ('nh_rib_version', (YLeaf(YType.uint32, 'nh-rib-version'), ['int'])),
                                                ('nh_nexthop_version', (YLeaf(YType.uint32, 'nh-nexthop-version'), ['int'])),
                                                ('nh_table_id', (YLeaf(YType.uint32, 'nh-table-id'), ['int'])),
                                                ('epe_table_version', (YLeaf(YType.uint32, 'epe-table-version'), ['int'])),
                                                ('epe_label_version', (YLeaf(YType.uint32, 'epe-label-version'), ['int'])),
                                                ('epe_downloaded_version', (YLeaf(YType.uint32, 'epe-downloaded-version'), ['int'])),
                                                ('epe_standby_version', (YLeaf(YType.uint32, 'epe-standby-version'), ['int'])),
                                            ])
                                            self.af_name = None
                                            self.gwaf_name = None
                                            self.total_nexthops = None
                                            self.critical_trigger_delay = None
                                            self.non_critical_trigger_delay = None
                                            self.table_active = None
                                            self.nh_rib_up = None
                                            self.nh_rib_version = None
                                            self.nh_nexthop_version = None
                                            self.nh_table_id = None
                                            self.epe_table_version = None
                                            self.epe_label_version = None
                                            self.epe_downloaded_version = None
                                            self.epe_standby_version = None

                                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics()
                                            self.performance_statistics.parent = self
                                            self._children_name_map["performance_statistics"] = "performance-statistics"
                                            self._segment_path = lambda: "next-hop-af-vrf-af"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf, [u'af_name', u'gwaf_name', u'total_nexthops', u'critical_trigger_delay', u'non_critical_trigger_delay', u'table_active', u'nh_rib_up', u'nh_rib_version', u'nh_nexthop_version', u'nh_table_id', u'epe_table_version', u'epe_label_version', u'epe_downloaded_version', u'epe_standby_version'], name, value)


                                        class PerformanceStatistics(Entity):
                                            """
                                            Performance statistics
                                            
                                            .. attribute:: critical_notf_count
                                            
                                            	Number of critical event notifications from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: noncritical_notf_count
                                            
                                            	Number of non\-critical event notifications from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_deletes
                                            
                                            	Number of bestpath deletes due to last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_notf_bestpath_changes
                                            
                                            	Number of bestpath changes due to last notification
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_sync_reg_calls
                                            
                                            	NH sync register calls
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_reg_calls
                                            
                                            	NH async register calls
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nha_sync_un_reg_calls
                                            
                                            	NH async unregister calls
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_pending_registrations
                                            
                                            	NH Registration List Count
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_peak_registrations
                                            
                                            	NH Registration List Count Peak
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_batch_finish_calls
                                            
                                            	NH batch finish calls
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_flush_timer_calls
                                            
                                            	NH flush timer calls
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_sync_reg_ts
                                            
                                            	NH Last sync Register TS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_reg_ts
                                            
                                            	NH Last async Register TS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_a_sync_un_reg_ts
                                            
                                            	NH Last async UnRegister TS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_batch_finish_ts
                                            
                                            	NH Last batch finish TS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_last_flush_timer_ts
                                            
                                            	NH Last flush timer TS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_calls
                                            
                                            	No. of calls to RIB update function
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nhrib_update_time
                                            
                                            	Time spent sending RIB updates (milliseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: nexthops_sent_to_rib
                                            
                                            	No. of nexthops sent to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_resent_to_rib
                                            
                                            	No. of nexthops re\-sent to RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthops_removed_from_rib
                                            
                                            	No. of nexthops withdrawn from RIB
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rib_sync_registers_failed
                                            
                                            	No. of sync registers with RIB that failed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: riba_sync_registers_failed
                                            
                                            	No. of async registers with RIB that failed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_tbl_id
                                            
                                            	No. of nh registers failed because of no tbl\-id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribnh_reg_failed_for_no_rib_conn
                                            
                                            	No. of nh registers failed because of no rib conn
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_nh_not_found
                                            
                                            	No. of times nexthop was not found during tunnel walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_gw_not_found
                                            
                                            	No. of times gw was not found during tunnel walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_walk_backup_creates
                                            
                                            	No. of times backup tid created during tunnel walk
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, self).__init__()

                                                self.yang_name = "performance-statistics"
                                                self.yang_parent_name = "next-hop-af-vrf-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('critical_notf_count', (YLeaf(YType.uint32, 'critical-notf-count'), ['int'])),
                                                    ('noncritical_notf_count', (YLeaf(YType.uint32, 'noncritical-notf-count'), ['int'])),
                                                    ('last_notf_bestpath_deletes', (YLeaf(YType.uint32, 'last-notf-bestpath-deletes'), ['int'])),
                                                    ('last_notf_bestpath_changes', (YLeaf(YType.uint32, 'last-notf-bestpath-changes'), ['int'])),
                                                    ('nh_sync_reg_calls', (YLeaf(YType.uint32, 'nh-sync-reg-calls'), ['int'])),
                                                    ('nha_sync_reg_calls', (YLeaf(YType.uint32, 'nha-sync-reg-calls'), ['int'])),
                                                    ('nha_sync_un_reg_calls', (YLeaf(YType.uint32, 'nha-sync-un-reg-calls'), ['int'])),
                                                    ('nh_pending_registrations', (YLeaf(YType.uint32, 'nh-pending-registrations'), ['int'])),
                                                    ('nh_peak_registrations', (YLeaf(YType.uint32, 'nh-peak-registrations'), ['int'])),
                                                    ('nh_batch_finish_calls', (YLeaf(YType.uint32, 'nh-batch-finish-calls'), ['int'])),
                                                    ('nh_flush_timer_calls', (YLeaf(YType.uint32, 'nh-flush-timer-calls'), ['int'])),
                                                    ('nh_last_sync_reg_ts', (YLeaf(YType.uint32, 'nh-last-sync-reg-ts'), ['int'])),
                                                    ('nh_last_a_sync_reg_ts', (YLeaf(YType.uint32, 'nh-last-a-sync-reg-ts'), ['int'])),
                                                    ('nh_last_a_sync_un_reg_ts', (YLeaf(YType.uint32, 'nh-last-a-sync-un-reg-ts'), ['int'])),
                                                    ('nh_last_batch_finish_ts', (YLeaf(YType.uint32, 'nh-last-batch-finish-ts'), ['int'])),
                                                    ('nh_last_flush_timer_ts', (YLeaf(YType.uint32, 'nh-last-flush-timer-ts'), ['int'])),
                                                    ('nhrib_update_calls', (YLeaf(YType.uint32, 'nhrib-update-calls'), ['int'])),
                                                    ('nhrib_update_time', (YLeaf(YType.uint32, 'nhrib-update-time'), ['int'])),
                                                    ('nexthops_sent_to_rib', (YLeaf(YType.uint32, 'nexthops-sent-to-rib'), ['int'])),
                                                    ('nexthops_resent_to_rib', (YLeaf(YType.uint32, 'nexthops-resent-to-rib'), ['int'])),
                                                    ('nexthops_removed_from_rib', (YLeaf(YType.uint32, 'nexthops-removed-from-rib'), ['int'])),
                                                    ('rib_sync_registers_failed', (YLeaf(YType.uint32, 'rib-sync-registers-failed'), ['int'])),
                                                    ('riba_sync_registers_failed', (YLeaf(YType.uint32, 'riba-sync-registers-failed'), ['int'])),
                                                    ('ribnh_reg_failed_for_no_tbl_id', (YLeaf(YType.uint32, 'ribnh-reg-failed-for-no-tbl-id'), ['int'])),
                                                    ('ribnh_reg_failed_for_no_rib_conn', (YLeaf(YType.uint32, 'ribnh-reg-failed-for-no-rib-conn'), ['int'])),
                                                    ('tunnel_walk_nh_not_found', (YLeaf(YType.uint32, 'tunnel-walk-nh-not-found'), ['int'])),
                                                    ('tunnel_walk_gw_not_found', (YLeaf(YType.uint32, 'tunnel-walk-gw-not-found'), ['int'])),
                                                    ('tunnel_walk_backup_creates', (YLeaf(YType.uint32, 'tunnel-walk-backup-creates'), ['int'])),
                                                ])
                                                self.critical_notf_count = None
                                                self.noncritical_notf_count = None
                                                self.last_notf_bestpath_deletes = None
                                                self.last_notf_bestpath_changes = None
                                                self.nh_sync_reg_calls = None
                                                self.nha_sync_reg_calls = None
                                                self.nha_sync_un_reg_calls = None
                                                self.nh_pending_registrations = None
                                                self.nh_peak_registrations = None
                                                self.nh_batch_finish_calls = None
                                                self.nh_flush_timer_calls = None
                                                self.nh_last_sync_reg_ts = None
                                                self.nh_last_a_sync_reg_ts = None
                                                self.nh_last_a_sync_un_reg_ts = None
                                                self.nh_last_batch_finish_ts = None
                                                self.nh_last_flush_timer_ts = None
                                                self.nhrib_update_calls = None
                                                self.nhrib_update_time = None
                                                self.nexthops_sent_to_rib = None
                                                self.nexthops_resent_to_rib = None
                                                self.nexthops_removed_from_rib = None
                                                self.rib_sync_registers_failed = None
                                                self.riba_sync_registers_failed = None
                                                self.ribnh_reg_failed_for_no_tbl_id = None
                                                self.ribnh_reg_failed_for_no_rib_conn = None
                                                self.tunnel_walk_nh_not_found = None
                                                self.tunnel_walk_gw_not_found = None
                                                self.tunnel_walk_backup_creates = None
                                                self._segment_path = lambda: "performance-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfVrfAf.PerformanceStatistics, [u'critical_notf_count', u'noncritical_notf_count', u'last_notf_bestpath_deletes', u'last_notf_bestpath_changes', u'nh_sync_reg_calls', u'nha_sync_reg_calls', u'nha_sync_un_reg_calls', u'nh_pending_registrations', u'nh_peak_registrations', u'nh_batch_finish_calls', u'nh_flush_timer_calls', u'nh_last_sync_reg_ts', u'nh_last_a_sync_reg_ts', u'nh_last_a_sync_un_reg_ts', u'nh_last_batch_finish_ts', u'nh_last_flush_timer_ts', u'nhrib_update_calls', u'nhrib_update_time', u'nexthops_sent_to_rib', u'nexthops_resent_to_rib', u'nexthops_removed_from_rib', u'rib_sync_registers_failed', u'riba_sync_registers_failed', u'ribnh_reg_failed_for_no_tbl_id', u'ribnh_reg_failed_for_no_rib_conn', u'tunnel_walk_nh_not_found', u'tunnel_walk_gw_not_found', u'tunnel_walk_backup_creates'], name, value)


                                    class NextHopAfs(Entity):
                                        """
                                        The BGP Next\-hop table
                                        
                                        .. attribute:: next_hop_af
                                        
                                        	A BGP Next hop entry
                                        	**type**\: list of  		 :py:class:`NextHopAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, self).__init__()

                                            self.yang_name = "next-hop-afs"
                                            self.yang_parent_name = "next-hop-address-family"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("next-hop-af", ("next_hop_af", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf))])
                                            self._leafs = OrderedDict()

                                            self.next_hop_af = YList(self)
                                            self._segment_path = lambda: "next-hop-afs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs, [], name, value)


                                        class NextHopAf(Entity):
                                            """
                                            A BGP Next hop entry
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	Next hop address
                                            	**type**\: union of the below types:
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            		**type**\: str
                                            
                                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_set
                                            
                                            	Attribute Set Name
                                            	**type**\: str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: nexthop_address
                                            
                                            	Nexthop address
                                            	**type**\:  :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel>`
                                            
                                            .. attribute:: nexthop_internal_info
                                            
                                            	Internal nexthop info
                                            	**type**\:  :py:class:`NexthopInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: rib_nexthop_id
                                            
                                            	RIB Nexthop Id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_pending_registration
                                            
                                            	Nexthop registration is pending
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: nexthop_reference_count
                                            
                                            	Number of neighbors/prefixes referencing this nexthop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_reference_count_total
                                            
                                            	Number of neighbors/prefixes referencing this nexthop (AFs)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nh_first_hop_if_handle
                                            
                                            	First\-hop interface handle
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: nexthop_aigp_metric
                                            
                                            	AIGP metrice of nexthop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_reachable
                                            
                                            	Is Gateway reachable ?
                                            	**type**\: bool
                                            
                                            .. attribute:: nexthop_gateway_prefix_connected
                                            
                                            	Is Gateway resolved through Connected route ?
                                            	**type**\: bool
                                            
                                            .. attribute:: nexthop_gateway_prefix_length
                                            
                                            	Gateway prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nexthop_gateway_info
                                            
                                            	Gateway related info, includingOptimal Route Reflector Gateways
                                            	**type**\: list of  		 :py:class:`NexthopGatewayInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address List
                                            	**type**\: list of  		 :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, self).__init__()

                                                self.yang_name = "next-hop-af"
                                                self.yang_parent_name = "next-hop-afs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nexthop-address", ("nexthop_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel)), ("nexthop-internal-info", ("nexthop_internal_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo)), ("nexthop-gateway-info", ("nexthop_gateway_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('next_hop_address', (YLeaf(YType.str, 'next-hop-address'), ['str','str'])),
                                                    ('attribute_set', (YLeaf(YType.str, 'attribute-set'), ['str'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('rib_nexthop_id', (YLeaf(YType.uint32, 'rib-nexthop-id'), ['int'])),
                                                    ('nexthop_pending_registration', (YLeaf(YType.uint8, 'nexthop-pending-registration'), ['int'])),
                                                    ('nexthop_reference_count', (YLeaf(YType.uint32, 'nexthop-reference-count'), ['int'])),
                                                    ('nh_reference_count_total', (YLeaf(YType.uint32, 'nh-reference-count-total'), ['int'])),
                                                    ('nh_first_hop_if_handle', (YLeaf(YType.str, 'nh-first-hop-if-handle'), ['str'])),
                                                    ('nexthop_aigp_metric', (YLeaf(YType.uint32, 'nexthop-aigp-metric'), ['int'])),
                                                    ('nexthop_gateway_reachable', (YLeaf(YType.boolean, 'nexthop-gateway-reachable'), ['bool'])),
                                                    ('nexthop_gateway_prefix_connected', (YLeaf(YType.boolean, 'nexthop-gateway-prefix-connected'), ['bool'])),
                                                    ('nexthop_gateway_prefix_length', (YLeaf(YType.uint32, 'nexthop-gateway-prefix-length'), ['int'])),
                                                ])
                                                self.next_hop_address = None
                                                self.attribute_set = None
                                                self.af_name = None
                                                self.rib_nexthop_id = None
                                                self.nexthop_pending_registration = None
                                                self.nexthop_reference_count = None
                                                self.nh_reference_count_total = None
                                                self.nh_first_hop_if_handle = None
                                                self.nexthop_aigp_metric = None
                                                self.nexthop_gateway_reachable = None
                                                self.nexthop_gateway_prefix_connected = None
                                                self.nexthop_gateway_prefix_length = None

                                                self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress()
                                                self.nexthop_address.parent = self
                                                self._children_name_map["nexthop_address"] = "nexthop-address"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.nexthop_internal_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo()
                                                self.nexthop_internal_info.parent = self
                                                self._children_name_map["nexthop_internal_info"] = "nexthop-internal-info"

                                                self.nexthop_gateway_info = YList(self)
                                                self.neighbor_address = YList(self)
                                                self._segment_path = lambda: "next-hop-af"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf, ['next_hop_address', 'attribute_set', u'af_name', u'rib_nexthop_id', u'nexthop_pending_registration', u'nexthop_reference_count', u'nh_reference_count_total', u'nh_first_hop_if_handle', u'nexthop_aigp_metric', u'nexthop_gateway_reachable', u'nexthop_gateway_prefix_connected', u'nexthop_gateway_prefix_length'], name, value)


                                            class NexthopAddress(Entity):
                                                """
                                                Nexthop address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, self).__init__()

                                                    self.yang_name = "nexthop-address"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "nexthop-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "nexthop-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class NexthopInternalInfo(Entity):
                                                """
                                                Internal nexthop info
                                                
                                                .. attribute:: nexthop_address
                                                
                                                	Nexthop address
                                                	**type**\:  :py:class:`NexthopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress>`
                                                
                                                .. attribute:: nexthop_id
                                                
                                                	Comm librray ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_version
                                                
                                                	Table version
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_flags
                                                
                                                	Nexthop flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_if_handle
                                                
                                                	Nexthop ifhandle
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_af_user_bits
                                                
                                                	Bitmask indicating the AFs which share the nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_label
                                                
                                                	Nexthop label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: gateway_flags
                                                
                                                	Gateway flags
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_metrice
                                                
                                                	Nexthop metrices
                                                	**type**\: list of  		 :py:class:`NexthopMetrice <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice>`
                                                
                                                .. attribute:: nexthop_refcount
                                                
                                                	Nexthop refcounts
                                                	**type**\: list of  		 :py:class:`NexthopRefcount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount>`
                                                
                                                .. attribute:: nexthop_gateway_internal_info
                                                
                                                	Internal nexthop Gateway info
                                                	**type**\: list of  		 :py:class:`NexthopGatewayInternalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, self).__init__()

                                                    self.yang_name = "nexthop-internal-info"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nexthop-address", ("nexthop_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress)), ("nexthop-metrice", ("nexthop_metrice", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice)), ("nexthop-refcount", ("nexthop_refcount", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount)), ("nexthop-gateway-internal-info", ("nexthop_gateway_internal_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo))])
                                                    self._leafs = OrderedDict([
                                                        ('nexthop_id', (YLeaf(YType.uint32, 'nexthop-id'), ['int'])),
                                                        ('nexthop_version', (YLeaf(YType.uint32, 'nexthop-version'), ['int'])),
                                                        ('nexthop_flags', (YLeaf(YType.uint32, 'nexthop-flags'), ['int'])),
                                                        ('nexthop_if_handle', (YLeaf(YType.uint32, 'nexthop-if-handle'), ['int'])),
                                                        ('nexthop_af_user_bits', (YLeaf(YType.uint32, 'nexthop-af-user-bits'), ['int'])),
                                                        ('nexthop_label', (YLeaf(YType.uint32, 'nexthop-label'), ['int'])),
                                                        ('gateway_flags', (YLeaf(YType.uint32, 'gateway-flags'), ['int'])),
                                                    ])
                                                    self.nexthop_id = None
                                                    self.nexthop_version = None
                                                    self.nexthop_flags = None
                                                    self.nexthop_if_handle = None
                                                    self.nexthop_af_user_bits = None
                                                    self.nexthop_label = None
                                                    self.gateway_flags = None

                                                    self.nexthop_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress()
                                                    self.nexthop_address.parent = self
                                                    self._children_name_map["nexthop_address"] = "nexthop-address"

                                                    self.nexthop_metrice = YList(self)
                                                    self.nexthop_refcount = YList(self)
                                                    self.nexthop_gateway_internal_info = YList(self)
                                                    self._segment_path = lambda: "nexthop-internal-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo, [u'nexthop_id', u'nexthop_version', u'nexthop_flags', u'nexthop_if_handle', u'nexthop_af_user_bits', u'nexthop_label', u'gateway_flags'], name, value)


                                                class NexthopAddress(Entity):
                                                    """
                                                    Nexthop address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, self).__init__()

                                                        self.yang_name = "nexthop-address"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "nexthop-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NexthopMetrice(Entity):
                                                    """
                                                    Nexthop metrices
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, self).__init__()

                                                        self.yang_name = "nexthop-metrice"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "nexthop-metrice"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopMetrice, [u'entry'], name, value)


                                                class NexthopRefcount(Entity):
                                                    """
                                                    Nexthop refcounts
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, self).__init__()

                                                        self.yang_name = "nexthop-refcount"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "nexthop-refcount"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopRefcount, [u'entry'], name, value)


                                                class NexthopGatewayInternalInfo(Entity):
                                                    """
                                                    Internal nexthop Gateway info
                                                    
                                                    .. attribute:: gateway_flags
                                                    
                                                    	Gateway flags
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: registration_type
                                                    
                                                    	Nexthop registration type
                                                    	**type**\:  :py:class:`BgpNhValidate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhValidate>`
                                                    
                                                    .. attribute:: registration_since
                                                    
                                                    	Time since registration
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, self).__init__()

                                                        self.yang_name = "nexthop-gateway-internal-info"
                                                        self.yang_parent_name = "nexthop-internal-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('gateway_flags', (YLeaf(YType.uint32, 'gateway-flags'), ['int'])),
                                                            ('registration_type', (YLeaf(YType.enumeration, 'registration-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhValidate', '')])),
                                                            ('registration_since', (YLeaf(YType.uint32, 'registration-since'), ['int'])),
                                                        ])
                                                        self.gateway_flags = None
                                                        self.registration_type = None
                                                        self.registration_since = None
                                                        self._segment_path = lambda: "nexthop-gateway-internal-info"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopInternalInfo.NexthopGatewayInternalInfo, [u'gateway_flags', u'registration_type', u'registration_since'], name, value)


                                            class NexthopGatewayInfo(Entity):
                                                """
                                                Gateway related info, includingOptimal Route
                                                Reflector Gateways
                                                
                                                .. attribute:: nexthop_route
                                                
                                                	Route resolving the nethop
                                                	**type**\:  :py:class:`NexthopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute>`
                                                
                                                .. attribute:: nexthop_route_prefix_length
                                                
                                                	Prefix length of the route resolving the nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_route_protocol
                                                
                                                	Protocol that resolves the route to the nexthop
                                                	**type**\: str
                                                
                                                .. attribute:: nexthop_route_path_count
                                                
                                                	Number of paths in the resolving route
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_af_invalid_bits
                                                
                                                	Bitmask indicating the AFs which have been invalidated for the nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: nexthop_status
                                                
                                                	Nexthop status
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nexthop_tableid
                                                
                                                	Nexthop Table id
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: nexthop_metric
                                                
                                                	IGP metric for nexthop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_type
                                                
                                                	Last nexthop event type
                                                	**type**\:  :py:class:`BgpNhEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhEvent>`
                                                
                                                .. attribute:: last_update_type
                                                
                                                	Last nexthop update type
                                                	**type**\:  :py:class:`BgpNhUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpNhUpdate>`
                                                
                                                .. attribute:: critical_events
                                                
                                                	Number of critical events received from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: non_critical_events
                                                
                                                	Number of non\-critical events received from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_event_since
                                                
                                                	Time since the last event sent to or received from RIB
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_rib_update
                                                
                                                	Time since the last rib update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_enabled
                                                
                                                	TRUE if MPLS is configured for IAS/CsC application
                                                	**type**\: bool
                                                
                                                .. attribute:: nexthop_mpls_interfaces
                                                
                                                	Number of interfaces on which MPLS is enabled
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_mpls_label
                                                
                                                	Local label allocated for IAS/CsC application
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: nexthop_route_path
                                                
                                                	Nexthops of the resolving route
                                                	**type**\: list of  		 :py:class:`NexthopRoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, self).__init__()

                                                    self.yang_name = "nexthop-gateway-info"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("nexthop-route", ("nexthop_route", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute)), ("nexthop-route-path", ("nexthop_route_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath))])
                                                    self._leafs = OrderedDict([
                                                        ('nexthop_route_prefix_length', (YLeaf(YType.uint8, 'nexthop-route-prefix-length'), ['int'])),
                                                        ('nexthop_route_protocol', (YLeaf(YType.str, 'nexthop-route-protocol'), ['str'])),
                                                        ('nexthop_route_path_count', (YLeaf(YType.uint32, 'nexthop-route-path-count'), ['int'])),
                                                        ('nexthop_af_invalid_bits', (YLeaf(YType.uint16, 'nexthop-af-invalid-bits'), ['int'])),
                                                        ('nexthop_status', (YLeaf(YType.uint8, 'nexthop-status'), ['int'])),
                                                        ('nexthop_tableid', (YLeaf(YType.uint64, 'nexthop-tableid'), ['int'])),
                                                        ('nexthop_metric', (YLeaf(YType.uint32, 'nexthop-metric'), ['int'])),
                                                        ('last_event_type', (YLeaf(YType.enumeration, 'last-event-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhEvent', '')])),
                                                        ('last_update_type', (YLeaf(YType.enumeration, 'last-update-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpNhUpdate', '')])),
                                                        ('critical_events', (YLeaf(YType.uint32, 'critical-events'), ['int'])),
                                                        ('non_critical_events', (YLeaf(YType.uint32, 'non-critical-events'), ['int'])),
                                                        ('last_event_since', (YLeaf(YType.uint32, 'last-event-since'), ['int'])),
                                                        ('last_rib_update', (YLeaf(YType.uint32, 'last-rib-update'), ['int'])),
                                                        ('nexthop_mpls_enabled', (YLeaf(YType.boolean, 'nexthop-mpls-enabled'), ['bool'])),
                                                        ('nexthop_mpls_interfaces', (YLeaf(YType.uint32, 'nexthop-mpls-interfaces'), ['int'])),
                                                        ('nexthop_mpls_label', (YLeaf(YType.uint32, 'nexthop-mpls-label'), ['int'])),
                                                    ])
                                                    self.nexthop_route_prefix_length = None
                                                    self.nexthop_route_protocol = None
                                                    self.nexthop_route_path_count = None
                                                    self.nexthop_af_invalid_bits = None
                                                    self.nexthop_status = None
                                                    self.nexthop_tableid = None
                                                    self.nexthop_metric = None
                                                    self.last_event_type = None
                                                    self.last_update_type = None
                                                    self.critical_events = None
                                                    self.non_critical_events = None
                                                    self.last_event_since = None
                                                    self.last_rib_update = None
                                                    self.nexthop_mpls_enabled = None
                                                    self.nexthop_mpls_interfaces = None
                                                    self.nexthop_mpls_label = None

                                                    self.nexthop_route = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute()
                                                    self.nexthop_route.parent = self
                                                    self._children_name_map["nexthop_route"] = "nexthop-route"

                                                    self.nexthop_route_path = YList(self)
                                                    self._segment_path = lambda: "nexthop-gateway-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo, [u'nexthop_route_prefix_length', u'nexthop_route_protocol', u'nexthop_route_path_count', u'nexthop_af_invalid_bits', u'nexthop_status', u'nexthop_tableid', u'nexthop_metric', u'last_event_type', u'last_update_type', u'critical_events', u'non_critical_events', u'last_event_since', u'last_rib_update', u'nexthop_mpls_enabled', u'nexthop_mpls_interfaces', u'nexthop_mpls_label'], name, value)


                                                class NexthopRoute(Entity):
                                                    """
                                                    Route resolving the nethop
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, self).__init__()

                                                        self.yang_name = "nexthop-route"
                                                        self.yang_parent_name = "nexthop-gateway-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "nexthop-route"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoute.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                                class NexthopRoutePath(Entity):
                                                    """
                                                    Nexthops of the resolving route
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, self).__init__()

                                                        self.yang_name = "nexthop-route-path"
                                                        self.yang_parent_name = "nexthop-gateway-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "nexthop-route-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "nexthop-route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NexthopGatewayInfo.NexthopRoutePath.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address List
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "next-hop-af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NextHopAddressFamilies.NextHopAddressFamily.NextHopAfs.NextHopAf.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class RtSetCounters(Entity):
                                """
                                The RT\-set counter table
                                
                                .. attribute:: rt_set_counter
                                
                                	One RT\-set counter table entry
                                	**type**\: list of  		 :py:class:`RtSetCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters, self).__init__()

                                    self.yang_name = "rt-set-counters"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rt-set-counter", ("rt_set_counter", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter))])
                                    self._leafs = OrderedDict()

                                    self.rt_set_counter = YList(self)
                                    self._segment_path = lambda: "rt-set-counters"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters, [], name, value)


                                class RtSetCounter(Entity):
                                    """
                                    One RT\-set counter table entry
                                    
                                    .. attribute:: rt_set_id  (key)
                                    
                                    	RTSet ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_target_set
                                    
                                    	Route Target set
                                    	**type**\:  :py:class:`RouteTargetSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter, self).__init__()

                                        self.yang_name = "rt-set-counter"
                                        self.yang_parent_name = "rt-set-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['rt_set_id']
                                        self._child_classes = OrderedDict([("route-target-set", ("route_target_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet))])
                                        self._leafs = OrderedDict([
                                            ('rt_set_id', (YLeaf(YType.uint32, 'rt-set-id'), ['int'])),
                                        ])
                                        self.rt_set_id = None

                                        self.route_target_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet()
                                        self.route_target_set.parent = self
                                        self._children_name_map["route_target_set"] = "route-target-set"
                                        self._segment_path = lambda: "rt-set-counter" + "[rt-set-id='" + str(self.rt_set_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter, ['rt_set_id'], name, value)


                                    class RouteTargetSet(Entity):
                                        """
                                        Route Target set
                                        
                                        .. attribute:: rt_set_len
                                        
                                        	Length in bytes of set of route targets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rt_set_id
                                        
                                        	Identifier of the rtset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rt_set_net_count
                                        
                                        	Count of nets with paths with the rtset
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rt_set
                                        
                                        	Set of route targets
                                        	**type**\: list of  		 :py:class:`RtSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, self).__init__()

                                            self.yang_name = "route-target-set"
                                            self.yang_parent_name = "rt-set-counter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rt-set", ("rt_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet))])
                                            self._leafs = OrderedDict([
                                                ('rt_set_len', (YLeaf(YType.uint8, 'rt-set-len'), ['int'])),
                                                ('rt_set_id', (YLeaf(YType.uint32, 'rt-set-id'), ['int'])),
                                                ('rt_set_net_count', (YLeaf(YType.uint32, 'rt-set-net-count'), ['int'])),
                                            ])
                                            self.rt_set_len = None
                                            self.rt_set_id = None
                                            self.rt_set_net_count = None

                                            self.rt_set = YList(self)
                                            self._segment_path = lambda: "route-target-set"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet, [u'rt_set_len', u'rt_set_id', u'rt_set_net_count'], name, value)


                                        class RtSet(Entity):
                                            """
                                            Set of route targets
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, self).__init__()

                                                self.yang_name = "rt-set"
                                                self.yang_parent_name = "route-target-set"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rt-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.RtSetCounters.RtSetCounter.RouteTargetSet.RtSet, [u'entry'], name, value)


                            class BmpPaths(Entity):
                                """
                                The paths in BMP Table
                                
                                .. attribute:: bmp_path
                                
                                	A BMP path table entry
                                	**type**\: list of  		 :py:class:`BmpPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths, self).__init__()

                                    self.yang_name = "bmp-paths"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bmp-path", ("bmp_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath))])
                                    self._leafs = OrderedDict()

                                    self.bmp_path = YList(self)
                                    self._segment_path = lambda: "bmp-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths, [], name, value)


                                class BmpPath(Entity):
                                    """
                                    A BMP path table entry
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Net Version bump timestamp
                                    	**type**\:  :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp>`
                                    
                                    .. attribute:: version_age
                                    
                                    	Net Version bump age
                                    	**type**\:  :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: bmp_net_flags
                                    
                                    	Flags associated with net
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_net_version
                                    
                                    	Net's version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for the net
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\: bool
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_path
                                    
                                    	List of paths under the BMP net
                                    	**type**\: list of  		 :py:class:`BmpPath_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath, self).__init__()

                                        self.yang_name = "bmp-path"
                                        self.yang_parent_name = "bmp-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix)), ("version-timestamp", ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp)), ("version-age", ("version_age", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge)), ("bmp-path", ("bmp_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_))])
                                        self._leafs = OrderedDict([
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('bmp_net_flags', (YLeaf(YType.uint32, 'bmp-net-flags'), ['int'])),
                                            ('bmp_net_version', (YLeaf(YType.uint32, 'bmp-net-version'), ['int'])),
                                            ('num_of_path', (YLeaf(YType.uint32, 'num-of-path'), ['int'])),
                                            ('has_local_label', (YLeaf(YType.boolean, 'has-local-label'), ['bool'])),
                                            ('net_local_label', (YLeaf(YType.uint32, 'net-local-label'), ['int'])),
                                        ])
                                        self.network = None
                                        self.prefix_length = None
                                        self.af_name = None
                                        self.bmp_net_flags = None
                                        self.bmp_net_version = None
                                        self.num_of_path = None
                                        self.has_local_label = None
                                        self.net_local_label = None

                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                        self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self._children_name_map["version_timestamp"] = "version-timestamp"

                                        self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge()
                                        self.version_age.parent = self
                                        self._children_name_map["version_age"] = "version-age"

                                        self.bmp_path = YList(self)
                                        self._segment_path = lambda: "bmp-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath, ['network', 'prefix_length', u'af_name', u'bmp_net_flags', u'bmp_net_version', u'num_of_path', u'has_local_label', u'net_local_label'], name, value)


                                    class BgpPrefix(Entity):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, self).__init__()

                                            self.yang_name = "bgp-prefix"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix_length = None

                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._segment_path = lambda: "bgp-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix, [u'prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bgp-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class VersionTimestamp(Entity):
                                        """
                                        Net Version bump timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, self).__init__()

                                            self.yang_name = "version-timestamp"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class VersionAge(Entity):
                                        """
                                        Net Version bump age
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge, self).__init__()

                                            self.yang_name = "version-age"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-age"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.VersionAge, [u'seconds', u'nanoseconds'], name, value)


                                    class BmpPath_(Entity):
                                        """
                                        List of paths under the BMP net
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress>`
                                        
                                        .. attribute:: bmp_path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_path_adv_bit_map
                                        
                                        	Path's Adv bit map
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bmp_path_snd_bit_map
                                        
                                        	Path's pending snd bit map
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: bmp_nbr_bit_map
                                        
                                        	Paths Nbr bmp bit map
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path
                                        
                                        	Is path originated locally?
                                        	**type**\: bool
                                        
                                        .. attribute:: bpath_pointer
                                        
                                        	BGP Path pointer
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: received_label
                                        
                                        	Set of received label stack
                                        	**type**\: list of  		 :py:class:`ReceivedLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_, self).__init__()

                                            self.yang_name = "bmp-path"
                                            self.yang_parent_name = "bmp-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress)), ("received-label", ("received_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel))])
                                            self._leafs = OrderedDict([
                                                ('bmp_path_flags', (YLeaf(YType.uint32, 'bmp-path-flags'), ['int'])),
                                                ('bmp_path_adv_bit_map', (YLeaf(YType.uint16, 'bmp-path-adv-bit-map'), ['int'])),
                                                ('bmp_path_snd_bit_map', (YLeaf(YType.uint16, 'bmp-path-snd-bit-map'), ['int'])),
                                                ('bmp_nbr_bit_map', (YLeaf(YType.uint32, 'bmp-nbr-bit-map'), ['int'])),
                                                ('local_path', (YLeaf(YType.boolean, 'local-path'), ['bool'])),
                                                ('bpath_pointer', (YLeaf(YType.uint64, 'bpath-pointer'), ['int'])),
                                            ])
                                            self.bmp_path_flags = None
                                            self.bmp_path_adv_bit_map = None
                                            self.bmp_path_snd_bit_map = None
                                            self.bmp_nbr_bit_map = None
                                            self.local_path = None
                                            self.bpath_pointer = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.received_label = YList(self)
                                            self._segment_path = lambda: "bmp-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_, [u'bmp_path_flags', u'bmp_path_adv_bit_map', u'bmp_path_snd_bit_map', u'bmp_nbr_bit_map', u'local_path', u'bpath_pointer'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class ReceivedLabel(Entity):
                                            """
                                            Set of received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel, self).__init__()

                                                self.yang_name = "received-label"
                                                self.yang_parent_name = "bmp-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "received-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.BmpPaths.BmpPath.BmpPath_.ReceivedLabel, [u'entry'], name, value)


                            class UpdateGenerationUpdateGroups(Entity):
                                """
                                Update generation for all update\-groups
                                
                                .. attribute:: update_generation_update_group
                                
                                	Update generation for update\-group
                                	**type**\: list of  		 :py:class:`UpdateGenerationUpdateGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups, self).__init__()

                                    self.yang_name = "update-generation-update-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-generation-update-group", ("update_generation_update_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup))])
                                    self._leafs = OrderedDict()

                                    self.update_generation_update_group = YList(self)
                                    self._segment_path = lambda: "update-generation-update-groups"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups, [], name, value)


                                class UpdateGenerationUpdateGroup(Entity):
                                    """
                                    Update generation for update\-group
                                    
                                    .. attribute:: update_group_index  (key)
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_timer_start_timestamp
                                    
                                    	Last update timer start time
                                    	**type**\:  :py:class:`LastUpdateTimerStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp>`
                                    
                                    .. attribute:: last_update_timer_stop_timestamp
                                    
                                    	Last update timer stop time
                                    	**type**\:  :py:class:`LastUpdateTimerStopTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp>`
                                    
                                    .. attribute:: last_update_timer_expiry_timestamp
                                    
                                    	Last update timer expiry time
                                    	**type**\:  :py:class:`LastUpdateTimerExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp>`
                                    
                                    .. attribute:: last_update_timer_remaining_value
                                    
                                    	Update timer remaining time
                                    	**type**\:  :py:class:`LastUpdateTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue>`
                                    
                                    .. attribute:: last_update_timer_delay_value
                                    
                                    	Last update timer delay value
                                    	**type**\:  :py:class:`LastUpdateTimerDelayValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue>`
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics>`
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: neighbor_session_af_name
                                    
                                    	Neighbor session address family
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_flags2
                                    
                                    	Update\-group internal flags2
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue Messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue Size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_sub_group_count
                                    
                                    	Sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_throttled_count
                                    
                                    	Throttled sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_count
                                    
                                    	Refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_throttled_count
                                    
                                    	Throttled refresh sub\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_count
                                    
                                    	Filter\-group count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_leaving_count
                                    
                                    	Count of neighbors leaving the update\-group
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_generation_recovery_pending
                                    
                                    	Is update generation recovery pending
                                    	**type**\: bool
                                    
                                    .. attribute:: last_update_timer_expiry_age
                                    
                                    	Time since last update timer expiry event
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_update_timer_running
                                    
                                    	Is update timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: perm_pelem_encountered
                                    
                                    	Count of Perm Pelems seen by updgen
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_allowed
                                    
                                    	Count of Perm Pelems allowed by updgen
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_not_allowed
                                    
                                    	Count of Perm Pelems not allowed by updgen
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_exp_wdr
                                    
                                    	Count of Perm Pelems explicitly wdrn by updgen
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: perm_pelem_spur_wdr
                                    
                                    	Count of Perm Pelems Spurious withdraws by updgen
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_permanent
                                    
                                    	Permanent UG check
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, self).__init__()

                                        self.yang_name = "update-generation-update-group"
                                        self.yang_parent_name = "update-generation-update-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['update_group_index']
                                        self._child_classes = OrderedDict([("last-update-timer-start-timestamp", ("last_update_timer_start_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp)), ("last-update-timer-stop-timestamp", ("last_update_timer_stop_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp)), ("last-update-timer-expiry-timestamp", ("last_update_timer_expiry_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp)), ("last-update-timer-remaining-value", ("last_update_timer_remaining_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue)), ("last-update-timer-delay-value", ("last_update_timer_delay_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics))])
                                        self._leafs = OrderedDict([
                                            ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                            ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('neighbor_session_af_name', (YLeaf(YType.uint8, 'neighbor-session-af-name'), ['int'])),
                                            ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                            ('update_group_flags2', (YLeaf(YType.uint32, 'update-group-flags2'), ['int'])),
                                            ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                            ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                            ('update_sub_group_count', (YLeaf(YType.uint32, 'update-sub-group-count'), ['int'])),
                                            ('sub_group_throttled_count', (YLeaf(YType.uint32, 'sub-group-throttled-count'), ['int'])),
                                            ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                            ('refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'refresh-sub-group-throttled-count'), ['int'])),
                                            ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                            ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                            ('neighbor_leaving_count', (YLeaf(YType.uint32, 'neighbor-leaving-count'), ['int'])),
                                            ('update_generation_recovery_pending', (YLeaf(YType.boolean, 'update-generation-recovery-pending'), ['bool'])),
                                            ('last_update_timer_expiry_age', (YLeaf(YType.uint32, 'last-update-timer-expiry-age'), ['int'])),
                                            ('is_update_timer_running', (YLeaf(YType.boolean, 'is-update-timer-running'), ['bool'])),
                                            ('perm_pelem_encountered', (YLeaf(YType.uint32, 'perm-pelem-encountered'), ['int'])),
                                            ('perm_pelem_allowed', (YLeaf(YType.uint32, 'perm-pelem-allowed'), ['int'])),
                                            ('perm_pelem_not_allowed', (YLeaf(YType.uint32, 'perm-pelem-not-allowed'), ['int'])),
                                            ('perm_pelem_exp_wdr', (YLeaf(YType.uint32, 'perm-pelem-exp-wdr'), ['int'])),
                                            ('perm_pelem_spur_wdr', (YLeaf(YType.uint32, 'perm-pelem-spur-wdr'), ['int'])),
                                            ('is_permanent', (YLeaf(YType.boolean, 'is-permanent'), ['bool'])),
                                        ])
                                        self.update_group_index = None
                                        self.process_id = None
                                        self.update_vrf_name = None
                                        self.update_group_af_name = None
                                        self.neighbor_session_af_name = None
                                        self.update_group_index_xr = None
                                        self.update_group_flags2 = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.update_sub_group_count = None
                                        self.sub_group_throttled_count = None
                                        self.refresh_sub_group_count = None
                                        self.refresh_sub_group_throttled_count = None
                                        self.filter_group_count = None
                                        self.neighbor_count = None
                                        self.neighbor_leaving_count = None
                                        self.update_generation_recovery_pending = None
                                        self.last_update_timer_expiry_age = None
                                        self.is_update_timer_running = None
                                        self.perm_pelem_encountered = None
                                        self.perm_pelem_allowed = None
                                        self.perm_pelem_not_allowed = None
                                        self.perm_pelem_exp_wdr = None
                                        self.perm_pelem_spur_wdr = None
                                        self.is_permanent = None

                                        self.last_update_timer_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp()
                                        self.last_update_timer_start_timestamp.parent = self
                                        self._children_name_map["last_update_timer_start_timestamp"] = "last-update-timer-start-timestamp"

                                        self.last_update_timer_stop_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp()
                                        self.last_update_timer_stop_timestamp.parent = self
                                        self._children_name_map["last_update_timer_stop_timestamp"] = "last-update-timer-stop-timestamp"

                                        self.last_update_timer_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp()
                                        self.last_update_timer_expiry_timestamp.parent = self
                                        self._children_name_map["last_update_timer_expiry_timestamp"] = "last-update-timer-expiry-timestamp"

                                        self.last_update_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue()
                                        self.last_update_timer_remaining_value.parent = self
                                        self._children_name_map["last_update_timer_remaining_value"] = "last-update-timer-remaining-value"

                                        self.last_update_timer_delay_value = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue()
                                        self.last_update_timer_delay_value.parent = self
                                        self._children_name_map["last_update_timer_delay_value"] = "last-update-timer-delay-value"

                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._segment_path = lambda: "update-generation-update-group" + "[update-group-index='" + str(self.update_group_index) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup, ['update_group_index', u'process_id', u'update_vrf_name', u'update_group_af_name', u'neighbor_session_af_name', u'update_group_index_xr', u'update_group_flags2', u'update_out_queue_messages', u'update_out_queue_size', u'update_sub_group_count', u'sub_group_throttled_count', u'refresh_sub_group_count', u'refresh_sub_group_throttled_count', u'filter_group_count', u'neighbor_count', u'neighbor_leaving_count', u'update_generation_recovery_pending', u'last_update_timer_expiry_age', u'is_update_timer_running', u'perm_pelem_encountered', u'perm_pelem_allowed', u'perm_pelem_not_allowed', u'perm_pelem_exp_wdr', u'perm_pelem_spur_wdr', u'is_permanent'], name, value)


                                    class LastUpdateTimerStartTimestamp(Entity):
                                        """
                                        Last update timer start time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-start-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-timer-start-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateTimerStopTimestamp(Entity):
                                        """
                                        Last update timer stop time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-stop-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-timer-stop-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerStopTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateTimerExpiryTimestamp(Entity):
                                        """
                                        Last update timer expiry time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, self).__init__()

                                            self.yang_name = "last-update-timer-expiry-timestamp"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-timer-expiry-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerExpiryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateTimerRemainingValue(Entity):
                                        """
                                        Update timer remaining time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, self).__init__()

                                            self.yang_name = "last-update-timer-remaining-value"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-timer-remaining-value"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerRemainingValue, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateTimerDelayValue(Entity):
                                        """
                                        Last update timer delay value
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, self).__init__()

                                            self.yang_name = "last-update-timer-delay-value"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-timer-delay-value"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.LastUpdateTimerDelayValue, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-update-group"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                            ])
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_size_high = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_cleared = None
                                            self.last_update_discard_age = None
                                            self.last_update_cleard_age = None
                                            self.update_throttle_count = None
                                            self.last_update_throttle_age = None
                                            self.update_recovery_count = None
                                            self.last_update_recovery_age = None
                                            self.update_memory_allocation_fail_count = None
                                            self.last_update_memory_allocation_fail_age = None

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._segment_path = lambda: "update-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-discard-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-cleared-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-throttle-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-recovery-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationUpdateGroups.UpdateGenerationUpdateGroup.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class UpdateGenerationFilterGroups(Entity):
                                """
                                Update generation for all filter\-groups under
                                a sub\-group
                                
                                .. attribute:: update_generation_filter_group
                                
                                	Update generation for filter\-group
                                	**type**\: list of  		 :py:class:`UpdateGenerationFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups, self).__init__()

                                    self.yang_name = "update-generation-filter-groups"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-generation-filter-group", ("update_generation_filter_group", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup))])
                                    self._leafs = OrderedDict()

                                    self.update_generation_filter_group = YList(self)
                                    self._segment_path = lambda: "update-generation-filter-groups"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups, [], name, value)


                                class UpdateGenerationFilterGroup(Entity):
                                    """
                                    Update generation for filter\-group
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_filter_group_index
                                    
                                    	Parent Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id_xr
                                    
                                    	Sub\-group identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_index
                                    
                                    	Parent Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: parent_sub_group_id
                                    
                                    	Parent Sub\-group identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_count
                                    
                                    	Neighbor count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, self).__init__()

                                        self.yang_name = "update-generation-filter-group"
                                        self.yang_parent_name = "update-generation-filter-groups"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                            ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                            ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                            ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                            ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('update_filter_group_index', (YLeaf(YType.uint32, 'update-filter-group-index'), ['int'])),
                                            ('parent_filter_group_index', (YLeaf(YType.uint32, 'parent-filter-group-index'), ['int'])),
                                            ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                            ('sub_group_id_xr', (YLeaf(YType.uint32, 'sub-group-id-xr'), ['int'])),
                                            ('parent_sub_group_index', (YLeaf(YType.uint32, 'parent-sub-group-index'), ['int'])),
                                            ('parent_sub_group_id', (YLeaf(YType.uint32, 'parent-sub-group-id'), ['int'])),
                                            ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                            ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                        ])
                                        self.update_group_index = None
                                        self.sub_group_index = None
                                        self.sub_group_id = None
                                        self.filter_group_index = None
                                        self.process_id = None
                                        self.update_vrf_name = None
                                        self.update_group_af_name = None
                                        self.update_filter_group_index = None
                                        self.parent_filter_group_index = None
                                        self.sub_group_index_xr = None
                                        self.sub_group_id_xr = None
                                        self.parent_sub_group_index = None
                                        self.parent_sub_group_id = None
                                        self.update_group_index_xr = None
                                        self.neighbor_count = None
                                        self._segment_path = lambda: "update-generation-filter-group"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationFilterGroups.UpdateGenerationFilterGroup, ['update_group_index', 'sub_group_index', 'sub_group_id', 'filter_group_index', u'process_id', u'update_vrf_name', u'update_group_af_name', u'update_filter_group_index', u'parent_filter_group_index', u'sub_group_index_xr', u'sub_group_id_xr', u'parent_sub_group_index', u'parent_sub_group_id', u'update_group_index_xr', u'neighbor_count'], name, value)


                            class Networks(Entity):
                                """
                                The BGP Network Table
                                
                                .. attribute:: network
                                
                                	A BGP Network table entry
                                	**type**\: list of  		 :py:class:`Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks, self).__init__()

                                    self.yang_name = "networks"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("network", ("network", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network))])
                                    self._leafs = OrderedDict()

                                    self.network = YList(self)
                                    self._segment_path = lambda: "networks"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks, [], name, value)


                                class Network(Entity):
                                    """
                                    A BGP Network table entry
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bgp_prefix
                                    
                                    	BGP prefix
                                    	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix>`
                                    
                                    .. attribute:: version_timestamp
                                    
                                    	Version timestamp
                                    	**type**\:  :py:class:`VersionTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp>`
                                    
                                    .. attribute:: version_age
                                    
                                    	Version age
                                    	**type**\:  :py:class:`VersionAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: has_inconsistent_paths
                                    
                                    	Net has inconsistent paths
                                    	**type**\: bool
                                    
                                    .. attribute:: is_net_aggregation_suppressed
                                    
                                    	Net suppressed due to aggregation
                                    	**type**\: bool
                                    
                                    .. attribute:: is_net_ldp_signaled
                                    
                                    	L2VPN Net LDP signaled  aggregation
                                    	**type**\: bool
                                    
                                    .. attribute:: table_version
                                    
                                    	Table version # for net
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: table_brib_version
                                    
                                    	Table version # for updates
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertisedto_pe
                                    
                                    	Net could be advertised                          to PE peers
                                    	**type**\: bool
                                    
                                    .. attribute:: has_local_label
                                    
                                    	Net has local label
                                    	**type**\: bool
                                    
                                    .. attribute:: net_local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_local_label_rewrite
                                    
                                    	Net label has rewrite
                                    	**type**\: bool
                                    
                                    .. attribute:: net_local_label_srgb
                                    
                                    	Net label allocated fromSegment routing global block
                                    	**type**\: bool
                                    
                                    .. attribute:: has_lbl_retained
                                    
                                    	Net has label retained
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: net_flags
                                    
                                    	Flags associated with                            net
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_extended_flags
                                    
                                    	Net extended flags
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: net_multipath
                                    
                                    	Net has multipaths
                                    	**type**\: bool
                                    
                                    .. attribute:: net_eibgp_multipath
                                    
                                    	Net has EIBGP multipaths
                                    	**type**\: bool
                                    
                                    .. attribute:: net_backup_available
                                    
                                    	Net has backup path
                                    	**type**\: bool
                                    
                                    .. attribute:: net_backup_label_rewrite_available
                                    
                                    	Net has label rewrite for backup path
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_failed
                                    
                                    	RIB install failed
                                    	**type**\: bool
                                    
                                    .. attribute:: gateway_array
                                    
                                    	Gateway array ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: resilient_nexthop_set
                                    
                                    	Resilient nexthop set ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_permanent_network
                                    
                                    	Permanent Network
                                    	**type**\: bool
                                    
                                    .. attribute:: num_of_path
                                    
                                    	Number of path for this net
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bit
                                    
                                    	Bit
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: flags
                                    
                                    	Flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: has_s_rv6sid_allocated
                                    
                                    	Net has SRv6 SID allocated
                                    	**type**\: bool
                                    
                                    .. attribute:: srv6sid_address
                                    
                                    	SRv6 SID address value
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: srv6sid_address_len
                                    
                                    	SRv6 SID address Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_peers_advertised_to
                                    
                                    	Local peers that this prefix has been advertised to
                                    	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo>`
                                    
                                    .. attribute:: pe_peers_advertised_to
                                    
                                    	PE peers that this prefix has been advertised to
                                    	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo>`
                                    
                                    .. attribute:: best_path_orr_bitfield
                                    
                                    	ORR Best path Bitfields
                                    	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield>`
                                    
                                    .. attribute:: add_path_orr_bitfield
                                    
                                    	ORR Add path Bitfields
                                    	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield>`
                                    
                                    .. attribute:: local_process_instance_path
                                    
                                    	Local (to process instance) paths for this net 
                                    	**type**\: list of  		 :py:class:`LocalProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath>`
                                    
                                    .. attribute:: active_process_instance_path
                                    
                                    	Active's paths for this net 
                                    	**type**\: list of  		 :py:class:`ActiveProcessInstancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath>`
                                    
                                    .. attribute:: local_path_element
                                    
                                    	Local path element list
                                    	**type**\: list of  		 :py:class:`LocalPathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement>`
                                    
                                    .. attribute:: active_path_element
                                    
                                    	Path element list received from Active inst
                                    	**type**\: list of  		 :py:class:`ActivePathElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network, self).__init__()

                                        self.yang_name = "network"
                                        self.yang_parent_name = "networks"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix)), ("version-timestamp", ("version_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp)), ("version-age", ("version_age", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield)), ("local-process-instance-path", ("local_process_instance_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath)), ("active-process-instance-path", ("active_process_instance_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath)), ("local-path-element", ("local_path_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement)), ("active-path-element", ("active_path_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('has_inconsistent_paths', (YLeaf(YType.boolean, 'has-inconsistent-paths'), ['bool'])),
                                            ('is_net_aggregation_suppressed', (YLeaf(YType.boolean, 'is-net-aggregation-suppressed'), ['bool'])),
                                            ('is_net_ldp_signaled', (YLeaf(YType.boolean, 'is-net-ldp-signaled'), ['bool'])),
                                            ('table_version', (YLeaf(YType.uint32, 'table-version'), ['int'])),
                                            ('table_brib_version', (YLeaf(YType.uint32, 'table-brib-version'), ['int'])),
                                            ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                            ('has_local_label', (YLeaf(YType.boolean, 'has-local-label'), ['bool'])),
                                            ('net_local_label', (YLeaf(YType.uint32, 'net-local-label'), ['int'])),
                                            ('net_local_label_rewrite', (YLeaf(YType.boolean, 'net-local-label-rewrite'), ['bool'])),
                                            ('net_local_label_srgb', (YLeaf(YType.boolean, 'net-local-label-srgb'), ['bool'])),
                                            ('has_lbl_retained', (YLeaf(YType.boolean, 'has-lbl-retained'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('net_flags', (YLeaf(YType.uint32, 'net-flags'), ['int'])),
                                            ('net_extended_flags', (YLeaf(YType.uint32, 'net-extended-flags'), ['int'])),
                                            ('net_multipath', (YLeaf(YType.boolean, 'net-multipath'), ['bool'])),
                                            ('net_eibgp_multipath', (YLeaf(YType.boolean, 'net-eibgp-multipath'), ['bool'])),
                                            ('net_backup_available', (YLeaf(YType.boolean, 'net-backup-available'), ['bool'])),
                                            ('net_backup_label_rewrite_available', (YLeaf(YType.boolean, 'net-backup-label-rewrite-available'), ['bool'])),
                                            ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                            ('gateway_array', (YLeaf(YType.uint32, 'gateway-array'), ['int'])),
                                            ('resilient_nexthop_set', (YLeaf(YType.uint32, 'resilient-nexthop-set'), ['int'])),
                                            ('is_permanent_network', (YLeaf(YType.boolean, 'is-permanent-network'), ['bool'])),
                                            ('num_of_path', (YLeaf(YType.uint32, 'num-of-path'), ['int'])),
                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                            ('bit', (YLeaf(YType.uint16, 'bit'), ['int'])),
                                            ('flags', (YLeaf(YType.uint8, 'flags'), ['int'])),
                                            ('has_s_rv6sid_allocated', (YLeaf(YType.boolean, 'has-s-rv6sid-allocated'), ['bool'])),
                                            ('srv6sid_address', (YLeaf(YType.str, 'srv6sid-address'), ['str'])),
                                            ('srv6sid_address_len', (YLeaf(YType.uint32, 'srv6sid-address-len'), ['int'])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.has_inconsistent_paths = None
                                        self.is_net_aggregation_suppressed = None
                                        self.is_net_ldp_signaled = None
                                        self.table_version = None
                                        self.table_brib_version = None
                                        self.advertisedto_pe = None
                                        self.has_local_label = None
                                        self.net_local_label = None
                                        self.net_local_label_rewrite = None
                                        self.net_local_label_srgb = None
                                        self.has_lbl_retained = None
                                        self.route_distinguisher = None
                                        self.vrf_name = None
                                        self.net_flags = None
                                        self.net_extended_flags = None
                                        self.net_multipath = None
                                        self.net_eibgp_multipath = None
                                        self.net_backup_available = None
                                        self.net_backup_label_rewrite_available = None
                                        self.rib_failed = None
                                        self.gateway_array = None
                                        self.resilient_nexthop_set = None
                                        self.is_permanent_network = None
                                        self.num_of_path = None
                                        self.version = None
                                        self.bit = None
                                        self.flags = None
                                        self.has_s_rv6sid_allocated = None
                                        self.srv6sid_address = None
                                        self.srv6sid_address_len = None

                                        self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix()
                                        self.bgp_prefix.parent = self
                                        self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                        self.version_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp()
                                        self.version_timestamp.parent = self
                                        self._children_name_map["version_timestamp"] = "version-timestamp"

                                        self.version_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge()
                                        self.version_age.parent = self
                                        self._children_name_map["version_age"] = "version-age"

                                        self.local_peers_advertised_to = YList(self)
                                        self.pe_peers_advertised_to = YList(self)
                                        self.best_path_orr_bitfield = YList(self)
                                        self.add_path_orr_bitfield = YList(self)
                                        self.local_process_instance_path = YList(self)
                                        self.active_process_instance_path = YList(self)
                                        self.local_path_element = YList(self)
                                        self.active_path_element = YList(self)
                                        self._segment_path = lambda: "network"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network, ['rd', 'network', 'prefix_length', u'af_name', u'process_instance_id', u'has_inconsistent_paths', u'is_net_aggregation_suppressed', u'is_net_ldp_signaled', u'table_version', u'table_brib_version', u'advertisedto_pe', u'has_local_label', u'net_local_label', u'net_local_label_rewrite', u'net_local_label_srgb', u'has_lbl_retained', u'route_distinguisher', u'vrf_name', u'net_flags', u'net_extended_flags', u'net_multipath', u'net_eibgp_multipath', u'net_backup_available', u'net_backup_label_rewrite_available', u'rib_failed', u'gateway_array', u'resilient_nexthop_set', u'is_permanent_network', u'num_of_path', u'version', u'bit', u'flags', u'has_s_rv6sid_allocated', u'srv6sid_address', u'srv6sid_address_len'], name, value)


                                    class BgpPrefix(Entity):
                                        """
                                        BGP prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix, self).__init__()

                                            self.yang_name = "bgp-prefix"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix_length = None

                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._segment_path = lambda: "bgp-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix, [u'prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bgp-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class VersionTimestamp(Entity):
                                        """
                                        Version timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp, self).__init__()

                                            self.yang_name = "version-timestamp"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class VersionAge(Entity):
                                        """
                                        Version age
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge, self).__init__()

                                            self.yang_name = "version-age"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "version-age"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.VersionAge, [u'seconds', u'nanoseconds'], name, value)


                                    class LocalPeersAdvertisedTo(Entity):
                                        """
                                        Local peers that this prefix has been advertised
                                        to
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\: bool
                                        
                                        .. attribute:: update_group_afi
                                        
                                        	AFI of the Update group it is advertised to
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, self).__init__()

                                            self.yang_name = "local-peers-advertised-to"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ])
                                            self.is_neighbor = None
                                            self.update_group_afi = None
                                            self.update_group_number = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "local-peers-advertised-to"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "local-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PePeersAdvertisedTo(Entity):
                                        """
                                        PE peers that this prefix has been advertised to
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress>`
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\: bool
                                        
                                        .. attribute:: update_group_afi
                                        
                                        	AFI of the Update group it is advertised to
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, self).__init__()

                                            self.yang_name = "pe-peers-advertised-to"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ])
                                            self.is_neighbor = None
                                            self.update_group_afi = None
                                            self.update_group_number = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "pe-peers-advertised-to"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "pe-peers-advertised-to"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class BestPathOrrBitfield(Entity):
                                        """
                                        ORR Best path Bitfields
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\: bool
                                        
                                        .. attribute:: update_group_afi
                                        
                                        	AFI of the Update group it is advertised to
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield, self).__init__()

                                            self.yang_name = "best-path-orr-bitfield"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ])
                                            self.is_neighbor = None
                                            self.update_group_afi = None
                                            self.update_group_number = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "best-path-orr-bitfield"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "best-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AddPathOrrBitfield(Entity):
                                        """
                                        ORR Add path Bitfields
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress>`
                                        
                                        .. attribute:: is_neighbor
                                        
                                        	Entry is a neighbor (not an update group)
                                        	**type**\: bool
                                        
                                        .. attribute:: update_group_afi
                                        
                                        	AFI of the Update group it is advertised to
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield, self).__init__()

                                            self.yang_name = "add-path-orr-bitfield"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                            ])
                                            self.is_neighbor = None
                                            self.update_group_afi = None
                                            self.update_group_number = None

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"
                                            self._segment_path = lambda: "add-path-orr-bitfield"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "add-path-orr-bitfield"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class LocalProcessInstancePath(Entity):
                                        """
                                        Local (to process instance) paths for this net 
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath, self).__init__()

                                            self.yang_name = "local-process-instance-path"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "local-process-instance-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "local-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class ActiveProcessInstancePath(Entity):
                                        """
                                        Active's paths for this net 
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, self).__init__()

                                            self.yang_name = "active-process-instance-path"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "active-process-instance-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "active-process-instance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActiveProcessInstancePath.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class LocalPathElement(Entity):
                                        """
                                        Local path element list
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:  :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:  :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement, self).__init__()

                                            self.yang_name = "local-path-element"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("pelem-path-nexthop", ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel)), ("pelem-path-neighbor-addr", ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr))])
                                            self._leafs = OrderedDict([
                                                ('pelem_path_id', (YLeaf(YType.uint32, 'pelem-path-id'), ['int'])),
                                                ('pelem_version', (YLeaf(YType.uint32, 'pelem-version'), ['int'])),
                                                ('pelem_flags', (YLeaf(YType.uint32, 'pelem-flags'), ['int'])),
                                                ('pelem_gw_metric', (YLeaf(YType.uint32, 'pelem-gw-metric'), ['int'])),
                                                ('pelem_path_flags', (YLeaf(YType.uint64, 'pelem-path-flags'), ['int'])),
                                                ('pelem_path_peer_path_id', (YLeaf(YType.uint32, 'pelem-path-peer-path-id'), ['int'])),
                                                ('pelem_table_attr_version', (YLeaf(YType.uint32, 'pelem-table-attr-version'), ['int'])),
                                                ('pelem_path_table_attr_version', (YLeaf(YType.uint32, 'pelem-path-table-attr-version'), ['int'])),
                                                ('pelem_no_bestpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-bestpath-table-attr-version'), ['int'])),
                                                ('pelem_no_addpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-addpath-table-attr-version'), ['int'])),
                                                ('is_perm_path_pelem', (YLeaf(YType.boolean, 'is-perm-path-pelem'), ['bool'])),
                                            ])
                                            self.pelem_path_id = None
                                            self.pelem_version = None
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.is_perm_path_pelem = None

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._segment_path = lambda: "local-path-element"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement, [u'pelem_path_id', u'pelem_version', u'pelem_flags', u'pelem_gw_metric', u'pelem_path_flags', u'pelem_path_peer_path_id', u'pelem_table_attr_version', u'pelem_path_table_attr_version', u'pelem_no_bestpath_table_attr_version', u'pelem_no_addpath_table_attr_version', u'is_perm_path_pelem'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "pelem-path-nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNexthop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "local-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.LocalPathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class ActivePathElement(Entity):
                                        """
                                        Path element list received from Active inst
                                        
                                        .. attribute:: pelem_path_nexthop
                                        
                                        	Path nexthop address
                                        	**type**\:  :py:class:`PelemPathNexthop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel>`
                                        
                                        .. attribute:: pelem_path_neighbor_addr
                                        
                                        	Path neighbor address
                                        	**type**\:  :py:class:`PelemPathNeighborAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr>`
                                        
                                        .. attribute:: pelem_path_id
                                        
                                        	Local Path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_version
                                        
                                        	Version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_flags
                                        
                                        	Flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_gw_metric
                                        
                                        	Gateway metric
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_flags
                                        
                                        	Path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: pelem_path_peer_path_id
                                        
                                        	Path peer path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_table_attr_version
                                        
                                        	Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_path_table_attr_version
                                        
                                        	Path Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_bestpath_table_attr_version
                                        
                                        	No\-bestpath Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pelem_no_addpath_table_attr_version
                                        
                                        	No\-addpath Table Attr version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_perm_path_pelem
                                        
                                        	Pelem for permanent path
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement, self).__init__()

                                            self.yang_name = "active-path-element"
                                            self.yang_parent_name = "network"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("pelem-path-nexthop", ("pelem_path_nexthop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel)), ("pelem-path-neighbor-addr", ("pelem_path_neighbor_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr))])
                                            self._leafs = OrderedDict([
                                                ('pelem_path_id', (YLeaf(YType.uint32, 'pelem-path-id'), ['int'])),
                                                ('pelem_version', (YLeaf(YType.uint32, 'pelem-version'), ['int'])),
                                                ('pelem_flags', (YLeaf(YType.uint32, 'pelem-flags'), ['int'])),
                                                ('pelem_gw_metric', (YLeaf(YType.uint32, 'pelem-gw-metric'), ['int'])),
                                                ('pelem_path_flags', (YLeaf(YType.uint64, 'pelem-path-flags'), ['int'])),
                                                ('pelem_path_peer_path_id', (YLeaf(YType.uint32, 'pelem-path-peer-path-id'), ['int'])),
                                                ('pelem_table_attr_version', (YLeaf(YType.uint32, 'pelem-table-attr-version'), ['int'])),
                                                ('pelem_path_table_attr_version', (YLeaf(YType.uint32, 'pelem-path-table-attr-version'), ['int'])),
                                                ('pelem_no_bestpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-bestpath-table-attr-version'), ['int'])),
                                                ('pelem_no_addpath_table_attr_version', (YLeaf(YType.uint32, 'pelem-no-addpath-table-attr-version'), ['int'])),
                                                ('is_perm_path_pelem', (YLeaf(YType.boolean, 'is-perm-path-pelem'), ['bool'])),
                                            ])
                                            self.pelem_path_id = None
                                            self.pelem_version = None
                                            self.pelem_flags = None
                                            self.pelem_gw_metric = None
                                            self.pelem_path_flags = None
                                            self.pelem_path_peer_path_id = None
                                            self.pelem_table_attr_version = None
                                            self.pelem_path_table_attr_version = None
                                            self.pelem_no_bestpath_table_attr_version = None
                                            self.pelem_no_addpath_table_attr_version = None
                                            self.is_perm_path_pelem = None

                                            self.pelem_path_nexthop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop()
                                            self.pelem_path_nexthop.parent = self
                                            self._children_name_map["pelem_path_nexthop"] = "pelem-path-nexthop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.pelem_path_neighbor_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr()
                                            self.pelem_path_neighbor_addr.parent = self
                                            self._children_name_map["pelem_path_neighbor_addr"] = "pelem-path-neighbor-addr"
                                            self._segment_path = lambda: "active-path-element"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement, [u'pelem_path_id', u'pelem_version', u'pelem_flags', u'pelem_gw_metric', u'pelem_path_flags', u'pelem_path_peer_path_id', u'pelem_table_attr_version', u'pelem_path_table_attr_version', u'pelem_no_bestpath_table_attr_version', u'pelem_no_addpath_table_attr_version', u'is_perm_path_pelem'], name, value)


                                        class PelemPathNexthop(Entity):
                                            """
                                            Path nexthop address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, self).__init__()

                                                self.yang_name = "pelem-path-nexthop"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "pelem-path-nexthop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-nexthop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNexthop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class PelemPathNeighborAddr(Entity):
                                            """
                                            Path neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, self).__init__()

                                                self.yang_name = "pelem-path-neighbor-addr"
                                                self.yang_parent_name = "active-path-element"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "pelem-path-neighbor-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "pelem-path-neighbor-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Networks.Network.ActivePathElement.PelemPathNeighborAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class PathTable(Entity):
                                """
                                The BGP Path Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable, self).__init__()

                                    self.yang_name = "path-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path))])
                                    self._leafs = OrderedDict()

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: orig_source_rd
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertised_neighbor
                                    
                                    	Advertised Neighbor Address. Valid in the case of Advertised table
                                    	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor>`
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: original_source_route_distinguisher
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\: str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                            ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                            ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                            ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                            ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                            ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                            ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.orig_source_rd = None
                                        self.path_id = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.label_oor = None
                                        self.label_oor_version = None
                                        self.label_fail = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.original_source_route_distinguisher = None
                                        self.prefix_version = None
                                        self.vrf_name = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None

                                        self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor()
                                        self.advertised_neighbor.parent = self
                                        self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                    class AdvertisedNeighbor(Entity):
                                        """
                                        Advertised Neighbor Address. Valid in the case
                                        of Advertised table
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor, self).__init__()

                                            self.yang_name = "advertised-neighbor"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "advertised-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied. In the
                                        case of path type received\-only this will be
                                        attributes before inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class Epes(Entity):
                                """
                                The BGP Egress Engineering table
                                
                                .. attribute:: epe
                                
                                	A BGP Egress Engineering table entry
                                	**type**\: list of  		 :py:class:`Epe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes, self).__init__()

                                    self.yang_name = "epes"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("epe", ("epe", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe))])
                                    self._leafs = OrderedDict()

                                    self.epe = YList(self)
                                    self._segment_path = lambda: "epes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes, [], name, value)


                                class Epe(Entity):
                                    """
                                    A BGP Egress Engineering table entry
                                    
                                    .. attribute:: epe_key_length
                                    
                                    	Epe Key Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_set_key
                                    
                                    	Epe Set Key
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: epe_local_address
                                    
                                    	Local address
                                    	**type**\:  :py:class:`EpeLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress>`
                                    
                                    .. attribute:: epe_next_hop
                                    
                                    	Nexthop address
                                    	**type**\:  :py:class:`EpeNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop>`
                                    
                                    .. attribute:: epe_key_length_xr
                                    
                                    	EPE key length in bits
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_version
                                    
                                    	EPE object's version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_flags
                                    
                                    	EPE object's flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: epe_local_asn
                                    
                                    	Local AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_remote_asn
                                    
                                    	Remote AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_remote_router_id
                                    
                                    	Remote router id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_local_router_id
                                    
                                    	Local router id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label
                                    
                                    	Label assigned to the RPCnext\-hop set
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ref_count
                                    
                                    	Refcount
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rpc_set_object_id
                                    
                                    	RPC set object ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: epe_key
                                    
                                    	Key of EPE object
                                    	**type**\: list of  		 :py:class:`EpeKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeKey>`
                                    
                                    .. attribute:: nexthop_id
                                    
                                    	List of nexthop ID of EPE
                                    	**type**\: list of  		 :py:class:`NexthopId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.NexthopId>`
                                    
                                    .. attribute:: ifhandle
                                    
                                    	List of ifhandle of EPE
                                    	**type**\: list of  		 :py:class:`Ifhandle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle>`
                                    
                                    .. attribute:: first_hop
                                    
                                    	List of firsthops of EPE
                                    	**type**\: list of  		 :py:class:`FirstHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe, self).__init__()

                                        self.yang_name = "epe"
                                        self.yang_parent_name = "epes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("epe-local-address", ("epe_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress)), ("epe-next-hop", ("epe_next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop)), ("epe-key", ("epe_key", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeKey)), ("nexthop-id", ("nexthop_id", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.NexthopId)), ("ifhandle", ("ifhandle", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle)), ("first-hop", ("first_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop))])
                                        self._leafs = OrderedDict([
                                            ('epe_key_length', (YLeaf(YType.uint32, 'epe-key-length'), ['int'])),
                                            ('epe_set_key', (YLeaf(YType.str, 'epe-set-key'), ['str'])),
                                            ('epe_key_length_xr', (YLeaf(YType.uint8, 'epe-key-length-xr'), ['int'])),
                                            ('epe_version', (YLeaf(YType.uint32, 'epe-version'), ['int'])),
                                            ('epe_flags', (YLeaf(YType.uint8, 'epe-flags'), ['int'])),
                                            ('epe_local_asn', (YLeaf(YType.uint32, 'epe-local-asn'), ['int'])),
                                            ('epe_remote_asn', (YLeaf(YType.uint32, 'epe-remote-asn'), ['int'])),
                                            ('epe_remote_router_id', (YLeaf(YType.uint32, 'epe-remote-router-id'), ['int'])),
                                            ('epe_local_router_id', (YLeaf(YType.uint32, 'epe-local-router-id'), ['int'])),
                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                            ('ref_count', (YLeaf(YType.uint32, 'ref-count'), ['int'])),
                                            ('rpc_set_object_id', (YLeaf(YType.uint32, 'rpc-set-object-id'), ['int'])),
                                        ])
                                        self.epe_key_length = None
                                        self.epe_set_key = None
                                        self.epe_key_length_xr = None
                                        self.epe_version = None
                                        self.epe_flags = None
                                        self.epe_local_asn = None
                                        self.epe_remote_asn = None
                                        self.epe_remote_router_id = None
                                        self.epe_local_router_id = None
                                        self.label = None
                                        self.ref_count = None
                                        self.rpc_set_object_id = None

                                        self.epe_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress()
                                        self.epe_local_address.parent = self
                                        self._children_name_map["epe_local_address"] = "epe-local-address"

                                        self.epe_next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop()
                                        self.epe_next_hop.parent = self
                                        self._children_name_map["epe_next_hop"] = "epe-next-hop"

                                        self.epe_key = YList(self)
                                        self.nexthop_id = YList(self)
                                        self.ifhandle = YList(self)
                                        self.first_hop = YList(self)
                                        self._segment_path = lambda: "epe"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe, ['epe_key_length', 'epe_set_key', u'epe_key_length_xr', u'epe_version', u'epe_flags', u'epe_local_asn', u'epe_remote_asn', u'epe_remote_router_id', u'epe_local_router_id', u'label', u'ref_count', u'rpc_set_object_id'], name, value)


                                    class EpeLocalAddress(Entity):
                                        """
                                        Local address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress, self).__init__()

                                            self.yang_name = "epe-local-address"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "epe-local-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "epe-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class EpeNextHop(Entity):
                                        """
                                        Nexthop address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop, self).__init__()

                                            self.yang_name = "epe-next-hop"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "epe-next-hop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "epe-next-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeNextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class EpeKey(Entity):
                                        """
                                        Key of EPE object
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeKey, self).__init__()

                                            self.yang_name = "epe-key"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "epe-key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.EpeKey, [u'entry'], name, value)


                                    class NexthopId(Entity):
                                        """
                                        List of nexthop ID of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.NexthopId, self).__init__()

                                            self.yang_name = "nexthop-id"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "nexthop-id"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.NexthopId, [u'entry'], name, value)


                                    class Ifhandle(Entity):
                                        """
                                        List of ifhandle of EPE
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle, self).__init__()

                                            self.yang_name = "ifhandle"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "ifhandle"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.Ifhandle, [u'entry'], name, value)


                                    class FirstHop(Entity):
                                        """
                                        List of firsthops of EPE
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop, self).__init__()

                                            self.yang_name = "first-hop"
                                            self.yang_parent_name = "epe"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "first-hop"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "first-hop"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Epes.Epe.FirstHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertisedPathCounts(Entity):
                                """
                                The BGP Advertised paths table (bestpath)
                                
                                .. attribute:: advertised_path_count
                                
                                	The BGP Advertised path table Count (bestpath)
                                	**type**\: list of  		 :py:class:`AdvertisedPathCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts, self).__init__()

                                    self.yang_name = "advertised-path-counts"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("advertised-path-count", ("advertised_path_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount))])
                                    self._leafs = OrderedDict()

                                    self.advertised_path_count = YList(self)
                                    self._segment_path = lambda: "advertised-path-counts"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts, [], name, value)


                                class AdvertisedPathCount(Entity):
                                    """
                                    The BGP Advertised path table Count
                                    (bestpath)
                                    
                                    .. attribute:: neighbor_address  (key)
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: max_prefix_advertisedcount
                                    
                                    	Number of prefixes advertsied to neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, self).__init__()

                                        self.yang_name = "advertised-path-count"
                                        self.yang_parent_name = "advertised-path-counts"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['neighbor_address']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('max_prefix_advertisedcount', (YLeaf(YType.uint32, 'max-prefix-advertisedcount'), ['int'])),
                                        ])
                                        self.neighbor_address = None
                                        self.max_prefix_advertisedcount = None
                                        self._segment_path = lambda: "advertised-path-count" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPathCounts.AdvertisedPathCount, ['neighbor_address', u'max_prefix_advertisedcount'], name, value)


                            class PathLabeledTable(Entity):
                                """
                                The BGP Path Labeled Table
                                
                                .. attribute:: path
                                
                                	A BGP path table entry
                                	**type**\: list of  		 :py:class:`Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable, self).__init__()

                                    self.yang_name = "path-labeled-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("path", ("path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path))])
                                    self._leafs = OrderedDict()

                                    self.path = YList(self)
                                    self._segment_path = lambda: "path-labeled-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable, [], name, value)


                                class Path(Entity):
                                    """
                                    A BGP path table entry
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix Length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor adddress
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_type
                                    
                                    	Route Type
                                    	**type**\:  :py:class:`BgpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute>`
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: orig_source_rd
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertised_neighbor
                                    
                                    	Advertised Neighbor Address. Valid in the case of Advertised table
                                    	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor>`
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: original_source_route_distinguisher
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\: str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path, self).__init__()

                                        self.yang_name = "path"
                                        self.yang_parent_name = "path-labeled-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute', '')])),
                                            ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                            ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                            ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                            ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                            ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                            ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None
                                        self.route_type = None
                                        self.source_rd = None
                                        self.orig_source_rd = None
                                        self.path_id = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.label_oor = None
                                        self.label_oor_version = None
                                        self.label_fail = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.original_source_route_distinguisher = None
                                        self.prefix_version = None
                                        self.vrf_name = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None

                                        self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor()
                                        self.advertised_neighbor.parent = self
                                        self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._segment_path = lambda: "path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path, ['rd', 'network', 'prefix_length', 'neighbor_address', 'route_type', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                    class AdvertisedNeighbor(Entity):
                                        """
                                        Advertised Neighbor Address. Valid in the case
                                        of Advertised table
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor, self).__init__()

                                            self.yang_name = "advertised-neighbor"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "advertised-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied. In the
                                        case of path type received\-only this will be
                                        attributes before inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PathLabeledTable.Path.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AdvertisedPaths(Entity):
                                """
                                The BGP Advertised paths table (add\-paths)
                                
                                .. attribute:: advertised_path
                                
                                	A BGP Advertised paths table entry (add\-paths)
                                	**type**\: list of  		 :py:class:`AdvertisedPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths, self).__init__()

                                    self.yang_name = "advertised-paths"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("advertised-path", ("advertised_path", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath))])
                                    self._leafs = OrderedDict()

                                    self.advertised_path = YList(self)
                                    self._segment_path = lambda: "advertised-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths, [], name, value)


                                class AdvertisedPath(Entity):
                                    """
                                    A BGP Advertised paths table entry
                                    (add\-paths)
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Network prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor 
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: paths
                                    
                                    	paths
                                    	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths>`
                                    
                                    .. attribute:: adv_path_info
                                    
                                    	Net Advertized Paths
                                    	**type**\: list of  		 :py:class:`AdvPathInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath, self).__init__()

                                        self.yang_name = "advertised-path"
                                        self.yang_parent_name = "advertised-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("paths", ("paths", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths)), ("adv-path-info", ("adv_path_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo))])
                                        self._leafs = OrderedDict([
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ])
                                        self.rd = None
                                        self.network = None
                                        self.prefix_length = None
                                        self.neighbor_address = None

                                        self.paths = YList(self)
                                        self.adv_path_info = YList(self)
                                        self._segment_path = lambda: "advertised-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath, ['rd', 'network', 'prefix_length', 'neighbor_address'], name, value)


                                    class Paths(Entity):
                                        """
                                        paths
                                        
                                        .. attribute:: advertised_neighbor
                                        
                                        	Advertised Neighbor Address. Valid in the case of Advertised table
                                        	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor>`
                                        
                                        .. attribute:: path_information
                                        
                                        	Path information
                                        	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: process_instance_id
                                        
                                        	Process instance ID
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: label_oor
                                        
                                        	LSD label space is exhausted
                                        	**type**\: bool
                                        
                                        .. attribute:: label_oor_version
                                        
                                        	Label Version when OOR happens
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: label_fail
                                        
                                        	LSD label allocation failed 
                                        	**type**\: bool
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: original_source_route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: prefix_version
                                        
                                        	Version of BGP Prefix Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        .. attribute:: source_vrf_name
                                        
                                        	Name of the source VRF
                                        	**type**\: str
                                        
                                        .. attribute:: srcaf_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, self).__init__()

                                            self.yang_name = "paths"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn))])
                                            self._leafs = OrderedDict([
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                                ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                                ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                                ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                                ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                                ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                                ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ])
                                            self.no_path = None
                                            self.af_name = None
                                            self.process_instance_id = None
                                            self.label_oor = None
                                            self.label_oor_version = None
                                            self.label_fail = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.original_source_route_distinguisher = None
                                            self.prefix_version = None
                                            self.vrf_name = None
                                            self.source_vrf_name = None
                                            self.srcaf_name = None

                                            self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor()
                                            self.advertised_neighbor.parent = self
                                            self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                            self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation()
                                            self.path_information.parent = self
                                            self._children_name_map["path_information"] = "path-information"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                            self._segment_path = lambda: "paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths, [u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                        class AdvertisedNeighbor(Entity):
                                            """
                                            Advertised Neighbor Address. Valid in the case
                                            of Advertised table
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor, self).__init__()

                                                self.yang_name = "advertised-neighbor"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "advertised-neighbor"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "advertised-neighbor"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInformation(Entity):
                                            """
                                            Path information
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, self).__init__()

                                                self.yang_name = "path-information"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-information"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy applied. In the
                                            case of path type received\-only this will be
                                            attributes before inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.Paths.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AdvPathInfo(Entity):
                                        """
                                        Net Advertized Paths
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor Address
                                        	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr>`
                                        
                                        .. attribute:: path_info_after_policy_in
                                        
                                        	Path information after inbound policy
                                        	**type**\:  :py:class:`PathInfoAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn>`
                                        
                                        .. attribute:: path_info_after_policy_out
                                        
                                        	Path information after outbound policy
                                        	**type**\:  :py:class:`PathInfoAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut>`
                                        
                                        .. attribute:: attributes_after_policy_in
                                        
                                        	Attributes after inbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn>`
                                        
                                        .. attribute:: attributes_after_policy_out
                                        
                                        	Attributes after outbound policy
                                        	**type**\:  :py:class:`AttributesAfterPolicyOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut>`
                                        
                                        .. attribute:: no_path
                                        
                                        	No path exists All 'sp\_path\_in' fields except 'sp\_path\_in\->bag\_prefix' are invalid.  All 'sp\_path\_out' fields are invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: source_route_distinguisher
                                        
                                        	Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: vrf_name
                                        
                                        	Name of the VRF
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, self).__init__()

                                            self.yang_name = "adv-path-info"
                                            self.yang_parent_name = "advertised-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr)), ("path-info-after-policy-in", ("path_info_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn)), ("path-info-after-policy-out", ("path_info_after_policy_out", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn)), ("attributes-after-policy-out", ("attributes_after_policy_out", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut))])
                                            self._leafs = OrderedDict([
                                                ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ])
                                            self.no_path = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.source_route_distinguisher = None
                                            self.vrf_name = None

                                            self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr()
                                            self.neighbor_address_xr.parent = self
                                            self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                            self.path_info_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn()
                                            self.path_info_after_policy_in.parent = self
                                            self._children_name_map["path_info_after_policy_in"] = "path-info-after-policy-in"

                                            self.path_info_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut()
                                            self.path_info_after_policy_out.parent = self
                                            self._children_name_map["path_info_after_policy_out"] = "path-info-after-policy-out"

                                            self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn()
                                            self.attributes_after_policy_in.parent = self
                                            self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"

                                            self.attributes_after_policy_out = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut()
                                            self.attributes_after_policy_out.parent = self
                                            self._children_name_map["attributes_after_policy_out"] = "attributes-after-policy-out"
                                            self._segment_path = lambda: "adv-path-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo, [u'no_path', u'af_name', u'route_distinguisher', u'source_route_distinguisher', u'vrf_name'], name, value)


                                        class NeighborAddressXr(Entity):
                                            """
                                            Neighbor Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, self).__init__()

                                                self.yang_name = "neighbor-address-xr"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address-xr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address-xr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInfoAfterPolicyIn(Entity):
                                            """
                                            Path information after inbound policy
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, self).__init__()

                                                self.yang_name = "path-info-after-policy-in"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyIn.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PathInfoAfterPolicyOut(Entity):
                                            """
                                            Path information after outbound policy
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix>`
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress>`
                                            
                                            .. attribute:: next_hop
                                            
                                            	Next hop
                                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop>`
                                            
                                            .. attribute:: nh_tunnel
                                            
                                            	NH tunnel information
                                            	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel>`
                                            
                                            .. attribute:: mdt_group_addr
                                            
                                            	IPv4 MDT Group Address for the path
                                            	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr>`
                                            
                                            .. attribute:: gw_addr
                                            
                                            	Path GW Address
                                            	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr>`
                                            
                                            .. attribute:: nh_addr
                                            
                                            	Path next\-hop Address
                                            	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr>`
                                            
                                            .. attribute:: best_path_comp_winner
                                            
                                            	Neighbor address of the path which won best path comparison
                                            	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner>`
                                            
                                            .. attribute:: mvpn_nbr_addr
                                            
                                            	Mvpn nbr Address for the path
                                            	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr>`
                                            
                                            .. attribute:: mvpn_nexthop_addr
                                            
                                            	Mvpn nexthop Address for the path
                                            	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr>`
                                            
                                            .. attribute:: vpn_nexthop_addr
                                            
                                            	Vpn nexthop Address for the path
                                            	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr>`
                                            
                                            .. attribute:: route_type
                                            
                                            	Route Type of path
                                            	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                            
                                            .. attribute:: is_path_valid
                                            
                                            	Path attributes are usable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_damped
                                            
                                            	Path suppressed due to dampening
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_history_held
                                            
                                            	Path entry held to remember history
                                            	**type**\: bool
                                            
                                            .. attribute:: is_internal_path
                                            
                                            	Received over an internal link
                                            	**type**\: bool
                                            
                                            .. attribute:: is_best_path
                                            
                                            	Best available path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_best
                                            
                                            	Best available path within AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_spkr_as_best
                                            
                                            	Best available path within AS in speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_best
                                            
                                            	Partial best path within distributed speaker
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregation_suppressed
                                            
                                            	Path suppressed due to aggregation
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_dampened
                                            
                                            	net import dampened
                                            	**type**\: bool
                                            
                                            .. attribute:: is_import_suspect
                                            
                                            	net import suspect
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised
                                            
                                            	Not advertised to any peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_not_advertised_to_ebgp
                                            
                                            	Not advertised to EBGPs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_advertised_local_as_only
                                            
                                            	Not advertised outside local AS
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_route_reflector
                                            
                                            	Path received from route reflector
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_received_only
                                            
                                            	Path is received only
                                            	**type**\: bool
                                            
                                            .. attribute:: is_received_path_not_modified
                                            
                                            	Received path used without modification
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_locally_sourced
                                            
                                            	Path sourced locally
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_local_aggregate
                                            
                                            	Path is a locally created aggregate
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_network_command
                                            
                                            	Path sourced by network command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_redistribute_command
                                            
                                            	Path sourced by redistribute command
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imported
                                            
                                            	Path is imported
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated
                                            
                                            	Path is reoriginated
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_reoriginated_stitching
                                            
                                            	Path is reoriginated with stitching RTs
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_vpn_only
                                            
                                            	Path is not in the vrf
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_from_confederation_peer
                                            
                                            	Path received from confederation peer
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_synced_with_igp
                                            
                                            	Path synchronized with IGP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_multipath
                                            
                                            	Path is one of multipath best routes
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_imp_candidate
                                            
                                            	Path is a candidate for multipath import
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_stale
                                            
                                            	Stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_long_lived_stale
                                            
                                            	Long lived stale routes learnt before neighbor restarts
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup
                                            
                                            	Path is a backup path 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_backup_protect_multipath
                                            
                                            	Path is a backup path to protect multipaths
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_best_external
                                            
                                            	Path is a best external path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_additional_path
                                            
                                            	Path is an additional\-path
                                            	**type**\: bool
                                            
                                            .. attribute:: is_path_nexthop_discarded
                                            
                                            	Path is redirected to Null0
                                            	**type**\: bool
                                            
                                            .. attribute:: has_local_net_label
                                            
                                            	Path has local label
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Path local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: igp_metric
                                            
                                            	IGP metric to the gateway
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_weight
                                            
                                            	Weight for the path
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: neighbor_router_id
                                            
                                            	Router ID of the neighbor for the path
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: has_mdt_group_addr
                                            
                                            	Path has MDT Group Address
                                            	**type**\: bool
                                            
                                            .. attribute:: l2vpn_size
                                            
                                            	Path block size
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: l2vpn_evpn_esi
                                            
                                            	L2VPN EVPN ESI
                                            	**type**\: str
                                            
                                            .. attribute:: has_gw_addr
                                            
                                            	Path has GW Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_nh_addr
                                            
                                            	Path has next\-hop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_second_label
                                            
                                            	Path has second received label
                                            	**type**\: bool
                                            
                                            .. attribute:: second_label
                                            
                                            	Path second received label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flap_count
                                            
                                            	Number of times this route has flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: seconds_since_first_flap
                                            
                                            	Seconds since route first flapped
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: time_to_unsuppress
                                            
                                            	Seconds until route is unsuppressed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: dampen_penalty
                                            
                                            	Dampening penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: halflife_time
                                            
                                            	Half\-life time for the penalty
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: suppress_penalty
                                            
                                            	Value to start suppressing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reuse_value
                                            
                                            	Value to start reusing a route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_suppress_time
                                            
                                            	Maximum duration to suppress a stable route
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_comp_stage
                                            
                                            	Stage where the path lost to the best path or group best
                                            	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                            
                                            .. attribute:: best_path_id_comp_winner
                                            
                                            	Path ID of the path which won best path comparison
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_flags
                                            
                                            	Flags associated with path
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: path_import_flags
                                            
                                            	Path import flags
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: best_path_id
                                            
                                            	Best path ID; DEPRECATED BYLocalPathId
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_path_id
                                            
                                            	Local path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rcvd_path_id
                                            
                                            	Received path ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_table_version
                                            
                                            	Table version # for pelem
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertisedto_pe
                                            
                                            	Net could be advertised                          to PE peers
                                            	**type**\: bool
                                            
                                            .. attribute:: rib_failed
                                            
                                            	Is net failed installed                          in RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: sn_rpki_origin_as_validity
                                            
                                            	RPKI origin validation state
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: show_rpki_origin_as_validity
                                            
                                            	Display validity state ?
                                            	**type**\: bool
                                            
                                            .. attribute:: ibgp_signaled_validity
                                            
                                            	IBGP signalled validation
                                            	**type**\: bool
                                            
                                            .. attribute:: rpki_origin_as_validation_disabled
                                            
                                            	RPKI originAS V. Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_path
                                            
                                            	Accept Own
                                            	**type**\: bool
                                            
                                            .. attribute:: accept_own_self_originated_path
                                            
                                            	Accept\-Own self\-originated
                                            	**type**\: bool
                                            
                                            .. attribute:: aigp_metric
                                            
                                            	Total AIGP metric
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: mvpn_sfs_path
                                            
                                            	Is MVPN single forwarder PE path
                                            	**type**\: bool
                                            
                                            .. attribute:: fspec_invalid_path
                                            
                                            	Is Fspec invalid path
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nbr_addr
                                            
                                            	Path has Mvpn nbr Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_nexthop_addr
                                            
                                            	Path has MVPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: has_mvpn_pmsi
                                            
                                            	Path has MVPN PMSI feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_pmsi_type
                                            
                                            	Mvpn PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mvpn_pmsi_flags
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mvpn_pmsi_label
                                            
                                            	Mvpn PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: has_mvpn_extcomm
                                            
                                            	Path has MVPN EXTCOMM feedback
                                            	**type**\: bool
                                            
                                            .. attribute:: mvpn_path_flags
                                            
                                            	Mvpn path flags
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: local_nh
                                            
                                            	Path has local nexthop
                                            	**type**\: bool
                                            
                                            .. attribute:: rt_set_limit_enabled
                                            
                                            	Path subject to RT\-set net limit
                                            	**type**\: bool
                                            
                                            .. attribute:: path_rt_set_id
                                            
                                            	RT\-set id of the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_rt_set_route_count
                                            
                                            	Count in RT\-set
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_path_af_install_eligible
                                            
                                            	Path can be installed in AF RIB
                                            	**type**\: bool
                                            
                                            .. attribute:: is_permanent_path
                                            
                                            	Path is of type Permanent path
                                            	**type**\: bool
                                            
                                            .. attribute:: graceful_shutdown
                                            
                                            	Marked for graceful shutdown
                                            	**type**\: bool
                                            
                                            .. attribute:: labeled_unicast_safi_path
                                            
                                            	Path was learnt by labeled\-unicast SAFI
                                            	**type**\: bool
                                            
                                            .. attribute:: has_vpn_nexthop_addr
                                            
                                            	Path has VPN nexthop Address
                                            	**type**\: bool
                                            
                                            .. attribute:: is_orig_src_rd_present
                                            
                                            	Original Source RD  present
                                            	**type**\: bool
                                            
                                            .. attribute:: af_name
                                            
                                            	Original Source Address family identifier
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: route_distinguisher
                                            
                                            	Original Source Route Distinguisher
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{16}
                                            
                                            .. attribute:: mac_ip_present
                                            
                                            	Mac IP Present  present
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_ip
                                            
                                            	Mac associated with IP
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: rcvd_label
                                            
                                            	Path received label stack
                                            	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel>`
                                            
                                            .. attribute:: l2vpn_circuit_status_value
                                            
                                            	L2VPN Circuit Status Value
                                            	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue>`
                                            
                                            .. attribute:: mvpn_pmsi_value
                                            
                                            	Mvpn PMSI Value
                                            	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Mvpn Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity>`
                                            
                                            .. attribute:: local_peers_advertised_to
                                            
                                            	Local peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo>`
                                            
                                            .. attribute:: pe_peers_advertised_to
                                            
                                            	PE peers that this prefix has been advertised to
                                            	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo>`
                                            
                                            .. attribute:: best_path_orr_bitfield
                                            
                                            	ORR Best path Bitfields
                                            	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield>`
                                            
                                            .. attribute:: add_path_orr_bitfield
                                            
                                            	ORR Add path Bitfields
                                            	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, self).__init__()

                                                self.yang_name = "path-info-after-policy-out"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield))])
                                                self._leafs = OrderedDict([
                                                    ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                    ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                    ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                    ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                    ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                    ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                    ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                    ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                    ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                    ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                    ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                    ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                    ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                    ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                    ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                    ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                    ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                    ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                    ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                    ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                    ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                    ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                    ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                    ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                    ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                    ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                    ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                    ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                    ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                    ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                    ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                    ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                    ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                    ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                    ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                    ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                    ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                    ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                    ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                    ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                    ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                    ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                    ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                    ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                    ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                    ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                    ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                    ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                    ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                    ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                    ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                    ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                    ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                    ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                    ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                    ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                    ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                    ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                    ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                    ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                    ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                    ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                    ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                    ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                    ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                    ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                    ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                    ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                    ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                    ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                    ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                    ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                    ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                    ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                    ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                    ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                    ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                    ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                    ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                    ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                    ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                    ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                    ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                    ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                    ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                    ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                    ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                    ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                    ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                    ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                    ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                    ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                    ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                    ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                    ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                    ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                                ])
                                                self.route_type = None
                                                self.is_path_valid = None
                                                self.is_path_damped = None
                                                self.is_path_history_held = None
                                                self.is_internal_path = None
                                                self.is_best_path = None
                                                self.is_as_best = None
                                                self.is_spkr_as_best = None
                                                self.is_partial_best = None
                                                self.is_aggregation_suppressed = None
                                                self.is_import_dampened = None
                                                self.is_import_suspect = None
                                                self.is_path_not_advertised = None
                                                self.is_path_not_advertised_to_ebgp = None
                                                self.is_path_advertised_local_as_only = None
                                                self.is_path_from_route_reflector = None
                                                self.is_path_received_only = None
                                                self.is_received_path_not_modified = None
                                                self.is_path_locally_sourced = None
                                                self.is_path_local_aggregate = None
                                                self.is_path_from_network_command = None
                                                self.is_path_from_redistribute_command = None
                                                self.is_path_imported = None
                                                self.is_path_reoriginated = None
                                                self.is_path_reoriginated_stitching = None
                                                self.is_path_vpn_only = None
                                                self.is_path_from_confederation_peer = None
                                                self.is_path_synced_with_igp = None
                                                self.is_path_multipath = None
                                                self.is_path_imp_candidate = None
                                                self.is_path_stale = None
                                                self.is_path_long_lived_stale = None
                                                self.is_path_backup = None
                                                self.is_path_backup_protect_multipath = None
                                                self.is_path_best_external = None
                                                self.is_path_additional_path = None
                                                self.is_path_nexthop_discarded = None
                                                self.has_local_net_label = None
                                                self.local_label = None
                                                self.igp_metric = None
                                                self.path_weight = None
                                                self.neighbor_router_id = None
                                                self.has_mdt_group_addr = None
                                                self.l2vpn_size = None
                                                self.l2vpn_evpn_esi = None
                                                self.has_gw_addr = None
                                                self.has_nh_addr = None
                                                self.has_second_label = None
                                                self.second_label = None
                                                self.path_flap_count = None
                                                self.seconds_since_first_flap = None
                                                self.time_to_unsuppress = None
                                                self.dampen_penalty = None
                                                self.halflife_time = None
                                                self.suppress_penalty = None
                                                self.reuse_value = None
                                                self.maximum_suppress_time = None
                                                self.best_path_comp_stage = None
                                                self.best_path_id_comp_winner = None
                                                self.path_flags = None
                                                self.path_import_flags = None
                                                self.best_path_id = None
                                                self.local_path_id = None
                                                self.rcvd_path_id = None
                                                self.path_table_version = None
                                                self.advertisedto_pe = None
                                                self.rib_failed = None
                                                self.sn_rpki_origin_as_validity = None
                                                self.show_rpki_origin_as_validity = None
                                                self.ibgp_signaled_validity = None
                                                self.rpki_origin_as_validation_disabled = None
                                                self.accept_own_path = None
                                                self.accept_own_self_originated_path = None
                                                self.aigp_metric = None
                                                self.mvpn_sfs_path = None
                                                self.fspec_invalid_path = None
                                                self.has_mvpn_nbr_addr = None
                                                self.has_mvpn_nexthop_addr = None
                                                self.has_mvpn_pmsi = None
                                                self.mvpn_pmsi_type = None
                                                self.mvpn_pmsi_flags = None
                                                self.mvpn_pmsi_label = None
                                                self.has_mvpn_extcomm = None
                                                self.mvpn_path_flags = None
                                                self.local_nh = None
                                                self.rt_set_limit_enabled = None
                                                self.path_rt_set_id = None
                                                self.path_rt_set_route_count = None
                                                self.is_path_af_install_eligible = None
                                                self.is_permanent_path = None
                                                self.graceful_shutdown = None
                                                self.labeled_unicast_safi_path = None
                                                self.has_vpn_nexthop_addr = None
                                                self.is_orig_src_rd_present = None
                                                self.af_name = None
                                                self.route_distinguisher = None
                                                self.mac_ip_present = None
                                                self.mac_ip = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"

                                                self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop()
                                                self.next_hop.parent = self
                                                self._children_name_map["next_hop"] = "next-hop"

                                                self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel()
                                                self.nh_tunnel.parent = self
                                                self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                                self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr()
                                                self.mdt_group_addr.parent = self
                                                self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                                self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr()
                                                self.gw_addr.parent = self
                                                self._children_name_map["gw_addr"] = "gw-addr"

                                                self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr()
                                                self.nh_addr.parent = self
                                                self._children_name_map["nh_addr"] = "nh-addr"

                                                self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner()
                                                self.best_path_comp_winner.parent = self
                                                self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                                self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr()
                                                self.mvpn_nbr_addr.parent = self
                                                self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                                self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr()
                                                self.mvpn_nexthop_addr.parent = self
                                                self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                                self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr()
                                                self.vpn_nexthop_addr.parent = self
                                                self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                                self.rcvd_label = YList(self)
                                                self.l2vpn_circuit_status_value = YList(self)
                                                self.mvpn_pmsi_value = YList(self)
                                                self.extended_community = YList(self)
                                                self.local_peers_advertised_to = YList(self)
                                                self.pe_peers_advertised_to = YList(self)
                                                self.best_path_orr_bitfield = YList(self)
                                                self.add_path_orr_bitfield = YList(self)
                                                self._segment_path = lambda: "path-info-after-policy-out"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NextHop(Entity):
                                                """
                                                Next hop
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, self).__init__()

                                                    self.yang_name = "next-hop"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class NhTunnel(Entity):
                                                """
                                                NH tunnel information
                                                
                                                .. attribute:: tunnel_type
                                                
                                                	Nexthop Tunnel Type
                                                	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                                
                                                .. attribute:: tunnel_name
                                                
                                                	Tunnel name attribute
                                                	**type**\: str
                                                
                                                .. attribute:: is_tunnel_up
                                                
                                                	Tunnel Up flag
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_info_stale
                                                
                                                	Tunnel is stale
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_registered
                                                
                                                	Tunnel registered flag
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_required
                                                
                                                	Tunnel need IPv6
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_v6_enabled
                                                
                                                	IPv6 enabled
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_notif_first_rcvd
                                                
                                                	Tunnel first notif received
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_state_skip_reg
                                                
                                                	Skip tunnel registration for Stale entry
                                                	**type**\: bool
                                                
                                                .. attribute:: binding_label
                                                
                                                	Binding label for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_if_handle
                                                
                                                	Interface handle for the tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: last_tunnel_update
                                                
                                                	Time since the last tunnel update happened
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_color
                                                
                                                	Color corresponding to this SR tunnel
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_tunnel_color_only
                                                
                                                	Is a Color Only (Null Endpoint) tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: tunnel_endpoint_afi
                                                
                                                	AFI of the Null Endpoint (IPv4/IPv6)
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, self).__init__()

                                                    self.yang_name = "nh-tunnel"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                        ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                        ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                        ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                        ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                        ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                        ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                        ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                        ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                        ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                        ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                        ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                        ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                        ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                        ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ])
                                                    self.tunnel_type = None
                                                    self.tunnel_name = None
                                                    self.is_tunnel_up = None
                                                    self.is_tunnel_info_stale = None
                                                    self.is_tunnel_registered = None
                                                    self.tunnel_v6_required = None
                                                    self.tunnel_v6_enabled = None
                                                    self.tunnel_notif_first_rcvd = None
                                                    self.tunnel_state_skip_reg = None
                                                    self.binding_label = None
                                                    self.tunnel_if_handle = None
                                                    self.last_tunnel_update = None
                                                    self.tunnel_color = None
                                                    self.is_tunnel_color_only = None
                                                    self.tunnel_endpoint_afi = None
                                                    self._segment_path = lambda: "nh-tunnel"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                            class MdtGroupAddr(Entity):
                                                """
                                                IPv4 MDT Group Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, self).__init__()

                                                    self.yang_name = "mdt-group-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mdt-group-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mdt-group-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class GwAddr(Entity):
                                                """
                                                Path GW Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, self).__init__()

                                                    self.yang_name = "gw-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "gw-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class NhAddr(Entity):
                                                """
                                                Path next\-hop Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, self).__init__()

                                                    self.yang_name = "nh-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "nh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                            class BestPathCompWinner(Entity):
                                                """
                                                Neighbor address of the path which won best path
                                                comparison
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, self).__init__()

                                                    self.yang_name = "best-path-comp-winner"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "best-path-comp-winner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "best-path-comp-winner"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNbrAddr(Entity):
                                                """
                                                Mvpn nbr Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, self).__init__()

                                                    self.yang_name = "mvpn-nbr-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nbr-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nbr-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class MvpnNexthopAddr(Entity):
                                                """
                                                Mvpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, self).__init__()

                                                    self.yang_name = "mvpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "mvpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "mvpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class VpnNexthopAddr(Entity):
                                                """
                                                Vpn nexthop Address for the path
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, self).__init__()

                                                    self.yang_name = "vpn-nexthop-addr"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "vpn-nexthop-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "vpn-nexthop-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class RcvdLabel(Entity):
                                                """
                                                Path received label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, self).__init__()

                                                    self.yang_name = "rcvd-label"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rcvd-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.RcvdLabel, [u'entry'], name, value)


                                            class L2vpnCircuitStatusValue(Entity):
                                                """
                                                L2VPN Circuit Status Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, self).__init__()

                                                    self.yang_name = "l2vpn-circuit-status-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                            class MvpnPmsiValue(Entity):
                                                """
                                                Mvpn PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, self).__init__()

                                                    self.yang_name = "mvpn-pmsi-value"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "mvpn-pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.MvpnPmsiValue, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Mvpn Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.ExtendedCommunity, [u'entry'], name, value)


                                            class LocalPeersAdvertisedTo(Entity):
                                                """
                                                Local peers that this prefix has been advertised
                                                to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "local-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "local-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "local-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class PePeersAdvertisedTo(Entity):
                                                """
                                                PE peers that this prefix has been advertised to
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, self).__init__()

                                                    self.yang_name = "pe-peers-advertised-to"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "pe-peers-advertised-to"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "pe-peers-advertised-to"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class BestPathOrrBitfield(Entity):
                                                """
                                                ORR Best path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, self).__init__()

                                                    self.yang_name = "best-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "best-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "best-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                            class AddPathOrrBitfield(Entity):
                                                """
                                                ORR Add path Bitfields
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Neighbor Address
                                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress>`
                                                
                                                .. attribute:: is_neighbor
                                                
                                                	Entry is a neighbor (not an update group)
                                                	**type**\: bool
                                                
                                                .. attribute:: update_group_afi
                                                
                                                	AFI of the Update group it is advertised to
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: update_group_number
                                                
                                                	Update group index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, self).__init__()

                                                    self.yang_name = "add-path-orr-bitfield"
                                                    self.yang_parent_name = "path-info-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                        ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                    ])
                                                    self.is_neighbor = None
                                                    self.update_group_afi = None
                                                    self.update_group_number = None

                                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress()
                                                    self.neighbor_address.parent = self
                                                    self._children_name_map["neighbor_address"] = "neighbor-address"
                                                    self._segment_path = lambda: "add-path-orr-bitfield"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                                class NeighborAddress(Entity):
                                                    """
                                                    Neighbor Address
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                        self.yang_name = "neighbor-address"
                                                        self.yang_parent_name = "add-path-orr-bitfield"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "neighbor-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "neighbor-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.PathInfoAfterPolicyOut.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyIn(Entity):
                                            """
                                            Attributes after inbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, self).__init__()

                                                self.yang_name = "attributes-after-policy-in"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-in"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-in"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AttributesAfterPolicyOut(Entity):
                                            """
                                            Attributes after outbound policy
                                            
                                            .. attribute:: common_attributes
                                            
                                            	Common attributes
                                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes>`
                                            
                                            .. attribute:: attr_set
                                            
                                            	ATTR\_SET attribute
                                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet>`
                                            
                                            .. attribute:: rnh_addr
                                            
                                            	RNH Address
                                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr>`
                                            
                                            .. attribute:: ribrnh_ip
                                            
                                            	RIB RNH IP Address
                                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp>`
                                            
                                            .. attribute:: is_as_path2_byte
                                            
                                            	AS path encoded as 2\-byte
                                            	**type**\: bool
                                            
                                            .. attribute:: is_application_gateway_present
                                            
                                            	Application gateway present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_attr_set_present
                                            
                                            	BGP ATTR\_SET attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_igp
                                            
                                            	AIGP set by policy inbound IGP 
                                            	**type**\: bool
                                            
                                            .. attribute:: set_aigp_inbound_metric
                                            
                                            	AIGP set by policy inbound metric
                                            	**type**\: bool
                                            
                                            .. attribute:: is_rnh_present
                                            
                                            	RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ribrnh_present
                                            
                                            	RIB RNH Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_key_number
                                            
                                            	Attribute key number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_config
                                            
                                            	Attribute reuse ID Configured
                                            	**type**\: bool
                                            
                                            .. attribute:: attribute_reuse_id_max_id
                                            
                                            	Attribute reuse ID maximum ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_node
                                            
                                            	Attribute reuse ID nodes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_current
                                            
                                            	Attribute reuse ID current ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_keys
                                            
                                            	Attribute reuse ID allocated keys
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: attribute_reuse_id_recover_sec
                                            
                                            	Attribute reuse ID timer in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: vpn_distinguisher
                                            
                                            	VPN Distinguisher
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rnh_type
                                            
                                            	RNH Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rnh_len
                                            
                                            	RNH Length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rnh_addr_len
                                            
                                            	RNH Address Length
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_table
                                            
                                            	RIB RNH Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_mac
                                            
                                            	RIB RNH MAC Address
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            .. attribute:: ribrnhip_table
                                            
                                            	RIB RNH IP Table
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_vni
                                            
                                            	RIB RNH Vni
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ribrnh_encap
                                            
                                            	RIB RNH Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, self).__init__()

                                                self.yang_name = "attributes-after-policy-out"
                                                self.yang_parent_name = "adv-path-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp))])
                                                self._leafs = OrderedDict([
                                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                                ])
                                                self.is_as_path2_byte = None
                                                self.is_application_gateway_present = None
                                                self.is_attr_set_present = None
                                                self.set_aigp_inbound_igp = None
                                                self.set_aigp_inbound_metric = None
                                                self.is_rnh_present = None
                                                self.is_ribrnh_present = None
                                                self.attribute_key_number = None
                                                self.attribute_reuse_id_config = None
                                                self.attribute_reuse_id_max_id = None
                                                self.attribute_reuse_id_node = None
                                                self.attribute_reuse_id_current = None
                                                self.attribute_reuse_id_keys = None
                                                self.attribute_reuse_id_recover_sec = None
                                                self.vpn_distinguisher = None
                                                self.rnh_type = None
                                                self.rnh_len = None
                                                self.rnh_addr_len = None
                                                self.ribrnh_table = None
                                                self.ribrnh_mac = None
                                                self.ribrnhip_table = None
                                                self.ribrnh_vni = None
                                                self.ribrnh_encap = None

                                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes()
                                                self.common_attributes.parent = self
                                                self._children_name_map["common_attributes"] = "common-attributes"

                                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet()
                                                self.attr_set.parent = self
                                                self._children_name_map["attr_set"] = "attr-set"

                                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr()
                                                self.rnh_addr.parent = self
                                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp()
                                                self.ribrnh_ip.parent = self
                                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                                self._segment_path = lambda: "attributes-after-policy-out"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                            class CommonAttributes(Entity):
                                                """
                                                Common attributes
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, self).__init__()

                                                    self.yang_name = "common-attributes"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "common-attributes"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "common-attributes"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class AttrSet(Entity):
                                                """
                                                ATTR\_SET attribute
                                                
                                                .. attribute:: prefix_sid_attr
                                                
                                                	Prefix SID attribute
                                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr>`
                                                
                                                .. attribute:: tunnel_encap
                                                
                                                	Tunnel Encapsulation attribute
                                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap>`
                                                
                                                .. attribute:: is_metric_present
                                                
                                                	Metric attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_local_pref_present
                                                
                                                	Local Preference attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_atomic_aggregate_present
                                                
                                                	Atomic aggregate attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aggregator_present
                                                
                                                	Aggregator attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_origin_present
                                                
                                                	Origin attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_as_path_present
                                                
                                                	AS path attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_community_present
                                                
                                                	Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_extended_community_present
                                                
                                                	Extended community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ssa_present
                                                
                                                	SSA attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_connector_present
                                                
                                                	Connector present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pmsi_present
                                                
                                                	PMSI Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pppmp_present
                                                
                                                	PPMP Attribute  present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_aigp_present
                                                
                                                	AIGP Present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_pe_distinguisher_label_present
                                                
                                                	PE distinguisher label  attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_ls_attribute_present
                                                
                                                	BGP LS attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: is_label_index_present
                                                
                                                	Label Index attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: neighbor_as
                                                
                                                	Neighbor AS number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_as
                                                
                                                	AS where aggregation was last performed
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: aggregator_address
                                                
                                                	Address where aggregation was performed
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: metric
                                                
                                                	Metric
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_preference
                                                
                                                	Local preference
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: origin
                                                
                                                	Origin
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: as_path
                                                
                                                	AS path attribute
                                                	**type**\: str
                                                
                                                .. attribute:: extended_community_flags
                                                
                                                	Extended community Flags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: originator
                                                
                                                	Originator attribute
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: l2tpv3_session_id
                                                
                                                	L2TPv3 session id
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: connector_type
                                                
                                                	Connector Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: aigp_metric_value
                                                
                                                	AIGP metric value
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: pmsi_type
                                                
                                                	PMSI Type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: pmsi_flags
                                                
                                                	PMSI Value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pmsi_label
                                                
                                                	PMSI label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ppm_pvalue
                                                
                                                	PPMP Value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_large_community_present
                                                
                                                	Large Community attribute present
                                                	**type**\: bool
                                                
                                                .. attribute:: community
                                                
                                                	Community attribute
                                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community>`
                                                
                                                .. attribute:: extended_community
                                                
                                                	Extended community attribute
                                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity>`
                                                
                                                .. attribute:: unknown_attribute
                                                
                                                	Unknown attributes
                                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute>`
                                                
                                                .. attribute:: cluster
                                                
                                                	Cluster list attribute
                                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster>`
                                                
                                                .. attribute:: l2tpv3_cookie
                                                
                                                	L2TPv3 Cookie
                                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie>`
                                                
                                                .. attribute:: connector_value
                                                
                                                	Connector Value
                                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue>`
                                                
                                                .. attribute:: pmsi_value
                                                
                                                	PMSI Value
                                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue>`
                                                
                                                .. attribute:: ls_attr
                                                
                                                	BGP LS attribute
                                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr>`
                                                
                                                .. attribute:: pe_distinguisher_label
                                                
                                                	PE distinguisher label attribute
                                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel>`
                                                
                                                .. attribute:: large_community
                                                
                                                	Large Community attribute
                                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, self).__init__()

                                                    self.yang_name = "attr-set"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity))])
                                                    self._leafs = OrderedDict([
                                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                    ])
                                                    self.is_metric_present = None
                                                    self.is_local_pref_present = None
                                                    self.is_atomic_aggregate_present = None
                                                    self.is_aggregator_present = None
                                                    self.is_origin_present = None
                                                    self.is_as_path_present = None
                                                    self.is_community_present = None
                                                    self.is_extended_community_present = None
                                                    self.is_ssa_present = None
                                                    self.is_connector_present = None
                                                    self.is_pmsi_present = None
                                                    self.is_pppmp_present = None
                                                    self.is_aigp_present = None
                                                    self.is_pe_distinguisher_label_present = None
                                                    self.is_ls_attribute_present = None
                                                    self.is_label_index_present = None
                                                    self.neighbor_as = None
                                                    self.aggregator_as = None
                                                    self.aggregator_address = None
                                                    self.metric = None
                                                    self.local_preference = None
                                                    self.origin = None
                                                    self.as_path = None
                                                    self.extended_community_flags = None
                                                    self.originator = None
                                                    self.l2tpv3_session_id = None
                                                    self.connector_type = None
                                                    self.aigp_metric_value = None
                                                    self.pmsi_type = None
                                                    self.pmsi_flags = None
                                                    self.pmsi_label = None
                                                    self.ppm_pvalue = None
                                                    self.is_large_community_present = None

                                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr()
                                                    self.prefix_sid_attr.parent = self
                                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap()
                                                    self.tunnel_encap.parent = self
                                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                    self.community = YList(self)
                                                    self.extended_community = YList(self)
                                                    self.unknown_attribute = YList(self)
                                                    self.cluster = YList(self)
                                                    self.l2tpv3_cookie = YList(self)
                                                    self.connector_value = YList(self)
                                                    self.pmsi_value = YList(self)
                                                    self.ls_attr = YList(self)
                                                    self.pe_distinguisher_label = YList(self)
                                                    self.large_community = YList(self)
                                                    self._segment_path = lambda: "attr-set"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                                class PrefixSidAttr(Entity):
                                                    """
                                                    Prefix SID attribute
                                                    
                                                    .. attribute:: prefix_sid_tlv
                                                    
                                                    	Prefix SID TLV array
                                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, self).__init__()

                                                        self.yang_name = "prefix-sid-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid_tlv = YList(self)
                                                        self._segment_path = lambda: "prefix-sid-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr, [], name, value)


                                                    class PrefixSidTlv(Entity):
                                                        """
                                                        Prefix SID TLV array
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Prefix SID TLV type field
                                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                        
                                                        .. attribute:: len
                                                        
                                                        	Prefix SID TLV Length in bytes
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**units**\: byte
                                                        
                                                        .. attribute:: val
                                                        
                                                        	Prefix SID TLV value string
                                                        	**type**\: str
                                                        
                                                        	**length:** 0..46
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                            self.yang_name = "prefix-sid-tlv"
                                                            self.yang_parent_name = "prefix-sid-attr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.len = None
                                                            self.val = None
                                                            self._segment_path = lambda: "prefix-sid-tlv"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                                class TunnelEncap(Entity):
                                                    """
                                                    Tunnel Encapsulation attribute
                                                    
                                                    .. attribute:: sr_policy
                                                    
                                                    	Tunnel encap type SR policy
                                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, self).__init__()

                                                        self.yang_name = "tunnel-encap"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy))])
                                                        self._leafs = OrderedDict()

                                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy()
                                                        self.sr_policy.parent = self
                                                        self._children_name_map["sr_policy"] = "sr-policy"
                                                        self._segment_path = lambda: "tunnel-encap"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap, [], name, value)


                                                    class SrPolicy(Entity):
                                                        """
                                                        Tunnel encap type SR policy
                                                        
                                                        .. attribute:: binding_sid
                                                        
                                                        	SR Policy incoming Binding sid
                                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                        
                                                        .. attribute:: allocated_binding_sid
                                                        
                                                        	SR Policy allocated Binding sid by the router
                                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                        
                                                        .. attribute:: tunnel_encap_type
                                                        
                                                        	Tunnel Encapsulation Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: preference
                                                        
                                                        	SR Policy Preference
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	SR Policy active state in forwarding
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: request_state
                                                        
                                                        	SR Policy programming Status
                                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                        
                                                        .. attribute:: usable
                                                        
                                                        	SR Policy is usable on this node
                                                        	**type**\: bool
                                                        
                                                        .. attribute:: segment_list
                                                        
                                                        	SR Policy Segment Lists
                                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                            self.yang_name = "sr-policy"
                                                            self.yang_parent_name = "tunnel-encap"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                            self._leafs = OrderedDict([
                                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                            ])
                                                            self.tunnel_encap_type = None
                                                            self.preference = None
                                                            self.state = None
                                                            self.request_state = None
                                                            self.usable = None

                                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                            self.binding_sid.parent = self
                                                            self._children_name_map["binding_sid"] = "binding-sid"

                                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                            self.allocated_binding_sid.parent = self
                                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                            self.segment_list = YList(self)
                                                            self._segment_path = lambda: "sr-policy"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                        class BindingSid(Entity):
                                                            """
                                                            SR Policy incoming Binding sid
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                                self.yang_name = "binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class AllocatedBindingSid(Entity):
                                                            """
                                                            SR Policy allocated Binding sid by the router
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 Addr
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                                self.yang_name = "allocated-binding-sid"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "allocated-binding-sid"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                        class SegmentList(Entity):
                                                            """
                                                            SR Policy Segment Lists
                                                            
                                                            .. attribute:: weight
                                                            
                                                            	Weight of segment list
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: segment
                                                            
                                                            	Segments in segment list
                                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                                self.yang_name = "segment-list"
                                                                self.yang_parent_name = "sr-policy"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                                self._leafs = OrderedDict([
                                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                ])
                                                                self.weight = None

                                                                self.segment = YList(self)
                                                                self._segment_path = lambda: "segment-list"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                            class Segment(Entity):
                                                                """
                                                                Segments in segment list
                                                                
                                                                .. attribute:: type
                                                                
                                                                	Type
                                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                                
                                                                .. attribute:: label
                                                                
                                                                	MPLS Label value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ipv4_address
                                                                
                                                                	IPv4 Address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: ipv6_address
                                                                
                                                                	IPv6 address value
                                                                	**type**\: str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-bgp-oper'
                                                                _revision = '2017-09-07'

                                                                def __init__(self):
                                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                    self.yang_name = "segment"
                                                                    self.yang_parent_name = "segment-list"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.label = None
                                                                    self.ipv4_address = None
                                                                    self.ipv6_address = None
                                                                    self._segment_path = lambda: "segment"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                                class Community(Entity):
                                                    """
                                                    Community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, self).__init__()

                                                        self.yang_name = "community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Community, [u'entry'], name, value)


                                                class ExtendedCommunity(Entity):
                                                    """
                                                    Extended community attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, self).__init__()

                                                        self.yang_name = "extended-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "extended-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                                class UnknownAttribute(Entity):
                                                    """
                                                    Unknown attributes
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, self).__init__()

                                                        self.yang_name = "unknown-attribute"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "unknown-attribute"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                                class Cluster(Entity):
                                                    """
                                                    Cluster list attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, self).__init__()

                                                        self.yang_name = "cluster"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "cluster"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.Cluster, [u'entry'], name, value)


                                                class L2tpv3Cookie(Entity):
                                                    """
                                                    L2TPv3 Cookie
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, self).__init__()

                                                        self.yang_name = "l2tpv3-cookie"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "l2tpv3-cookie"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                                class ConnectorValue(Entity):
                                                    """
                                                    Connector Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, self).__init__()

                                                        self.yang_name = "connector-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "connector-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.ConnectorValue, [u'entry'], name, value)


                                                class PmsiValue(Entity):
                                                    """
                                                    PMSI Value
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, self).__init__()

                                                        self.yang_name = "pmsi-value"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "pmsi-value"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PmsiValue, [u'entry'], name, value)


                                                class LsAttr(Entity):
                                                    """
                                                    BGP LS attribute
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, self).__init__()

                                                        self.yang_name = "ls-attr"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "ls-attr"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LsAttr, [u'entry'], name, value)


                                                class PeDistinguisherLabel(Entity):
                                                    """
                                                    PE distinguisher label attribute
                                                    
                                                    .. attribute:: pe_address
                                                    
                                                    	 PE address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: label
                                                    
                                                    	Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, self).__init__()

                                                        self.yang_name = "pe-distinguisher-label"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ])
                                                        self.pe_address = None
                                                        self.label = None
                                                        self._segment_path = lambda: "pe-distinguisher-label"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                                class LargeCommunity(Entity):
                                                    """
                                                    Large Community attribute
                                                    
                                                    .. attribute:: global_admin
                                                    
                                                    	Global Administrator
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data1
                                                    
                                                    	Local Data 1
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: local_data2
                                                    
                                                    	Local Data 2
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, self).__init__()

                                                        self.yang_name = "large-community"
                                                        self.yang_parent_name = "attr-set"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                        ])
                                                        self.global_admin = None
                                                        self.local_data1 = None
                                                        self.local_data2 = None
                                                        self._segment_path = lambda: "large-community"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                            class RnhAddr(Entity):
                                                """
                                                RNH Address
                                                
                                                .. attribute:: len
                                                
                                                	len
                                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: mac_address
                                                
                                                	MAC Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, self).__init__()

                                                    self.yang_name = "rnh-addr"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                    ])
                                                    self.len = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self.mac_address = None
                                                    self._segment_path = lambda: "rnh-addr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                            class RibrnhIp(Entity):
                                                """
                                                RIB RNH IP Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, self).__init__()

                                                    self.yang_name = "ribrnh-ip"
                                                    self.yang_parent_name = "attributes-after-policy-out"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "ribrnh-ip"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "ribrnh-ip"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.AdvertisedPaths.AdvertisedPath.AdvPathInfo.AttributesAfterPolicyOut.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NeighborAfTable(Entity):
                                """
                                The BGP Neighbor AF table
                                
                                .. attribute:: neighbor
                                
                                	A BGP Neighbor table entry
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable, self).__init__()

                                    self.yang_name = "neighbor-af-table"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "neighbor-af-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    A BGP Neighbor table entry
                                    
                                    .. attribute:: neighbor_address  (key)
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: connection_local_address
                                    
                                    	Local address for the connection
                                    	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress>`
                                    
                                    .. attribute:: connection_remote_address
                                    
                                    	Remote address for the connection
                                    	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress>`
                                    
                                    .. attribute:: send_notification_info
                                    
                                    	Information on the last notification sent
                                    	**type**\:  :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo>`
                                    
                                    .. attribute:: received_notification_info
                                    
                                    	Information on the last notification received
                                    	**type**\:  :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo>`
                                    
                                    .. attribute:: performance_statistics
                                    
                                    	Performance statistics
                                    	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics>`
                                    
                                    .. attribute:: message_statistics
                                    
                                    	Message statistics
                                    	**type**\:  :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics>`
                                    
                                    .. attribute:: tcp_init_sync_time_spec
                                    
                                    	Time When neighbor entered TCP Init Sync
                                    	**type**\:  :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_phase_two_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Phase Two
                                    	**type**\:  :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                                    
                                    .. attribute:: tcp_init_sync_done_time_spec
                                    
                                    	Time when neighbor entered TCP Init Sync Done
                                    	**type**\:  :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec>`
                                    
                                    .. attribute:: graceful_maintenance
                                    
                                    	Graceful Maintenance
                                    	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance>`
                                    
                                    .. attribute:: speaker_id
                                    
                                    	Speaker this neighbor is allocated to
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: description
                                    
                                    	Description
                                    	**type**\: str
                                    
                                    .. attribute:: local_as
                                    
                                    	Local AS number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as
                                    
                                    	Remote AS number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: has_internal_link
                                    
                                    	Internal link to neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: is_external_neighbor_not_directly_connected
                                    
                                    	External neighbor not directly connected
                                    	**type**\: bool
                                    
                                    .. attribute:: messages_received
                                    
                                    	Number of messages received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_sent
                                    
                                    	Number of messages sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_messages_in
                                    
                                    	No. of update msgs received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_messages_out
                                    
                                    	No. of update messages sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_queued_in
                                    
                                    	No. of msgs on receive queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: messages_queued_out
                                    
                                    	No. of messages on send queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_established_time
                                    
                                    	Time (in secs) that the connection has been established
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_state
                                    
                                    	State of connection
                                    	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                    
                                    .. attribute:: previous_connection_state
                                    
                                    	Previous state of connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_admin_status
                                    
                                    	Administrative status of connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: open_check_error_code
                                    
                                    	Open check error code
                                    	**type**\:  :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                                    
                                    .. attribute:: is_local_address_configured
                                    
                                    	Local address configured for the neighbor connection
                                    	**type**\: bool
                                    
                                    .. attribute:: connection_local_port
                                    
                                    	Local port for the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_remote_port
                                    
                                    	Remote port for the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_interface_handle
                                    
                                    	Interface Handle of Neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reset_notification_sent
                                    
                                    	Notification was sent during last reset
                                    	**type**\: bool
                                    
                                    .. attribute:: is_administratively_shut_down
                                    
                                    	Neighbor is administratively shut down
                                    	**type**\: bool
                                    
                                    .. attribute:: is_neighbor_max_prefix_shutdown
                                    
                                    	Neighbor shut down because it exceeded max prfx count
                                    	**type**\: bool
                                    
                                    .. attribute:: is_out_of_memory_shutdown
                                    
                                    	Neighbor shut down during a SEVERE low memory condition
                                    	**type**\: bool
                                    
                                    .. attribute:: is_out_of_memory_forced_up
                                    
                                    	Neighbor forced up during a low memory condition
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ebgp_peer_as_league
                                    
                                    	EBGP peer belongs to AS League
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ebgp_peer_common_admin
                                    
                                    	EBGP peer with common administation
                                    	**type**\: bool
                                    
                                    .. attribute:: ttl_security_enabled
                                    
                                    	TTL Security enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: suppress4_byte_as
                                    
                                    	Suppress 4byteas capability
                                    	**type**\: bool
                                    
                                    .. attribute:: bfd_session_state
                                    
                                    	BFD state for this peer
                                    	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                    
                                    .. attribute:: bfd_session_created_state
                                    
                                    	BFD state for this peer
                                    	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                                    
                                    .. attribute:: bfd_session_enable_mode
                                    
                                    	BFD enable mode for this peer
                                    	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                                    
                                    .. attribute:: bfd_minintervalval
                                    
                                    	BFD Mininterval for this peer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_multiplierval
                                    
                                    	BFD Multiplier for this peer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_state_ts
                                    
                                    	Timestamp since when nbr is in this bfd state
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: router_id
                                    
                                    	Router ID for the neighbor
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: negotiated_protocol_version
                                    
                                    	Negotiated protocol version
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ebgp_time_to_live
                                    
                                    	Maximum number of hops for external BGP neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                                    
                                    	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: tcpmss
                                    
                                    	Neighbor TCP Maximum Segment                     size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: msg_log_in
                                    
                                    	Message in log count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: msg_log_out
                                    
                                    	Message out log count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_local_as
                                    
                                    	Local AS configured on the neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_as_no_prepend
                                    
                                    	Option to not prepend the Local AS to announcements
                                    	**type**\: bool
                                    
                                    .. attribute:: is_capability_negotiation_suppressed
                                    
                                    	Capability negotiation suppressed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_capability_negotiation_performed
                                    
                                    	Capability negotiation performed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_route_refresh_capability_received
                                    
                                    	Route refresh capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_route_refresh_old_capability_received
                                    
                                    	Route refresh old capability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is_gr_aware
                                    
                                    	GR awareness received
                                    	**type**\: bool
                                    
                                    .. attribute:: is4_byte_as_capability_received
                                    
                                    	4\-byte AScapability received
                                    	**type**\: bool
                                    
                                    .. attribute:: is4_byte_as_capability_sent
                                    
                                    	4\-byte AScapability Snt
                                    	**type**\: bool
                                    
                                    .. attribute:: multi_protocol_capability_received
                                    
                                    	Multi\-protocol capability has been received
                                    	**type**\: bool
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time (in secs) negotiated for this connection
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: keep_alive_time
                                    
                                    	Keepalive time (in secs) negotiated for this connection
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_hold_time
                                    
                                    	Hold time (in secs) configured for this connection
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_keepalive
                                    
                                    	Keepalive time (in secs) configured for this connection
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: configured_min_acc_hold_time
                                    
                                    	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: min_advertise_interval
                                    
                                    	Minimum advertisement interval, secs part
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: min_advertise_interval_msecs
                                    
                                    	Minimum advertisement interval, msecs part
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: min_origination_interval
                                    
                                    	Minimum origination interval (in secs)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connect_retry_interval
                                    
                                    	Time (in secs) for connect retry timer
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_update
                                    
                                    	Time (in secs) since last update message was received
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read
                                    
                                    	Time (in secs) since last read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_since_last_read_reset
                                    
                                    	Time (in secs) since last read before last reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: time_last_cb
                                    
                                    	CB
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: time_last_cb_reset
                                    
                                    	Last CB before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_last_fb
                                    
                                    	FB
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: count_last_write
                                    
                                    	Count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_last_write
                                    
                                    	Time (in secs) since last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: attempted_last_write_bytes
                                    
                                    	Attempted size of last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_last_write_bytes
                                    
                                    	Actual size of last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_second_last_write
                                    
                                    	Time (in secs) since second  last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: attempted_second_last_write_bytes
                                    
                                    	Attempted size of second last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_bytes
                                    
                                    	Actual size of second last write
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: attempted_last_write_reset_bytes
                                    
                                    	Attempted size of last write before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_last_write_reset_bytes
                                    
                                    	Actual size of last write before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_second_last_write_reset
                                    
                                    	Time (in secs) since last write before last reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: attempted_second_last_write_reset_bytes
                                    
                                    	Attempted size of second last write before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: actual_second_last_write_reset_bytes
                                    
                                    	Actual size of second last write before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_write_event
                                    
                                    	Time (in secs) since last write thread event
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_write_event
                                    
                                    	Time (in secs) since second last write thread event
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_aexpiry_reset
                                    
                                    	Time (in secs) since last KA timer expiry before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_k_aexpiry_reset
                                    
                                    	Time (in secs) since second last KA timer expiry before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_anotsent_reset
                                    
                                    	Duration (in secs) since last time that KA was not sent before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_aerror_reset
                                    
                                    	Duration (in secs) since last time that an error was encountered after KA expiry
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_k_astart_reset
                                    
                                    	Time (in secs) since the last KA timer start before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: second_last_k_astart_reset
                                    
                                    	Time (in secs) since the second last KA timer start before reset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of times the connection was established
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of times connection was dropped
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_since_connection_last_dropped
                                    
                                    	Time since the connection last went down (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: reset_reason
                                    
                                    	Reason for last connection reset
                                    	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    .. attribute:: peer_reset_reason
                                    
                                    	Reason for last peer close event
                                    	**type**\:  :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                                    
                                    .. attribute:: peer_error_code
                                    
                                    	If peer closed, error received from transport
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_notify_error_code
                                    
                                    	Code for the last error notification seen on the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notify_error_subcode
                                    
                                    	Error subcode of the last error notification seen on the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: error_notifies_received
                                    
                                    	Number of error notifications received on the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: error_notifies_sent
                                    
                                    	Number of error notifications sent on the connection
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_as_number
                                    
                                    	Remote AS number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dmz_link_bandwidth
                                    
                                    	Bandwidth of link to single\-hop eBGP peer
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ebgp_recv_dmz
                                    
                                    	Receive Bandwidth of link to single\-hop eBGP peer
                                    	**type**\: bool
                                    
                                    .. attribute:: ebgp_send_dmz_mode
                                    
                                    	Ebgp send dmz link bw mode
                                    	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                                    
                                    .. attribute:: tos_type
                                    
                                    	Precedence or DSCP type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_value
                                    
                                    	Precedence or DSCP value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tcp_session_open_mode
                                    
                                    	The TCP mode to be used to set up BGP session with the neighbor
                                    	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: standby_rp
                                    
                                    	Standby RP socket inited for Active Open
                                    	**type**\: bool
                                    
                                    .. attribute:: nsr_enabled
                                    
                                    	Neighbor supports NSR
                                    	**type**\: bool
                                    
                                    .. attribute:: graceful_restart_enabled_nbr
                                    
                                    	Neighbor supports graceful\-restart
                                    	**type**\: bool
                                    
                                    .. attribute:: gr_restart_time
                                    
                                    	Neighbor restart time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: gr_stale_path_time
                                    
                                    	Neighbor stale\-path time (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: fssn_offset
                                    
                                    	First standby SeqNo offset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fpbsn_offset
                                    
                                    	First standby PDU boundary SeqNo offset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_ackd_seq_no
                                    
                                    	SeqNo of the last Ackd byte
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bytes_written
                                    
                                    	Total bytes written by write thread
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: bytes_read
                                    
                                    	Total bytes read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: socket_read_bytes
                                    
                                    	Total read bytes value insocket\-lib
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: is_read_disabled
                                    
                                    	If true, socket read isdisabled
                                    	**type**\: bool
                                    
                                    .. attribute:: update_bytes_read
                                    
                                    	Total update bytes read
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: nsr_state
                                    
                                    	NSR state
                                    	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                                    
                                    .. attribute:: is_passive_close
                                    
                                    	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: nbr_enforce_first_as
                                    
                                    	Neighbor enforce first AS
                                    	**type**\: bool
                                    
                                    .. attribute:: active_bmp_servers
                                    
                                    	BMP Servers to which the neighbor sends logs
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nbr_cluster_id
                                    
                                    	Cluster id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nbr_in_cluster
                                    
                                    	Type of cluster\_id\:undefined/number/Ip address
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ignore_connected
                                    
                                    	If true, the VPN client isan IBGP CE peer
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_vpn_client
                                    
                                    	If true, don't do NHconnected check for nbr
                                    	**type**\: bool
                                    
                                    .. attribute:: io_armed
                                    
                                    	If true, socket has beenauto\-armed for io control
                                    	**type**\: bool
                                    
                                    .. attribute:: read_armed
                                    
                                    	If true, socket has beenauto\-armed for read
                                    	**type**\: bool
                                    
                                    .. attribute:: write_armed
                                    
                                    	If true, socket has beenauto\-armed for write
                                    	**type**\: bool
                                    
                                    .. attribute:: discard_data_bytes
                                    
                                    	Remaining discard data (bytes) on Standby
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: local_as_replace_as
                                    
                                    	Local AS Replace\-AS option
                                    	**type**\: bool
                                    
                                    .. attribute:: local_as_dual_as
                                    
                                    	Local AS Dual\-AS option
                                    	**type**\: bool
                                    
                                    .. attribute:: local_as_dual_as_mode_native
                                    
                                    	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                                    	**type**\: bool
                                    
                                    .. attribute:: egress_peer_engineering_enabled
                                    
                                    	Indicates if Egress Peer Engineering is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: discard_as4_path
                                    
                                    	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rpki_disable
                                    
                                    	Prefix validation disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: rpki_use_validity
                                    
                                    	Prefix v. use validity
                                    	**type**\: bool
                                    
                                    .. attribute:: rpki_allow_invalid
                                    
                                    	Prefix v. allow invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: rpki_signal_ibgp
                                    
                                    	Prefix v. signal ibgp
                                    	**type**\: bool
                                    
                                    .. attribute:: dynamic_neighbor
                                    
                                    	Dynamic neighbor
                                    	**type**\: bool
                                    
                                    .. attribute:: af_data
                                    
                                    	Address family specific neighbor data
                                    	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "neighbor-af-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['neighbor_address']
                                        self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress)), ("send-notification-info", ("send_notification_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo)), ("received-notification-info", ("received_notification_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics)), ("message-statistics", ("message_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics)), ("tcp-init-sync-time-spec", ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec)), ("tcp-init-sync-phase-two-time-spec", ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec)), ("tcp-init-sync-done-time-spec", ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData))])
                                        self._leafs = OrderedDict([
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                            ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                            ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                            ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                            ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                            ('is_external_neighbor_not_directly_connected', (YLeaf(YType.boolean, 'is-external-neighbor-not-directly-connected'), ['bool'])),
                                            ('messages_received', (YLeaf(YType.uint32, 'messages-received'), ['int'])),
                                            ('messages_sent', (YLeaf(YType.uint32, 'messages-sent'), ['int'])),
                                            ('update_messages_in', (YLeaf(YType.uint32, 'update-messages-in'), ['int'])),
                                            ('update_messages_out', (YLeaf(YType.uint32, 'update-messages-out'), ['int'])),
                                            ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                            ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                            ('connection_established_time', (YLeaf(YType.uint32, 'connection-established-time'), ['int'])),
                                            ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                            ('previous_connection_state', (YLeaf(YType.uint32, 'previous-connection-state'), ['int'])),
                                            ('connection_admin_status', (YLeaf(YType.uint32, 'connection-admin-status'), ['int'])),
                                            ('open_check_error_code', (YLeaf(YType.enumeration, 'open-check-error-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpOpenCheckErr', '')])),
                                            ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                            ('connection_local_port', (YLeaf(YType.uint32, 'connection-local-port'), ['int'])),
                                            ('connection_remote_port', (YLeaf(YType.uint32, 'connection-remote-port'), ['int'])),
                                            ('neighbor_interface_handle', (YLeaf(YType.uint32, 'neighbor-interface-handle'), ['int'])),
                                            ('reset_notification_sent', (YLeaf(YType.boolean, 'reset-notification-sent'), ['bool'])),
                                            ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                            ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                            ('is_out_of_memory_shutdown', (YLeaf(YType.boolean, 'is-out-of-memory-shutdown'), ['bool'])),
                                            ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                            ('is_ebgp_peer_as_league', (YLeaf(YType.boolean, 'is-ebgp-peer-as-league'), ['bool'])),
                                            ('is_ebgp_peer_common_admin', (YLeaf(YType.boolean, 'is-ebgp-peer-common-admin'), ['bool'])),
                                            ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                            ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                            ('bfd_session_state', (YLeaf(YType.enumeration, 'bfd-session-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                            ('bfd_session_created_state', (YLeaf(YType.enumeration, 'bfd-session-created-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                            ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                            ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                            ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                            ('bfd_state_ts', (YLeaf(YType.uint64, 'bfd-state-ts'), ['int'])),
                                            ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                            ('negotiated_protocol_version', (YLeaf(YType.uint16, 'negotiated-protocol-version'), ['int'])),
                                            ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                            ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                            ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                            ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                            ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                            ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                            ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                            ('is_capability_negotiation_suppressed', (YLeaf(YType.boolean, 'is-capability-negotiation-suppressed'), ['bool'])),
                                            ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                            ('is_route_refresh_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-capability-received'), ['bool'])),
                                            ('is_route_refresh_old_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-old-capability-received'), ['bool'])),
                                            ('is_gr_aware', (YLeaf(YType.boolean, 'is-gr-aware'), ['bool'])),
                                            ('is4_byte_as_capability_received', (YLeaf(YType.boolean, 'is4-byte-as-capability-received'), ['bool'])),
                                            ('is4_byte_as_capability_sent', (YLeaf(YType.boolean, 'is4-byte-as-capability-sent'), ['bool'])),
                                            ('multi_protocol_capability_received', (YLeaf(YType.boolean, 'multi-protocol-capability-received'), ['bool'])),
                                            ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                            ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                            ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                            ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                            ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                            ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                            ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                            ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                            ('connect_retry_interval', (YLeaf(YType.uint16, 'connect-retry-interval'), ['int'])),
                                            ('time_since_last_update', (YLeaf(YType.uint32, 'time-since-last-update'), ['int'])),
                                            ('time_since_last_read', (YLeaf(YType.uint32, 'time-since-last-read'), ['int'])),
                                            ('time_since_last_read_reset', (YLeaf(YType.uint32, 'time-since-last-read-reset'), ['int'])),
                                            ('time_last_cb', (YLeaf(YType.uint64, 'time-last-cb'), ['int'])),
                                            ('time_last_cb_reset', (YLeaf(YType.uint32, 'time-last-cb-reset'), ['int'])),
                                            ('time_last_fb', (YLeaf(YType.uint64, 'time-last-fb'), ['int'])),
                                            ('count_last_write', (YLeaf(YType.uint32, 'count-last-write'), ['int'])),
                                            ('time_since_last_write', (YLeaf(YType.uint32, 'time-since-last-write'), ['int'])),
                                            ('attempted_last_write_bytes', (YLeaf(YType.uint32, 'attempted-last-write-bytes'), ['int'])),
                                            ('actual_last_write_bytes', (YLeaf(YType.uint32, 'actual-last-write-bytes'), ['int'])),
                                            ('time_since_second_last_write', (YLeaf(YType.uint32, 'time-since-second-last-write'), ['int'])),
                                            ('attempted_second_last_write_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-bytes'), ['int'])),
                                            ('actual_second_last_write_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-bytes'), ['int'])),
                                            ('time_since_last_write_reset', (YLeaf(YType.uint32, 'time-since-last-write-reset'), ['int'])),
                                            ('attempted_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-last-write-reset-bytes'), ['int'])),
                                            ('actual_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-last-write-reset-bytes'), ['int'])),
                                            ('time_since_second_last_write_reset', (YLeaf(YType.uint32, 'time-since-second-last-write-reset'), ['int'])),
                                            ('attempted_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-reset-bytes'), ['int'])),
                                            ('actual_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-reset-bytes'), ['int'])),
                                            ('last_write_event', (YLeaf(YType.uint32, 'last-write-event'), ['int'])),
                                            ('second_last_write_event', (YLeaf(YType.uint32, 'second-last-write-event'), ['int'])),
                                            ('last_k_aexpiry_reset', (YLeaf(YType.uint32, 'last-k-aexpiry-reset'), ['int'])),
                                            ('second_last_k_aexpiry_reset', (YLeaf(YType.uint32, 'second-last-k-aexpiry-reset'), ['int'])),
                                            ('last_k_anotsent_reset', (YLeaf(YType.uint32, 'last-k-anotsent-reset'), ['int'])),
                                            ('last_k_aerror_reset', (YLeaf(YType.uint32, 'last-k-aerror-reset'), ['int'])),
                                            ('last_k_astart_reset', (YLeaf(YType.uint32, 'last-k-astart-reset'), ['int'])),
                                            ('second_last_k_astart_reset', (YLeaf(YType.uint32, 'second-last-k-astart-reset'), ['int'])),
                                            ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                            ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                            ('time_since_connection_last_dropped', (YLeaf(YType.uint32, 'time-since-connection-last-dropped'), ['int'])),
                                            ('reset_reason', (YLeaf(YType.enumeration, 'reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                            ('peer_reset_reason', (YLeaf(YType.enumeration, 'peer-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPeerResetReasonIndex', '')])),
                                            ('peer_error_code', (YLeaf(YType.uint32, 'peer-error-code'), ['int'])),
                                            ('last_notify_error_code', (YLeaf(YType.uint8, 'last-notify-error-code'), ['int'])),
                                            ('last_notify_error_subcode', (YLeaf(YType.uint8, 'last-notify-error-subcode'), ['int'])),
                                            ('error_notifies_received', (YLeaf(YType.uint32, 'error-notifies-received'), ['int'])),
                                            ('error_notifies_sent', (YLeaf(YType.uint32, 'error-notifies-sent'), ['int'])),
                                            ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                            ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                            ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                            ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                            ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                            ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                            ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                            ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                            ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                            ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                            ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                            ('fssn_offset', (YLeaf(YType.uint32, 'fssn-offset'), ['int'])),
                                            ('fpbsn_offset', (YLeaf(YType.uint32, 'fpbsn-offset'), ['int'])),
                                            ('last_ackd_seq_no', (YLeaf(YType.uint32, 'last-ackd-seq-no'), ['int'])),
                                            ('bytes_written', (YLeaf(YType.uint32, 'bytes-written'), ['int'])),
                                            ('bytes_read', (YLeaf(YType.uint32, 'bytes-read'), ['int'])),
                                            ('socket_read_bytes', (YLeaf(YType.uint32, 'socket-read-bytes'), ['int'])),
                                            ('is_read_disabled', (YLeaf(YType.boolean, 'is-read-disabled'), ['bool'])),
                                            ('update_bytes_read', (YLeaf(YType.uint32, 'update-bytes-read'), ['int'])),
                                            ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                            ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                            ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                            ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                            ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                            ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                            ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                            ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                            ('io_armed', (YLeaf(YType.boolean, 'io-armed'), ['bool'])),
                                            ('read_armed', (YLeaf(YType.boolean, 'read-armed'), ['bool'])),
                                            ('write_armed', (YLeaf(YType.boolean, 'write-armed'), ['bool'])),
                                            ('discard_data_bytes', (YLeaf(YType.uint32, 'discard-data-bytes'), ['int'])),
                                            ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                            ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                            ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                            ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                            ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                            ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                            ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                            ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                            ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                            ('dynamic_neighbor', (YLeaf(YType.boolean, 'dynamic-neighbor'), ['bool'])),
                                        ])
                                        self.neighbor_address = None
                                        self.speaker_id = None
                                        self.description = None
                                        self.local_as = None
                                        self.remote_as = None
                                        self.has_internal_link = None
                                        self.is_external_neighbor_not_directly_connected = None
                                        self.messages_received = None
                                        self.messages_sent = None
                                        self.update_messages_in = None
                                        self.update_messages_out = None
                                        self.messages_queued_in = None
                                        self.messages_queued_out = None
                                        self.connection_established_time = None
                                        self.connection_state = None
                                        self.previous_connection_state = None
                                        self.connection_admin_status = None
                                        self.open_check_error_code = None
                                        self.is_local_address_configured = None
                                        self.connection_local_port = None
                                        self.connection_remote_port = None
                                        self.neighbor_interface_handle = None
                                        self.reset_notification_sent = None
                                        self.is_administratively_shut_down = None
                                        self.is_neighbor_max_prefix_shutdown = None
                                        self.is_out_of_memory_shutdown = None
                                        self.is_out_of_memory_forced_up = None
                                        self.is_ebgp_peer_as_league = None
                                        self.is_ebgp_peer_common_admin = None
                                        self.ttl_security_enabled = None
                                        self.suppress4_byte_as = None
                                        self.bfd_session_state = None
                                        self.bfd_session_created_state = None
                                        self.bfd_session_enable_mode = None
                                        self.bfd_minintervalval = None
                                        self.bfd_multiplierval = None
                                        self.bfd_state_ts = None
                                        self.router_id = None
                                        self.negotiated_protocol_version = None
                                        self.ebgp_time_to_live = None
                                        self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                        self.tcpmss = None
                                        self.msg_log_in = None
                                        self.msg_log_out = None
                                        self.neighbor_local_as = None
                                        self.local_as_no_prepend = None
                                        self.is_capability_negotiation_suppressed = None
                                        self.is_capability_negotiation_performed = None
                                        self.is_route_refresh_capability_received = None
                                        self.is_route_refresh_old_capability_received = None
                                        self.is_gr_aware = None
                                        self.is4_byte_as_capability_received = None
                                        self.is4_byte_as_capability_sent = None
                                        self.multi_protocol_capability_received = None
                                        self.hold_time = None
                                        self.keep_alive_time = None
                                        self.configured_hold_time = None
                                        self.configured_keepalive = None
                                        self.configured_min_acc_hold_time = None
                                        self.min_advertise_interval = None
                                        self.min_advertise_interval_msecs = None
                                        self.min_origination_interval = None
                                        self.connect_retry_interval = None
                                        self.time_since_last_update = None
                                        self.time_since_last_read = None
                                        self.time_since_last_read_reset = None
                                        self.time_last_cb = None
                                        self.time_last_cb_reset = None
                                        self.time_last_fb = None
                                        self.count_last_write = None
                                        self.time_since_last_write = None
                                        self.attempted_last_write_bytes = None
                                        self.actual_last_write_bytes = None
                                        self.time_since_second_last_write = None
                                        self.attempted_second_last_write_bytes = None
                                        self.actual_second_last_write_bytes = None
                                        self.time_since_last_write_reset = None
                                        self.attempted_last_write_reset_bytes = None
                                        self.actual_last_write_reset_bytes = None
                                        self.time_since_second_last_write_reset = None
                                        self.attempted_second_last_write_reset_bytes = None
                                        self.actual_second_last_write_reset_bytes = None
                                        self.last_write_event = None
                                        self.second_last_write_event = None
                                        self.last_k_aexpiry_reset = None
                                        self.second_last_k_aexpiry_reset = None
                                        self.last_k_anotsent_reset = None
                                        self.last_k_aerror_reset = None
                                        self.last_k_astart_reset = None
                                        self.second_last_k_astart_reset = None
                                        self.connection_up_count = None
                                        self.connection_down_count = None
                                        self.time_since_connection_last_dropped = None
                                        self.reset_reason = None
                                        self.peer_reset_reason = None
                                        self.peer_error_code = None
                                        self.last_notify_error_code = None
                                        self.last_notify_error_subcode = None
                                        self.error_notifies_received = None
                                        self.error_notifies_sent = None
                                        self.remote_as_number = None
                                        self.dmz_link_bandwidth = None
                                        self.ebgp_recv_dmz = None
                                        self.ebgp_send_dmz_mode = None
                                        self.tos_type = None
                                        self.tos_value = None
                                        self.tcp_session_open_mode = None
                                        self.vrf_name = None
                                        self.standby_rp = None
                                        self.nsr_enabled = None
                                        self.graceful_restart_enabled_nbr = None
                                        self.gr_restart_time = None
                                        self.gr_stale_path_time = None
                                        self.fssn_offset = None
                                        self.fpbsn_offset = None
                                        self.last_ackd_seq_no = None
                                        self.bytes_written = None
                                        self.bytes_read = None
                                        self.socket_read_bytes = None
                                        self.is_read_disabled = None
                                        self.update_bytes_read = None
                                        self.nsr_state = None
                                        self.is_passive_close = None
                                        self.nbr_enforce_first_as = None
                                        self.active_bmp_servers = None
                                        self.nbr_cluster_id = None
                                        self.nbr_in_cluster = None
                                        self.ignore_connected = None
                                        self.internal_vpn_client = None
                                        self.io_armed = None
                                        self.read_armed = None
                                        self.write_armed = None
                                        self.discard_data_bytes = None
                                        self.local_as_replace_as = None
                                        self.local_as_dual_as = None
                                        self.local_as_dual_as_mode_native = None
                                        self.egress_peer_engineering_enabled = None
                                        self.discard_as4_path = None
                                        self.rpki_disable = None
                                        self.rpki_use_validity = None
                                        self.rpki_allow_invalid = None
                                        self.rpki_signal_ibgp = None
                                        self.dynamic_neighbor = None

                                        self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress()
                                        self.connection_local_address.parent = self
                                        self._children_name_map["connection_local_address"] = "connection-local-address"

                                        self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress()
                                        self.connection_remote_address.parent = self
                                        self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                        self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo()
                                        self.send_notification_info.parent = self
                                        self._children_name_map["send_notification_info"] = "send-notification-info"

                                        self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo()
                                        self.received_notification_info.parent = self
                                        self._children_name_map["received_notification_info"] = "received-notification-info"

                                        self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics()
                                        self.performance_statistics.parent = self
                                        self._children_name_map["performance_statistics"] = "performance-statistics"

                                        self.message_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics()
                                        self.message_statistics.parent = self
                                        self._children_name_map["message_statistics"] = "message-statistics"

                                        self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec()
                                        self.tcp_init_sync_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"

                                        self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                        self.tcp_init_sync_phase_two_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"

                                        self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec()
                                        self.tcp_init_sync_done_time_spec.parent = self
                                        self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"

                                        self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance()
                                        self.graceful_maintenance.parent = self
                                        self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                        self.af_data = YList(self)
                                        self._segment_path = lambda: "neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_external_neighbor_not_directly_connected', u'messages_received', u'messages_sent', u'update_messages_in', u'update_messages_out', u'messages_queued_in', u'messages_queued_out', u'connection_established_time', u'connection_state', u'previous_connection_state', u'connection_admin_status', u'open_check_error_code', u'is_local_address_configured', u'connection_local_port', u'connection_remote_port', u'neighbor_interface_handle', u'reset_notification_sent', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_shutdown', u'is_out_of_memory_forced_up', u'is_ebgp_peer_as_league', u'is_ebgp_peer_common_admin', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_state', u'bfd_session_created_state', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'bfd_state_ts', u'router_id', u'negotiated_protocol_version', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_suppressed', u'is_capability_negotiation_performed', u'is_route_refresh_capability_received', u'is_route_refresh_old_capability_received', u'is_gr_aware', u'is4_byte_as_capability_received', u'is4_byte_as_capability_sent', u'multi_protocol_capability_received', u'hold_time', u'keep_alive_time', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'connect_retry_interval', u'time_since_last_update', u'time_since_last_read', u'time_since_last_read_reset', u'time_last_cb', u'time_last_cb_reset', u'time_last_fb', u'count_last_write', u'time_since_last_write', u'attempted_last_write_bytes', u'actual_last_write_bytes', u'time_since_second_last_write', u'attempted_second_last_write_bytes', u'actual_second_last_write_bytes', u'time_since_last_write_reset', u'attempted_last_write_reset_bytes', u'actual_last_write_reset_bytes', u'time_since_second_last_write_reset', u'attempted_second_last_write_reset_bytes', u'actual_second_last_write_reset_bytes', u'last_write_event', u'second_last_write_event', u'last_k_aexpiry_reset', u'second_last_k_aexpiry_reset', u'last_k_anotsent_reset', u'last_k_aerror_reset', u'last_k_astart_reset', u'second_last_k_astart_reset', u'connection_up_count', u'connection_down_count', u'time_since_connection_last_dropped', u'reset_reason', u'peer_reset_reason', u'peer_error_code', u'last_notify_error_code', u'last_notify_error_subcode', u'error_notifies_received', u'error_notifies_sent', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'fssn_offset', u'fpbsn_offset', u'last_ackd_seq_no', u'bytes_written', u'bytes_read', u'socket_read_bytes', u'is_read_disabled', u'update_bytes_read', u'nsr_state', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'io_armed', u'read_armed', u'write_armed', u'discard_data_bytes', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'dynamic_neighbor'], name, value)


                                    class ConnectionLocalAddress(Entity):
                                        """
                                        Local address for the connection
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, self).__init__()

                                            self.yang_name = "connection-local-address"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "connection-local-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "connection-local-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class ConnectionRemoteAddress(Entity):
                                        """
                                        Remote address for the connection
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, self).__init__()

                                            self.yang_name = "connection-remote-address"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "connection-remote-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "connection-remote-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class SendNotificationInfo(Entity):
                                        """
                                        Information on the last notification sent
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, self).__init__()

                                            self.yang_name = "send-notification-info"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData))])
                                            self._leafs = OrderedDict([
                                                ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                                ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                                ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                            ])
                                            self.time_since_last_notification = None
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "send-notification-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "send-notification-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "last-notification-data"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.SendNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                    class ReceivedNotificationInfo(Entity):
                                        """
                                        Information on the last notification received
                                        
                                        .. attribute:: time_since_last_notification
                                        
                                        	Time since the last notification was sent or received (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: notification_error_code
                                        
                                        	Error code in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: notification_error_subcode
                                        
                                        	Error subcode in last notification
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_notification_data
                                        
                                        	Message data in last notification
                                        	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, self).__init__()

                                            self.yang_name = "received-notification-info"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData))])
                                            self._leafs = OrderedDict([
                                                ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                                ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                                ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                            ])
                                            self.time_since_last_notification = None
                                            self.notification_error_code = None
                                            self.notification_error_subcode = None

                                            self.last_notification_data = YList(self)
                                            self._segment_path = lambda: "received-notification-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                        class LastNotificationData(Entity):
                                            """
                                            Message data in last notification
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                                self.yang_name = "last-notification-data"
                                                self.yang_parent_name = "received-notification-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "last-notification-data"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.ReceivedNotificationInfo.LastNotificationData, [u'entry'], name, value)


                                    class PerformanceStatistics(Entity):
                                        """
                                        Performance statistics
                                        
                                        .. attribute:: read_throttles
                                        
                                        	Number of partial read throttles
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_throttled_read
                                        
                                        	Num socket reads after nbrs crossed low threshold
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: high_throttled_read
                                        
                                        	Num of socket reads after nbr crossed high threshold
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: time_since_last_throttled_read
                                        
                                        	Time (in secs) since last read after being throttled
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: read_calls_count
                                        
                                        	No. of calls to function to read inbound data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: read_messages_count
                                        
                                        	Number of BGP messages read
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: data_bytes_read
                                        
                                        	No. of bytes of data read
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: io_read_time
                                        
                                        	Time spent reading inbound data (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: write_calls_count
                                        
                                        	No. of calls to function to write outbound data
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: data_bytes_written
                                        
                                        	No. of data bytes written
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: io_write_time
                                        
                                        	Time spent writing outbound data (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: last_sent_seq_no
                                        
                                        	Seq No of the last sent byte
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_subgroup_calls_count
                                        
                                        	No. of calls to function to process sub\-group message list
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_subgroup_messages_count
                                        
                                        	Number of sub\-group msgs processed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: subgroup_list_time
                                        
                                        	Time spent processing sub\-group message list  (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: write_queue_calls_count
                                        
                                        	No. of calls to function to process write queue
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_messages_count
                                        
                                        	Number of write queue messages processed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: write_queue_time
                                        
                                        	Time spent processing write queue (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: inbound_update_messages
                                        
                                        	Number of inbound update messages processed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inbound_update_messages_time
                                        
                                        	Time spent processing inbound update messages (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: maximum_read_size
                                        
                                        	Size of largest socket (milliseconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: actives
                                        
                                        	Number of retried Active opens for this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: failed_post_actives
                                        
                                        	Number of Active Opens that failed in the Post Active State for this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passives
                                        
                                        	Number of retried Passive opens for this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rejected_passives
                                        
                                        	Number of rejected Passive opens for this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: active_collision
                                        
                                        	Number of Closed Active connections for this neighbor due to collision 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: passive_collision
                                        
                                        	Number of Closed Remote opens for this neighborneighbor due to collision 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_read_thread_trigger
                                        
                                        	Number of times io\-control thread trigger read thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: control_to_write_thread_trigger
                                        
                                        	Number of times io\-control thread trigger write thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: network_status
                                        
                                        	Socket status, TRUE if socket closed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reset_flags
                                        
                                        	Reset flags, per thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nbr_flags
                                        
                                        	Nbr flags, per thread
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nbr_fd
                                        
                                        	Primary FD, per nbr
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: reset_retries
                                        
                                        	Reset Retries, per nbr
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: sync_flags
                                        
                                        	Sync flags, per nbr
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: nsr_oper_down_count
                                        
                                        	Number of times NSR scoped sync has been done
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_nsr_scoped_sync
                                        
                                        	Last time NSR scoped syncwas done for the neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, self).__init__()

                                            self.yang_name = "performance-statistics"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('read_throttles', (YLeaf(YType.uint32, 'read-throttles'), ['int'])),
                                                ('low_throttled_read', (YLeaf(YType.uint32, 'low-throttled-read'), ['int'])),
                                                ('high_throttled_read', (YLeaf(YType.uint32, 'high-throttled-read'), ['int'])),
                                                ('time_since_last_throttled_read', (YLeaf(YType.uint32, 'time-since-last-throttled-read'), ['int'])),
                                                ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                                ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                                ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                                ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                                ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                                ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                                ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                                ('last_sent_seq_no', (YLeaf(YType.uint32, 'last-sent-seq-no'), ['int'])),
                                                ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                                ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                                ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                                ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                                ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                                ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                                ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                                ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                                ('maximum_read_size', (YLeaf(YType.uint32, 'maximum-read-size'), ['int'])),
                                                ('actives', (YLeaf(YType.uint32, 'actives'), ['int'])),
                                                ('failed_post_actives', (YLeaf(YType.uint32, 'failed-post-actives'), ['int'])),
                                                ('passives', (YLeaf(YType.uint32, 'passives'), ['int'])),
                                                ('rejected_passives', (YLeaf(YType.uint32, 'rejected-passives'), ['int'])),
                                                ('active_collision', (YLeaf(YType.uint32, 'active-collision'), ['int'])),
                                                ('passive_collision', (YLeaf(YType.uint32, 'passive-collision'), ['int'])),
                                                ('control_to_read_thread_trigger', (YLeaf(YType.uint32, 'control-to-read-thread-trigger'), ['int'])),
                                                ('control_to_write_thread_trigger', (YLeaf(YType.uint32, 'control-to-write-thread-trigger'), ['int'])),
                                                ('network_status', (YLeaf(YType.uint32, 'network-status'), ['int'])),
                                                ('reset_flags', (YLeaf(YType.uint32, 'reset-flags'), ['int'])),
                                                ('nbr_flags', (YLeaf(YType.uint32, 'nbr-flags'), ['int'])),
                                                ('nbr_fd', (YLeaf(YType.int32, 'nbr-fd'), ['int'])),
                                                ('reset_retries', (YLeaf(YType.uint8, 'reset-retries'), ['int'])),
                                                ('sync_flags', (YLeaf(YType.uint32, 'sync-flags'), ['int'])),
                                                ('nsr_oper_down_count', (YLeaf(YType.uint32, 'nsr-oper-down-count'), ['int'])),
                                                ('last_nsr_scoped_sync', (YLeaf(YType.uint32, 'last-nsr-scoped-sync'), ['int'])),
                                            ])
                                            self.read_throttles = None
                                            self.low_throttled_read = None
                                            self.high_throttled_read = None
                                            self.time_since_last_throttled_read = None
                                            self.read_calls_count = None
                                            self.read_messages_count = None
                                            self.data_bytes_read = None
                                            self.io_read_time = None
                                            self.write_calls_count = None
                                            self.data_bytes_written = None
                                            self.io_write_time = None
                                            self.last_sent_seq_no = None
                                            self.write_subgroup_calls_count = None
                                            self.write_subgroup_messages_count = None
                                            self.subgroup_list_time = None
                                            self.write_queue_calls_count = None
                                            self.write_queue_messages_count = None
                                            self.write_queue_time = None
                                            self.inbound_update_messages = None
                                            self.inbound_update_messages_time = None
                                            self.maximum_read_size = None
                                            self.actives = None
                                            self.failed_post_actives = None
                                            self.passives = None
                                            self.rejected_passives = None
                                            self.active_collision = None
                                            self.passive_collision = None
                                            self.control_to_read_thread_trigger = None
                                            self.control_to_write_thread_trigger = None
                                            self.network_status = None
                                            self.reset_flags = None
                                            self.nbr_flags = None
                                            self.nbr_fd = None
                                            self.reset_retries = None
                                            self.sync_flags = None
                                            self.nsr_oper_down_count = None
                                            self.last_nsr_scoped_sync = None
                                            self._segment_path = lambda: "performance-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.PerformanceStatistics, [u'read_throttles', u'low_throttled_read', u'high_throttled_read', u'time_since_last_throttled_read', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'last_sent_seq_no', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time', u'maximum_read_size', u'actives', u'failed_post_actives', u'passives', u'rejected_passives', u'active_collision', u'passive_collision', u'control_to_read_thread_trigger', u'control_to_write_thread_trigger', u'network_status', u'reset_flags', u'nbr_flags', u'nbr_fd', u'reset_retries', u'sync_flags', u'nsr_oper_down_count', u'last_nsr_scoped_sync'], name, value)


                                    class MessageStatistics(Entity):
                                        """
                                        Message statistics
                                        
                                        .. attribute:: open
                                        
                                        	Open
                                        	**type**\:  :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open>`
                                        
                                        .. attribute:: notification
                                        
                                        	Notification
                                        	**type**\:  :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification>`
                                        
                                        .. attribute:: update
                                        
                                        	Update
                                        	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update>`
                                        
                                        .. attribute:: keepalive
                                        
                                        	Keepalive
                                        	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive>`
                                        
                                        .. attribute:: route_refresh
                                        
                                        	Route refresh
                                        	**type**\:  :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh>`
                                        
                                        .. attribute:: total
                                        
                                        	Total
                                        	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, self).__init__()

                                            self.yang_name = "message-statistics"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("open", ("open", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open)), ("notification", ("notification", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification)), ("update", ("update", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update)), ("keepalive", ("keepalive", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive)), ("route-refresh", ("route_refresh", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh)), ("total", ("total", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total))])
                                            self._leafs = OrderedDict()

                                            self.open = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open()
                                            self.open.parent = self
                                            self._children_name_map["open"] = "open"

                                            self.notification = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification()
                                            self.notification.parent = self
                                            self._children_name_map["notification"] = "notification"

                                            self.update = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update()
                                            self.update.parent = self
                                            self._children_name_map["update"] = "update"

                                            self.keepalive = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive()
                                            self.keepalive.parent = self
                                            self._children_name_map["keepalive"] = "keepalive"

                                            self.route_refresh = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh()
                                            self.route_refresh.parent = self
                                            self._children_name_map["route_refresh"] = "route-refresh"

                                            self.total = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total()
                                            self.total.parent = self
                                            self._children_name_map["total"] = "total"
                                            self._segment_path = lambda: "message-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics, [], name, value)


                                        class Open(Entity):
                                            """
                                            Open
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, self).__init__()

                                                self.yang_name = "open"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "open"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "open"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "open"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Notification(Entity):
                                            """
                                            Notification
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, self).__init__()

                                                self.yang_name = "notification"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "notification"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "notification"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "notification"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Update(Entity):
                                            """
                                            Update
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, self).__init__()

                                                self.yang_name = "update"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "update"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "update"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Keepalive(Entity):
                                            """
                                            Keepalive
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                                self.yang_name = "keepalive"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "keepalive"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "keepalive"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "keepalive"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class RouteRefresh(Entity):
                                            """
                                            Route refresh
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                                self.yang_name = "route-refresh"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "route-refresh"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "route-refresh"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "route-refresh"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                        class Total(Entity):
                                            """
                                            Total
                                            
                                            .. attribute:: tx
                                            
                                            	Transmit
                                            	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx>`
                                            
                                            .. attribute:: rx
                                            
                                            	Receive
                                            	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, self).__init__()

                                                self.yang_name = "total"
                                                self.yang_parent_name = "message-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx))])
                                                self._leafs = OrderedDict()

                                                self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx()
                                                self.tx.parent = self
                                                self._children_name_map["tx"] = "tx"

                                                self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx()
                                                self.rx.parent = self
                                                self._children_name_map["rx"] = "rx"
                                                self._segment_path = lambda: "total"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total, [], name, value)


                                            class Tx(Entity):
                                                """
                                                Transmit
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                                    self.yang_name = "tx"
                                                    self.yang_parent_name = "total"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "tx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "tx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                            class Rx(Entity):
                                                """
                                                Receive
                                                
                                                .. attribute:: last_time_spec
                                                
                                                	Last timespec
                                                	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                                
                                                .. attribute:: count
                                                
                                                	Count
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                                    self.yang_name = "rx"
                                                    self.yang_parent_name = "total"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec))])
                                                    self._leafs = OrderedDict([
                                                        ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                                    ])
                                                    self.count = None

                                                    self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                                    self.last_time_spec.parent = self
                                                    self._children_name_map["last_time_spec"] = "last-time-spec"
                                                    self._segment_path = lambda: "rx"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx, [u'count'], name, value)


                                                class LastTimeSpec(Entity):
                                                    """
                                                    Last timespec
                                                    
                                                    .. attribute:: seconds
                                                    
                                                    	Seconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: nanoseconds
                                                    
                                                    	Nanoseconds part of time value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: nanosecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                        self.yang_name = "last-time-spec"
                                                        self.yang_parent_name = "rx"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                        ])
                                                        self.seconds = None
                                                        self.nanoseconds = None
                                                        self._segment_path = lambda: "last-time-spec"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TcpInitSyncTimeSpec(Entity):
                                        """
                                        Time When neighbor entered TCP Init Sync
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "tcp-init-sync-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                        """
                                        Time when neighbor entered TCP Init Sync Phase
                                        Two
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncPhaseTwoTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class TcpInitSyncDoneTimeSpec(Entity):
                                        """
                                        Time when neighbor entered TCP Init Sync Done
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                            self.yang_name = "tcp-init-sync-done-time-spec"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "tcp-init-sync-done-time-spec"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.TcpInitSyncDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class GracefulMaintenance(Entity):
                                        """
                                        Graceful Maintenance
                                        
                                        .. attribute:: gshut_exists
                                        
                                        	Graceful Maintenance enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_local_active
                                        
                                        	Graceful Maintenance locally activated
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_active
                                        
                                        	Graceful Maintenance activated
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_locpref_set
                                        
                                        	Graceful Maintenance Local Preference set
                                        	**type**\: bool
                                        
                                        .. attribute:: gshut_locpref
                                        
                                        	Graceful Maintenance Local Preference
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: gshut_prepends
                                        
                                        	Graceful Maintenance number of AS prepends
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, self).__init__()

                                            self.yang_name = "graceful-maintenance"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                                ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                                ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                                ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                                ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                                ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                            ])
                                            self.gshut_exists = None
                                            self.gshut_local_active = None
                                            self.gshut_active = None
                                            self.gshut_locpref_set = None
                                            self.gshut_locpref = None
                                            self.gshut_prepends = None
                                            self._segment_path = lambda: "graceful-maintenance"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                                    class AfData(Entity):
                                        """
                                        Address family specific neighbor data
                                        
                                        .. attribute:: neighbor_af_performance_statistics
                                        
                                        	Neighbor AF statistics
                                        	**type**\:  :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                        
                                        .. attribute:: af_name
                                        
                                        	Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: is_neighbor_route_reflector_client
                                        
                                        	Nbr is a route reflector client
                                        	**type**\: bool
                                        
                                        .. attribute:: is_legacy_pe_rt
                                        
                                        	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_af_capable
                                        
                                        	Address family capability received from neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: is_soft_reconfiguration_inbound_allowed
                                        
                                        	Inbound soft reconfiguration allowed
                                        	**type**\: bool
                                        
                                        .. attribute:: is_use_soft_reconfiguration_always_on
                                        
                                        	Soft reconf overrides route refresh
                                        	**type**\: bool
                                        
                                        .. attribute:: remove_private_as_from_updates
                                        
                                        	Private AS numbers removed from updates to this nbr
                                        	**type**\: bool
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_updates
                                        
                                        	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                        	**type**\: bool
                                        
                                        .. attribute:: remove_private_as_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr
                                        	**type**\: bool
                                        
                                        .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                        
                                        	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                        	**type**\: bool
                                        
                                        .. attribute:: flowspec_validation_d_isable
                                        
                                        	Flowspec Validation Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: flowspec_redirect_validation_d_isable
                                        
                                        	Flowspec Redirect Validation Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: orr_group_name
                                        
                                        	ORR Group Name
                                        	**type**\: str
                                        
                                        .. attribute:: orr_group_index
                                        
                                        	ORR Group Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_orr_root_address_configured
                                        
                                        	ORR Root address configuredfor the neighbor connection
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_afi
                                        
                                        	Encode in Advertise AFI
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_afi_reorg
                                        
                                        	Encode in Advertise AFI
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_afi_disable
                                        
                                        	Encode in Advertise AFI
                                        	**type**\: bool
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_rt_type
                                        
                                        	Advertise RT type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: advertise_afi_def_vrf_imp_disable
                                        
                                        	Advertise of default VRF import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                        
                                        	Advertise of v4 default VRF import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                        
                                        	Advertise of v6 default VRF import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_afi_vrf_re_imp_disable
                                        
                                        	Advertise of VRF re\-import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                        
                                        	Advertise of v4 VRF re\-import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                        
                                        	Advertise of v6 VRF re\-import disable
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_afi_eo_r_ready
                                        
                                        	EoR Can be sent for Advertise AFI
                                        	**type**\: bool
                                        
                                        .. attribute:: always_use_next_hop_local
                                        
                                        	Local router always used for next\-hop
                                        	**type**\: bool
                                        
                                        .. attribute:: sent_community_to_neighbor
                                        
                                        	Community attribute sent to neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: sent_gshut_community_to_neighbor
                                        
                                        	GSHUT Community attribute sent to neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: sent_extended_community_to_neighbor
                                        
                                        	Extended community attribute sent to neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor_default_originate
                                        
                                        	Neighbor originates default
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orf_sent
                                        
                                        	Outbound route filter sent to neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: is_update_deferred
                                        
                                        	Update deferred until ORF/route refresh received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orf_send_scheduled
                                        
                                        	Scheduled to send prefix based ORF
                                        	**type**\: bool
                                        
                                        .. attribute:: update_group_number
                                        
                                        	Update group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: filter_group_index
                                        
                                        	Filter group index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_update_throttled
                                        
                                        	Updates Throttled becausewrite limit is reached
                                        	**type**\: bool
                                        
                                        .. attribute:: is_update_leaving
                                        
                                        	Nbr leaving update\-groupto another
                                        	**type**\: bool
                                        
                                        .. attribute:: vpn_update_gen_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\: bool
                                        
                                        .. attribute:: vpn_update_gen_trigger_enabled
                                        
                                        	RT Nbr enabled for updategento another
                                        	**type**\: bool
                                        
                                        .. attribute:: is_addpath_send_operational
                                        
                                        	Addpath is operational on send\-side
                                        	**type**\: bool
                                        
                                        .. attribute:: is_addpath_receive_operational
                                        
                                        	Addpath is operational on receive\-side
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor_version
                                        
                                        	Neighbor version
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: weight
                                        
                                        	Weight for this AF
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_prefix_limit
                                        
                                        	Max limit for # of prefixes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: use_max_prefix_warning_only
                                        
                                        	Warning only when maximum prefix limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: max_prefix_discard_extra_paths
                                        
                                        	Discard extra paths when prefix limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: max_prefix_exceed_discard_paths
                                        
                                        	Did we discard extra paths when prefix limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: max_prefix_threshold_percent
                                        
                                        	Percentage of maximum no. of prefixes at which to generate warning
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: max_prefix_restart_time
                                        
                                        	Time interval (in minutes) after which peering session will be reestablished
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: prefixes_accepted
                                        
                                        	No. of prefixes accepted
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_synced
                                        
                                        	Number of prefixes synced to standby
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn_not_found
                                        
                                        	No. of prefixes withdrawn but not found
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied
                                        
                                        	No. of prefixes denied
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_no_policy
                                        
                                        	No. of prefixes denied because there was no inbound policy
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_rt_permit
                                        
                                        	No. of prefixes denied because RT extended community is not imported
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_orf_policy
                                        
                                        	No. of prefixes denied by prefix based ORF policy
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_denied_policy
                                        
                                        	No. of prefixes denied by inbound policy
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_bestpaths
                                        
                                        	No. of bestpaths from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_best_externalpaths
                                        
                                        	No. of best\-external paths from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_advertised
                                        
                                        	No. of prefixes advertised
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_be_advertised
                                        
                                        	No BE prefixes advertised
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_suppressed
                                        
                                        	No. of prefixes suppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefixes_withdrawn
                                        
                                        	No. of prefixes withdrawn
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_peer_orf_capable
                                        
                                        	Peer has outbound route filter capability
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertised_orf_send
                                        
                                        	Prefix based ORF send mode capability advertised
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_orf_send_capable
                                        
                                        	Prefix based ORF send mode capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertised_orf_receive
                                        
                                        	Prefix based ORF receive mode capability advertised
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_orf_receive_capable
                                        
                                        	Prefix based ORF receive mode capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertised_graceful_restart
                                        
                                        	Graceful Restart Capability advertised
                                        	**type**\: bool
                                        
                                        .. attribute:: is_graceful_restart_state_flag
                                        
                                        	Restart state flag enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_graceful_restart_capable
                                        
                                        	Graceful Restart Capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_add_path_send_capability_advertised
                                        
                                        	Addpath Send capability advertised
                                        	**type**\: bool
                                        
                                        .. attribute:: is_add_path_send_capability_received
                                        
                                        	Addpath Send capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_add_path_receive_capability_advertised
                                        
                                        	Addpath Receive capability advertised
                                        	**type**\: bool
                                        
                                        .. attribute:: is_add_path_receive_capability_received
                                        
                                        	Addpath Receive capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_received
                                        
                                        	Extended nexthop encoding capability received
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ext_nh_encoding_capability_sent
                                        
                                        	Extended nexhop encoding capability Sent
                                        	**type**\: bool
                                        
                                        .. attribute:: restart_time
                                        
                                        	Restart time advertised (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: local_restart_time
                                        
                                        	Local Restart time (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: stale_path_timeout
                                        
                                        	Stale path timeout time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: rib_purge_timeout_value
                                        
                                        	RIB purge timeout time (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_preserved_forwarding_state
                                        
                                        	Neighbor preserved forwarding state
                                        	**type**\: bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_configured
                                        
                                        	Long\-lived graceful\-restart stale time is configured
                                        	**type**\: bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_sent
                                        
                                        	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_accept
                                        
                                        	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: long_lived_graceful_restart_capability_received
                                        
                                        	Long\-lived graceful\-restart capability received from the neighbor
                                        	**type**\: bool
                                        
                                        .. attribute:: long_lived_graceful_restart_stale_time_received
                                        
                                        	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                        
                                        	Neighbor preserved long\-lived forwarding state
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_capable
                                        
                                        	Treat neighbor as long\-lived graceful\-restart capable
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                        
                                        	Remaining long\-lived graceful\-restart time
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_refreshes_received
                                        
                                        	Number of route refresh requests received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_refreshes_sent
                                        
                                        	Number of route refresh requests sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_target_version
                                        
                                        	Target version for refresh update generation
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_version
                                        
                                        	Version till which refresh updates have been generated
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: refresh_acked_version
                                        
                                        	Version acked by the peer for refresh updates sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_prefix_orf_present
                                        
                                        	Outbound route filter prefix ORF present
                                        	**type**\: bool
                                        
                                        .. attribute:: orf_entries_received
                                        
                                        	Number of outbound route filter entries received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_default_originate_sent
                                        
                                        	Default origination update sent
                                        	**type**\: bool
                                        
                                        .. attribute:: route_policy_prefix_orf
                                        
                                        	Prefix based ORF for incoming updates
                                        	**type**\: str
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Incoming route policy name
                                        	**type**\: str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Outgoing route policy name
                                        	**type**\: str
                                        
                                        .. attribute:: route_policy_default_originate
                                        
                                        	Default\-originate route policy name
                                        	**type**\: str
                                        
                                        .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                        
                                        	eBGP neighbor with no configured inbound policy
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                        
                                        	eBGP neighbor with no configured outbound policy
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_override_set
                                        
                                        	As override set 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_allow_as_in_set
                                        
                                        	Allowas\-in set 
                                        	**type**\: bool
                                        
                                        .. attribute:: allow_as_in_count
                                        
                                        	Allowas\-in count config
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: address_family_long_lived_time
                                        
                                        	AF specific Long\-lived\-time config
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: eo_r_received_in_read_only
                                        
                                        	An EoR was received while in read\-only mode
                                        	**type**\: bool
                                        
                                        .. attribute:: acked_version
                                        
                                        	Version mapped from acked seqNo
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: synced_acked_version
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version
                                        
                                        	No. of all outstanding version objects waiting for ack from the peer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_refresh_version
                                        
                                        	No. of only refresh version objects waiting for ack from the peer
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: outstanding_version_max
                                        
                                        	Version mapped from acked seqNo that was synced last
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_aigp_set
                                        
                                        	AIGP set 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rt_present
                                        
                                        	RT attribute list present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rt_present_standby
                                        
                                        	RT attribute list present
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_enabled
                                        
                                        	Accept\-Own enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: selective_multipath_eligible
                                        
                                        	Selective multipath eligible
                                        	**type**\: bool
                                        
                                        .. attribute:: afrpki_disable
                                        
                                        	Prefix validation disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: afrpki_use_validity
                                        
                                        	Prefix v. use validity
                                        	**type**\: bool
                                        
                                        .. attribute:: afrpki_allow_invalid
                                        
                                        	Prefix v. allow invalid
                                        	**type**\: bool
                                        
                                        .. attribute:: afrpki_signal_ibgp
                                        
                                        	Prefix v. signal ibgp
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertise_permanent_network
                                        
                                        	Advertise Permanent Network
                                        	**type**\: bool
                                        
                                        .. attribute:: is_send_mcast_attr
                                        
                                        	Send Mcast Attr
                                        	**type**\: bool
                                        
                                        .. attribute:: import_stitching
                                        
                                        	Import Stitching enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: import_reoriginate
                                        
                                        	Import Reoriginate enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: import_reoriginate_stitching
                                        
                                        	Import Reoriginate Stitching enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_v4_flags
                                        
                                        	Advertise options for VPNV4
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_v6_flags
                                        
                                        	Advertise options for VPNV6
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertise_local_labeled_route_unicast
                                        
                                        	Advertise routes with 
                                        	**type**\: bool
                                        
                                        .. attribute:: prefixes_denied_non_cumulative
                                        
                                        	No. of prefixes exactly denied (non cumulative)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: enable_label_stack
                                        
                                        	Enable label stack
                                        	**type**\: bool
                                        
                                        .. attribute:: extended_community
                                        
                                        	Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity>`
                                        
                                        .. attribute:: extended_community_standby
                                        
                                        	Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData, self).__init__()

                                            self.yang_name = "af-data"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-af-performance-statistics", ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby))])
                                            self._leafs = OrderedDict([
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                                ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                                ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                                ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                                ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                                ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                                ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                                ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                                ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                                ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                                ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                                ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                                ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                                ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                                ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                                ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                                ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                                ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                                ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                                ('advertise_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-def-vrf-imp-disable'), ['bool'])),
                                                ('advertise_evpnv4_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-def-vrf-imp-disable'), ['bool'])),
                                                ('advertise_evpnv6_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-def-vrf-imp-disable'), ['bool'])),
                                                ('advertise_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-vrf-re-imp-disable'), ['bool'])),
                                                ('advertise_evpnv4_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-vrf-re-imp-disable'), ['bool'])),
                                                ('advertise_evpnv6_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-vrf-re-imp-disable'), ['bool'])),
                                                ('advertise_afi_eo_r_ready', (YLeaf(YType.boolean, 'advertise-afi-eo-r-ready'), ['bool'])),
                                                ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                                ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                                ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                                ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                                ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                                ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                                ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                                ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                                ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                                ('is_update_throttled', (YLeaf(YType.boolean, 'is-update-throttled'), ['bool'])),
                                                ('is_update_leaving', (YLeaf(YType.boolean, 'is-update-leaving'), ['bool'])),
                                                ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                                ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                                ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                                ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                                ('neighbor_version', (YLeaf(YType.uint32, 'neighbor-version'), ['int'])),
                                                ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                                ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                                ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                                ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                                ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                                ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                                ('prefixes_accepted', (YLeaf(YType.uint32, 'prefixes-accepted'), ['int'])),
                                                ('prefixes_synced', (YLeaf(YType.uint32, 'prefixes-synced'), ['int'])),
                                                ('prefixes_withdrawn_not_found', (YLeaf(YType.uint32, 'prefixes-withdrawn-not-found'), ['int'])),
                                                ('prefixes_denied', (YLeaf(YType.uint32, 'prefixes-denied'), ['int'])),
                                                ('prefixes_denied_no_policy', (YLeaf(YType.uint32, 'prefixes-denied-no-policy'), ['int'])),
                                                ('prefixes_denied_rt_permit', (YLeaf(YType.uint32, 'prefixes-denied-rt-permit'), ['int'])),
                                                ('prefixes_denied_orf_policy', (YLeaf(YType.uint32, 'prefixes-denied-orf-policy'), ['int'])),
                                                ('prefixes_denied_policy', (YLeaf(YType.uint32, 'prefixes-denied-policy'), ['int'])),
                                                ('number_of_bestpaths', (YLeaf(YType.uint32, 'number-of-bestpaths'), ['int'])),
                                                ('number_of_best_externalpaths', (YLeaf(YType.uint32, 'number-of-best-externalpaths'), ['int'])),
                                                ('prefixes_advertised', (YLeaf(YType.uint32, 'prefixes-advertised'), ['int'])),
                                                ('prefixes_be_advertised', (YLeaf(YType.uint32, 'prefixes-be-advertised'), ['int'])),
                                                ('prefixes_suppressed', (YLeaf(YType.uint32, 'prefixes-suppressed'), ['int'])),
                                                ('prefixes_withdrawn', (YLeaf(YType.uint32, 'prefixes-withdrawn'), ['int'])),
                                                ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                                ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                                ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                                ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                                ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                                ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                                ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                                ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                                ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                                ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                                ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                                ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                                ('is_ext_nh_encoding_capability_received', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-received'), ['bool'])),
                                                ('is_ext_nh_encoding_capability_sent', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-sent'), ['bool'])),
                                                ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                                ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                                ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                                ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                                ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                                ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                                ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                                ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                                ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                                ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                                ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                                ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                                ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                                ('route_refreshes_received', (YLeaf(YType.uint32, 'route-refreshes-received'), ['int'])),
                                                ('route_refreshes_sent', (YLeaf(YType.uint32, 'route-refreshes-sent'), ['int'])),
                                                ('refresh_target_version', (YLeaf(YType.uint32, 'refresh-target-version'), ['int'])),
                                                ('refresh_version', (YLeaf(YType.uint32, 'refresh-version'), ['int'])),
                                                ('refresh_acked_version', (YLeaf(YType.uint32, 'refresh-acked-version'), ['int'])),
                                                ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                                ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                                ('is_default_originate_sent', (YLeaf(YType.boolean, 'is-default-originate-sent'), ['bool'])),
                                                ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                                ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                                ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                                ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                                ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                                ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                                ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                                ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                                ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                                ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                                ('eo_r_received_in_read_only', (YLeaf(YType.boolean, 'eo-r-received-in-read-only'), ['bool'])),
                                                ('acked_version', (YLeaf(YType.uint32, 'acked-version'), ['int'])),
                                                ('synced_acked_version', (YLeaf(YType.uint32, 'synced-acked-version'), ['int'])),
                                                ('outstanding_version', (YLeaf(YType.uint32, 'outstanding-version'), ['int'])),
                                                ('outstanding_refresh_version', (YLeaf(YType.uint32, 'outstanding-refresh-version'), ['int'])),
                                                ('outstanding_version_max', (YLeaf(YType.uint32, 'outstanding-version-max'), ['int'])),
                                                ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                                ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                                ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                                ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                                ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                                ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                                ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                                ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                                ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                                ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                                ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                                ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                                ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                                ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                                ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                                ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                                ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                                ('prefixes_denied_non_cumulative', (YLeaf(YType.uint32, 'prefixes-denied-non-cumulative'), ['int'])),
                                                ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                            ])
                                            self.af_name = None
                                            self.is_neighbor_route_reflector_client = None
                                            self.is_legacy_pe_rt = None
                                            self.is_neighbor_af_capable = None
                                            self.is_soft_reconfiguration_inbound_allowed = None
                                            self.is_use_soft_reconfiguration_always_on = None
                                            self.remove_private_as_from_updates = None
                                            self.remove_private_as_entire_aspath_from_updates = None
                                            self.remove_private_as_from_inbound_updates = None
                                            self.remove_private_as_entire_aspath_from_inbound_updates = None
                                            self.flowspec_validation_d_isable = None
                                            self.flowspec_redirect_validation_d_isable = None
                                            self.orr_group_name = None
                                            self.orr_group_index = None
                                            self.is_orr_root_address_configured = None
                                            self.advertise_afi = None
                                            self.advertise_afi_reorg = None
                                            self.advertise_afi_disable = None
                                            self.encapsulation_type = None
                                            self.advertise_rt_type = None
                                            self.advertise_afi_def_vrf_imp_disable = None
                                            self.advertise_evpnv4_afi_def_vrf_imp_disable = None
                                            self.advertise_evpnv6_afi_def_vrf_imp_disable = None
                                            self.advertise_afi_vrf_re_imp_disable = None
                                            self.advertise_evpnv4_afi_vrf_re_imp_disable = None
                                            self.advertise_evpnv6_afi_vrf_re_imp_disable = None
                                            self.advertise_afi_eo_r_ready = None
                                            self.always_use_next_hop_local = None
                                            self.sent_community_to_neighbor = None
                                            self.sent_gshut_community_to_neighbor = None
                                            self.sent_extended_community_to_neighbor = None
                                            self.neighbor_default_originate = None
                                            self.is_orf_sent = None
                                            self.is_update_deferred = None
                                            self.is_orf_send_scheduled = None
                                            self.update_group_number = None
                                            self.filter_group_index = None
                                            self.is_update_throttled = None
                                            self.is_update_leaving = None
                                            self.vpn_update_gen_enabled = None
                                            self.vpn_update_gen_trigger_enabled = None
                                            self.is_addpath_send_operational = None
                                            self.is_addpath_receive_operational = None
                                            self.neighbor_version = None
                                            self.weight = None
                                            self.max_prefix_limit = None
                                            self.use_max_prefix_warning_only = None
                                            self.max_prefix_discard_extra_paths = None
                                            self.max_prefix_exceed_discard_paths = None
                                            self.max_prefix_threshold_percent = None
                                            self.max_prefix_restart_time = None
                                            self.prefixes_accepted = None
                                            self.prefixes_synced = None
                                            self.prefixes_withdrawn_not_found = None
                                            self.prefixes_denied = None
                                            self.prefixes_denied_no_policy = None
                                            self.prefixes_denied_rt_permit = None
                                            self.prefixes_denied_orf_policy = None
                                            self.prefixes_denied_policy = None
                                            self.number_of_bestpaths = None
                                            self.number_of_best_externalpaths = None
                                            self.prefixes_advertised = None
                                            self.prefixes_be_advertised = None
                                            self.prefixes_suppressed = None
                                            self.prefixes_withdrawn = None
                                            self.is_peer_orf_capable = None
                                            self.is_advertised_orf_send = None
                                            self.is_received_orf_send_capable = None
                                            self.is_advertised_orf_receive = None
                                            self.is_received_orf_receive_capable = None
                                            self.is_advertised_graceful_restart = None
                                            self.is_graceful_restart_state_flag = None
                                            self.is_received_graceful_restart_capable = None
                                            self.is_add_path_send_capability_advertised = None
                                            self.is_add_path_send_capability_received = None
                                            self.is_add_path_receive_capability_advertised = None
                                            self.is_add_path_receive_capability_received = None
                                            self.is_ext_nh_encoding_capability_received = None
                                            self.is_ext_nh_encoding_capability_sent = None
                                            self.restart_time = None
                                            self.local_restart_time = None
                                            self.stale_path_timeout = None
                                            self.rib_purge_timeout_value = None
                                            self.neighbor_preserved_forwarding_state = None
                                            self.long_lived_graceful_restart_stale_time_configured = None
                                            self.long_lived_graceful_restart_stale_time_sent = None
                                            self.long_lived_graceful_restart_stale_time_accept = None
                                            self.long_lived_graceful_restart_capability_received = None
                                            self.long_lived_graceful_restart_stale_time_received = None
                                            self.neighbor_preserved_long_lived_forwarding_state = None
                                            self.neighbor_long_lived_graceful_restart_capable = None
                                            self.neighbor_long_lived_graceful_restart_time_remaining = None
                                            self.route_refreshes_received = None
                                            self.route_refreshes_sent = None
                                            self.refresh_target_version = None
                                            self.refresh_version = None
                                            self.refresh_acked_version = None
                                            self.is_prefix_orf_present = None
                                            self.orf_entries_received = None
                                            self.is_default_originate_sent = None
                                            self.route_policy_prefix_orf = None
                                            self.route_policy_in = None
                                            self.route_policy_out = None
                                            self.route_policy_default_originate = None
                                            self.is_neighbor_ebgp_without_inbound_policy = None
                                            self.is_neighbor_ebgp_without_outbound_policy = None
                                            self.is_as_override_set = None
                                            self.is_allow_as_in_set = None
                                            self.allow_as_in_count = None
                                            self.address_family_long_lived_time = None
                                            self.eo_r_received_in_read_only = None
                                            self.acked_version = None
                                            self.synced_acked_version = None
                                            self.outstanding_version = None
                                            self.outstanding_refresh_version = None
                                            self.outstanding_version_max = None
                                            self.is_aigp_set = None
                                            self.is_rt_present = None
                                            self.is_rt_present_standby = None
                                            self.accept_own_enabled = None
                                            self.selective_multipath_eligible = None
                                            self.afrpki_disable = None
                                            self.afrpki_use_validity = None
                                            self.afrpki_allow_invalid = None
                                            self.afrpki_signal_ibgp = None
                                            self.is_advertise_permanent_network = None
                                            self.is_send_mcast_attr = None
                                            self.import_stitching = None
                                            self.import_reoriginate = None
                                            self.import_reoriginate_stitching = None
                                            self.advertise_v4_flags = None
                                            self.advertise_v6_flags = None
                                            self.advertise_local_labeled_route_unicast = None
                                            self.prefixes_denied_non_cumulative = None
                                            self.enable_label_stack = None

                                            self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                            self.neighbor_af_performance_statistics.parent = self
                                            self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"

                                            self.extended_community = YList(self)
                                            self.extended_community_standby = YList(self)
                                            self._segment_path = lambda: "af-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_disable', u'encapsulation_type', u'advertise_rt_type', u'advertise_afi_def_vrf_imp_disable', u'advertise_evpnv4_afi_def_vrf_imp_disable', u'advertise_evpnv6_afi_def_vrf_imp_disable', u'advertise_afi_vrf_re_imp_disable', u'advertise_evpnv4_afi_vrf_re_imp_disable', u'advertise_evpnv6_afi_vrf_re_imp_disable', u'advertise_afi_eo_r_ready', u'always_use_next_hop_local', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'update_group_number', u'filter_group_index', u'is_update_throttled', u'is_update_leaving', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'neighbor_version', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'prefixes_accepted', u'prefixes_synced', u'prefixes_withdrawn_not_found', u'prefixes_denied', u'prefixes_denied_no_policy', u'prefixes_denied_rt_permit', u'prefixes_denied_orf_policy', u'prefixes_denied_policy', u'number_of_bestpaths', u'number_of_best_externalpaths', u'prefixes_advertised', u'prefixes_be_advertised', u'prefixes_suppressed', u'prefixes_withdrawn', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'is_ext_nh_encoding_capability_received', u'is_ext_nh_encoding_capability_sent', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'route_refreshes_received', u'route_refreshes_sent', u'refresh_target_version', u'refresh_version', u'refresh_acked_version', u'is_prefix_orf_present', u'orf_entries_received', u'is_default_originate_sent', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'eo_r_received_in_read_only', u'acked_version', u'synced_acked_version', u'outstanding_version', u'outstanding_refresh_version', u'outstanding_version_max', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'advertise_local_labeled_route_unicast', u'prefixes_denied_non_cumulative', u'enable_label_stack'], name, value)


                                        class NeighborAfPerformanceStatistics(Entity):
                                            """
                                            Neighbor AF statistics
                                            
                                            .. attribute:: sub_group_pending_message_count
                                            
                                            	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: processed_messages
                                            
                                            	Number of messages processed from the neighbor's write queue
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sent_messages
                                            
                                            	Number of messages sent from the neighbor's write queue
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_transmit
                                            
                                            	No. of update messages with split\-horizon flag that were sent out
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_update_blocked
                                            
                                            	No. of update messages with split\-horizon flag that were blocked
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_transmit
                                            
                                            	No. of withdraw messages with split\-horizon flag that were sent out
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: split_horizon_withdraw_blocked
                                            
                                            	No. of withdraw messages with split\-horizon flag that were blocked
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                                self.yang_name = "neighbor-af-performance-statistics"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('sub_group_pending_message_count', (YLeaf(YType.uint32, 'sub-group-pending-message-count'), ['int'])),
                                                    ('processed_messages', (YLeaf(YType.uint32, 'processed-messages'), ['int'])),
                                                    ('sent_messages', (YLeaf(YType.uint32, 'sent-messages'), ['int'])),
                                                    ('split_horizon_update_transmit', (YLeaf(YType.uint32, 'split-horizon-update-transmit'), ['int'])),
                                                    ('split_horizon_update_blocked', (YLeaf(YType.uint32, 'split-horizon-update-blocked'), ['int'])),
                                                    ('split_horizon_withdraw_transmit', (YLeaf(YType.uint32, 'split-horizon-withdraw-transmit'), ['int'])),
                                                    ('split_horizon_withdraw_blocked', (YLeaf(YType.uint32, 'split-horizon-withdraw-blocked'), ['int'])),
                                                ])
                                                self.sub_group_pending_message_count = None
                                                self.processed_messages = None
                                                self.sent_messages = None
                                                self.split_horizon_update_transmit = None
                                                self.split_horizon_update_blocked = None
                                                self.split_horizon_withdraw_transmit = None
                                                self.split_horizon_withdraw_blocked = None
                                                self._segment_path = lambda: "neighbor-af-performance-statistics"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.NeighborAfPerformanceStatistics, [u'sub_group_pending_message_count', u'processed_messages', u'sent_messages', u'split_horizon_update_transmit', u'split_horizon_update_blocked', u'split_horizon_withdraw_transmit', u'split_horizon_withdraw_blocked'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunity, [u'entry'], name, value)


                                        class ExtendedCommunityStandby(Entity):
                                            """
                                            Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                                self.yang_name = "extended-community-standby"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community-standby"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.NeighborAfTable.Neighbor.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                            class UpdateGenerationNeighbors(Entity):
                                """
                                Update generation for all neighbors
                                
                                .. attribute:: update_generation_neighbor
                                
                                	Update generation for neighbor
                                	**type**\: list of  		 :py:class:`UpdateGenerationNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors, self).__init__()

                                    self.yang_name = "update-generation-neighbors"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-generation-neighbor", ("update_generation_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor))])
                                    self._leafs = OrderedDict()

                                    self.update_generation_neighbor = YList(self)
                                    self._segment_path = lambda: "update-generation-neighbors"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors, [], name, value)


                                class UpdateGenerationNeighbor(Entity):
                                    """
                                    Update generation for neighbor
                                    
                                    .. attribute:: update_group_index
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_id
                                    
                                    	Sub\-group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: update_neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress>`
                                    
                                    .. attribute:: last_sub_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:  :py:class:`LastSubGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp>`
                                    
                                    .. attribute:: last_sub_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:  :py:class:`LastSubGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp>`
                                    
                                    .. attribute:: last_filter_group_add_timestamp
                                    
                                    	Last added time
                                    	**type**\:  :py:class:`LastFilterGroupAddTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp>`
                                    
                                    .. attribute:: last_filter_group_remove_timestamp
                                    
                                    	Last removed time
                                    	**type**\:  :py:class:`LastFilterGroupRemoveTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp>`
                                    
                                    .. attribute:: first_default_originate_timestamp
                                    
                                    	First default\-origination time
                                    	**type**\:  :py:class:`FirstDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: last_default_originate_timestamp
                                    
                                    	Last default\-origination time
                                    	**type**\:  :py:class:`LastDefaultOriginateTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp>`
                                    
                                    .. attribute:: last_update_group_start_timestamp
                                    
                                    	Last update\-group timer start
                                    	**type**\:  :py:class:`LastUpdateGroupStartTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp>`
                                    
                                    .. attribute:: last_update_group_expiry_timestamp
                                    
                                    	Last update\-group timer expiry
                                    	**type**\:  :py:class:`LastUpdateGroupExpiryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp>`
                                    
                                    .. attribute:: first_update_queued_timestamp
                                    
                                    	First update queued time
                                    	**type**\:  :py:class:`FirstUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_update_queued_timestamp
                                    
                                    	Last update queued time
                                    	**type**\:  :py:class:`LastUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_queued_timestamp
                                    
                                    	Last refresh update queued time
                                    	**type**\:  :py:class:`LastRefreshUpdateQueuedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp>`
                                    
                                    .. attribute:: first_update_write_timestamp
                                    
                                    	First update write time
                                    	**type**\:  :py:class:`FirstUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp>`
                                    
                                    .. attribute:: last_update_write_timestamp
                                    
                                    	Last update write time
                                    	**type**\:  :py:class:`LastUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp>`
                                    
                                    .. attribute:: last_refresh_update_write_timestamp
                                    
                                    	Last refresh update write time
                                    	**type**\:  :py:class:`LastRefreshUpdateWriteTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp>`
                                    
                                    .. attribute:: update_statistics
                                    
                                    	Update statistics
                                    	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics>`
                                    
                                    .. attribute:: process_id
                                    
                                    	ProcessID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: update_group_af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: update_filter_group_index
                                    
                                    	Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_filter_group_index
                                    
                                    	Refresh Filter\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sub_group_index_xr
                                    
                                    	Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_index
                                    
                                    	Refresh Sub\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_sub_group_id
                                    
                                    	Refresh sub\-group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_group_index_xr
                                    
                                    	Update\-group index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_main_table_version
                                    
                                    	Main table version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_vrf_table_rib_version
                                    
                                    	VRF Table RIB version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages
                                    
                                    	OutQueue messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size
                                    
                                    	OutQueue size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_messages
                                    
                                    	Refresh OutQueue messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_update_out_queue_size
                                    
                                    	Refresh OutQueue size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_filter_group_messages
                                    
                                    	Filter\-group messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_target_version
                                    
                                    	Pending target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_resume_version
                                    
                                    	Resume version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ack_version
                                    
                                    	Ack version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: synced_ack_version
                                    
                                    	Synced ack version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: outstanding_version_count
                                    
                                    	Outstanding version count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_version
                                    
                                    	Refresh version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_requested_target_version
                                    
                                    	Requested refresh target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_refresh_target_version
                                    
                                    	Refresh target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_pending_target_version
                                    
                                    	Pending refresh target version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_next_resume_version
                                    
                                    	Refresh resume version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: refresh_ack_version
                                    
                                    	Refresh Ack version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_default_originate_age
                                    
                                    	Time since last default\-origination event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: default_originate_state
                                    
                                    	Default\-origination state
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: default_originate_internal_context
                                    
                                    	Default\-origination context
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: is_eor_outstanding
                                    
                                    	Number of EORs outstanding
                                    	**type**\: bool
                                    
                                    .. attribute:: outbound_refresh_count
                                    
                                    	Refresh Outbound count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inbound_refresh_count
                                    
                                    	Refresh Inbound count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_update_group_timer_running
                                    
                                    	Is update\-group timer running
                                    	**type**\: bool
                                    
                                    .. attribute:: current_update_group_af_name
                                    
                                    	Current Update\-group address\-family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: last_update_group_af_name
                                    
                                    	Last Update\-group address\-family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: last_update_queued_age
                                    
                                    	Time since last update queued event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_queued_age
                                    
                                    	Time since last refresh update queued event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_write_age
                                    
                                    	Time since last update write event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_refresh_update_write_age
                                    
                                    	Time since last refresh update write event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, self).__init__()

                                        self.yang_name = "update-generation-neighbor"
                                        self.yang_parent_name = "update-generation-neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress)), ("last-sub-group-add-timestamp", ("last_sub_group_add_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp)), ("last-sub-group-remove-timestamp", ("last_sub_group_remove_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp)), ("last-filter-group-add-timestamp", ("last_filter_group_add_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp)), ("last-filter-group-remove-timestamp", ("last_filter_group_remove_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp)), ("first-default-originate-timestamp", ("first_default_originate_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp)), ("last-default-originate-timestamp", ("last_default_originate_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp)), ("last-update-group-start-timestamp", ("last_update_group_start_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp)), ("last-update-group-expiry-timestamp", ("last_update_group_expiry_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp)), ("first-update-queued-timestamp", ("first_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp)), ("last-update-queued-timestamp", ("last_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp)), ("last-refresh-update-queued-timestamp", ("last_refresh_update_queued_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp)), ("first-update-write-timestamp", ("first_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp)), ("last-update-write-timestamp", ("last_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp)), ("last-refresh-update-write-timestamp", ("last_refresh_update_write_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp)), ("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics))])
                                        self._leafs = OrderedDict([
                                            ('update_group_index', (YLeaf(YType.uint32, 'update-group-index'), ['int'])),
                                            ('sub_group_index', (YLeaf(YType.uint32, 'sub-group-index'), ['int'])),
                                            ('sub_group_id', (YLeaf(YType.uint32, 'sub-group-id'), ['int'])),
                                            ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('process_id', (YLeaf(YType.uint32, 'process-id'), ['int'])),
                                            ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                            ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('update_filter_group_index', (YLeaf(YType.uint32, 'update-filter-group-index'), ['int'])),
                                            ('refresh_filter_group_index', (YLeaf(YType.uint32, 'refresh-filter-group-index'), ['int'])),
                                            ('sub_group_index_xr', (YLeaf(YType.uint32, 'sub-group-index-xr'), ['int'])),
                                            ('refresh_sub_group_index', (YLeaf(YType.uint32, 'refresh-sub-group-index'), ['int'])),
                                            ('refresh_sub_group_id', (YLeaf(YType.uint32, 'refresh-sub-group-id'), ['int'])),
                                            ('update_group_index_xr', (YLeaf(YType.uint32, 'update-group-index-xr'), ['int'])),
                                            ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                            ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                            ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                            ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                            ('refresh_update_out_queue_messages', (YLeaf(YType.uint32, 'refresh-update-out-queue-messages'), ['int'])),
                                            ('refresh_update_out_queue_size', (YLeaf(YType.uint32, 'refresh-update-out-queue-size'), ['int'])),
                                            ('update_filter_group_messages', (YLeaf(YType.uint32, 'update-filter-group-messages'), ['int'])),
                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                            ('pending_target_version', (YLeaf(YType.uint32, 'pending-target-version'), ['int'])),
                                            ('next_resume_version', (YLeaf(YType.uint32, 'next-resume-version'), ['int'])),
                                            ('ack_version', (YLeaf(YType.uint32, 'ack-version'), ['int'])),
                                            ('synced_ack_version', (YLeaf(YType.uint32, 'synced-ack-version'), ['int'])),
                                            ('outstanding_version_count', (YLeaf(YType.uint32, 'outstanding-version-count'), ['int'])),
                                            ('update_refresh_version', (YLeaf(YType.uint32, 'update-refresh-version'), ['int'])),
                                            ('refresh_requested_target_version', (YLeaf(YType.uint32, 'refresh-requested-target-version'), ['int'])),
                                            ('update_refresh_target_version', (YLeaf(YType.uint32, 'update-refresh-target-version'), ['int'])),
                                            ('refresh_pending_target_version', (YLeaf(YType.uint32, 'refresh-pending-target-version'), ['int'])),
                                            ('refresh_next_resume_version', (YLeaf(YType.uint32, 'refresh-next-resume-version'), ['int'])),
                                            ('refresh_ack_version', (YLeaf(YType.uint32, 'refresh-ack-version'), ['int'])),
                                            ('last_default_originate_age', (YLeaf(YType.uint32, 'last-default-originate-age'), ['int'])),
                                            ('default_originate_state', (YLeaf(YType.int32, 'default-originate-state'), ['int'])),
                                            ('default_originate_internal_context', (YLeaf(YType.int32, 'default-originate-internal-context'), ['int'])),
                                            ('is_eor_outstanding', (YLeaf(YType.boolean, 'is-eor-outstanding'), ['bool'])),
                                            ('outbound_refresh_count', (YLeaf(YType.uint32, 'outbound-refresh-count'), ['int'])),
                                            ('inbound_refresh_count', (YLeaf(YType.uint32, 'inbound-refresh-count'), ['int'])),
                                            ('is_update_group_timer_running', (YLeaf(YType.boolean, 'is-update-group-timer-running'), ['bool'])),
                                            ('current_update_group_af_name', (YLeaf(YType.enumeration, 'current-update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('last_update_group_af_name', (YLeaf(YType.enumeration, 'last-update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('last_update_queued_age', (YLeaf(YType.uint32, 'last-update-queued-age'), ['int'])),
                                            ('last_refresh_update_queued_age', (YLeaf(YType.uint32, 'last-refresh-update-queued-age'), ['int'])),
                                            ('last_update_write_age', (YLeaf(YType.uint32, 'last-update-write-age'), ['int'])),
                                            ('last_refresh_update_write_age', (YLeaf(YType.uint32, 'last-refresh-update-write-age'), ['int'])),
                                        ])
                                        self.update_group_index = None
                                        self.sub_group_index = None
                                        self.sub_group_id = None
                                        self.filter_group_index = None
                                        self.neighbor_address = None
                                        self.process_id = None
                                        self.update_vrf_name = None
                                        self.update_group_af_name = None
                                        self.update_filter_group_index = None
                                        self.refresh_filter_group_index = None
                                        self.sub_group_index_xr = None
                                        self.refresh_sub_group_index = None
                                        self.refresh_sub_group_id = None
                                        self.update_group_index_xr = None
                                        self.update_main_table_version = None
                                        self.update_vrf_table_rib_version = None
                                        self.update_out_queue_messages = None
                                        self.update_out_queue_size = None
                                        self.refresh_update_out_queue_messages = None
                                        self.refresh_update_out_queue_size = None
                                        self.update_filter_group_messages = None
                                        self.version = None
                                        self.pending_target_version = None
                                        self.next_resume_version = None
                                        self.ack_version = None
                                        self.synced_ack_version = None
                                        self.outstanding_version_count = None
                                        self.update_refresh_version = None
                                        self.refresh_requested_target_version = None
                                        self.update_refresh_target_version = None
                                        self.refresh_pending_target_version = None
                                        self.refresh_next_resume_version = None
                                        self.refresh_ack_version = None
                                        self.last_default_originate_age = None
                                        self.default_originate_state = None
                                        self.default_originate_internal_context = None
                                        self.is_eor_outstanding = None
                                        self.outbound_refresh_count = None
                                        self.inbound_refresh_count = None
                                        self.is_update_group_timer_running = None
                                        self.current_update_group_af_name = None
                                        self.last_update_group_af_name = None
                                        self.last_update_queued_age = None
                                        self.last_refresh_update_queued_age = None
                                        self.last_update_write_age = None
                                        self.last_refresh_update_write_age = None

                                        self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress()
                                        self.update_neighbor_address.parent = self
                                        self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                        self.last_sub_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp()
                                        self.last_sub_group_add_timestamp.parent = self
                                        self._children_name_map["last_sub_group_add_timestamp"] = "last-sub-group-add-timestamp"

                                        self.last_sub_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp()
                                        self.last_sub_group_remove_timestamp.parent = self
                                        self._children_name_map["last_sub_group_remove_timestamp"] = "last-sub-group-remove-timestamp"

                                        self.last_filter_group_add_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp()
                                        self.last_filter_group_add_timestamp.parent = self
                                        self._children_name_map["last_filter_group_add_timestamp"] = "last-filter-group-add-timestamp"

                                        self.last_filter_group_remove_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp()
                                        self.last_filter_group_remove_timestamp.parent = self
                                        self._children_name_map["last_filter_group_remove_timestamp"] = "last-filter-group-remove-timestamp"

                                        self.first_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp()
                                        self.first_default_originate_timestamp.parent = self
                                        self._children_name_map["first_default_originate_timestamp"] = "first-default-originate-timestamp"

                                        self.last_default_originate_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp()
                                        self.last_default_originate_timestamp.parent = self
                                        self._children_name_map["last_default_originate_timestamp"] = "last-default-originate-timestamp"

                                        self.last_update_group_start_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp()
                                        self.last_update_group_start_timestamp.parent = self
                                        self._children_name_map["last_update_group_start_timestamp"] = "last-update-group-start-timestamp"

                                        self.last_update_group_expiry_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp()
                                        self.last_update_group_expiry_timestamp.parent = self
                                        self._children_name_map["last_update_group_expiry_timestamp"] = "last-update-group-expiry-timestamp"

                                        self.first_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp()
                                        self.first_update_queued_timestamp.parent = self
                                        self._children_name_map["first_update_queued_timestamp"] = "first-update-queued-timestamp"

                                        self.last_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp()
                                        self.last_update_queued_timestamp.parent = self
                                        self._children_name_map["last_update_queued_timestamp"] = "last-update-queued-timestamp"

                                        self.last_refresh_update_queued_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp()
                                        self.last_refresh_update_queued_timestamp.parent = self
                                        self._children_name_map["last_refresh_update_queued_timestamp"] = "last-refresh-update-queued-timestamp"

                                        self.first_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp()
                                        self.first_update_write_timestamp.parent = self
                                        self._children_name_map["first_update_write_timestamp"] = "first-update-write-timestamp"

                                        self.last_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp()
                                        self.last_update_write_timestamp.parent = self
                                        self._children_name_map["last_update_write_timestamp"] = "last-update-write-timestamp"

                                        self.last_refresh_update_write_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp()
                                        self.last_refresh_update_write_timestamp.parent = self
                                        self._children_name_map["last_refresh_update_write_timestamp"] = "last-refresh-update-write-timestamp"

                                        self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics()
                                        self.update_statistics.parent = self
                                        self._children_name_map["update_statistics"] = "update-statistics"
                                        self._segment_path = lambda: "update-generation-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor, ['update_group_index', 'sub_group_index', 'sub_group_id', 'filter_group_index', 'neighbor_address', u'process_id', u'update_vrf_name', u'update_group_af_name', u'update_filter_group_index', u'refresh_filter_group_index', u'sub_group_index_xr', u'refresh_sub_group_index', u'refresh_sub_group_id', u'update_group_index_xr', u'update_main_table_version', u'update_vrf_table_rib_version', u'update_out_queue_messages', u'update_out_queue_size', u'refresh_update_out_queue_messages', u'refresh_update_out_queue_size', u'update_filter_group_messages', u'version', u'pending_target_version', u'next_resume_version', u'ack_version', u'synced_ack_version', u'outstanding_version_count', u'update_refresh_version', u'refresh_requested_target_version', u'update_refresh_target_version', u'refresh_pending_target_version', u'refresh_next_resume_version', u'refresh_ack_version', u'last_default_originate_age', u'default_originate_state', u'default_originate_internal_context', u'is_eor_outstanding', u'outbound_refresh_count', u'inbound_refresh_count', u'is_update_group_timer_running', u'current_update_group_af_name', u'last_update_group_af_name', u'last_update_queued_age', u'last_refresh_update_queued_age', u'last_update_write_age', u'last_refresh_update_write_age'], name, value)


                                    class UpdateNeighborAddress(Entity):
                                        """
                                        Neighbor address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, self).__init__()

                                            self.yang_name = "update-neighbor-address"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "update-neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "update-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class LastSubGroupAddTimestamp(Entity):
                                        """
                                        Last added time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, self).__init__()

                                            self.yang_name = "last-sub-group-add-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-sub-group-add-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupAddTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastSubGroupRemoveTimestamp(Entity):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, self).__init__()

                                            self.yang_name = "last-sub-group-remove-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-sub-group-remove-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastSubGroupRemoveTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastFilterGroupAddTimestamp(Entity):
                                        """
                                        Last added time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, self).__init__()

                                            self.yang_name = "last-filter-group-add-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-filter-group-add-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupAddTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastFilterGroupRemoveTimestamp(Entity):
                                        """
                                        Last removed time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, self).__init__()

                                            self.yang_name = "last-filter-group-remove-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-filter-group-remove-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastFilterGroupRemoveTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstDefaultOriginateTimestamp(Entity):
                                        """
                                        First default\-origination time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, self).__init__()

                                            self.yang_name = "first-default-originate-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-default-originate-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstDefaultOriginateTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastDefaultOriginateTimestamp(Entity):
                                        """
                                        Last default\-origination time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, self).__init__()

                                            self.yang_name = "last-default-originate-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-default-originate-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastDefaultOriginateTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateGroupStartTimestamp(Entity):
                                        """
                                        Last update\-group timer start
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, self).__init__()

                                            self.yang_name = "last-update-group-start-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-group-start-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupStartTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateGroupExpiryTimestamp(Entity):
                                        """
                                        Last update\-group timer expiry
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, self).__init__()

                                            self.yang_name = "last-update-group-expiry-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-group-expiry-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateGroupExpiryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstUpdateQueuedTimestamp(Entity):
                                        """
                                        First update queued time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "first-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-update-queued-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateQueuedTimestamp(Entity):
                                        """
                                        Last update queued time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-queued-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRefreshUpdateQueuedTimestamp(Entity):
                                        """
                                        Last refresh update queued time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, self).__init__()

                                            self.yang_name = "last-refresh-update-queued-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-refresh-update-queued-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateQueuedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstUpdateWriteTimestamp(Entity):
                                        """
                                        First update write time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "first-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-update-write-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.FirstUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateWriteTimestamp(Entity):
                                        """
                                        Last update write time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "last-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-write-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRefreshUpdateWriteTimestamp(Entity):
                                        """
                                        Last refresh update write time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, self).__init__()

                                            self.yang_name = "last-refresh-update-write-timestamp"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-refresh-update-write-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.LastRefreshUpdateWriteTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class UpdateStatistics(Entity):
                                        """
                                        Update statistics
                                        
                                        .. attribute:: last_update_discard_timestamp
                                        
                                        	Last Discarded time
                                        	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                        
                                        .. attribute:: last_update_cleared_timestamp
                                        
                                        	Last Cleared time
                                        	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp>`
                                        
                                        .. attribute:: last_update_throttle_timestamp
                                        
                                        	Last Throttled time
                                        	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                        
                                        .. attribute:: last_update_recovery_timestamp
                                        
                                        	Last Recovery time
                                        	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                        
                                        .. attribute:: last_update_memory_allocation_fail_timestamp
                                        
                                        	Memory allocation failure time
                                        	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                        
                                        .. attribute:: update_out_queue_messages_high
                                        
                                        	OutQueue High Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cumulative
                                        
                                        	OutQueue Cumulative Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_discarded
                                        
                                        	OutQueue Discarded Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_messages_cleared
                                        
                                        	OutQueue Cleared Messages
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_high
                                        
                                        	OutQueue Hi Size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: update_out_queue_size_cumulative
                                        
                                        	OutQueue Cumulative Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_discarded
                                        
                                        	OutQueue Discarded Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: update_out_queue_size_cleared
                                        
                                        	OutQueue Cleared Size
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_update_discard_age
                                        
                                        	Time since last Discard event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: last_update_cleard_age
                                        
                                        	Time since last Clear event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_throttle_count
                                        
                                        	Throttle Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_throttle_age
                                        
                                        	Time since last Throttle event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_recovery_count
                                        
                                        	Recovery Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_recovery_age
                                        
                                        	Time since last Recovery event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: update_memory_allocation_fail_count
                                        
                                        	Memory allocation failure count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_update_memory_allocation_fail_age
                                        
                                        	Time since last memory allocation failure event (in seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, self).__init__()

                                            self.yang_name = "update-statistics"
                                            self.yang_parent_name = "update-generation-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                            self._leafs = OrderedDict([
                                                ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                                ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                                ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                                ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                                ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                                ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                                ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                                ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                                ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                                ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                                ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                                ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                                ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                                ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                                ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                                ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                            ])
                                            self.update_out_queue_messages_high = None
                                            self.update_out_queue_messages_cumulative = None
                                            self.update_out_queue_messages_discarded = None
                                            self.update_out_queue_messages_cleared = None
                                            self.update_out_queue_size_high = None
                                            self.update_out_queue_size_cumulative = None
                                            self.update_out_queue_size_discarded = None
                                            self.update_out_queue_size_cleared = None
                                            self.last_update_discard_age = None
                                            self.last_update_cleard_age = None
                                            self.update_throttle_count = None
                                            self.last_update_throttle_age = None
                                            self.update_recovery_count = None
                                            self.last_update_recovery_age = None
                                            self.update_memory_allocation_fail_count = None
                                            self.last_update_memory_allocation_fail_age = None

                                            self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp()
                                            self.last_update_discard_timestamp.parent = self
                                            self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                            self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp()
                                            self.last_update_cleared_timestamp.parent = self
                                            self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                            self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp()
                                            self.last_update_throttle_timestamp.parent = self
                                            self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                            self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                            self.last_update_recovery_timestamp.parent = self
                                            self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                            self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                            self.last_update_memory_allocation_fail_timestamp.parent = self
                                            self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                            self._segment_path = lambda: "update-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                        class LastUpdateDiscardTimestamp(Entity):
                                            """
                                            Last Discarded time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                                self.yang_name = "last-update-discard-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-discard-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateClearedTimestamp(Entity):
                                            """
                                            Last Cleared time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                                self.yang_name = "last-update-cleared-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-cleared-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateThrottleTimestamp(Entity):
                                            """
                                            Last Throttled time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                                self.yang_name = "last-update-throttle-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-throttle-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateRecoveryTimestamp(Entity):
                                            """
                                            Last Recovery time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                                self.yang_name = "last-update-recovery-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-recovery-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                        class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                            """
                                            Memory allocation failure time
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                                self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                                self.yang_parent_name = "update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationNeighbors.UpdateGenerationNeighbor.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class UpdateGenerationAddressFamily(Entity):
                                """
                                Update generation for address\-family
                                
                                .. attribute:: update_statistics
                                
                                	Upate statistics
                                	**type**\:  :py:class:`UpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics>`
                                
                                .. attribute:: update_group_af_name
                                
                                	Address family identifier
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_main_table_version
                                
                                	Main table version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_rib_version
                                
                                	RIB version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_min_neighbor_version
                                
                                	Minimum Neighbor version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_af
                                
                                	Current AF update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_af
                                
                                	Configured AF update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_subgrp_ebgp
                                
                                	Current EBGP sub\-group update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_subgrp_ebgp
                                
                                	Configured EBGP sub\-group update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: current_update_limit_sub_group_ibgp
                                
                                	Current IBGP sub\-group update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_update_limit_sub_group_ibgp
                                
                                	Configured IBGP sub\-group update limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_messages
                                
                                	OutQueue messsages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_out_queue_size
                                
                                	OutQueue size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_throttled
                                
                                	Is Update throttled
                                	**type**\: bool
                                
                                .. attribute:: update_update_group_count
                                
                                	Update\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_sub_group_count
                                
                                	Sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sub_group_throttled_count
                                
                                	Throttled sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_count
                                
                                	Refresh sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_sub_group_throttled_count
                                
                                	Throttled refresh sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: filter_group_count
                                
                                	Filter\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_count
                                
                                	Neighbor count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_vrf_name
                                
                                	VRF Name
                                	**type**\: str
                                
                                .. attribute:: update_vrfaf_name
                                
                                	Address family identifier
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_rd_version
                                
                                	RD Version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_vrf_table_rib_version
                                
                                	VRF Table RIB version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_update_group_count
                                
                                	VRF Table update\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_sub_group_count
                                
                                	VRF Table sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_sub_group_throttled_count
                                
                                	VRF Table throttled sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_count
                                
                                	VRF Table refresh sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_refresh_sub_group_throttled_count
                                
                                	VRF Table throttled refresh sub\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_table_filter_group_count
                                
                                	VRF Table filter\-group count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: table_neighbor_count
                                
                                	VRF Table neighbor count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily, self).__init__()

                                    self.yang_name = "update-generation-address-family"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-statistics", ("update_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics))])
                                    self._leafs = OrderedDict([
                                        ('update_group_af_name', (YLeaf(YType.enumeration, 'update-group-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('update_main_table_version', (YLeaf(YType.uint32, 'update-main-table-version'), ['int'])),
                                        ('update_rib_version', (YLeaf(YType.uint32, 'update-rib-version'), ['int'])),
                                        ('update_min_neighbor_version', (YLeaf(YType.uint32, 'update-min-neighbor-version'), ['int'])),
                                        ('current_update_limit_af', (YLeaf(YType.uint32, 'current-update-limit-af'), ['int'])),
                                        ('configured_update_limit_af', (YLeaf(YType.uint32, 'configured-update-limit-af'), ['int'])),
                                        ('current_update_limit_subgrp_ebgp', (YLeaf(YType.uint32, 'current-update-limit-subgrp-ebgp'), ['int'])),
                                        ('configured_update_limit_subgrp_ebgp', (YLeaf(YType.uint32, 'configured-update-limit-subgrp-ebgp'), ['int'])),
                                        ('current_update_limit_sub_group_ibgp', (YLeaf(YType.uint32, 'current-update-limit-sub-group-ibgp'), ['int'])),
                                        ('configured_update_limit_sub_group_ibgp', (YLeaf(YType.uint32, 'configured-update-limit-sub-group-ibgp'), ['int'])),
                                        ('update_out_queue_messages', (YLeaf(YType.uint32, 'update-out-queue-messages'), ['int'])),
                                        ('update_out_queue_size', (YLeaf(YType.uint32, 'update-out-queue-size'), ['int'])),
                                        ('update_throttled', (YLeaf(YType.boolean, 'update-throttled'), ['bool'])),
                                        ('update_update_group_count', (YLeaf(YType.uint32, 'update-update-group-count'), ['int'])),
                                        ('update_sub_group_count', (YLeaf(YType.uint32, 'update-sub-group-count'), ['int'])),
                                        ('sub_group_throttled_count', (YLeaf(YType.uint32, 'sub-group-throttled-count'), ['int'])),
                                        ('refresh_sub_group_count', (YLeaf(YType.uint32, 'refresh-sub-group-count'), ['int'])),
                                        ('refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'refresh-sub-group-throttled-count'), ['int'])),
                                        ('filter_group_count', (YLeaf(YType.uint32, 'filter-group-count'), ['int'])),
                                        ('neighbor_count', (YLeaf(YType.uint32, 'neighbor-count'), ['int'])),
                                        ('update_table_vrf_name', (YLeaf(YType.str, 'update-table-vrf-name'), ['str'])),
                                        ('update_vrfaf_name', (YLeaf(YType.uint32, 'update-vrfaf-name'), ['int'])),
                                        ('update_vrf_rd_version', (YLeaf(YType.uint32, 'update-vrf-rd-version'), ['int'])),
                                        ('update_vrf_table_rib_version', (YLeaf(YType.uint32, 'update-vrf-table-rib-version'), ['int'])),
                                        ('table_update_group_count', (YLeaf(YType.uint32, 'table-update-group-count'), ['int'])),
                                        ('update_table_sub_group_count', (YLeaf(YType.uint32, 'update-table-sub-group-count'), ['int'])),
                                        ('table_sub_group_throttled_count', (YLeaf(YType.uint32, 'table-sub-group-throttled-count'), ['int'])),
                                        ('table_refresh_sub_group_count', (YLeaf(YType.uint32, 'table-refresh-sub-group-count'), ['int'])),
                                        ('table_refresh_sub_group_throttled_count', (YLeaf(YType.uint32, 'table-refresh-sub-group-throttled-count'), ['int'])),
                                        ('update_table_filter_group_count', (YLeaf(YType.uint32, 'update-table-filter-group-count'), ['int'])),
                                        ('table_neighbor_count', (YLeaf(YType.uint32, 'table-neighbor-count'), ['int'])),
                                    ])
                                    self.update_group_af_name = None
                                    self.update_main_table_version = None
                                    self.update_rib_version = None
                                    self.update_min_neighbor_version = None
                                    self.current_update_limit_af = None
                                    self.configured_update_limit_af = None
                                    self.current_update_limit_subgrp_ebgp = None
                                    self.configured_update_limit_subgrp_ebgp = None
                                    self.current_update_limit_sub_group_ibgp = None
                                    self.configured_update_limit_sub_group_ibgp = None
                                    self.update_out_queue_messages = None
                                    self.update_out_queue_size = None
                                    self.update_throttled = None
                                    self.update_update_group_count = None
                                    self.update_sub_group_count = None
                                    self.sub_group_throttled_count = None
                                    self.refresh_sub_group_count = None
                                    self.refresh_sub_group_throttled_count = None
                                    self.filter_group_count = None
                                    self.neighbor_count = None
                                    self.update_table_vrf_name = None
                                    self.update_vrfaf_name = None
                                    self.update_vrf_rd_version = None
                                    self.update_vrf_table_rib_version = None
                                    self.table_update_group_count = None
                                    self.update_table_sub_group_count = None
                                    self.table_sub_group_throttled_count = None
                                    self.table_refresh_sub_group_count = None
                                    self.table_refresh_sub_group_throttled_count = None
                                    self.update_table_filter_group_count = None
                                    self.table_neighbor_count = None

                                    self.update_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics()
                                    self.update_statistics.parent = self
                                    self._children_name_map["update_statistics"] = "update-statistics"
                                    self._segment_path = lambda: "update-generation-address-family"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily, [u'update_group_af_name', u'update_main_table_version', u'update_rib_version', u'update_min_neighbor_version', u'current_update_limit_af', u'configured_update_limit_af', u'current_update_limit_subgrp_ebgp', u'configured_update_limit_subgrp_ebgp', u'current_update_limit_sub_group_ibgp', u'configured_update_limit_sub_group_ibgp', u'update_out_queue_messages', u'update_out_queue_size', u'update_throttled', u'update_update_group_count', u'update_sub_group_count', u'sub_group_throttled_count', u'refresh_sub_group_count', u'refresh_sub_group_throttled_count', u'filter_group_count', u'neighbor_count', u'update_table_vrf_name', u'update_vrfaf_name', u'update_vrf_rd_version', u'update_vrf_table_rib_version', u'table_update_group_count', u'update_table_sub_group_count', u'table_sub_group_throttled_count', u'table_refresh_sub_group_count', u'table_refresh_sub_group_throttled_count', u'update_table_filter_group_count', u'table_neighbor_count'], name, value)


                                class UpdateStatistics(Entity):
                                    """
                                    Upate statistics
                                    
                                    .. attribute:: last_update_discard_timestamp
                                    
                                    	Last Discarded time
                                    	**type**\:  :py:class:`LastUpdateDiscardTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp>`
                                    
                                    .. attribute:: last_update_cleared_timestamp
                                    
                                    	Last Cleared time
                                    	**type**\:  :py:class:`LastUpdateClearedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp>`
                                    
                                    .. attribute:: last_update_throttle_timestamp
                                    
                                    	Last Throttled time
                                    	**type**\:  :py:class:`LastUpdateThrottleTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp>`
                                    
                                    .. attribute:: last_update_recovery_timestamp
                                    
                                    	Last Recovery time
                                    	**type**\:  :py:class:`LastUpdateRecoveryTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp>`
                                    
                                    .. attribute:: last_update_memory_allocation_fail_timestamp
                                    
                                    	Memory allocation failure time
                                    	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp>`
                                    
                                    .. attribute:: update_out_queue_messages_high
                                    
                                    	OutQueue High Messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cumulative
                                    
                                    	OutQueue Cumulative Messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_discarded
                                    
                                    	OutQueue Discarded Messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_messages_cleared
                                    
                                    	OutQueue Cleared Messages
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size_high
                                    
                                    	OutQueue Hi Size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: update_out_queue_size_cumulative
                                    
                                    	OutQueue Cumulative Size
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_discarded
                                    
                                    	OutQueue Discarded Size
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: update_out_queue_size_cleared
                                    
                                    	OutQueue Cleared Size
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_update_discard_age
                                    
                                    	Time since last Discard event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: last_update_cleard_age
                                    
                                    	Time since last Clear event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: update_throttle_count
                                    
                                    	Throttle Count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_throttle_age
                                    
                                    	Time since last Throttle event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: update_recovery_count
                                    
                                    	Recovery Count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_recovery_age
                                    
                                    	Time since last Recovery event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: update_memory_allocation_fail_count
                                    
                                    	Memory allocation failure count
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_update_memory_allocation_fail_age
                                    
                                    	Time since last memory allocation failure event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, self).__init__()

                                        self.yang_name = "update-statistics"
                                        self.yang_parent_name = "update-generation-address-family"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("last-update-discard-timestamp", ("last_update_discard_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp)), ("last-update-cleared-timestamp", ("last_update_cleared_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp)), ("last-update-throttle-timestamp", ("last_update_throttle_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp)), ("last-update-recovery-timestamp", ("last_update_recovery_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('update_out_queue_messages_high', (YLeaf(YType.uint32, 'update-out-queue-messages-high'), ['int'])),
                                            ('update_out_queue_messages_cumulative', (YLeaf(YType.uint32, 'update-out-queue-messages-cumulative'), ['int'])),
                                            ('update_out_queue_messages_discarded', (YLeaf(YType.uint32, 'update-out-queue-messages-discarded'), ['int'])),
                                            ('update_out_queue_messages_cleared', (YLeaf(YType.uint32, 'update-out-queue-messages-cleared'), ['int'])),
                                            ('update_out_queue_size_high', (YLeaf(YType.uint32, 'update-out-queue-size-high'), ['int'])),
                                            ('update_out_queue_size_cumulative', (YLeaf(YType.uint64, 'update-out-queue-size-cumulative'), ['int'])),
                                            ('update_out_queue_size_discarded', (YLeaf(YType.uint64, 'update-out-queue-size-discarded'), ['int'])),
                                            ('update_out_queue_size_cleared', (YLeaf(YType.uint64, 'update-out-queue-size-cleared'), ['int'])),
                                            ('last_update_discard_age', (YLeaf(YType.uint32, 'last-update-discard-age'), ['int'])),
                                            ('last_update_cleard_age', (YLeaf(YType.uint32, 'last-update-cleard-age'), ['int'])),
                                            ('update_throttle_count', (YLeaf(YType.uint32, 'update-throttle-count'), ['int'])),
                                            ('last_update_throttle_age', (YLeaf(YType.uint32, 'last-update-throttle-age'), ['int'])),
                                            ('update_recovery_count', (YLeaf(YType.uint32, 'update-recovery-count'), ['int'])),
                                            ('last_update_recovery_age', (YLeaf(YType.uint32, 'last-update-recovery-age'), ['int'])),
                                            ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                            ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                        ])
                                        self.update_out_queue_messages_high = None
                                        self.update_out_queue_messages_cumulative = None
                                        self.update_out_queue_messages_discarded = None
                                        self.update_out_queue_messages_cleared = None
                                        self.update_out_queue_size_high = None
                                        self.update_out_queue_size_cumulative = None
                                        self.update_out_queue_size_discarded = None
                                        self.update_out_queue_size_cleared = None
                                        self.last_update_discard_age = None
                                        self.last_update_cleard_age = None
                                        self.update_throttle_count = None
                                        self.last_update_throttle_age = None
                                        self.update_recovery_count = None
                                        self.last_update_recovery_age = None
                                        self.update_memory_allocation_fail_count = None
                                        self.last_update_memory_allocation_fail_age = None

                                        self.last_update_discard_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp()
                                        self.last_update_discard_timestamp.parent = self
                                        self._children_name_map["last_update_discard_timestamp"] = "last-update-discard-timestamp"

                                        self.last_update_cleared_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp()
                                        self.last_update_cleared_timestamp.parent = self
                                        self._children_name_map["last_update_cleared_timestamp"] = "last-update-cleared-timestamp"

                                        self.last_update_throttle_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp()
                                        self.last_update_throttle_timestamp.parent = self
                                        self._children_name_map["last_update_throttle_timestamp"] = "last-update-throttle-timestamp"

                                        self.last_update_recovery_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp()
                                        self.last_update_recovery_timestamp.parent = self
                                        self._children_name_map["last_update_recovery_timestamp"] = "last-update-recovery-timestamp"

                                        self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp()
                                        self.last_update_memory_allocation_fail_timestamp.parent = self
                                        self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"
                                        self._segment_path = lambda: "update-statistics"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics, [u'update_out_queue_messages_high', u'update_out_queue_messages_cumulative', u'update_out_queue_messages_discarded', u'update_out_queue_messages_cleared', u'update_out_queue_size_high', u'update_out_queue_size_cumulative', u'update_out_queue_size_discarded', u'update_out_queue_size_cleared', u'last_update_discard_age', u'last_update_cleard_age', u'update_throttle_count', u'last_update_throttle_age', u'update_recovery_count', u'last_update_recovery_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age'], name, value)


                                    class LastUpdateDiscardTimestamp(Entity):
                                        """
                                        Last Discarded time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, self).__init__()

                                            self.yang_name = "last-update-discard-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-discard-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateDiscardTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateClearedTimestamp(Entity):
                                        """
                                        Last Cleared time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, self).__init__()

                                            self.yang_name = "last-update-cleared-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-cleared-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateClearedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateThrottleTimestamp(Entity):
                                        """
                                        Last Throttled time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, self).__init__()

                                            self.yang_name = "last-update-throttle-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-throttle-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateThrottleTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateRecoveryTimestamp(Entity):
                                        """
                                        Last Recovery time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, self).__init__()

                                            self.yang_name = "last-update-recovery-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-recovery-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateRecoveryTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                        """
                                        Memory allocation failure time
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                            self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                            self.yang_parent_name = "update-statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.UpdateGenerationAddressFamily.UpdateStatistics.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class Dampenings(Entity):
                                """
                                The BGP Dampening table
                                
                                .. attribute:: dampening
                                
                                	A BGP Dampening table entry
                                	**type**\: list of  		 :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings, self).__init__()

                                    self.yang_name = "dampenings"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dampening", ("dampening", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening))])
                                    self._leafs = OrderedDict()

                                    self.dampening = YList(self)
                                    self._segment_path = lambda: "dampenings"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings, [], name, value)


                                class Dampening(Entity):
                                    """
                                    A BGP Dampening table entry
                                    
                                    .. attribute:: reuse
                                    
                                    	Reuse array index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: version
                                    
                                    	Version number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rd
                                    
                                    	Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: network
                                    
                                    	Network prefix in dotted decimal format for ip prefix, else in hex string format
                                    	**type**\: str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: length
                                    
                                    	Prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_rd
                                    
                                    	Source Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: orig_source_rd
                                    
                                    	Original Source Route Distinguisher value
                                    	**type**\: str
                                    
                                    .. attribute:: path_id
                                    
                                    	Received Path ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: advertised_neighbor
                                    
                                    	Advertised Neighbor Address. Valid in the case of Advertised table
                                    	**type**\:  :py:class:`AdvertisedNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor>`
                                    
                                    .. attribute:: path_information
                                    
                                    	Path information
                                    	**type**\:  :py:class:`PathInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation>`
                                    
                                    .. attribute:: attributes_after_policy_in
                                    
                                    	Attributes after inbound policy applied. In the case of path type received\-only this will be attributes before inbound policy
                                    	**type**\:  :py:class:`AttributesAfterPolicyIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn>`
                                    
                                    .. attribute:: no_path
                                    
                                    	No path exists. All 'sp\_path' fields except 'sp\_path\->bag\_prefix' are invalid
                                    	**type**\: bool
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: label_oor
                                    
                                    	LSD label space is exhausted
                                    	**type**\: bool
                                    
                                    .. attribute:: label_oor_version
                                    
                                    	Label Version when OOR happens
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_fail
                                    
                                    	LSD label allocation failed 
                                    	**type**\: bool
                                    
                                    .. attribute:: route_distinguisher
                                    
                                    	Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: source_route_distinguisher
                                    
                                    	Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: original_source_route_distinguisher
                                    
                                    	Original Source Route Distinguisher
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{16}
                                    
                                    .. attribute:: prefix_version
                                    
                                    	Version of BGP Prefix Table
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    .. attribute:: source_vrf_name
                                    
                                    	Name of the source VRF
                                    	**type**\: str
                                    
                                    .. attribute:: srcaf_name
                                    
                                    	Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "dampenings"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("advertised-neighbor", ("advertised_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor)), ("path-information", ("path_information", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation)), ("attributes-after-policy-in", ("attributes_after_policy_in", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn))])
                                        self._leafs = OrderedDict([
                                            ('reuse', (YLeaf(YType.uint32, 'reuse'), ['int'])),
                                            ('version', (YLeaf(YType.uint32, 'version'), ['int'])),
                                            ('rd', (YLeaf(YType.str, 'rd'), ['str'])),
                                            ('network', (YLeaf(YType.str, 'network'), ['str'])),
                                            ('length', (YLeaf(YType.uint32, 'length'), ['int'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('source_rd', (YLeaf(YType.str, 'source-rd'), ['str'])),
                                            ('orig_source_rd', (YLeaf(YType.str, 'orig-source-rd'), ['str'])),
                                            ('path_id', (YLeaf(YType.uint32, 'path-id'), ['int'])),
                                            ('no_path', (YLeaf(YType.boolean, 'no-path'), ['bool'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('label_oor', (YLeaf(YType.boolean, 'label-oor'), ['bool'])),
                                            ('label_oor_version', (YLeaf(YType.uint32, 'label-oor-version'), ['int'])),
                                            ('label_fail', (YLeaf(YType.boolean, 'label-fail'), ['bool'])),
                                            ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                            ('source_route_distinguisher', (YLeaf(YType.str, 'source-route-distinguisher'), ['str'])),
                                            ('original_source_route_distinguisher', (YLeaf(YType.str, 'original-source-route-distinguisher'), ['str'])),
                                            ('prefix_version', (YLeaf(YType.uint32, 'prefix-version'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('source_vrf_name', (YLeaf(YType.str, 'source-vrf-name'), ['str'])),
                                            ('srcaf_name', (YLeaf(YType.enumeration, 'srcaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.reuse = None
                                        self.version = None
                                        self.rd = None
                                        self.network = None
                                        self.length = None
                                        self.neighbor_address = None
                                        self.source_rd = None
                                        self.orig_source_rd = None
                                        self.path_id = None
                                        self.no_path = None
                                        self.af_name = None
                                        self.process_instance_id = None
                                        self.label_oor = None
                                        self.label_oor_version = None
                                        self.label_fail = None
                                        self.route_distinguisher = None
                                        self.source_route_distinguisher = None
                                        self.original_source_route_distinguisher = None
                                        self.prefix_version = None
                                        self.vrf_name = None
                                        self.source_vrf_name = None
                                        self.srcaf_name = None

                                        self.advertised_neighbor = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor()
                                        self.advertised_neighbor.parent = self
                                        self._children_name_map["advertised_neighbor"] = "advertised-neighbor"

                                        self.path_information = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation()
                                        self.path_information.parent = self
                                        self._children_name_map["path_information"] = "path-information"

                                        self.attributes_after_policy_in = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn()
                                        self.attributes_after_policy_in.parent = self
                                        self._children_name_map["attributes_after_policy_in"] = "attributes-after-policy-in"
                                        self._segment_path = lambda: "dampening"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening, ['reuse', 'version', 'rd', 'network', 'length', 'neighbor_address', 'source_rd', 'orig_source_rd', 'path_id', u'no_path', u'af_name', u'process_instance_id', u'label_oor', u'label_oor_version', u'label_fail', u'route_distinguisher', u'source_route_distinguisher', u'original_source_route_distinguisher', u'prefix_version', u'vrf_name', u'source_vrf_name', u'srcaf_name'], name, value)


                                    class AdvertisedNeighbor(Entity):
                                        """
                                        Advertised Neighbor Address. Valid in the case
                                        of Advertised table
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor, self).__init__()

                                            self.yang_name = "advertised-neighbor"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "advertised-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "advertised-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AdvertisedNeighbor.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PathInformation(Entity):
                                        """
                                        Path information
                                        
                                        .. attribute:: bgp_prefix
                                        
                                        	BGP prefix
                                        	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix>`
                                        
                                        .. attribute:: neighbor_address
                                        
                                        	Neighbor address
                                        	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress>`
                                        
                                        .. attribute:: next_hop
                                        
                                        	Next hop
                                        	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop>`
                                        
                                        .. attribute:: nh_tunnel
                                        
                                        	NH tunnel information
                                        	**type**\:  :py:class:`NhTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel>`
                                        
                                        .. attribute:: mdt_group_addr
                                        
                                        	IPv4 MDT Group Address for the path
                                        	**type**\:  :py:class:`MdtGroupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr>`
                                        
                                        .. attribute:: gw_addr
                                        
                                        	Path GW Address
                                        	**type**\:  :py:class:`GwAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr>`
                                        
                                        .. attribute:: nh_addr
                                        
                                        	Path next\-hop Address
                                        	**type**\:  :py:class:`NhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr>`
                                        
                                        .. attribute:: best_path_comp_winner
                                        
                                        	Neighbor address of the path which won best path comparison
                                        	**type**\:  :py:class:`BestPathCompWinner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner>`
                                        
                                        .. attribute:: mvpn_nbr_addr
                                        
                                        	Mvpn nbr Address for the path
                                        	**type**\:  :py:class:`MvpnNbrAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr>`
                                        
                                        .. attribute:: mvpn_nexthop_addr
                                        
                                        	Mvpn nexthop Address for the path
                                        	**type**\:  :py:class:`MvpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr>`
                                        
                                        .. attribute:: vpn_nexthop_addr
                                        
                                        	Vpn nexthop Address for the path
                                        	**type**\:  :py:class:`VpnNexthopAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr>`
                                        
                                        .. attribute:: route_type
                                        
                                        	Route Type of path
                                        	**type**\:  :py:class:`BgpRoute1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRoute1>`
                                        
                                        .. attribute:: is_path_valid
                                        
                                        	Path attributes are usable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_damped
                                        
                                        	Path suppressed due to dampening
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_history_held
                                        
                                        	Path entry held to remember history
                                        	**type**\: bool
                                        
                                        .. attribute:: is_internal_path
                                        
                                        	Received over an internal link
                                        	**type**\: bool
                                        
                                        .. attribute:: is_best_path
                                        
                                        	Best available path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_as_best
                                        
                                        	Best available path within AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_spkr_as_best
                                        
                                        	Best available path within AS in speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_best
                                        
                                        	Partial best path within distributed speaker
                                        	**type**\: bool
                                        
                                        .. attribute:: is_aggregation_suppressed
                                        
                                        	Path suppressed due to aggregation
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_dampened
                                        
                                        	net import dampened
                                        	**type**\: bool
                                        
                                        .. attribute:: is_import_suspect
                                        
                                        	net import suspect
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised
                                        
                                        	Not advertised to any peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_not_advertised_to_ebgp
                                        
                                        	Not advertised to EBGPs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_advertised_local_as_only
                                        
                                        	Not advertised outside local AS
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_route_reflector
                                        
                                        	Path received from route reflector
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_received_only
                                        
                                        	Path is received only
                                        	**type**\: bool
                                        
                                        .. attribute:: is_received_path_not_modified
                                        
                                        	Received path used without modification
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_locally_sourced
                                        
                                        	Path sourced locally
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_local_aggregate
                                        
                                        	Path is a locally created aggregate
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_network_command
                                        
                                        	Path sourced by network command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_redistribute_command
                                        
                                        	Path sourced by redistribute command
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imported
                                        
                                        	Path is imported
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated
                                        
                                        	Path is reoriginated
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_reoriginated_stitching
                                        
                                        	Path is reoriginated with stitching RTs
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_vpn_only
                                        
                                        	Path is not in the vrf
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_from_confederation_peer
                                        
                                        	Path received from confederation peer
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_synced_with_igp
                                        
                                        	Path synchronized with IGP
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_multipath
                                        
                                        	Path is one of multipath best routes
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_imp_candidate
                                        
                                        	Path is a candidate for multipath import
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_stale
                                        
                                        	Stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_long_lived_stale
                                        
                                        	Long lived stale routes learnt before neighbor restarts
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup
                                        
                                        	Path is a backup path 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_backup_protect_multipath
                                        
                                        	Path is a backup path to protect multipaths
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_best_external
                                        
                                        	Path is a best external path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_additional_path
                                        
                                        	Path is an additional\-path
                                        	**type**\: bool
                                        
                                        .. attribute:: is_path_nexthop_discarded
                                        
                                        	Path is redirected to Null0
                                        	**type**\: bool
                                        
                                        .. attribute:: has_local_net_label
                                        
                                        	Path has local label
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Path local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: igp_metric
                                        
                                        	IGP metric to the gateway
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_weight
                                        
                                        	Weight for the path
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_router_id
                                        
                                        	Router ID of the neighbor for the path
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: has_mdt_group_addr
                                        
                                        	Path has MDT Group Address
                                        	**type**\: bool
                                        
                                        .. attribute:: l2vpn_size
                                        
                                        	Path block size
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: l2vpn_evpn_esi
                                        
                                        	L2VPN EVPN ESI
                                        	**type**\: str
                                        
                                        .. attribute:: has_gw_addr
                                        
                                        	Path has GW Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_nh_addr
                                        
                                        	Path has next\-hop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_second_label
                                        
                                        	Path has second received label
                                        	**type**\: bool
                                        
                                        .. attribute:: second_label
                                        
                                        	Path second received label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flap_count
                                        
                                        	Number of times this route has flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seconds_since_first_flap
                                        
                                        	Seconds since route first flapped
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: time_to_unsuppress
                                        
                                        	Seconds until route is unsuppressed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: dampen_penalty
                                        
                                        	Dampening penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: halflife_time
                                        
                                        	Half\-life time for the penalty
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_penalty
                                        
                                        	Value to start suppressing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reuse_value
                                        
                                        	Value to start reusing a route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_suppress_time
                                        
                                        	Maximum duration to suppress a stable route
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_comp_stage
                                        
                                        	Stage where the path lost to the best path or group best
                                        	**type**\:  :py:class:`BgpBpStage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBpStage>`
                                        
                                        .. attribute:: best_path_id_comp_winner
                                        
                                        	Path ID of the path which won best path comparison
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_flags
                                        
                                        	Flags associated with path
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: path_import_flags
                                        
                                        	Path import flags
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: best_path_id
                                        
                                        	Best path ID; DEPRECATED BYLocalPathId
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_path_id
                                        
                                        	Local path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rcvd_path_id
                                        
                                        	Received path ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_table_version
                                        
                                        	Table version # for pelem
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertisedto_pe
                                        
                                        	Net could be advertised                          to PE peers
                                        	**type**\: bool
                                        
                                        .. attribute:: rib_failed
                                        
                                        	Is net failed installed                          in RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: sn_rpki_origin_as_validity
                                        
                                        	RPKI origin validation state
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: show_rpki_origin_as_validity
                                        
                                        	Display validity state ?
                                        	**type**\: bool
                                        
                                        .. attribute:: ibgp_signaled_validity
                                        
                                        	IBGP signalled validation
                                        	**type**\: bool
                                        
                                        .. attribute:: rpki_origin_as_validation_disabled
                                        
                                        	RPKI originAS V. Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_path
                                        
                                        	Accept Own
                                        	**type**\: bool
                                        
                                        .. attribute:: accept_own_self_originated_path
                                        
                                        	Accept\-Own self\-originated
                                        	**type**\: bool
                                        
                                        .. attribute:: aigp_metric
                                        
                                        	Total AIGP metric
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: mvpn_sfs_path
                                        
                                        	Is MVPN single forwarder PE path
                                        	**type**\: bool
                                        
                                        .. attribute:: fspec_invalid_path
                                        
                                        	Is Fspec invalid path
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nbr_addr
                                        
                                        	Path has Mvpn nbr Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_nexthop_addr
                                        
                                        	Path has MVPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: has_mvpn_pmsi
                                        
                                        	Path has MVPN PMSI feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_pmsi_type
                                        
                                        	Mvpn PMSI Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mvpn_pmsi_flags
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: mvpn_pmsi_label
                                        
                                        	Mvpn PMSI label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: has_mvpn_extcomm
                                        
                                        	Path has MVPN EXTCOMM feedback
                                        	**type**\: bool
                                        
                                        .. attribute:: mvpn_path_flags
                                        
                                        	Mvpn path flags
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: local_nh
                                        
                                        	Path has local nexthop
                                        	**type**\: bool
                                        
                                        .. attribute:: rt_set_limit_enabled
                                        
                                        	Path subject to RT\-set net limit
                                        	**type**\: bool
                                        
                                        .. attribute:: path_rt_set_id
                                        
                                        	RT\-set id of the path
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_rt_set_route_count
                                        
                                        	Count in RT\-set
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_path_af_install_eligible
                                        
                                        	Path can be installed in AF RIB
                                        	**type**\: bool
                                        
                                        .. attribute:: is_permanent_path
                                        
                                        	Path is of type Permanent path
                                        	**type**\: bool
                                        
                                        .. attribute:: graceful_shutdown
                                        
                                        	Marked for graceful shutdown
                                        	**type**\: bool
                                        
                                        .. attribute:: labeled_unicast_safi_path
                                        
                                        	Path was learnt by labeled\-unicast SAFI
                                        	**type**\: bool
                                        
                                        .. attribute:: has_vpn_nexthop_addr
                                        
                                        	Path has VPN nexthop Address
                                        	**type**\: bool
                                        
                                        .. attribute:: is_orig_src_rd_present
                                        
                                        	Original Source RD  present
                                        	**type**\: bool
                                        
                                        .. attribute:: af_name
                                        
                                        	Original Source Address family identifier
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: route_distinguisher
                                        
                                        	Original Source Route Distinguisher
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{16}
                                        
                                        .. attribute:: mac_ip_present
                                        
                                        	Mac IP Present  present
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_ip
                                        
                                        	Mac associated with IP
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: rcvd_label
                                        
                                        	Path received label stack
                                        	**type**\: list of  		 :py:class:`RcvdLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel>`
                                        
                                        .. attribute:: l2vpn_circuit_status_value
                                        
                                        	L2VPN Circuit Status Value
                                        	**type**\: list of  		 :py:class:`L2vpnCircuitStatusValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue>`
                                        
                                        .. attribute:: mvpn_pmsi_value
                                        
                                        	Mvpn PMSI Value
                                        	**type**\: list of  		 :py:class:`MvpnPmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue>`
                                        
                                        .. attribute:: extended_community
                                        
                                        	Mvpn Extended community attribute
                                        	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity>`
                                        
                                        .. attribute:: local_peers_advertised_to
                                        
                                        	Local peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`LocalPeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo>`
                                        
                                        .. attribute:: pe_peers_advertised_to
                                        
                                        	PE peers that this prefix has been advertised to
                                        	**type**\: list of  		 :py:class:`PePeersAdvertisedTo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo>`
                                        
                                        .. attribute:: best_path_orr_bitfield
                                        
                                        	ORR Best path Bitfields
                                        	**type**\: list of  		 :py:class:`BestPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield>`
                                        
                                        .. attribute:: add_path_orr_bitfield
                                        
                                        	ORR Add path Bitfields
                                        	**type**\: list of  		 :py:class:`AddPathOrrBitfield <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation, self).__init__()

                                            self.yang_name = "path-information"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix)), ("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress)), ("next-hop", ("next_hop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop)), ("nh-tunnel", ("nh_tunnel", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel)), ("mdt-group-addr", ("mdt_group_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr)), ("gw-addr", ("gw_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr)), ("nh-addr", ("nh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr)), ("best-path-comp-winner", ("best_path_comp_winner", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner)), ("mvpn-nbr-addr", ("mvpn_nbr_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr)), ("mvpn-nexthop-addr", ("mvpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr)), ("vpn-nexthop-addr", ("vpn_nexthop_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr)), ("rcvd-label", ("rcvd_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel)), ("l2vpn-circuit-status-value", ("l2vpn_circuit_status_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue)), ("mvpn-pmsi-value", ("mvpn_pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity)), ("local-peers-advertised-to", ("local_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo)), ("pe-peers-advertised-to", ("pe_peers_advertised_to", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo)), ("best-path-orr-bitfield", ("best_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield)), ("add-path-orr-bitfield", ("add_path_orr_bitfield", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield))])
                                            self._leafs = OrderedDict([
                                                ('route_type', (YLeaf(YType.enumeration, 'route-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRoute1', '')])),
                                                ('is_path_valid', (YLeaf(YType.boolean, 'is-path-valid'), ['bool'])),
                                                ('is_path_damped', (YLeaf(YType.boolean, 'is-path-damped'), ['bool'])),
                                                ('is_path_history_held', (YLeaf(YType.boolean, 'is-path-history-held'), ['bool'])),
                                                ('is_internal_path', (YLeaf(YType.boolean, 'is-internal-path'), ['bool'])),
                                                ('is_best_path', (YLeaf(YType.boolean, 'is-best-path'), ['bool'])),
                                                ('is_as_best', (YLeaf(YType.boolean, 'is-as-best'), ['bool'])),
                                                ('is_spkr_as_best', (YLeaf(YType.boolean, 'is-spkr-as-best'), ['bool'])),
                                                ('is_partial_best', (YLeaf(YType.boolean, 'is-partial-best'), ['bool'])),
                                                ('is_aggregation_suppressed', (YLeaf(YType.boolean, 'is-aggregation-suppressed'), ['bool'])),
                                                ('is_import_dampened', (YLeaf(YType.boolean, 'is-import-dampened'), ['bool'])),
                                                ('is_import_suspect', (YLeaf(YType.boolean, 'is-import-suspect'), ['bool'])),
                                                ('is_path_not_advertised', (YLeaf(YType.boolean, 'is-path-not-advertised'), ['bool'])),
                                                ('is_path_not_advertised_to_ebgp', (YLeaf(YType.boolean, 'is-path-not-advertised-to-ebgp'), ['bool'])),
                                                ('is_path_advertised_local_as_only', (YLeaf(YType.boolean, 'is-path-advertised-local-as-only'), ['bool'])),
                                                ('is_path_from_route_reflector', (YLeaf(YType.boolean, 'is-path-from-route-reflector'), ['bool'])),
                                                ('is_path_received_only', (YLeaf(YType.boolean, 'is-path-received-only'), ['bool'])),
                                                ('is_received_path_not_modified', (YLeaf(YType.boolean, 'is-received-path-not-modified'), ['bool'])),
                                                ('is_path_locally_sourced', (YLeaf(YType.boolean, 'is-path-locally-sourced'), ['bool'])),
                                                ('is_path_local_aggregate', (YLeaf(YType.boolean, 'is-path-local-aggregate'), ['bool'])),
                                                ('is_path_from_network_command', (YLeaf(YType.boolean, 'is-path-from-network-command'), ['bool'])),
                                                ('is_path_from_redistribute_command', (YLeaf(YType.boolean, 'is-path-from-redistribute-command'), ['bool'])),
                                                ('is_path_imported', (YLeaf(YType.boolean, 'is-path-imported'), ['bool'])),
                                                ('is_path_reoriginated', (YLeaf(YType.boolean, 'is-path-reoriginated'), ['bool'])),
                                                ('is_path_reoriginated_stitching', (YLeaf(YType.boolean, 'is-path-reoriginated-stitching'), ['bool'])),
                                                ('is_path_vpn_only', (YLeaf(YType.boolean, 'is-path-vpn-only'), ['bool'])),
                                                ('is_path_from_confederation_peer', (YLeaf(YType.boolean, 'is-path-from-confederation-peer'), ['bool'])),
                                                ('is_path_synced_with_igp', (YLeaf(YType.boolean, 'is-path-synced-with-igp'), ['bool'])),
                                                ('is_path_multipath', (YLeaf(YType.boolean, 'is-path-multipath'), ['bool'])),
                                                ('is_path_imp_candidate', (YLeaf(YType.boolean, 'is-path-imp-candidate'), ['bool'])),
                                                ('is_path_stale', (YLeaf(YType.boolean, 'is-path-stale'), ['bool'])),
                                                ('is_path_long_lived_stale', (YLeaf(YType.boolean, 'is-path-long-lived-stale'), ['bool'])),
                                                ('is_path_backup', (YLeaf(YType.boolean, 'is-path-backup'), ['bool'])),
                                                ('is_path_backup_protect_multipath', (YLeaf(YType.boolean, 'is-path-backup-protect-multipath'), ['bool'])),
                                                ('is_path_best_external', (YLeaf(YType.boolean, 'is-path-best-external'), ['bool'])),
                                                ('is_path_additional_path', (YLeaf(YType.boolean, 'is-path-additional-path'), ['bool'])),
                                                ('is_path_nexthop_discarded', (YLeaf(YType.boolean, 'is-path-nexthop-discarded'), ['bool'])),
                                                ('has_local_net_label', (YLeaf(YType.boolean, 'has-local-net-label'), ['bool'])),
                                                ('local_label', (YLeaf(YType.uint32, 'local-label'), ['int'])),
                                                ('igp_metric', (YLeaf(YType.uint32, 'igp-metric'), ['int'])),
                                                ('path_weight', (YLeaf(YType.uint16, 'path-weight'), ['int'])),
                                                ('neighbor_router_id', (YLeaf(YType.str, 'neighbor-router-id'), ['str'])),
                                                ('has_mdt_group_addr', (YLeaf(YType.boolean, 'has-mdt-group-addr'), ['bool'])),
                                                ('l2vpn_size', (YLeaf(YType.uint32, 'l2vpn-size'), ['int'])),
                                                ('l2vpn_evpn_esi', (YLeaf(YType.str, 'l2vpn-evpn-esi'), ['str'])),
                                                ('has_gw_addr', (YLeaf(YType.boolean, 'has-gw-addr'), ['bool'])),
                                                ('has_nh_addr', (YLeaf(YType.boolean, 'has-nh-addr'), ['bool'])),
                                                ('has_second_label', (YLeaf(YType.boolean, 'has-second-label'), ['bool'])),
                                                ('second_label', (YLeaf(YType.uint32, 'second-label'), ['int'])),
                                                ('path_flap_count', (YLeaf(YType.uint32, 'path-flap-count'), ['int'])),
                                                ('seconds_since_first_flap', (YLeaf(YType.uint32, 'seconds-since-first-flap'), ['int'])),
                                                ('time_to_unsuppress', (YLeaf(YType.uint32, 'time-to-unsuppress'), ['int'])),
                                                ('dampen_penalty', (YLeaf(YType.uint32, 'dampen-penalty'), ['int'])),
                                                ('halflife_time', (YLeaf(YType.uint32, 'halflife-time'), ['int'])),
                                                ('suppress_penalty', (YLeaf(YType.uint32, 'suppress-penalty'), ['int'])),
                                                ('reuse_value', (YLeaf(YType.uint32, 'reuse-value'), ['int'])),
                                                ('maximum_suppress_time', (YLeaf(YType.uint32, 'maximum-suppress-time'), ['int'])),
                                                ('best_path_comp_stage', (YLeaf(YType.enumeration, 'best-path-comp-stage'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBpStage', '')])),
                                                ('best_path_id_comp_winner', (YLeaf(YType.uint32, 'best-path-id-comp-winner'), ['int'])),
                                                ('path_flags', (YLeaf(YType.uint64, 'path-flags'), ['int'])),
                                                ('path_import_flags', (YLeaf(YType.uint32, 'path-import-flags'), ['int'])),
                                                ('best_path_id', (YLeaf(YType.uint32, 'best-path-id'), ['int'])),
                                                ('local_path_id', (YLeaf(YType.uint32, 'local-path-id'), ['int'])),
                                                ('rcvd_path_id', (YLeaf(YType.uint32, 'rcvd-path-id'), ['int'])),
                                                ('path_table_version', (YLeaf(YType.uint32, 'path-table-version'), ['int'])),
                                                ('advertisedto_pe', (YLeaf(YType.boolean, 'advertisedto-pe'), ['bool'])),
                                                ('rib_failed', (YLeaf(YType.boolean, 'rib-failed'), ['bool'])),
                                                ('sn_rpki_origin_as_validity', (YLeaf(YType.uint8, 'sn-rpki-origin-as-validity'), ['int'])),
                                                ('show_rpki_origin_as_validity', (YLeaf(YType.boolean, 'show-rpki-origin-as-validity'), ['bool'])),
                                                ('ibgp_signaled_validity', (YLeaf(YType.boolean, 'ibgp-signaled-validity'), ['bool'])),
                                                ('rpki_origin_as_validation_disabled', (YLeaf(YType.boolean, 'rpki-origin-as-validation-disabled'), ['bool'])),
                                                ('accept_own_path', (YLeaf(YType.boolean, 'accept-own-path'), ['bool'])),
                                                ('accept_own_self_originated_path', (YLeaf(YType.boolean, 'accept-own-self-originated-path'), ['bool'])),
                                                ('aigp_metric', (YLeaf(YType.uint64, 'aigp-metric'), ['int'])),
                                                ('mvpn_sfs_path', (YLeaf(YType.boolean, 'mvpn-sfs-path'), ['bool'])),
                                                ('fspec_invalid_path', (YLeaf(YType.boolean, 'fspec-invalid-path'), ['bool'])),
                                                ('has_mvpn_nbr_addr', (YLeaf(YType.boolean, 'has-mvpn-nbr-addr'), ['bool'])),
                                                ('has_mvpn_nexthop_addr', (YLeaf(YType.boolean, 'has-mvpn-nexthop-addr'), ['bool'])),
                                                ('has_mvpn_pmsi', (YLeaf(YType.boolean, 'has-mvpn-pmsi'), ['bool'])),
                                                ('mvpn_pmsi_type', (YLeaf(YType.uint16, 'mvpn-pmsi-type'), ['int'])),
                                                ('mvpn_pmsi_flags', (YLeaf(YType.uint8, 'mvpn-pmsi-flags'), ['int'])),
                                                ('mvpn_pmsi_label', (YLeaf(YType.uint32, 'mvpn-pmsi-label'), ['int'])),
                                                ('has_mvpn_extcomm', (YLeaf(YType.boolean, 'has-mvpn-extcomm'), ['bool'])),
                                                ('mvpn_path_flags', (YLeaf(YType.uint16, 'mvpn-path-flags'), ['int'])),
                                                ('local_nh', (YLeaf(YType.boolean, 'local-nh'), ['bool'])),
                                                ('rt_set_limit_enabled', (YLeaf(YType.boolean, 'rt-set-limit-enabled'), ['bool'])),
                                                ('path_rt_set_id', (YLeaf(YType.uint32, 'path-rt-set-id'), ['int'])),
                                                ('path_rt_set_route_count', (YLeaf(YType.uint32, 'path-rt-set-route-count'), ['int'])),
                                                ('is_path_af_install_eligible', (YLeaf(YType.boolean, 'is-path-af-install-eligible'), ['bool'])),
                                                ('is_permanent_path', (YLeaf(YType.boolean, 'is-permanent-path'), ['bool'])),
                                                ('graceful_shutdown', (YLeaf(YType.boolean, 'graceful-shutdown'), ['bool'])),
                                                ('labeled_unicast_safi_path', (YLeaf(YType.boolean, 'labeled-unicast-safi-path'), ['bool'])),
                                                ('has_vpn_nexthop_addr', (YLeaf(YType.boolean, 'has-vpn-nexthop-addr'), ['bool'])),
                                                ('is_orig_src_rd_present', (YLeaf(YType.boolean, 'is-orig-src-rd-present'), ['bool'])),
                                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                                ('mac_ip_present', (YLeaf(YType.boolean, 'mac-ip-present'), ['bool'])),
                                                ('mac_ip', (YLeaf(YType.str, 'mac-ip'), ['str'])),
                                            ])
                                            self.route_type = None
                                            self.is_path_valid = None
                                            self.is_path_damped = None
                                            self.is_path_history_held = None
                                            self.is_internal_path = None
                                            self.is_best_path = None
                                            self.is_as_best = None
                                            self.is_spkr_as_best = None
                                            self.is_partial_best = None
                                            self.is_aggregation_suppressed = None
                                            self.is_import_dampened = None
                                            self.is_import_suspect = None
                                            self.is_path_not_advertised = None
                                            self.is_path_not_advertised_to_ebgp = None
                                            self.is_path_advertised_local_as_only = None
                                            self.is_path_from_route_reflector = None
                                            self.is_path_received_only = None
                                            self.is_received_path_not_modified = None
                                            self.is_path_locally_sourced = None
                                            self.is_path_local_aggregate = None
                                            self.is_path_from_network_command = None
                                            self.is_path_from_redistribute_command = None
                                            self.is_path_imported = None
                                            self.is_path_reoriginated = None
                                            self.is_path_reoriginated_stitching = None
                                            self.is_path_vpn_only = None
                                            self.is_path_from_confederation_peer = None
                                            self.is_path_synced_with_igp = None
                                            self.is_path_multipath = None
                                            self.is_path_imp_candidate = None
                                            self.is_path_stale = None
                                            self.is_path_long_lived_stale = None
                                            self.is_path_backup = None
                                            self.is_path_backup_protect_multipath = None
                                            self.is_path_best_external = None
                                            self.is_path_additional_path = None
                                            self.is_path_nexthop_discarded = None
                                            self.has_local_net_label = None
                                            self.local_label = None
                                            self.igp_metric = None
                                            self.path_weight = None
                                            self.neighbor_router_id = None
                                            self.has_mdt_group_addr = None
                                            self.l2vpn_size = None
                                            self.l2vpn_evpn_esi = None
                                            self.has_gw_addr = None
                                            self.has_nh_addr = None
                                            self.has_second_label = None
                                            self.second_label = None
                                            self.path_flap_count = None
                                            self.seconds_since_first_flap = None
                                            self.time_to_unsuppress = None
                                            self.dampen_penalty = None
                                            self.halflife_time = None
                                            self.suppress_penalty = None
                                            self.reuse_value = None
                                            self.maximum_suppress_time = None
                                            self.best_path_comp_stage = None
                                            self.best_path_id_comp_winner = None
                                            self.path_flags = None
                                            self.path_import_flags = None
                                            self.best_path_id = None
                                            self.local_path_id = None
                                            self.rcvd_path_id = None
                                            self.path_table_version = None
                                            self.advertisedto_pe = None
                                            self.rib_failed = None
                                            self.sn_rpki_origin_as_validity = None
                                            self.show_rpki_origin_as_validity = None
                                            self.ibgp_signaled_validity = None
                                            self.rpki_origin_as_validation_disabled = None
                                            self.accept_own_path = None
                                            self.accept_own_self_originated_path = None
                                            self.aigp_metric = None
                                            self.mvpn_sfs_path = None
                                            self.fspec_invalid_path = None
                                            self.has_mvpn_nbr_addr = None
                                            self.has_mvpn_nexthop_addr = None
                                            self.has_mvpn_pmsi = None
                                            self.mvpn_pmsi_type = None
                                            self.mvpn_pmsi_flags = None
                                            self.mvpn_pmsi_label = None
                                            self.has_mvpn_extcomm = None
                                            self.mvpn_path_flags = None
                                            self.local_nh = None
                                            self.rt_set_limit_enabled = None
                                            self.path_rt_set_id = None
                                            self.path_rt_set_route_count = None
                                            self.is_path_af_install_eligible = None
                                            self.is_permanent_path = None
                                            self.graceful_shutdown = None
                                            self.labeled_unicast_safi_path = None
                                            self.has_vpn_nexthop_addr = None
                                            self.is_orig_src_rd_present = None
                                            self.af_name = None
                                            self.route_distinguisher = None
                                            self.mac_ip_present = None
                                            self.mac_ip = None

                                            self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix()
                                            self.bgp_prefix.parent = self
                                            self._children_name_map["bgp_prefix"] = "bgp-prefix"

                                            self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress()
                                            self.neighbor_address.parent = self
                                            self._children_name_map["neighbor_address"] = "neighbor-address"

                                            self.next_hop = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop()
                                            self.next_hop.parent = self
                                            self._children_name_map["next_hop"] = "next-hop"

                                            self.nh_tunnel = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel()
                                            self.nh_tunnel.parent = self
                                            self._children_name_map["nh_tunnel"] = "nh-tunnel"

                                            self.mdt_group_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr()
                                            self.mdt_group_addr.parent = self
                                            self._children_name_map["mdt_group_addr"] = "mdt-group-addr"

                                            self.gw_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr()
                                            self.gw_addr.parent = self
                                            self._children_name_map["gw_addr"] = "gw-addr"

                                            self.nh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr()
                                            self.nh_addr.parent = self
                                            self._children_name_map["nh_addr"] = "nh-addr"

                                            self.best_path_comp_winner = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner()
                                            self.best_path_comp_winner.parent = self
                                            self._children_name_map["best_path_comp_winner"] = "best-path-comp-winner"

                                            self.mvpn_nbr_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr()
                                            self.mvpn_nbr_addr.parent = self
                                            self._children_name_map["mvpn_nbr_addr"] = "mvpn-nbr-addr"

                                            self.mvpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr()
                                            self.mvpn_nexthop_addr.parent = self
                                            self._children_name_map["mvpn_nexthop_addr"] = "mvpn-nexthop-addr"

                                            self.vpn_nexthop_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr()
                                            self.vpn_nexthop_addr.parent = self
                                            self._children_name_map["vpn_nexthop_addr"] = "vpn-nexthop-addr"

                                            self.rcvd_label = YList(self)
                                            self.l2vpn_circuit_status_value = YList(self)
                                            self.mvpn_pmsi_value = YList(self)
                                            self.extended_community = YList(self)
                                            self.local_peers_advertised_to = YList(self)
                                            self.pe_peers_advertised_to = YList(self)
                                            self.best_path_orr_bitfield = YList(self)
                                            self.add_path_orr_bitfield = YList(self)
                                            self._segment_path = lambda: "path-information"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation, [u'route_type', u'is_path_valid', u'is_path_damped', u'is_path_history_held', u'is_internal_path', u'is_best_path', u'is_as_best', u'is_spkr_as_best', u'is_partial_best', u'is_aggregation_suppressed', u'is_import_dampened', u'is_import_suspect', u'is_path_not_advertised', u'is_path_not_advertised_to_ebgp', u'is_path_advertised_local_as_only', u'is_path_from_route_reflector', u'is_path_received_only', u'is_received_path_not_modified', u'is_path_locally_sourced', u'is_path_local_aggregate', u'is_path_from_network_command', u'is_path_from_redistribute_command', u'is_path_imported', u'is_path_reoriginated', u'is_path_reoriginated_stitching', u'is_path_vpn_only', u'is_path_from_confederation_peer', u'is_path_synced_with_igp', u'is_path_multipath', u'is_path_imp_candidate', u'is_path_stale', u'is_path_long_lived_stale', u'is_path_backup', u'is_path_backup_protect_multipath', u'is_path_best_external', u'is_path_additional_path', u'is_path_nexthop_discarded', u'has_local_net_label', u'local_label', u'igp_metric', u'path_weight', u'neighbor_router_id', u'has_mdt_group_addr', u'l2vpn_size', u'l2vpn_evpn_esi', u'has_gw_addr', u'has_nh_addr', u'has_second_label', u'second_label', u'path_flap_count', u'seconds_since_first_flap', u'time_to_unsuppress', u'dampen_penalty', u'halflife_time', u'suppress_penalty', u'reuse_value', u'maximum_suppress_time', u'best_path_comp_stage', u'best_path_id_comp_winner', u'path_flags', u'path_import_flags', u'best_path_id', u'local_path_id', u'rcvd_path_id', u'path_table_version', u'advertisedto_pe', u'rib_failed', u'sn_rpki_origin_as_validity', u'show_rpki_origin_as_validity', u'ibgp_signaled_validity', u'rpki_origin_as_validation_disabled', u'accept_own_path', u'accept_own_self_originated_path', u'aigp_metric', u'mvpn_sfs_path', u'fspec_invalid_path', u'has_mvpn_nbr_addr', u'has_mvpn_nexthop_addr', u'has_mvpn_pmsi', u'mvpn_pmsi_type', u'mvpn_pmsi_flags', u'mvpn_pmsi_label', u'has_mvpn_extcomm', u'mvpn_path_flags', u'local_nh', u'rt_set_limit_enabled', u'path_rt_set_id', u'path_rt_set_route_count', u'is_path_af_install_eligible', u'is_permanent_path', u'graceful_shutdown', u'labeled_unicast_safi_path', u'has_vpn_nexthop_addr', u'is_orig_src_rd_present', u'af_name', u'route_distinguisher', u'mac_ip_present', u'mac_ip'], name, value)


                                        class BgpPrefix(Entity):
                                            """
                                            BGP prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	Prefix
                                            	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, self).__init__()

                                                self.yang_name = "bgp-prefix"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix_length = None

                                                self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix()
                                                self.prefix.parent = self
                                                self._children_name_map["prefix"] = "prefix"
                                                self._segment_path = lambda: "bgp-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix, [u'prefix_length'], name, value)


                                            class Prefix(Entity):
                                                """
                                                Prefix
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "bgp-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NeighborAddress(Entity):
                                            """
                                            Neighbor address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, self).__init__()

                                                self.yang_name = "neighbor-address"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NextHop(Entity):
                                            """
                                            Next hop
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, self).__init__()

                                                self.yang_name = "next-hop"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NextHop.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class NhTunnel(Entity):
                                            """
                                            NH tunnel information
                                            
                                            .. attribute:: tunnel_type
                                            
                                            	Nexthop Tunnel Type
                                            	**type**\:  :py:class:`BgpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTunnel>`
                                            
                                            .. attribute:: tunnel_name
                                            
                                            	Tunnel name attribute
                                            	**type**\: str
                                            
                                            .. attribute:: is_tunnel_up
                                            
                                            	Tunnel Up flag
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_info_stale
                                            
                                            	Tunnel is stale
                                            	**type**\: bool
                                            
                                            .. attribute:: is_tunnel_registered
                                            
                                            	Tunnel registered flag
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_required
                                            
                                            	Tunnel need IPv6
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_v6_enabled
                                            
                                            	IPv6 enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_notif_first_rcvd
                                            
                                            	Tunnel first notif received
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state_skip_reg
                                            
                                            	Skip tunnel registration for Stale entry
                                            	**type**\: bool
                                            
                                            .. attribute:: binding_label
                                            
                                            	Binding label for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_if_handle
                                            
                                            	Interface handle for the tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_tunnel_update
                                            
                                            	Time since the last tunnel update happened
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_color
                                            
                                            	Color corresponding to this SR tunnel
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tunnel_color_only
                                            
                                            	Is a Color Only (Null Endpoint) tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_endpoint_afi
                                            
                                            	AFI of the Null Endpoint (IPv4/IPv6)
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, self).__init__()

                                                self.yang_name = "nh-tunnel"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('tunnel_type', (YLeaf(YType.enumeration, 'tunnel-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTunnel', '')])),
                                                    ('tunnel_name', (YLeaf(YType.str, 'tunnel-name'), ['str'])),
                                                    ('is_tunnel_up', (YLeaf(YType.boolean, 'is-tunnel-up'), ['bool'])),
                                                    ('is_tunnel_info_stale', (YLeaf(YType.boolean, 'is-tunnel-info-stale'), ['bool'])),
                                                    ('is_tunnel_registered', (YLeaf(YType.boolean, 'is-tunnel-registered'), ['bool'])),
                                                    ('tunnel_v6_required', (YLeaf(YType.boolean, 'tunnel-v6-required'), ['bool'])),
                                                    ('tunnel_v6_enabled', (YLeaf(YType.boolean, 'tunnel-v6-enabled'), ['bool'])),
                                                    ('tunnel_notif_first_rcvd', (YLeaf(YType.boolean, 'tunnel-notif-first-rcvd'), ['bool'])),
                                                    ('tunnel_state_skip_reg', (YLeaf(YType.boolean, 'tunnel-state-skip-reg'), ['bool'])),
                                                    ('binding_label', (YLeaf(YType.uint32, 'binding-label'), ['int'])),
                                                    ('tunnel_if_handle', (YLeaf(YType.uint32, 'tunnel-if-handle'), ['int'])),
                                                    ('last_tunnel_update', (YLeaf(YType.uint32, 'last-tunnel-update'), ['int'])),
                                                    ('tunnel_color', (YLeaf(YType.uint32, 'tunnel-color'), ['int'])),
                                                    ('is_tunnel_color_only', (YLeaf(YType.boolean, 'is-tunnel-color-only'), ['bool'])),
                                                    ('tunnel_endpoint_afi', (YLeaf(YType.enumeration, 'tunnel-endpoint-afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ])
                                                self.tunnel_type = None
                                                self.tunnel_name = None
                                                self.is_tunnel_up = None
                                                self.is_tunnel_info_stale = None
                                                self.is_tunnel_registered = None
                                                self.tunnel_v6_required = None
                                                self.tunnel_v6_enabled = None
                                                self.tunnel_notif_first_rcvd = None
                                                self.tunnel_state_skip_reg = None
                                                self.binding_label = None
                                                self.tunnel_if_handle = None
                                                self.last_tunnel_update = None
                                                self.tunnel_color = None
                                                self.is_tunnel_color_only = None
                                                self.tunnel_endpoint_afi = None
                                                self._segment_path = lambda: "nh-tunnel"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhTunnel, [u'tunnel_type', u'tunnel_name', u'is_tunnel_up', u'is_tunnel_info_stale', u'is_tunnel_registered', u'tunnel_v6_required', u'tunnel_v6_enabled', u'tunnel_notif_first_rcvd', u'tunnel_state_skip_reg', u'binding_label', u'tunnel_if_handle', u'last_tunnel_update', u'tunnel_color', u'is_tunnel_color_only', u'tunnel_endpoint_afi'], name, value)


                                        class MdtGroupAddr(Entity):
                                            """
                                            IPv4 MDT Group Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, self).__init__()

                                                self.yang_name = "mdt-group-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mdt-group-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mdt-group-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MdtGroupAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class GwAddr(Entity):
                                            """
                                            Path GW Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, self).__init__()

                                                self.yang_name = "gw-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "gw-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.GwAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class NhAddr(Entity):
                                            """
                                            Path next\-hop Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpV4V6Len <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpV4V6Len>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, self).__init__()

                                                self.yang_name = "nh-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpV4V6Len', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "nh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.NhAddr, [u'len', u'ipv4_address', u'ipv6_address'], name, value)


                                        class BestPathCompWinner(Entity):
                                            """
                                            Neighbor address of the path which won best path
                                            comparison
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, self).__init__()

                                                self.yang_name = "best-path-comp-winner"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "best-path-comp-winner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "best-path-comp-winner"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathCompWinner.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNbrAddr(Entity):
                                            """
                                            Mvpn nbr Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, self).__init__()

                                                self.yang_name = "mvpn-nbr-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nbr-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nbr-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNbrAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class MvpnNexthopAddr(Entity):
                                            """
                                            Mvpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, self).__init__()

                                                self.yang_name = "mvpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "mvpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "mvpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class VpnNexthopAddr(Entity):
                                            """
                                            Vpn nexthop Address for the path
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, self).__init__()

                                                self.yang_name = "vpn-nexthop-addr"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "vpn-nexthop-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "vpn-nexthop-addr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.VpnNexthopAddr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class RcvdLabel(Entity):
                                            """
                                            Path received label stack
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, self).__init__()

                                                self.yang_name = "rcvd-label"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rcvd-label"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.RcvdLabel, [u'entry'], name, value)


                                        class L2vpnCircuitStatusValue(Entity):
                                            """
                                            L2VPN Circuit Status Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue, self).__init__()

                                                self.yang_name = "l2vpn-circuit-status-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "l2vpn-circuit-status-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.L2vpnCircuitStatusValue, [u'entry'], name, value)


                                        class MvpnPmsiValue(Entity):
                                            """
                                            Mvpn PMSI Value
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, self).__init__()

                                                self.yang_name = "mvpn-pmsi-value"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "mvpn-pmsi-value"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.MvpnPmsiValue, [u'entry'], name, value)


                                        class ExtendedCommunity(Entity):
                                            """
                                            Mvpn Extended community attribute
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, self).__init__()

                                                self.yang_name = "extended-community"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "extended-community"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.ExtendedCommunity, [u'entry'], name, value)


                                        class LocalPeersAdvertisedTo(Entity):
                                            """
                                            Local peers that this prefix has been advertised
                                            to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, self).__init__()

                                                self.yang_name = "local-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "local-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "local-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.LocalPeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class PePeersAdvertisedTo(Entity):
                                            """
                                            PE peers that this prefix has been advertised to
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, self).__init__()

                                                self.yang_name = "pe-peers-advertised-to"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "pe-peers-advertised-to"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "pe-peers-advertised-to"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.PePeersAdvertisedTo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class BestPathOrrBitfield(Entity):
                                            """
                                            ORR Best path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, self).__init__()

                                                self.yang_name = "best-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "best-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "best-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.BestPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                        class AddPathOrrBitfield(Entity):
                                            """
                                            ORR Add path Bitfields
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Neighbor Address
                                            	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress>`
                                            
                                            .. attribute:: is_neighbor
                                            
                                            	Entry is a neighbor (not an update group)
                                            	**type**\: bool
                                            
                                            .. attribute:: update_group_afi
                                            
                                            	AFI of the Update group it is advertised to
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: update_group_number
                                            
                                            	Update group index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, self).__init__()

                                                self.yang_name = "add-path-orr-bitfield"
                                                self.yang_parent_name = "path-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress))])
                                                self._leafs = OrderedDict([
                                                    ('is_neighbor', (YLeaf(YType.boolean, 'is-neighbor'), ['bool'])),
                                                    ('update_group_afi', (YLeaf(YType.uint8, 'update-group-afi'), ['int'])),
                                                    ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                                ])
                                                self.is_neighbor = None
                                                self.update_group_afi = None
                                                self.update_group_number = None

                                                self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress()
                                                self.neighbor_address.parent = self
                                                self._children_name_map["neighbor_address"] = "neighbor-address"
                                                self._segment_path = lambda: "add-path-orr-bitfield"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield, [u'is_neighbor', u'update_group_afi', u'update_group_number'], name, value)


                                            class NeighborAddress(Entity):
                                                """
                                                Neighbor Address
                                                
                                                .. attribute:: l2vpn_vpls_address
                                                
                                                	L2VPN VPLS Addr
                                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress>`
                                                
                                                .. attribute:: l2vpn_mspw_address
                                                
                                                	L2VPN MSPW Addr
                                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress>`
                                                
                                                .. attribute:: ipv4_sr_policy_address
                                                
                                                	IPV4 Policy Addr
                                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress>`
                                                
                                                .. attribute:: ipv6_sr_policy_address
                                                
                                                	IPV6 Policy Addr
                                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress>`
                                                
                                                .. attribute:: afi
                                                
                                                	AFI
                                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_mcast_address
                                                
                                                	IPv4 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_label_address
                                                
                                                	IPv4 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4_tunnel_address
                                                
                                                	IPv4 Tunnel
                                                	**type**\: str
                                                
                                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4_mdt_address
                                                
                                                	IPv4 MDT Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                
                                                .. attribute:: ipv4vpn_address
                                                
                                                	IPv4 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv4vpna_mcastddress
                                                
                                                	IPv4 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPV6 Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_mcast_address
                                                
                                                	IPV6 Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_label_address
                                                
                                                	IPv6 Label Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_address
                                                
                                                	IPv6 VPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6vpn_mcast_address
                                                
                                                	IPv6 VPN Mcast Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: rt_constraint_address
                                                
                                                	RT Constrt Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{24}
                                                
                                                .. attribute:: ipv6mvpn_address
                                                
                                                	MVPN addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{104}
                                                
                                                .. attribute:: ipv4mvpn_address
                                                
                                                	MVPN4 addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{56}
                                                
                                                .. attribute:: l2vpn_evpn_address
                                                
                                                	L2VPN EVPN Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{58}
                                                
                                                .. attribute:: ls_ls_address
                                                
                                                	LINKSTATE LINKSTATE Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]+
                                                
                                                .. attribute:: ipv4_flowspec_address
                                                
                                                	IPV4 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6_flowspec_address
                                                
                                                	IPV6 Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv4vpn_flowspec_address
                                                
                                                	IPV4 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                .. attribute:: ipv6vpn_flowspec_address
                                                
                                                	IPV6 VPN Flowspec Addr
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, self).__init__()

                                                    self.yang_name = "neighbor-address"
                                                    self.yang_parent_name = "add-path-orr-bitfield"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                    ])
                                                    self.afi = None
                                                    self.ipv4_address = None
                                                    self.ipv4_mcast_address = None
                                                    self.ipv4_label_address = None
                                                    self.ipv4_tunnel_address = None
                                                    self.ipv4_mdt_address = None
                                                    self.ipv4vpn_address = None
                                                    self.ipv4vpna_mcastddress = None
                                                    self.ipv6_address = None
                                                    self.ipv6_mcast_address = None
                                                    self.ipv6_label_address = None
                                                    self.ipv6vpn_address = None
                                                    self.ipv6vpn_mcast_address = None
                                                    self.rt_constraint_address = None
                                                    self.ipv6mvpn_address = None
                                                    self.ipv4mvpn_address = None
                                                    self.l2vpn_evpn_address = None
                                                    self.ls_ls_address = None
                                                    self.ipv4_flowspec_address = None
                                                    self.ipv6_flowspec_address = None
                                                    self.ipv4vpn_flowspec_address = None
                                                    self.ipv6vpn_flowspec_address = None

                                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress()
                                                    self.l2vpn_vpls_address.parent = self
                                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress()
                                                    self.l2vpn_mspw_address.parent = self
                                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress()
                                                    self.ipv4_sr_policy_address.parent = self
                                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress()
                                                    self.ipv6_sr_policy_address.parent = self
                                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                    self._segment_path = lambda: "neighbor-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                class L2vpnVplsAddress(Entity):
                                                    """
                                                    L2VPN VPLS Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                        self.yang_name = "l2vpn-vpls-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                class L2vpnMspwAddress(Entity):
                                                    """
                                                    L2VPN MSPW Addr
                                                    
                                                    .. attribute:: l2vpn_address
                                                    
                                                    	l2vpn address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                        self.yang_name = "l2vpn-mspw-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                        ])
                                                        self.l2vpn_address = None
                                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                class Ipv4SrPolicyAddress(Entity):
                                                    """
                                                    IPV4 Policy Addr
                                                    
                                                    .. attribute:: ipv4_srpolicy_address
                                                    
                                                    	ipv4 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv4-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv4_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                class Ipv6SrPolicyAddress(Entity):
                                                    """
                                                    IPV6 Policy Addr
                                                    
                                                    .. attribute:: ipv6_srpolicy_address
                                                    
                                                    	ipv6 srpolicy address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                        self.yang_name = "ipv6-sr-policy-address"
                                                        self.yang_parent_name = "neighbor-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                        ])
                                                        self.ipv6_srpolicy_address = None
                                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.PathInformation.AddPathOrrBitfield.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class AttributesAfterPolicyIn(Entity):
                                        """
                                        Attributes after inbound policy applied. In the
                                        case of path type received\-only this will be
                                        attributes before inbound policy
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, self).__init__()

                                            self.yang_name = "attributes-after-policy-in"
                                            self.yang_parent_name = "dampening"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attributes-after-policy-in"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attributes-after-policy-in"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Dampenings.Dampening.AttributesAfterPolicyIn.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class PrefixFilters(Entity):
                                """
                                The BGP Prefix Filter table
                                
                                .. attribute:: prefix_filter
                                
                                	A BGP prefix filter table entry
                                	**type**\: list of  		 :py:class:`PrefixFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters, self).__init__()

                                    self.yang_name = "prefix-filters"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("prefix-filter", ("prefix_filter", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter))])
                                    self._leafs = OrderedDict()

                                    self.prefix_filter = YList(self)
                                    self._segment_path = lambda: "prefix-filters"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters, [], name, value)


                                class PrefixFilter(Entity):
                                    """
                                    A BGP prefix filter table entry
                                    
                                    .. attribute:: neighbor_address  (key)
                                    
                                    	Neighbor address
                                    	**type**\: union of the below types:
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    		**type**\: str
                                    
                                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`NeighborAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr>`
                                    
                                    .. attribute:: prefix_list_info
                                    
                                    	Prefix list
                                    	**type**\:  :py:class:`PrefixListInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo>`
                                    
                                    .. attribute:: af_name
                                    
                                    	Address family identfier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter, self).__init__()

                                        self.yang_name = "prefix-filter"
                                        self.yang_parent_name = "prefix-filters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['neighbor_address']
                                        self._child_classes = OrderedDict([("neighbor-address-xr", ("neighbor_address_xr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr)), ("prefix-list-info", ("prefix_list_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo))])
                                        self._leafs = OrderedDict([
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ])
                                        self.neighbor_address = None
                                        self.af_name = None

                                        self.neighbor_address_xr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr()
                                        self.neighbor_address_xr.parent = self
                                        self._children_name_map["neighbor_address_xr"] = "neighbor-address-xr"

                                        self.prefix_list_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo()
                                        self.prefix_list_info.parent = self
                                        self._children_name_map["prefix_list_info"] = "prefix-list-info"
                                        self._segment_path = lambda: "prefix-filter" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter, ['neighbor_address', u'af_name'], name, value)


                                    class NeighborAddressXr(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, self).__init__()

                                            self.yang_name = "neighbor-address-xr"
                                            self.yang_parent_name = "prefix-filter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address-xr"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address-xr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.NeighborAddressXr.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class PrefixListInfo(Entity):
                                        """
                                        Prefix list
                                        
                                        .. attribute:: bgp_pfxlst
                                        
                                        	bgp pfxlst
                                        	**type**\: list of  		 :py:class:`BgpPfxlst <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, self).__init__()

                                            self.yang_name = "prefix-list-info"
                                            self.yang_parent_name = "prefix-filter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("bgp-pfxlst", ("bgp_pfxlst", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst))])
                                            self._leafs = OrderedDict()

                                            self.bgp_pfxlst = YList(self)
                                            self._segment_path = lambda: "prefix-list-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo, [], name, value)


                                        class BgpPfxlst(Entity):
                                            """
                                            bgp pfxlst
                                            
                                            .. attribute:: bgp_prefix
                                            
                                            	BGP prefix
                                            	**type**\:  :py:class:`BgpPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix>`
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_prefix_grant
                                            
                                            	TRUE = permit, FALSE = deny
                                            	**type**\: bool
                                            
                                            .. attribute:: min_prefix_length
                                            
                                            	Minimum prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: max_prefix_length
                                            
                                            	Maximum prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, self).__init__()

                                                self.yang_name = "bgp-pfxlst"
                                                self.yang_parent_name = "prefix-list-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("bgp-prefix", ("bgp_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix))])
                                                self._leafs = OrderedDict([
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('is_prefix_grant', (YLeaf(YType.boolean, 'is-prefix-grant'), ['bool'])),
                                                    ('min_prefix_length', (YLeaf(YType.uint8, 'min-prefix-length'), ['int'])),
                                                    ('max_prefix_length', (YLeaf(YType.uint8, 'max-prefix-length'), ['int'])),
                                                ])
                                                self.sequence_number = None
                                                self.is_prefix_grant = None
                                                self.min_prefix_length = None
                                                self.max_prefix_length = None

                                                self.bgp_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix()
                                                self.bgp_prefix.parent = self
                                                self._children_name_map["bgp_prefix"] = "bgp-prefix"
                                                self._segment_path = lambda: "bgp-pfxlst"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst, [u'sequence_number', u'is_prefix_grant', u'min_prefix_length', u'max_prefix_length'], name, value)


                                            class BgpPrefix(Entity):
                                                """
                                                BGP prefix
                                                
                                                .. attribute:: prefix
                                                
                                                	Prefix
                                                	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix>`
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, self).__init__()

                                                    self.yang_name = "bgp-prefix"
                                                    self.yang_parent_name = "bgp-pfxlst"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix_length = None

                                                    self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix()
                                                    self.prefix.parent = self
                                                    self._children_name_map["prefix"] = "prefix"
                                                    self._segment_path = lambda: "bgp-prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix, [u'prefix_length'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Prefix
                                                    
                                                    .. attribute:: l2vpn_vpls_address
                                                    
                                                    	L2VPN VPLS Addr
                                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress>`
                                                    
                                                    .. attribute:: l2vpn_mspw_address
                                                    
                                                    	L2VPN MSPW Addr
                                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress>`
                                                    
                                                    .. attribute:: ipv4_sr_policy_address
                                                    
                                                    	IPV4 Policy Addr
                                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress>`
                                                    
                                                    .. attribute:: ipv6_sr_policy_address
                                                    
                                                    	IPV6 Policy Addr
                                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress>`
                                                    
                                                    .. attribute:: afi
                                                    
                                                    	AFI
                                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_mcast_address
                                                    
                                                    	IPv4 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_label_address
                                                    
                                                    	IPv4 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4_tunnel_address
                                                    
                                                    	IPv4 Tunnel
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4_mdt_address
                                                    
                                                    	IPv4 MDT Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                                    
                                                    .. attribute:: ipv4vpn_address
                                                    
                                                    	IPv4 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv4vpna_mcastddress
                                                    
                                                    	IPv4 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_address
                                                    
                                                    	IPV6 Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_mcast_address
                                                    
                                                    	IPV6 Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6_label_address
                                                    
                                                    	IPv6 Label Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_address
                                                    
                                                    	IPv6 VPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6vpn_mcast_address
                                                    
                                                    	IPv6 VPN Mcast Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: rt_constraint_address
                                                    
                                                    	RT Constrt Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                                    
                                                    .. attribute:: ipv6mvpn_address
                                                    
                                                    	MVPN addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                                    
                                                    .. attribute:: ipv4mvpn_address
                                                    
                                                    	MVPN4 addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                                    
                                                    .. attribute:: l2vpn_evpn_address
                                                    
                                                    	L2VPN EVPN Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                                    
                                                    .. attribute:: ls_ls_address
                                                    
                                                    	LINKSTATE LINKSTATE Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]+
                                                    
                                                    .. attribute:: ipv4_flowspec_address
                                                    
                                                    	IPV4 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6_flowspec_address
                                                    
                                                    	IPV6 Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv4vpn_flowspec_address
                                                    
                                                    	IPV4 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    .. attribute:: ipv6vpn_flowspec_address
                                                    
                                                    	IPV6 VPN Flowspec Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "bgp-prefix"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress))])
                                                        self._leafs = OrderedDict([
                                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                        ])
                                                        self.afi = None
                                                        self.ipv4_address = None
                                                        self.ipv4_mcast_address = None
                                                        self.ipv4_label_address = None
                                                        self.ipv4_tunnel_address = None
                                                        self.ipv4_mdt_address = None
                                                        self.ipv4vpn_address = None
                                                        self.ipv4vpna_mcastddress = None
                                                        self.ipv6_address = None
                                                        self.ipv6_mcast_address = None
                                                        self.ipv6_label_address = None
                                                        self.ipv6vpn_address = None
                                                        self.ipv6vpn_mcast_address = None
                                                        self.rt_constraint_address = None
                                                        self.ipv6mvpn_address = None
                                                        self.ipv4mvpn_address = None
                                                        self.l2vpn_evpn_address = None
                                                        self.ls_ls_address = None
                                                        self.ipv4_flowspec_address = None
                                                        self.ipv6_flowspec_address = None
                                                        self.ipv4vpn_flowspec_address = None
                                                        self.ipv6vpn_flowspec_address = None

                                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress()
                                                        self.l2vpn_vpls_address.parent = self
                                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress()
                                                        self.l2vpn_mspw_address.parent = self
                                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress()
                                                        self.ipv4_sr_policy_address.parent = self
                                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress()
                                                        self.ipv6_sr_policy_address.parent = self
                                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                                    class L2vpnVplsAddress(Entity):
                                                        """
                                                        L2VPN VPLS Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                            self.yang_name = "l2vpn-vpls-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                                    class L2vpnMspwAddress(Entity):
                                                        """
                                                        L2VPN MSPW Addr
                                                        
                                                        .. attribute:: l2vpn_address
                                                        
                                                        	l2vpn address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                            self.yang_name = "l2vpn-mspw-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                            ])
                                                            self.l2vpn_address = None
                                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                                    class Ipv4SrPolicyAddress(Entity):
                                                        """
                                                        IPV4 Policy Addr
                                                        
                                                        .. attribute:: ipv4_srpolicy_address
                                                        
                                                        	ipv4 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv4-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv4_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                                    class Ipv6SrPolicyAddress(Entity):
                                                        """
                                                        IPV6 Policy Addr
                                                        
                                                        .. attribute:: ipv6_srpolicy_address
                                                        
                                                        	ipv6 srpolicy address
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                            self.yang_name = "ipv6-sr-policy-address"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                            ])
                                                            self.ipv6_srpolicy_address = None
                                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.PrefixFilters.PrefixFilter.PrefixListInfo.BgpPfxlst.BgpPrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class Attributes(Entity):
                                """
                                The BGP Attribute table
                                
                                .. attribute:: attribute
                                
                                	A BGP Attribute table entry
                                	**type**\: list of  		 :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes, self).__init__()

                                    self.yang_name = "attributes"
                                    self.yang_parent_name = "af"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("attribute", ("attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute))])
                                    self._leafs = OrderedDict()

                                    self.attribute = YList(self)
                                    self._segment_path = lambda: "attributes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes, [], name, value)


                                class Attribute(Entity):
                                    """
                                    A BGP Attribute table entry
                                    
                                    .. attribute:: attribute_iid
                                    
                                    	Attribute IID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_cache_bucket
                                    
                                    	Attribute cache bucket
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_cache_id
                                    
                                    	Attribute cache ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_info
                                    
                                    	Attributes
                                    	**type**\:  :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo>`
                                    
                                    .. attribute:: process_instance_id
                                    
                                    	Process instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: attribute_instance_id
                                    
                                    	Attribute Instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: attribute_structure_id
                                    
                                    	ID of attribute structure
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: attribute_structure_hash_value
                                    
                                    	Hash value for attribute structure
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_count
                                    
                                    	Number of paths which use this attribute structure
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute, self).__init__()

                                        self.yang_name = "attribute"
                                        self.yang_parent_name = "attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("attribute-info", ("attribute_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo))])
                                        self._leafs = OrderedDict([
                                            ('attribute_iid', (YLeaf(YType.uint32, 'attribute-iid'), ['int'])),
                                            ('attribute_cache_bucket', (YLeaf(YType.uint32, 'attribute-cache-bucket'), ['int'])),
                                            ('attribute_cache_id', (YLeaf(YType.uint32, 'attribute-cache-id'), ['int'])),
                                            ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                            ('attribute_instance_id', (YLeaf(YType.uint8, 'attribute-instance-id'), ['int'])),
                                            ('attribute_structure_id', (YLeaf(YType.uint32, 'attribute-structure-id'), ['int'])),
                                            ('attribute_structure_hash_value', (YLeaf(YType.uint32, 'attribute-structure-hash-value'), ['int'])),
                                            ('reference_count', (YLeaf(YType.uint32, 'reference-count'), ['int'])),
                                        ])
                                        self.attribute_iid = None
                                        self.attribute_cache_bucket = None
                                        self.attribute_cache_id = None
                                        self.process_instance_id = None
                                        self.attribute_instance_id = None
                                        self.attribute_structure_id = None
                                        self.attribute_structure_hash_value = None
                                        self.reference_count = None

                                        self.attribute_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo()
                                        self.attribute_info.parent = self
                                        self._children_name_map["attribute_info"] = "attribute-info"
                                        self._segment_path = lambda: "attribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute, ['attribute_iid', 'attribute_cache_bucket', 'attribute_cache_id', u'process_instance_id', u'attribute_instance_id', u'attribute_structure_id', u'attribute_structure_hash_value', u'reference_count'], name, value)


                                    class AttributeInfo(Entity):
                                        """
                                        Attributes
                                        
                                        .. attribute:: common_attributes
                                        
                                        	Common attributes
                                        	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                                        
                                        .. attribute:: attr_set
                                        
                                        	ATTR\_SET attribute
                                        	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet>`
                                        
                                        .. attribute:: rnh_addr
                                        
                                        	RNH Address
                                        	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr>`
                                        
                                        .. attribute:: ribrnh_ip
                                        
                                        	RIB RNH IP Address
                                        	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                                        
                                        .. attribute:: is_as_path2_byte
                                        
                                        	AS path encoded as 2\-byte
                                        	**type**\: bool
                                        
                                        .. attribute:: is_application_gateway_present
                                        
                                        	Application gateway present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_attr_set_present
                                        
                                        	BGP ATTR\_SET attribute present
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_igp
                                        
                                        	AIGP set by policy inbound IGP 
                                        	**type**\: bool
                                        
                                        .. attribute:: set_aigp_inbound_metric
                                        
                                        	AIGP set by policy inbound metric
                                        	**type**\: bool
                                        
                                        .. attribute:: is_rnh_present
                                        
                                        	RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ribrnh_present
                                        
                                        	RIB RNH Attribute  present
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_key_number
                                        
                                        	Attribute key number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_config
                                        
                                        	Attribute reuse ID Configured
                                        	**type**\: bool
                                        
                                        .. attribute:: attribute_reuse_id_max_id
                                        
                                        	Attribute reuse ID maximum ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_node
                                        
                                        	Attribute reuse ID nodes
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_current
                                        
                                        	Attribute reuse ID current ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_keys
                                        
                                        	Attribute reuse ID allocated keys
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: attribute_reuse_id_recover_sec
                                        
                                        	Attribute reuse ID timer in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: vpn_distinguisher
                                        
                                        	VPN Distinguisher
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rnh_type
                                        
                                        	RNH Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rnh_len
                                        
                                        	RNH Length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rnh_addr_len
                                        
                                        	RNH Address Length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_table
                                        
                                        	RIB RNH Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_mac
                                        
                                        	RIB RNH MAC Address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: ribrnhip_table
                                        
                                        	RIB RNH IP Table
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_vni
                                        
                                        	RIB RNH Vni
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ribrnh_encap
                                        
                                        	RIB RNH Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo, self).__init__()

                                            self.yang_name = "attribute-info"
                                            self.yang_parent_name = "attribute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp))])
                                            self._leafs = OrderedDict([
                                                ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                                ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                                ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                                ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                                ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                                ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                                ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                                ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                                ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                                ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                                ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                                ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                                ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                                ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                                ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                                ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                                ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                                ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                                ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                                ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                                ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                                ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                                ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                            ])
                                            self.is_as_path2_byte = None
                                            self.is_application_gateway_present = None
                                            self.is_attr_set_present = None
                                            self.set_aigp_inbound_igp = None
                                            self.set_aigp_inbound_metric = None
                                            self.is_rnh_present = None
                                            self.is_ribrnh_present = None
                                            self.attribute_key_number = None
                                            self.attribute_reuse_id_config = None
                                            self.attribute_reuse_id_max_id = None
                                            self.attribute_reuse_id_node = None
                                            self.attribute_reuse_id_current = None
                                            self.attribute_reuse_id_keys = None
                                            self.attribute_reuse_id_recover_sec = None
                                            self.vpn_distinguisher = None
                                            self.rnh_type = None
                                            self.rnh_len = None
                                            self.rnh_addr_len = None
                                            self.ribrnh_table = None
                                            self.ribrnh_mac = None
                                            self.ribrnhip_table = None
                                            self.ribrnh_vni = None
                                            self.ribrnh_encap = None

                                            self.common_attributes = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                            self.common_attributes.parent = self
                                            self._children_name_map["common_attributes"] = "common-attributes"

                                            self.attr_set = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet()
                                            self.attr_set.parent = self
                                            self._children_name_map["attr_set"] = "attr-set"

                                            self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr()
                                            self.rnh_addr.parent = self
                                            self._children_name_map["rnh_addr"] = "rnh-addr"

                                            self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                            self.ribrnh_ip.parent = self
                                            self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                            self._segment_path = lambda: "attribute-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                                        class CommonAttributes(Entity):
                                            """
                                            Common attributes
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                                self.yang_name = "common-attributes"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "common-attributes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "common-attributes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class AttrSet(Entity):
                                            """
                                            ATTR\_SET attribute
                                            
                                            .. attribute:: prefix_sid_attr
                                            
                                            	Prefix SID attribute
                                            	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr>`
                                            
                                            .. attribute:: tunnel_encap
                                            
                                            	Tunnel Encapsulation attribute
                                            	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                            
                                            .. attribute:: is_metric_present
                                            
                                            	Metric attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_local_pref_present
                                            
                                            	Local Preference attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_atomic_aggregate_present
                                            
                                            	Atomic aggregate attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aggregator_present
                                            
                                            	Aggregator attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_origin_present
                                            
                                            	Origin attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_as_path_present
                                            
                                            	AS path attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_community_present
                                            
                                            	Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_extended_community_present
                                            
                                            	Extended community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ssa_present
                                            
                                            	SSA attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_connector_present
                                            
                                            	Connector present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pmsi_present
                                            
                                            	PMSI Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pppmp_present
                                            
                                            	PPMP Attribute  present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_aigp_present
                                            
                                            	AIGP Present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pe_distinguisher_label_present
                                            
                                            	PE distinguisher label  attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ls_attribute_present
                                            
                                            	BGP LS attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: is_label_index_present
                                            
                                            	Label Index attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: neighbor_as
                                            
                                            	Neighbor AS number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_as
                                            
                                            	AS where aggregation was last performed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: aggregator_address
                                            
                                            	Address where aggregation was performed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: metric
                                            
                                            	Metric
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_preference
                                            
                                            	Local preference
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: origin
                                            
                                            	Origin
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_path
                                            
                                            	AS path attribute
                                            	**type**\: str
                                            
                                            .. attribute:: extended_community_flags
                                            
                                            	Extended community Flags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: originator
                                            
                                            	Originator attribute
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tpv3_session_id
                                            
                                            	L2TPv3 session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: connector_type
                                            
                                            	Connector Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: aigp_metric_value
                                            
                                            	AIGP metric value
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: pmsi_type
                                            
                                            	PMSI Type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pmsi_flags
                                            
                                            	PMSI Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pmsi_label
                                            
                                            	PMSI label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ppm_pvalue
                                            
                                            	PPMP Value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_large_community_present
                                            
                                            	Large Community attribute present
                                            	**type**\: bool
                                            
                                            .. attribute:: community
                                            
                                            	Community attribute
                                            	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                            
                                            .. attribute:: extended_community
                                            
                                            	Extended community attribute
                                            	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                            
                                            .. attribute:: unknown_attribute
                                            
                                            	Unknown attributes
                                            	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                            
                                            .. attribute:: cluster
                                            
                                            	Cluster list attribute
                                            	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                            
                                            .. attribute:: l2tpv3_cookie
                                            
                                            	L2TPv3 Cookie
                                            	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie>`
                                            
                                            .. attribute:: connector_value
                                            
                                            	Connector Value
                                            	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                            
                                            .. attribute:: pmsi_value
                                            
                                            	PMSI Value
                                            	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                            
                                            .. attribute:: ls_attr
                                            
                                            	BGP LS attribute
                                            	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                            
                                            .. attribute:: pe_distinguisher_label
                                            
                                            	PE distinguisher label attribute
                                            	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                            
                                            .. attribute:: large_community
                                            
                                            	Large Community attribute
                                            	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                                self.yang_name = "attr-set"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity))])
                                                self._leafs = OrderedDict([
                                                    ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                                    ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                                    ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                                    ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                                    ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                                    ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                                    ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                                    ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                                    ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                                    ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                                    ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                                    ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                                    ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                                    ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                                    ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                                    ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                                    ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                                    ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                                    ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                                    ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                                    ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                                    ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                                    ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                                    ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                                    ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                                    ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                                    ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                                    ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                                    ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                                    ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                                    ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                                ])
                                                self.is_metric_present = None
                                                self.is_local_pref_present = None
                                                self.is_atomic_aggregate_present = None
                                                self.is_aggregator_present = None
                                                self.is_origin_present = None
                                                self.is_as_path_present = None
                                                self.is_community_present = None
                                                self.is_extended_community_present = None
                                                self.is_ssa_present = None
                                                self.is_connector_present = None
                                                self.is_pmsi_present = None
                                                self.is_pppmp_present = None
                                                self.is_aigp_present = None
                                                self.is_pe_distinguisher_label_present = None
                                                self.is_ls_attribute_present = None
                                                self.is_label_index_present = None
                                                self.neighbor_as = None
                                                self.aggregator_as = None
                                                self.aggregator_address = None
                                                self.metric = None
                                                self.local_preference = None
                                                self.origin = None
                                                self.as_path = None
                                                self.extended_community_flags = None
                                                self.originator = None
                                                self.l2tpv3_session_id = None
                                                self.connector_type = None
                                                self.aigp_metric_value = None
                                                self.pmsi_type = None
                                                self.pmsi_flags = None
                                                self.pmsi_label = None
                                                self.ppm_pvalue = None
                                                self.is_large_community_present = None

                                                self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr()
                                                self.prefix_sid_attr.parent = self
                                                self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                                self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                                self.tunnel_encap.parent = self
                                                self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                                self.community = YList(self)
                                                self.extended_community = YList(self)
                                                self.unknown_attribute = YList(self)
                                                self.cluster = YList(self)
                                                self.l2tpv3_cookie = YList(self)
                                                self.connector_value = YList(self)
                                                self.pmsi_value = YList(self)
                                                self.ls_attr = YList(self)
                                                self.pe_distinguisher_label = YList(self)
                                                self.large_community = YList(self)
                                                self._segment_path = lambda: "attr-set"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                            class PrefixSidAttr(Entity):
                                                """
                                                Prefix SID attribute
                                                
                                                .. attribute:: prefix_sid_tlv
                                                
                                                	Prefix SID TLV array
                                                	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, self).__init__()

                                                    self.yang_name = "prefix-sid-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sid_tlv = YList(self)
                                                    self._segment_path = lambda: "prefix-sid-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, [], name, value)


                                                class PrefixSidTlv(Entity):
                                                    """
                                                    Prefix SID TLV array
                                                    
                                                    .. attribute:: type
                                                    
                                                    	Prefix SID TLV type field
                                                    	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                                    
                                                    .. attribute:: len
                                                    
                                                    	Prefix SID TLV Length in bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: val
                                                    
                                                    	Prefix SID TLV value string
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..46
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                                        self.yang_name = "prefix-sid-tlv"
                                                        self.yang_parent_name = "prefix-sid-attr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                            ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                            ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.len = None
                                                        self.val = None
                                                        self._segment_path = lambda: "prefix-sid-tlv"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                            class TunnelEncap(Entity):
                                                """
                                                Tunnel Encapsulation attribute
                                                
                                                .. attribute:: sr_policy
                                                
                                                	Tunnel encap type SR policy
                                                	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                                    self.yang_name = "tunnel-encap"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy))])
                                                    self._leafs = OrderedDict()

                                                    self.sr_policy = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                                    self.sr_policy.parent = self
                                                    self._children_name_map["sr_policy"] = "sr-policy"
                                                    self._segment_path = lambda: "tunnel-encap"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, [], name, value)


                                                class SrPolicy(Entity):
                                                    """
                                                    Tunnel encap type SR policy
                                                    
                                                    .. attribute:: binding_sid
                                                    
                                                    	SR Policy incoming Binding sid
                                                    	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                                    
                                                    .. attribute:: allocated_binding_sid
                                                    
                                                    	SR Policy allocated Binding sid by the router
                                                    	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                                    
                                                    .. attribute:: tunnel_encap_type
                                                    
                                                    	Tunnel Encapsulation Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: preference
                                                    
                                                    	SR Policy Preference
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: state
                                                    
                                                    	SR Policy active state in forwarding
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: request_state
                                                    
                                                    	SR Policy programming Status
                                                    	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                                    
                                                    .. attribute:: usable
                                                    
                                                    	SR Policy is usable on this node
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: segment_list
                                                    
                                                    	SR Policy Segment Lists
                                                    	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-bgp-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                                        self.yang_name = "sr-policy"
                                                        self.yang_parent_name = "tunnel-encap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                                        self._leafs = OrderedDict([
                                                            ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                            ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                            ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                            ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                            ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                                        ])
                                                        self.tunnel_encap_type = None
                                                        self.preference = None
                                                        self.state = None
                                                        self.request_state = None
                                                        self.usable = None

                                                        self.binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                                        self.binding_sid.parent = self
                                                        self._children_name_map["binding_sid"] = "binding-sid"

                                                        self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                                        self.allocated_binding_sid.parent = self
                                                        self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                                        self.segment_list = YList(self)
                                                        self._segment_path = lambda: "sr-policy"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                                    class BindingSid(Entity):
                                                        """
                                                        SR Policy incoming Binding sid
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                            self.yang_name = "binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class AllocatedBindingSid(Entity):
                                                        """
                                                        SR Policy allocated Binding sid by the router
                                                        
                                                        .. attribute:: type
                                                        
                                                        	Type
                                                        	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                                        
                                                        .. attribute:: label
                                                        
                                                        	MPLS Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ipv6_address
                                                        
                                                        	IPv6 Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                            self.yang_name = "allocated-binding-sid"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                                ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                            ])
                                                            self.type = None
                                                            self.label = None
                                                            self.ipv6_address = None
                                                            self._segment_path = lambda: "allocated-binding-sid"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                                    class SegmentList(Entity):
                                                        """
                                                        SR Policy Segment Lists
                                                        
                                                        .. attribute:: weight
                                                        
                                                        	Weight of segment list
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: segment
                                                        
                                                        	Segments in segment list
                                                        	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-bgp-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                            self.yang_name = "segment-list"
                                                            self.yang_parent_name = "sr-policy"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                            self._leafs = OrderedDict([
                                                                ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                            ])
                                                            self.weight = None

                                                            self.segment = YList(self)
                                                            self._segment_path = lambda: "segment-list"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                                        class Segment(Entity):
                                                            """
                                                            Segments in segment list
                                                            
                                                            .. attribute:: type
                                                            
                                                            	Type
                                                            	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                            
                                                            .. attribute:: label
                                                            
                                                            	MPLS Label value
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: ipv4_address
                                                            
                                                            	IPv4 Address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: ipv6_address
                                                            
                                                            	IPv6 address value
                                                            	**type**\: str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-bgp-oper'
                                                            _revision = '2017-09-07'

                                                            def __init__(self):
                                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                                self.yang_name = "segment"
                                                                self.yang_parent_name = "segment-list"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                                ])
                                                                self.type = None
                                                                self.label = None
                                                                self.ipv4_address = None
                                                                self.ipv6_address = None
                                                                self._segment_path = lambda: "segment"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                            class Community(Entity):
                                                """
                                                Community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                                    self.yang_name = "community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Community, [u'entry'], name, value)


                                            class ExtendedCommunity(Entity):
                                                """
                                                Extended community attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                                    self.yang_name = "extended-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "extended-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                            class UnknownAttribute(Entity):
                                                """
                                                Unknown attributes
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                                    self.yang_name = "unknown-attribute"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "unknown-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                            class Cluster(Entity):
                                                """
                                                Cluster list attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                                    self.yang_name = "cluster"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "cluster"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, [u'entry'], name, value)


                                            class L2tpv3Cookie(Entity):
                                                """
                                                L2TPv3 Cookie
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, self).__init__()

                                                    self.yang_name = "l2tpv3-cookie"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "l2tpv3-cookie"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                            class ConnectorValue(Entity):
                                                """
                                                Connector Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                                    self.yang_name = "connector-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "connector-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, [u'entry'], name, value)


                                            class PmsiValue(Entity):
                                                """
                                                PMSI Value
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                                    self.yang_name = "pmsi-value"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "pmsi-value"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, [u'entry'], name, value)


                                            class LsAttr(Entity):
                                                """
                                                BGP LS attribute
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                                    self.yang_name = "ls-attr"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "ls-attr"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, [u'entry'], name, value)


                                            class PeDistinguisherLabel(Entity):
                                                """
                                                PE distinguisher label attribute
                                                
                                                .. attribute:: pe_address
                                                
                                                	 PE address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: label
                                                
                                                	Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                                    self.yang_name = "pe-distinguisher-label"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ])
                                                    self.pe_address = None
                                                    self.label = None
                                                    self._segment_path = lambda: "pe-distinguisher-label"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                            class LargeCommunity(Entity):
                                                """
                                                Large Community attribute
                                                
                                                .. attribute:: global_admin
                                                
                                                	Global Administrator
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data1
                                                
                                                	Local Data 1
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: local_data2
                                                
                                                	Local Data 2
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                                    self.yang_name = "large-community"
                                                    self.yang_parent_name = "attr-set"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                                        ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                                        ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                                    ])
                                                    self.global_admin = None
                                                    self.local_data1 = None
                                                    self.local_data2 = None
                                                    self._segment_path = lambda: "large-community"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                                        class RnhAddr(Entity):
                                            """
                                            RNH Address
                                            
                                            .. attribute:: len
                                            
                                            	len
                                            	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: mac_address
                                            
                                            	MAC Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                                self.yang_name = "rnh-addr"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                                ])
                                                self.len = None
                                                self.ipv4_address = None
                                                self.ipv6_address = None
                                                self.mac_address = None
                                                self._segment_path = lambda: "rnh-addr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                                        class RibrnhIp(Entity):
                                            """
                                            RIB RNH IP Address
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                                self.yang_name = "ribrnh-ip"
                                                self.yang_parent_name = "attribute-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "ribrnh-ip"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "ribrnh-ip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Afs.Af.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                    class Information(Entity):
                        """
                        Meta data for VRF
                        
                        .. attribute:: route_distinguisher
                        
                        	Route Distinguisher
                        	**type**\: str
                        
                        	**pattern:** [a\-fA\-F0\-9]{16}
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information, self).__init__()

                            self.yang_name = "information"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                            ])
                            self.route_distinguisher = None
                            self._segment_path = lambda: "information"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Information, [u'route_distinguisher'], name, value)


                    class UpdateInboundFilterVrf(Entity):
                        """
                        Update inbound filtering information for the VRF
                        
                        .. attribute:: last_update_filtered_timestamp
                        
                        	Last Filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                        	**type**\:  :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp>`
                        
                        .. attribute:: update_vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: update_filtered_message_count
                        
                        	Filtered messages count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update_filtered_neighbor_count
                        
                        	Count of neighbors that received filtered messages
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_update_filtered_age
                        
                        	Time since last filtered messages received event (in seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf, self).__init__()

                            self.yang_name = "update-inbound-filter-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("last-update-filtered-timestamp", ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp))])
                            self._leafs = OrderedDict([
                                ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                ('update_filtered_message_count', (YLeaf(YType.uint32, 'update-filtered-message-count'), ['int'])),
                                ('update_filtered_neighbor_count', (YLeaf(YType.uint32, 'update-filtered-neighbor-count'), ['int'])),
                                ('last_update_filtered_age', (YLeaf(YType.uint32, 'last-update-filtered-age'), ['int'])),
                            ])
                            self.update_vrf_name = None
                            self.update_filtered_message_count = None
                            self.update_filtered_neighbor_count = None
                            self.last_update_filtered_age = None

                            self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp()
                            self.last_update_filtered_timestamp.parent = self
                            self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                            self._segment_path = lambda: "update-inbound-filter-vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf, [u'update_vrf_name', u'update_filtered_message_count', u'update_filtered_neighbor_count', u'last_update_filtered_age'], name, value)


                        class LastUpdateFilteredTimestamp(Entity):
                            """
                            Last Filtered messages received time\: time
                            elapsed since 00\:00\:00 UTC, January 1, 1970
                            
                            .. attribute:: seconds
                            
                            	Seconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanoseconds
                            
                            	Nanoseconds part of time value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, self).__init__()

                                self.yang_name = "last-update-filtered-timestamp"
                                self.yang_parent_name = "update-inbound-filter-vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nanoseconds = None
                                self._segment_path = lambda: "last-update-filtered-timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterVrf.LastUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                    class Postits(Entity):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: postit
                        
                        	A BGP Postit table entry
                        	**type**\: list of  		 :py:class:`Postit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits, self).__init__()

                            self.yang_name = "postits"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("postit", ("postit", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit))])
                            self._leafs = OrderedDict()

                            self.postit = YList(self)
                            self._segment_path = lambda: "postits"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits, [], name, value)


                        class Postit(Entity):
                            """
                            A BGP Postit table entry
                            
                            .. attribute:: neighbor_address  (key)
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbors_address
                            
                            	Neighbor Addr
                            	**type**\:  :py:class:`NeighborsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress>`
                            
                            .. attribute:: vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: connect_state
                            
                            	State
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: start_time
                            
                            	StartTime
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: neighbor_af
                            
                            	Neighbor Afi
                            	**type**\: list of  		 :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborAf>`
                            
                            .. attribute:: postit_info
                            
                            	Postit Info
                            	**type**\: list of  		 :py:class:`PostitInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit, self).__init__()

                                self.yang_name = "postit"
                                self.yang_parent_name = "postits"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_classes = OrderedDict([("neighbors-address", ("neighbors_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress)), ("neighbor-af", ("neighbor_af", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborAf)), ("postit-info", ("postit_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('connect_state', (YLeaf(YType.uint32, 'connect-state'), ['int'])),
                                    ('start_time', (YLeaf(YType.uint32, 'start-time'), ['int'])),
                                    ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                ])
                                self.neighbor_address = None
                                self.vrf_name = None
                                self.connect_state = None
                                self.start_time = None
                                self.nsr_state = None

                                self.neighbors_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress()
                                self.neighbors_address.parent = self
                                self._children_name_map["neighbors_address"] = "neighbors-address"

                                self.neighbor_af = YList(self)
                                self.postit_info = YList(self)
                                self._segment_path = lambda: "postit" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit, ['neighbor_address', u'vrf_name', u'connect_state', u'start_time', u'nsr_state'], name, value)


                            class NeighborsAddress(Entity):
                                """
                                Neighbor Addr
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress, self).__init__()

                                    self.yang_name = "neighbors-address"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "neighbors-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "neighbors-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborsAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class NeighborAf(Entity):
                                """
                                Neighbor Afi
                                
                                .. attribute:: entry
                                
                                	Array entry
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborAf, self).__init__()

                                    self.yang_name = "neighbor-af"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "neighbor-af"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.NeighborAf, [u'entry'], name, value)


                            class PostitInfo(Entity):
                                """
                                Postit Info
                                
                                .. attribute:: postit_notification
                                
                                	Postit notification
                                	**type**\:  :py:class:`PostitNotification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification>`
                                
                                .. attribute:: postit_type
                                
                                	Postit Type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_subtype
                                
                                	Postit Subtype
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_flags
                                
                                	Postit Flags
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_af_name
                                
                                	Postit Afi
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: postit_ts
                                
                                	Postit TS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: postit_direction
                                
                                	Postit Direction
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: postit_id
                                
                                	Postit ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: peer_id
                                
                                	Peer ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: postit_policy
                                
                                	Policy
                                	**type**\: str
                                
                                .. attribute:: postit_reset
                                
                                	Reset
                                	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo, self).__init__()

                                    self.yang_name = "postit-info"
                                    self.yang_parent_name = "postit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("postit-notification", ("postit_notification", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification))])
                                    self._leafs = OrderedDict([
                                        ('postit_type', (YLeaf(YType.uint32, 'postit-type'), ['int'])),
                                        ('postit_subtype', (YLeaf(YType.uint32, 'postit-subtype'), ['int'])),
                                        ('postit_flags', (YLeaf(YType.uint8, 'postit-flags'), ['int'])),
                                        ('postit_af_name', (YLeaf(YType.enumeration, 'postit-af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('postit_ts', (YLeaf(YType.uint64, 'postit-ts'), ['int'])),
                                        ('postit_direction', (YLeaf(YType.uint8, 'postit-direction'), ['int'])),
                                        ('postit_id', (YLeaf(YType.uint32, 'postit-id'), ['int'])),
                                        ('peer_id', (YLeaf(YType.uint32, 'peer-id'), ['int'])),
                                        ('postit_policy', (YLeaf(YType.str, 'postit-policy'), ['str'])),
                                        ('postit_reset', (YLeaf(YType.enumeration, 'postit-reset'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                    ])
                                    self.postit_type = None
                                    self.postit_subtype = None
                                    self.postit_flags = None
                                    self.postit_af_name = None
                                    self.postit_ts = None
                                    self.postit_direction = None
                                    self.postit_id = None
                                    self.peer_id = None
                                    self.postit_policy = None
                                    self.postit_reset = None

                                    self.postit_notification = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification()
                                    self.postit_notification.parent = self
                                    self._children_name_map["postit_notification"] = "postit-notification"
                                    self._segment_path = lambda: "postit-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo, [u'postit_type', u'postit_subtype', u'postit_flags', u'postit_af_name', u'postit_ts', u'postit_direction', u'postit_id', u'peer_id', u'postit_policy', u'postit_reset'], name, value)


                                class PostitNotification(Entity):
                                    """
                                    Postit notification
                                    
                                    .. attribute:: time_since_last_notification
                                    
                                    	Time since the last notification was sent or received (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: notification_error_code
                                    
                                    	Error code in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: notification_error_subcode
                                    
                                    	Error subcode in last notification
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_notification_data
                                    
                                    	Message data in last notification
                                    	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification, self).__init__()

                                        self.yang_name = "postit-notification"
                                        self.yang_parent_name = "postit-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData))])
                                        self._leafs = OrderedDict([
                                            ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                            ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                            ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                        ])
                                        self.time_since_last_notification = None
                                        self.notification_error_code = None
                                        self.notification_error_subcode = None

                                        self.last_notification_data = YList(self)
                                        self._segment_path = lambda: "postit-notification"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                    class LastNotificationData(Entity):
                                        """
                                        Message data in last notification
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, self).__init__()

                                            self.yang_name = "last-notification-data"
                                            self.yang_parent_name = "postit-notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "last-notification-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Postits.Postit.PostitInfo.PostitNotification.LastNotificationData, [u'entry'], name, value)


                    class GlobalProcessInfo(Entity):
                        """
                        The Global Process information table
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf>`
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\: str
                        
                        .. attribute:: vrfid
                        
                        	VRF ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo, self).__init__()

                            self.yang_name = "global-process-info"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf))])
                            self._leafs = OrderedDict([
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('vrfid', (YLeaf(YType.uint32, 'vrfid'), ['int'])),
                            ])
                            self.vrf_name = None
                            self.vrfid = None

                            self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"

                            self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"
                            self._segment_path = lambda: "global-process-info"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo, [u'vrf_name', u'vrfid'], name, value)


                        class Global(Entity):
                            """
                            Global information
                            
                            .. attribute:: in_standalone_mode
                            
                            	Standalone or Distributed mode
                            	**type**\: bool
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_name
                            
                            	Name of BGP instance
                            	**type**\: str
                            
                            .. attribute:: restart_count
                            
                            	No of times BGP has started
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_delay
                            
                            	Update delay timeout time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: generic_scan_period
                            
                            	Period (in seconds) of generic scanner runs
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: confederation_id
                            
                            	Confederation ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: cluster_id
                            
                            	Cluster ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_cluster_id
                            
                            	Configured cluster ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_cluster_id_specified_as_ip
                            
                            	Cluster ID specified as an IP address
                            	**type**\: bool
                            
                            .. attribute:: asn_format
                            
                            	BGP AS Number Format
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start_configured
                            
                            	Configured segment\-routing Global Block start value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end_configured
                            
                            	Configured segment\-routing Global Block end value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start
                            
                            	In use segment\-routing Global Block start value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_end
                            
                            	In use Segment\-routing Global Block end value
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\: bool
                            
                            .. attribute:: graceful_maint_all_nbrs
                            
                            	Graceful Maintenance also for neighbors without GM configuration
                            	**type**\: bool
                            
                            .. attribute:: graceful_maint_retain_routes
                            
                            	Retaining routes in RIB when BGP process stops while in Graceful Maintenance
                            	**type**\: bool
                            
                            .. attribute:: process_rlimit
                            
                            	Platform RLIMIT max for the process
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_maximum_buffer_size
                            
                            	Maximum limit user can configure for max\-buffer\-size command under bmp\-server
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_default_buffer_size
                            
                            	Default value for BMP buffer limit when a value is not configured
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_current_buffer_size
                            
                            	Current value for BMP buffer 
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bmp_cur_maximum_buffer_size
                            
                            	Maximum limit user has configure using max\-buffer\-size command under bmp\-server
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: cluster_id_entry
                            
                            	All configured Cluster IDs
                            	**type**\: list of  		 :py:class:`ClusterIdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global.ClusterIdEntry>`
                            
                            .. attribute:: color_id
                            
                            	All configured Color IDs
                            	**type**\: list of  		 :py:class:`ColorId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global.ColorId>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "global-process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("cluster-id-entry", ("cluster_id_entry", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global.ClusterIdEntry)), ("color-id", ("color_id", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global.ColorId))])
                                self._leafs = OrderedDict([
                                    ('in_standalone_mode', (YLeaf(YType.boolean, 'in-standalone-mode'), ['bool'])),
                                    ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                    ('instance_name', (YLeaf(YType.str, 'instance-name'), ['str'])),
                                    ('restart_count', (YLeaf(YType.uint32, 'restart-count'), ['int'])),
                                    ('update_delay', (YLeaf(YType.uint32, 'update-delay'), ['int'])),
                                    ('generic_scan_period', (YLeaf(YType.uint16, 'generic-scan-period'), ['int'])),
                                    ('confederation_id', (YLeaf(YType.uint32, 'confederation-id'), ['int'])),
                                    ('cluster_id', (YLeaf(YType.uint32, 'cluster-id'), ['int'])),
                                    ('configured_cluster_id', (YLeaf(YType.uint32, 'configured-cluster-id'), ['int'])),
                                    ('is_cluster_id_specified_as_ip', (YLeaf(YType.boolean, 'is-cluster-id-specified-as-ip'), ['bool'])),
                                    ('asn_format', (YLeaf(YType.uint32, 'asn-format'), ['int'])),
                                    ('srgb_start_configured', (YLeaf(YType.uint32, 'srgb-start-configured'), ['int'])),
                                    ('srgb_end_configured', (YLeaf(YType.uint32, 'srgb-end-configured'), ['int'])),
                                    ('srgb_start', (YLeaf(YType.uint32, 'srgb-start'), ['int'])),
                                    ('srgb_end', (YLeaf(YType.uint32, 'srgb-end'), ['int'])),
                                    ('graceful_maintenance', (YLeaf(YType.boolean, 'graceful-maintenance'), ['bool'])),
                                    ('graceful_maint_all_nbrs', (YLeaf(YType.boolean, 'graceful-maint-all-nbrs'), ['bool'])),
                                    ('graceful_maint_retain_routes', (YLeaf(YType.boolean, 'graceful-maint-retain-routes'), ['bool'])),
                                    ('process_rlimit', (YLeaf(YType.uint64, 'process-rlimit'), ['int'])),
                                    ('bmp_maximum_buffer_size', (YLeaf(YType.uint64, 'bmp-maximum-buffer-size'), ['int'])),
                                    ('bmp_default_buffer_size', (YLeaf(YType.uint64, 'bmp-default-buffer-size'), ['int'])),
                                    ('bmp_current_buffer_size', (YLeaf(YType.uint64, 'bmp-current-buffer-size'), ['int'])),
                                    ('bmp_cur_maximum_buffer_size', (YLeaf(YType.uint64, 'bmp-cur-maximum-buffer-size'), ['int'])),
                                ])
                                self.in_standalone_mode = None
                                self.local_as = None
                                self.instance_name = None
                                self.restart_count = None
                                self.update_delay = None
                                self.generic_scan_period = None
                                self.confederation_id = None
                                self.cluster_id = None
                                self.configured_cluster_id = None
                                self.is_cluster_id_specified_as_ip = None
                                self.asn_format = None
                                self.srgb_start_configured = None
                                self.srgb_end_configured = None
                                self.srgb_start = None
                                self.srgb_end = None
                                self.graceful_maintenance = None
                                self.graceful_maint_all_nbrs = None
                                self.graceful_maint_retain_routes = None
                                self.process_rlimit = None
                                self.bmp_maximum_buffer_size = None
                                self.bmp_default_buffer_size = None
                                self.bmp_current_buffer_size = None
                                self.bmp_cur_maximum_buffer_size = None

                                self.cluster_id_entry = YList(self)
                                self.color_id = YList(self)
                                self._segment_path = lambda: "global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global, [u'in_standalone_mode', u'local_as', u'instance_name', u'restart_count', u'update_delay', u'generic_scan_period', u'confederation_id', u'cluster_id', u'configured_cluster_id', u'is_cluster_id_specified_as_ip', u'asn_format', u'srgb_start_configured', u'srgb_end_configured', u'srgb_start', u'srgb_end', u'graceful_maintenance', u'graceful_maint_all_nbrs', u'graceful_maint_retain_routes', u'process_rlimit', u'bmp_maximum_buffer_size', u'bmp_default_buffer_size', u'bmp_current_buffer_size', u'bmp_cur_maximum_buffer_size'], name, value)


                            class ClusterIdEntry(Entity):
                                """
                                All configured Cluster IDs
                                
                                .. attribute:: cluster_id_val
                                
                                	Cluster ID 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: cluster_id_type
                                
                                	Cluster ID type\: number or IPv4 address
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global.ClusterIdEntry, self).__init__()

                                    self.yang_name = "cluster-id-entry"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('cluster_id_val', (YLeaf(YType.uint32, 'cluster-id-val'), ['int'])),
                                        ('cluster_id_type', (YLeaf(YType.uint8, 'cluster-id-type'), ['int'])),
                                    ])
                                    self.cluster_id_val = None
                                    self.cluster_id_type = None
                                    self._segment_path = lambda: "cluster-id-entry"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global.ClusterIdEntry, [u'cluster_id_val', u'cluster_id_type'], name, value)


                            class ColorId(Entity):
                                """
                                All configured Color IDs
                                
                                .. attribute:: color_id_val
                                
                                	Color ID 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global.ColorId, self).__init__()

                                    self.yang_name = "color-id"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('color_id_val', (YLeaf(YType.uint32, 'color-id-val'), ['int'])),
                                    ])
                                    self.color_id_val = None
                                    self._segment_path = lambda: "color-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Global.ColorId, [u'color_id_val'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: vrf_is_active
                            
                            	VRF state
                            	**type**\: bool
                            
                            .. attribute:: route_distinguisher
                            
                            	Route Distinguisher
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: router_id
                            
                            	Router ID for the VRF
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: configured_router_id
                            
                            	Configured router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_redistribute_ibgp_to_ig_ps_enabled
                            
                            	Redistribute iBGP into IGPs enabled
                            	**type**\: bool
                            
                            .. attribute:: is_fast_external_fallover_enabled
                            
                            	Fast external fallover enabled
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_missing_med_is_worst_enabled
                            
                            	Bestpath\: Treat missing MED as worst
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_always_compare_med_enabled
                            
                            	Bestpath\: Always compare MED
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_ignore_as_path_enabled
                            
                            	Bestpath\: Ignore AS path
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_as_path_mpath_relax_enabled
                            
                            	Bestpath\: Relax AS path for mpath
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_compare_med_from_confed_peer_enabled
                            
                            	Bestpath\: Compare MED from confed peer
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_compare_router_id_for_ebgp_peers_enabled
                            
                            	Bestpath\: Compare routerID for eBGP peers
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_aigp_ignore_enabled
                            
                            	Bestpath\: Ignore AIGP unless both paths have AIGP attribute
                            	**type**\: bool
                            
                            .. attribute:: is_bestpath_igp_metric_ignore_enabled
                            
                            	Bestpath\: Ignore IGP metric
                            	**type**\: bool
                            
                            .. attribute:: is_multipath_as_path_ignore_onwards_enabled
                            
                            	Multipath\: Ignore everything AS path onwards for mpath
                            	**type**\: bool
                            
                            .. attribute:: is_enforce_first_as_enabled
                            
                            	Enforce first AS
                            	**type**\: bool
                            
                            .. attribute:: default_local_preference
                            
                            	Default local preference
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: keep_alive_time
                            
                            	Default keepalive timer (seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: hold_time
                            
                            	Default hold timer (seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: min_acceptable_hold_time
                            
                            	Default min acceptable hold time from neighbor(seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: is_neighbor_logging
                            
                            	Neighbor logging enabled
                            	**type**\: bool
                            
                            .. attribute:: is_default_metric_configured
                            
                            	Default metric configured
                            	**type**\: bool
                            
                            .. attribute:: default_metric
                            
                            	Default metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_default_originate_configured
                            
                            	Default route originate configured
                            	**type**\: bool
                            
                            .. attribute:: is_graceful_restart
                            
                            	Graceful restart enabled
                            	**type**\: bool
                            
                            .. attribute:: is_nsr
                            
                            	Non\-stop routing enabled
                            	**type**\: bool
                            
                            .. attribute:: restart_time
                            
                            	Restart time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: stale_path_time
                            
                            	Stale path timeout time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: rib_purge_timeout
                            
                            	RIB purge timeout time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: rpki_use_validity
                            
                            	Use RPKI validity for bestpath calculation
                            	**type**\: bool
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Allow invalid paths
                            	**type**\: bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Signal RPKI validity to iBGP peers
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "global-process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('vrf_is_active', (YLeaf(YType.boolean, 'vrf-is-active'), ['bool'])),
                                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str'])),
                                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                    ('configured_router_id', (YLeaf(YType.str, 'configured-router-id'), ['str'])),
                                    ('is_redistribute_ibgp_to_ig_ps_enabled', (YLeaf(YType.boolean, 'is-redistribute-ibgp-to-ig-ps-enabled'), ['bool'])),
                                    ('is_fast_external_fallover_enabled', (YLeaf(YType.boolean, 'is-fast-external-fallover-enabled'), ['bool'])),
                                    ('is_bestpath_missing_med_is_worst_enabled', (YLeaf(YType.boolean, 'is-bestpath-missing-med-is-worst-enabled'), ['bool'])),
                                    ('is_bestpath_always_compare_med_enabled', (YLeaf(YType.boolean, 'is-bestpath-always-compare-med-enabled'), ['bool'])),
                                    ('is_bestpath_ignore_as_path_enabled', (YLeaf(YType.boolean, 'is-bestpath-ignore-as-path-enabled'), ['bool'])),
                                    ('is_bestpath_as_path_mpath_relax_enabled', (YLeaf(YType.boolean, 'is-bestpath-as-path-mpath-relax-enabled'), ['bool'])),
                                    ('is_bestpath_compare_med_from_confed_peer_enabled', (YLeaf(YType.boolean, 'is-bestpath-compare-med-from-confed-peer-enabled'), ['bool'])),
                                    ('is_bestpath_compare_router_id_for_ebgp_peers_enabled', (YLeaf(YType.boolean, 'is-bestpath-compare-router-id-for-ebgp-peers-enabled'), ['bool'])),
                                    ('is_bestpath_aigp_ignore_enabled', (YLeaf(YType.boolean, 'is-bestpath-aigp-ignore-enabled'), ['bool'])),
                                    ('is_bestpath_igp_metric_ignore_enabled', (YLeaf(YType.boolean, 'is-bestpath-igp-metric-ignore-enabled'), ['bool'])),
                                    ('is_multipath_as_path_ignore_onwards_enabled', (YLeaf(YType.boolean, 'is-multipath-as-path-ignore-onwards-enabled'), ['bool'])),
                                    ('is_enforce_first_as_enabled', (YLeaf(YType.boolean, 'is-enforce-first-as-enabled'), ['bool'])),
                                    ('default_local_preference', (YLeaf(YType.uint32, 'default-local-preference'), ['int'])),
                                    ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                    ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                    ('min_acceptable_hold_time', (YLeaf(YType.uint16, 'min-acceptable-hold-time'), ['int'])),
                                    ('is_neighbor_logging', (YLeaf(YType.boolean, 'is-neighbor-logging'), ['bool'])),
                                    ('is_default_metric_configured', (YLeaf(YType.boolean, 'is-default-metric-configured'), ['bool'])),
                                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                    ('is_default_originate_configured', (YLeaf(YType.boolean, 'is-default-originate-configured'), ['bool'])),
                                    ('is_graceful_restart', (YLeaf(YType.boolean, 'is-graceful-restart'), ['bool'])),
                                    ('is_nsr', (YLeaf(YType.boolean, 'is-nsr'), ['bool'])),
                                    ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                    ('stale_path_time', (YLeaf(YType.uint32, 'stale-path-time'), ['int'])),
                                    ('rib_purge_timeout', (YLeaf(YType.uint32, 'rib-purge-timeout'), ['int'])),
                                    ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                    ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                    ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                ])
                                self.vrf_is_active = None
                                self.route_distinguisher = None
                                self.router_id = None
                                self.configured_router_id = None
                                self.is_redistribute_ibgp_to_ig_ps_enabled = None
                                self.is_fast_external_fallover_enabled = None
                                self.is_bestpath_missing_med_is_worst_enabled = None
                                self.is_bestpath_always_compare_med_enabled = None
                                self.is_bestpath_ignore_as_path_enabled = None
                                self.is_bestpath_as_path_mpath_relax_enabled = None
                                self.is_bestpath_compare_med_from_confed_peer_enabled = None
                                self.is_bestpath_compare_router_id_for_ebgp_peers_enabled = None
                                self.is_bestpath_aigp_ignore_enabled = None
                                self.is_bestpath_igp_metric_ignore_enabled = None
                                self.is_multipath_as_path_ignore_onwards_enabled = None
                                self.is_enforce_first_as_enabled = None
                                self.default_local_preference = None
                                self.keep_alive_time = None
                                self.hold_time = None
                                self.min_acceptable_hold_time = None
                                self.is_neighbor_logging = None
                                self.is_default_metric_configured = None
                                self.default_metric = None
                                self.is_default_originate_configured = None
                                self.is_graceful_restart = None
                                self.is_nsr = None
                                self.restart_time = None
                                self.stale_path_time = None
                                self.rib_purge_timeout = None
                                self.rpki_use_validity = None
                                self.rpki_allow_invalid = None
                                self.rpki_signal_ibgp = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.GlobalProcessInfo.Vrf, [u'vrf_is_active', u'route_distinguisher', u'router_id', u'configured_router_id', u'is_redistribute_ibgp_to_ig_ps_enabled', u'is_fast_external_fallover_enabled', u'is_bestpath_missing_med_is_worst_enabled', u'is_bestpath_always_compare_med_enabled', u'is_bestpath_ignore_as_path_enabled', u'is_bestpath_as_path_mpath_relax_enabled', u'is_bestpath_compare_med_from_confed_peer_enabled', u'is_bestpath_compare_router_id_for_ebgp_peers_enabled', u'is_bestpath_aigp_ignore_enabled', u'is_bestpath_igp_metric_ignore_enabled', u'is_multipath_as_path_ignore_onwards_enabled', u'is_enforce_first_as_enabled', u'default_local_preference', u'keep_alive_time', u'hold_time', u'min_acceptable_hold_time', u'is_neighbor_logging', u'is_default_metric_configured', u'default_metric', u'is_default_originate_configured', u'is_graceful_restart', u'is_nsr', u'restart_time', u'stale_path_time', u'rib_purge_timeout', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp'], name, value)


                    class UpdateInboundErrorNeighbors(Entity):
                        """
                        Update inbound error information for all
                        neighbors
                        
                        .. attribute:: update_inbound_error_neighbor
                        
                        	Update inbound error information for neighbor
                        	**type**\: list of  		 :py:class:`UpdateInboundErrorNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors, self).__init__()

                            self.yang_name = "update-inbound-error-neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("update-inbound-error-neighbor", ("update_inbound_error_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor))])
                            self._leafs = OrderedDict()

                            self.update_inbound_error_neighbor = YList(self)
                            self._segment_path = lambda: "update-inbound-error-neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors, [], name, value)


                        class UpdateInboundErrorNeighbor(Entity):
                            """
                            Update inbound error information for neighbor
                            
                            .. attribute:: neighbor_address  (key)
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: first_update_malformed_timestamp
                            
                            	First malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`FirstUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp>`
                            
                            .. attribute:: last_update_malformed_timestamp
                            
                            	Last malformed message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp>`
                            
                            .. attribute:: first_update_memory_allocation_fail_timestamp
                            
                            	First memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`FirstUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: last_update_memory_allocation_fail_timestamp
                            
                            	Last memory allocation failure time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastUpdateMemoryAllocationFailTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp>`
                            
                            .. attribute:: first_update_error_handling_reset_timestamp
                            
                            	First error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`FirstUpdateErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp>`
                            
                            .. attribute:: last_error_handling_reset_timestamp
                            
                            	Last error\-handling reset time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastErrorHandlingResetTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: update_error_handling_avoid_reset
                            
                            	Configure error\-handling to avoid resets
                            	**type**\: bool
                            
                            .. attribute:: total_update_message_count
                            
                            	Total update messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_malformed_message_count
                            
                            	Malformed messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_update_malformed_age
                            
                            	Time since last malformed message received event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: update_memory_allocation_fail_count
                            
                            	Memory allocation failure count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_update_memory_allocation_fail_age
                            
                            	Time since last memory allocation failure event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: update_error_handling_reset_count
                            
                            	Error\-handling reset count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_error_handling_reset_age
                            
                            	Time since last error\-handling reset event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: update_error_message_list_count
                            
                            	Malformed messages list count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_discard_count
                            
                            	Discarded attribute count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_total_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_action_count
                            
                            	Number of occurence of each action type since  session establishment
                            	**type**\: list of  		 :py:class:`EstablishmentActionCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount>`
                            
                            .. attribute:: update_error_message
                            
                            	List of malformed messages
                            	**type**\: list of  		 :py:class:`UpdateErrorMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, self).__init__()

                                self.yang_name = "update-inbound-error-neighbor"
                                self.yang_parent_name = "update-inbound-error-neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress)), ("first-update-malformed-timestamp", ("first_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp)), ("last-update-malformed-timestamp", ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp)), ("first-update-memory-allocation-fail-timestamp", ("first_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp)), ("last-update-memory-allocation-fail-timestamp", ("last_update_memory_allocation_fail_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp)), ("first-update-error-handling-reset-timestamp", ("first_update_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp)), ("last-error-handling-reset-timestamp", ("last_error_handling_reset_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp)), ("establishment-action-count", ("establishment_action_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount)), ("update-error-message", ("update_error_message", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                    ('update_error_handling_avoid_reset', (YLeaf(YType.boolean, 'update-error-handling-avoid-reset'), ['bool'])),
                                    ('total_update_message_count', (YLeaf(YType.uint32, 'total-update-message-count'), ['int'])),
                                    ('update_malformed_message_count', (YLeaf(YType.uint32, 'update-malformed-message-count'), ['int'])),
                                    ('last_update_malformed_age', (YLeaf(YType.uint32, 'last-update-malformed-age'), ['int'])),
                                    ('update_memory_allocation_fail_count', (YLeaf(YType.uint32, 'update-memory-allocation-fail-count'), ['int'])),
                                    ('last_update_memory_allocation_fail_age', (YLeaf(YType.uint32, 'last-update-memory-allocation-fail-age'), ['int'])),
                                    ('update_error_handling_reset_count', (YLeaf(YType.uint32, 'update-error-handling-reset-count'), ['int'])),
                                    ('last_error_handling_reset_age', (YLeaf(YType.uint32, 'last-error-handling-reset-age'), ['int'])),
                                    ('update_error_message_list_count', (YLeaf(YType.uint32, 'update-error-message-list-count'), ['int'])),
                                    ('update_attribute_discard_count', (YLeaf(YType.uint32, 'update-attribute-discard-count'), ['int'])),
                                    ('establishment_total_update_message_count', (YLeaf(YType.uint32, 'establishment-total-update-message-count'), ['int'])),
                                ])
                                self.neighbor_address = None
                                self.update_vrf_name = None
                                self.update_error_handling_avoid_reset = None
                                self.total_update_message_count = None
                                self.update_malformed_message_count = None
                                self.last_update_malformed_age = None
                                self.update_memory_allocation_fail_count = None
                                self.last_update_memory_allocation_fail_age = None
                                self.update_error_handling_reset_count = None
                                self.last_error_handling_reset_age = None
                                self.update_error_message_list_count = None
                                self.update_attribute_discard_count = None
                                self.establishment_total_update_message_count = None

                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                self.first_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp()
                                self.first_update_malformed_timestamp.parent = self
                                self._children_name_map["first_update_malformed_timestamp"] = "first-update-malformed-timestamp"

                                self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp()
                                self.last_update_malformed_timestamp.parent = self
                                self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"

                                self.first_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp()
                                self.first_update_memory_allocation_fail_timestamp.parent = self
                                self._children_name_map["first_update_memory_allocation_fail_timestamp"] = "first-update-memory-allocation-fail-timestamp"

                                self.last_update_memory_allocation_fail_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp()
                                self.last_update_memory_allocation_fail_timestamp.parent = self
                                self._children_name_map["last_update_memory_allocation_fail_timestamp"] = "last-update-memory-allocation-fail-timestamp"

                                self.first_update_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp()
                                self.first_update_error_handling_reset_timestamp.parent = self
                                self._children_name_map["first_update_error_handling_reset_timestamp"] = "first-update-error-handling-reset-timestamp"

                                self.last_error_handling_reset_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp()
                                self.last_error_handling_reset_timestamp.parent = self
                                self._children_name_map["last_error_handling_reset_timestamp"] = "last-error-handling-reset-timestamp"

                                self.establishment_action_count = YList(self)
                                self.update_error_message = YList(self)
                                self._segment_path = lambda: "update-inbound-error-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor, ['neighbor_address', u'update_vrf_name', u'update_error_handling_avoid_reset', u'total_update_message_count', u'update_malformed_message_count', u'last_update_malformed_age', u'update_memory_allocation_fail_count', u'last_update_memory_allocation_fail_age', u'update_error_handling_reset_count', u'last_error_handling_reset_age', u'update_error_message_list_count', u'update_attribute_discard_count', u'establishment_total_update_message_count'], name, value)


                            class UpdateNeighborAddress(Entity):
                                """
                                Neighbor address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, self).__init__()

                                    self.yang_name = "update-neighbor-address"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "update-neighbor-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class FirstUpdateMalformedTimestamp(Entity):
                                """
                                First malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "first-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "first-update-malformed-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class LastUpdateMalformedTimestamp(Entity):
                                """
                                Last malformed message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, self).__init__()

                                    self.yang_name = "last-update-malformed-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-update-malformed-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class FirstUpdateMemoryAllocationFailTimestamp(Entity):
                                """
                                First memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, self).__init__()

                                    self.yang_name = "first-update-memory-allocation-fail-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "first-update-memory-allocation-fail-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class LastUpdateMemoryAllocationFailTimestamp(Entity):
                                """
                                Last memory allocation failure time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, self).__init__()

                                    self.yang_name = "last-update-memory-allocation-fail-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-update-memory-allocation-fail-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastUpdateMemoryAllocationFailTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class FirstUpdateErrorHandlingResetTimestamp(Entity):
                                """
                                First error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, self).__init__()

                                    self.yang_name = "first-update-error-handling-reset-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "first-update-error-handling-reset-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.FirstUpdateErrorHandlingResetTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class LastErrorHandlingResetTimestamp(Entity):
                                """
                                Last error\-handling reset time\: time elapsed
                                since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, self).__init__()

                                    self.yang_name = "last-error-handling-reset-timestamp"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-error-handling-reset-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.LastErrorHandlingResetTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class EstablishmentActionCount(Entity):
                                """
                                Number of occurence of each action type since
                                
                                session establishment
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, self).__init__()

                                    self.yang_name = "establishment-action-count"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "establishment-action-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.EstablishmentActionCount, [u'entry'], name, value)


                            class UpdateErrorMessage(Entity):
                                """
                                List of malformed messages
                                
                                .. attribute:: update_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`UpdateMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp>`
                                
                                .. attribute:: update_message_reset_data
                                
                                	Reset data
                                	**type**\:  :py:class:`UpdateMessageResetData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData>`
                                
                                .. attribute:: update_error_final_action
                                
                                	Error final action
                                	**type**\:  :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                
                                .. attribute:: update_attribute_discard_count
                                
                                	Discarded attribute count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_error_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_error_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\: str
                                
                                .. attribute:: update_error_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\: bool
                                
                                .. attribute:: update_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of  		 :py:class:`UpdateMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData>`
                                
                                .. attribute:: update_error_element
                                
                                	Error element list
                                	**type**\: list of  		 :py:class:`UpdateErrorElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, self).__init__()

                                    self.yang_name = "update-error-message"
                                    self.yang_parent_name = "update-inbound-error-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-message-timestamp", ("update_message_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp)), ("update-message-reset-data", ("update_message_reset_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData)), ("update-message-data", ("update_message_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData)), ("update-error-element", ("update_error_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement))])
                                    self._leafs = OrderedDict([
                                        ('update_error_final_action', (YLeaf(YType.enumeration, 'update-error-final-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdErrAction', '')])),
                                        ('update_attribute_discard_count', (YLeaf(YType.uint32, 'update-attribute-discard-count'), ['int'])),
                                        ('update_error_nlri_address_family', (YLeaf(YType.enumeration, 'update-error-nlri-address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('update_error_nlri_string', (YLeaf(YType.str, 'update-error-nlri-string'), ['str'])),
                                        ('update_error_nlri_string_truncated', (YLeaf(YType.boolean, 'update-error-nlri-string-truncated'), ['bool'])),
                                    ])
                                    self.update_error_final_action = None
                                    self.update_attribute_discard_count = None
                                    self.update_error_nlri_address_family = None
                                    self.update_error_nlri_string = None
                                    self.update_error_nlri_string_truncated = None

                                    self.update_message_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp()
                                    self.update_message_timestamp.parent = self
                                    self._children_name_map["update_message_timestamp"] = "update-message-timestamp"

                                    self.update_message_reset_data = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData()
                                    self.update_message_reset_data.parent = self
                                    self._children_name_map["update_message_reset_data"] = "update-message-reset-data"

                                    self.update_message_data = YList(self)
                                    self.update_error_element = YList(self)
                                    self._segment_path = lambda: "update-error-message"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage, [u'update_error_final_action', u'update_attribute_discard_count', u'update_error_nlri_address_family', u'update_error_nlri_string', u'update_error_nlri_string_truncated'], name, value)


                                class UpdateMessageTimestamp(Entity):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, self).__init__()

                                        self.yang_name = "update-message-timestamp"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "update-message-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateMessageResetData(Entity):
                                    """
                                    Reset data
                                    
                                    .. attribute:: update_error_reset_reason
                                    
                                    	Reset Reason
                                    	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                                    
                                    .. attribute:: update_error_reset_notification_code
                                    
                                    	Notification code
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_error_reset_notification_sub_code
                                    
                                    	Notification sub code
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_reset_notification_data
                                    
                                    	Notification data
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_reset_notification_data_length
                                    
                                    	Notification data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, self).__init__()

                                        self.yang_name = "update-message-reset-data"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('update_error_reset_reason', (YLeaf(YType.enumeration, 'update-error-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                            ('update_error_reset_notification_code', (YLeaf(YType.uint8, 'update-error-reset-notification-code'), ['int'])),
                                            ('update_error_reset_notification_sub_code', (YLeaf(YType.uint16, 'update-error-reset-notification-sub-code'), ['int'])),
                                            ('update_error_reset_notification_data', (YLeaf(YType.str, 'update-error-reset-notification-data'), ['str'])),
                                            ('update_error_reset_notification_data_length', (YLeaf(YType.uint16, 'update-error-reset-notification-data-length'), ['int'])),
                                        ])
                                        self.update_error_reset_reason = None
                                        self.update_error_reset_notification_code = None
                                        self.update_error_reset_notification_sub_code = None
                                        self.update_error_reset_notification_data = None
                                        self.update_error_reset_notification_data_length = None
                                        self._segment_path = lambda: "update-message-reset-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageResetData, [u'update_error_reset_reason', u'update_error_reset_notification_code', u'update_error_reset_notification_sub_code', u'update_error_reset_notification_data', u'update_error_reset_notification_data_length'], name, value)


                                class UpdateMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, self).__init__()

                                        self.yang_name = "update-message-data"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "update-message-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateMessageData, [u'entry'], name, value)


                                class UpdateErrorElement(Entity):
                                    """
                                    Error element list
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_length
                                    
                                    	Attribute Length [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_data
                                    
                                    	Error data
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: update_error_data_length
                                    
                                    	Error data length
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: update_error_action
                                    
                                    	Error action
                                    	**type**\:  :py:class:`BgpBagUpdErrAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdErrAction>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, self).__init__()

                                        self.yang_name = "update-error-element"
                                        self.yang_parent_name = "update-error-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('update_attribute_flags', (YLeaf(YType.uint8, 'update-attribute-flags'), ['int'])),
                                            ('update_attribute_code', (YLeaf(YType.uint8, 'update-attribute-code'), ['int'])),
                                            ('update_attribute_length', (YLeaf(YType.uint16, 'update-attribute-length'), ['int'])),
                                            ('update_error_data', (YLeaf(YType.str, 'update-error-data'), ['str'])),
                                            ('update_error_data_length', (YLeaf(YType.uint16, 'update-error-data-length'), ['int'])),
                                            ('update_error_action', (YLeaf(YType.enumeration, 'update-error-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdErrAction', '')])),
                                        ])
                                        self.update_attribute_flags = None
                                        self.update_attribute_code = None
                                        self.update_attribute_length = None
                                        self.update_error_data = None
                                        self.update_error_data_length = None
                                        self.update_error_action = None
                                        self._segment_path = lambda: "update-error-element"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundErrorNeighbors.UpdateInboundErrorNeighbor.UpdateErrorMessage.UpdateErrorElement, [u'update_attribute_flags', u'update_attribute_code', u'update_attribute_length', u'update_error_data', u'update_error_data_length', u'update_error_action'], name, value)


                    class UpdateInboundFilterNeighbors(Entity):
                        """
                        Update inbound filtering information for all
                        neighbors
                        
                        .. attribute:: update_inbound_filter_neighbor
                        
                        	Update inbound filtering information for neighbor
                        	**type**\: list of  		 :py:class:`UpdateInboundFilterNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors, self).__init__()

                            self.yang_name = "update-inbound-filter-neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("update-inbound-filter-neighbor", ("update_inbound_filter_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor))])
                            self._leafs = OrderedDict()

                            self.update_inbound_filter_neighbor = YList(self)
                            self._segment_path = lambda: "update-inbound-filter-neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors, [], name, value)


                        class UpdateInboundFilterNeighbor(Entity):
                            """
                            Update inbound filtering information for
                            neighbor
                            
                            .. attribute:: neighbor_address  (key)
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: update_neighbor_address
                            
                            	Neighbor address
                            	**type**\:  :py:class:`UpdateNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress>`
                            
                            .. attribute:: first_update_filtered_timestamp
                            
                            	First filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`FirstUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp>`
                            
                            .. attribute:: last_update_filtered_timestamp
                            
                            	Last filtered message received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                            	**type**\:  :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp>`
                            
                            .. attribute:: update_vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: update_filter_logging_enabled
                            
                            	Logging is enabled
                            	**type**\: bool
                            
                            .. attribute:: configured_update_filter_message_buffer_count
                            
                            	Configured Filtered message buffer count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: operational_update_filter_message_buffer_count
                            
                            	Operational Filtered messages buffer count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filter_message_buffer_circular
                            
                            	Indicates if the message buffers are circular
                            	**type**\: bool
                            
                            .. attribute:: update_attribute_filter_group_name
                            
                            	Update attribute\-filter group name
                            	**type**\: str
                            
                            .. attribute:: operational_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled
                            	**type**\: bool
                            
                            .. attribute:: message_update_attribute_filtering_enabled
                            
                            	Attribute filtering is enabled for the current message being parsed
                            	**type**\: bool
                            
                            .. attribute:: total_filter_update_message_count
                            
                            	Total update messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_total_filter_update_message_count
                            
                            	Total update messages count since session establishment
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_filtered_message_count
                            
                            	Filtered messages count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: establishment_update_filtered_message_count
                            
                            	Filtered messages count since session establishment
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_update_filtered_age
                            
                            	Time since last filtered message received event (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: update_filter_message_list_count
                            
                            	Filtered messages list count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_attribute_filter_attributes
                            
                            	List of attributes that can be filtered
                            	**type**\: list of  		 :py:class:`UpdateAttributeFilterAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes>`
                            
                            .. attribute:: update_filter_message
                            
                            	List of filtered messages
                            	**type**\: list of  		 :py:class:`UpdateFilterMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, self).__init__()

                                self.yang_name = "update-inbound-filter-neighbor"
                                self.yang_parent_name = "update-inbound-filter-neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_classes = OrderedDict([("update-neighbor-address", ("update_neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress)), ("first-update-filtered-timestamp", ("first_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp)), ("last-update-filtered-timestamp", ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp)), ("update-attribute-filter-attributes", ("update_attribute_filter_attributes", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes)), ("update-filter-message", ("update_filter_message", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('update_vrf_name', (YLeaf(YType.str, 'update-vrf-name'), ['str'])),
                                    ('update_filter_logging_enabled', (YLeaf(YType.boolean, 'update-filter-logging-enabled'), ['bool'])),
                                    ('configured_update_filter_message_buffer_count', (YLeaf(YType.uint32, 'configured-update-filter-message-buffer-count'), ['int'])),
                                    ('operational_update_filter_message_buffer_count', (YLeaf(YType.uint32, 'operational-update-filter-message-buffer-count'), ['int'])),
                                    ('update_filter_message_buffer_circular', (YLeaf(YType.boolean, 'update-filter-message-buffer-circular'), ['bool'])),
                                    ('update_attribute_filter_group_name', (YLeaf(YType.str, 'update-attribute-filter-group-name'), ['str'])),
                                    ('operational_update_attribute_filtering_enabled', (YLeaf(YType.boolean, 'operational-update-attribute-filtering-enabled'), ['bool'])),
                                    ('message_update_attribute_filtering_enabled', (YLeaf(YType.boolean, 'message-update-attribute-filtering-enabled'), ['bool'])),
                                    ('total_filter_update_message_count', (YLeaf(YType.uint32, 'total-filter-update-message-count'), ['int'])),
                                    ('establishment_total_filter_update_message_count', (YLeaf(YType.uint32, 'establishment-total-filter-update-message-count'), ['int'])),
                                    ('update_filtered_message_count', (YLeaf(YType.uint32, 'update-filtered-message-count'), ['int'])),
                                    ('establishment_update_filtered_message_count', (YLeaf(YType.uint32, 'establishment-update-filtered-message-count'), ['int'])),
                                    ('last_update_filtered_age', (YLeaf(YType.uint32, 'last-update-filtered-age'), ['int'])),
                                    ('update_filter_message_list_count', (YLeaf(YType.uint32, 'update-filter-message-list-count'), ['int'])),
                                ])
                                self.neighbor_address = None
                                self.update_vrf_name = None
                                self.update_filter_logging_enabled = None
                                self.configured_update_filter_message_buffer_count = None
                                self.operational_update_filter_message_buffer_count = None
                                self.update_filter_message_buffer_circular = None
                                self.update_attribute_filter_group_name = None
                                self.operational_update_attribute_filtering_enabled = None
                                self.message_update_attribute_filtering_enabled = None
                                self.total_filter_update_message_count = None
                                self.establishment_total_filter_update_message_count = None
                                self.update_filtered_message_count = None
                                self.establishment_update_filtered_message_count = None
                                self.last_update_filtered_age = None
                                self.update_filter_message_list_count = None

                                self.update_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress()
                                self.update_neighbor_address.parent = self
                                self._children_name_map["update_neighbor_address"] = "update-neighbor-address"

                                self.first_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp()
                                self.first_update_filtered_timestamp.parent = self
                                self._children_name_map["first_update_filtered_timestamp"] = "first-update-filtered-timestamp"

                                self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp()
                                self.last_update_filtered_timestamp.parent = self
                                self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"

                                self.update_attribute_filter_attributes = YList(self)
                                self.update_filter_message = YList(self)
                                self._segment_path = lambda: "update-inbound-filter-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor, ['neighbor_address', u'update_vrf_name', u'update_filter_logging_enabled', u'configured_update_filter_message_buffer_count', u'operational_update_filter_message_buffer_count', u'update_filter_message_buffer_circular', u'update_attribute_filter_group_name', u'operational_update_attribute_filtering_enabled', u'message_update_attribute_filtering_enabled', u'total_filter_update_message_count', u'establishment_total_filter_update_message_count', u'update_filtered_message_count', u'establishment_update_filtered_message_count', u'last_update_filtered_age', u'update_filter_message_list_count'], name, value)


                            class UpdateNeighborAddress(Entity):
                                """
                                Neighbor address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, self).__init__()

                                    self.yang_name = "update-neighbor-address"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "update-neighbor-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "update-neighbor-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class FirstUpdateFilteredTimestamp(Entity):
                                """
                                First filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "first-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "first-update-filtered-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.FirstUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class LastUpdateFilteredTimestamp(Entity):
                                """
                                Last filtered message received time\: time
                                elapsed since 00\:00\:00 UTC, January 1, 1970
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, self).__init__()

                                    self.yang_name = "last-update-filtered-timestamp"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "last-update-filtered-timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.LastUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class UpdateAttributeFilterAttributes(Entity):
                                """
                                List of attributes that can be filtered
                                
                                .. attribute:: last_update_filter_match_timestamp
                                
                                	Last attribute filtered time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`LastUpdateFilterMatchTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp>`
                                
                                .. attribute:: update_internal_attribute_code
                                
                                	Internal attribute code [RFC4271\: BGP4]
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filter_action
                                
                                	Filtering action
                                	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                
                                .. attribute:: update_filter_match_count
                                
                                	Filter match counter
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: establishment_update_filter_match_count
                                
                                	Filter match counter since last session establishment
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_update_filter_match_age
                                
                                	Time since this attribute was last filtered (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, self).__init__()

                                    self.yang_name = "update-attribute-filter-attributes"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("last-update-filter-match-timestamp", ("last_update_filter_match_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp))])
                                    self._leafs = OrderedDict([
                                        ('update_internal_attribute_code', (YLeaf(YType.uint32, 'update-internal-attribute-code'), ['int'])),
                                        ('update_filter_action', (YLeaf(YType.enumeration, 'update-filter-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                        ('update_filter_match_count', (YLeaf(YType.uint32, 'update-filter-match-count'), ['int'])),
                                        ('establishment_update_filter_match_count', (YLeaf(YType.uint32, 'establishment-update-filter-match-count'), ['int'])),
                                        ('last_update_filter_match_age', (YLeaf(YType.uint32, 'last-update-filter-match-age'), ['int'])),
                                    ])
                                    self.update_internal_attribute_code = None
                                    self.update_filter_action = None
                                    self.update_filter_match_count = None
                                    self.establishment_update_filter_match_count = None
                                    self.last_update_filter_match_age = None

                                    self.last_update_filter_match_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp()
                                    self.last_update_filter_match_timestamp.parent = self
                                    self._children_name_map["last_update_filter_match_timestamp"] = "last-update-filter-match-timestamp"
                                    self._segment_path = lambda: "update-attribute-filter-attributes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes, [u'update_internal_attribute_code', u'update_filter_action', u'update_filter_match_count', u'establishment_update_filter_match_count', u'last_update_filter_match_age'], name, value)


                                class LastUpdateFilterMatchTimestamp(Entity):
                                    """
                                    Last attribute filtered time\: time elapsed since
                                    00\:00\:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, self).__init__()

                                        self.yang_name = "last-update-filter-match-timestamp"
                                        self.yang_parent_name = "update-attribute-filter-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "last-update-filter-match-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateAttributeFilterAttributes.LastUpdateFilterMatchTimestamp, [u'seconds', u'nanoseconds'], name, value)


                            class UpdateFilterMessage(Entity):
                                """
                                List of filtered messages
                                
                                .. attribute:: update_filter_message_timestamp
                                
                                	Message timestamp\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`UpdateFilterMessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp>`
                                
                                .. attribute:: update_filtered_attribute_count
                                
                                	Filtered attributes count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: update_filter_final_action
                                
                                	Filtering final action
                                	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                
                                .. attribute:: update_filter_nlri_address_family
                                
                                	NLRI address\-family
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: update_filter_nlri_string
                                
                                	List of NLRIs in string format
                                	**type**\: str
                                
                                .. attribute:: update_filter_nlri_string_truncated
                                
                                	Indicates whether NLRI string was truncated due to lack of space
                                	**type**\: bool
                                
                                .. attribute:: update_filter_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of  		 :py:class:`UpdateFilterMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData>`
                                
                                .. attribute:: update_filter_element
                                
                                	Filtering element list
                                	**type**\: list of  		 :py:class:`UpdateFilterElement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, self).__init__()

                                    self.yang_name = "update-filter-message"
                                    self.yang_parent_name = "update-inbound-filter-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("update-filter-message-timestamp", ("update_filter_message_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp)), ("update-filter-message-data", ("update_filter_message_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData)), ("update-filter-element", ("update_filter_element", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement))])
                                    self._leafs = OrderedDict([
                                        ('update_filtered_attribute_count', (YLeaf(YType.uint32, 'update-filtered-attribute-count'), ['int'])),
                                        ('update_filter_final_action', (YLeaf(YType.enumeration, 'update-filter-final-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                        ('update_filter_nlri_address_family', (YLeaf(YType.enumeration, 'update-filter-nlri-address-family'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('update_filter_nlri_string', (YLeaf(YType.str, 'update-filter-nlri-string'), ['str'])),
                                        ('update_filter_nlri_string_truncated', (YLeaf(YType.boolean, 'update-filter-nlri-string-truncated'), ['bool'])),
                                    ])
                                    self.update_filtered_attribute_count = None
                                    self.update_filter_final_action = None
                                    self.update_filter_nlri_address_family = None
                                    self.update_filter_nlri_string = None
                                    self.update_filter_nlri_string_truncated = None

                                    self.update_filter_message_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp()
                                    self.update_filter_message_timestamp.parent = self
                                    self._children_name_map["update_filter_message_timestamp"] = "update-filter-message-timestamp"

                                    self.update_filter_message_data = YList(self)
                                    self.update_filter_element = YList(self)
                                    self._segment_path = lambda: "update-filter-message"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage, [u'update_filtered_attribute_count', u'update_filter_final_action', u'update_filter_nlri_address_family', u'update_filter_nlri_string', u'update_filter_nlri_string_truncated'], name, value)


                                class UpdateFilterMessageTimestamp(Entity):
                                    """
                                    Message timestamp\: time elapsed since 00\:00\:00
                                    UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, self).__init__()

                                        self.yang_name = "update-filter-message-timestamp"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "update-filter-message-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateFilterMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, self).__init__()

                                        self.yang_name = "update-filter-message-data"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "update-filter-message-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterMessageData, [u'entry'], name, value)


                                class UpdateFilterElement(Entity):
                                    """
                                    Filtering element list
                                    
                                    .. attribute:: update_attribute_flags
                                    
                                    	Attribute Flags [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_attribute_code
                                    
                                    	Attribute code [RFC4271\: BGP4]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: update_filter_action
                                    
                                    	Filtering action
                                    	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, self).__init__()

                                        self.yang_name = "update-filter-element"
                                        self.yang_parent_name = "update-filter-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('update_attribute_flags', (YLeaf(YType.uint8, 'update-attribute-flags'), ['int'])),
                                            ('update_attribute_code', (YLeaf(YType.uint8, 'update-attribute-code'), ['int'])),
                                            ('update_filter_action', (YLeaf(YType.enumeration, 'update-filter-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                        ])
                                        self.update_attribute_flags = None
                                        self.update_attribute_code = None
                                        self.update_filter_action = None
                                        self._segment_path = lambda: "update-filter-element"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.UpdateInboundFilterNeighbors.UpdateInboundFilterNeighbor.UpdateFilterMessage.UpdateFilterElement, [u'update_attribute_flags', u'update_attribute_code', u'update_filter_action'], name, value)


                    class Bmp(Entity):
                        """
                        BMP related Operational Data
                        
                        .. attribute:: server_summaries
                        
                        	Table of BMP Servers
                        	**type**\:  :py:class:`ServerSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries>`
                        
                        .. attribute:: server_neighbors
                        
                        	Table of Neighbors for a BMP Server
                        	**type**\:  :py:class:`ServerNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp, self).__init__()

                            self.yang_name = "bmp"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("server-summaries", ("server_summaries", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries)), ("server-neighbors", ("server_neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors))])
                            self._leafs = OrderedDict()

                            self.server_summaries = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries()
                            self.server_summaries.parent = self
                            self._children_name_map["server_summaries"] = "server-summaries"

                            self.server_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors()
                            self.server_neighbors.parent = self
                            self._children_name_map["server_neighbors"] = "server-neighbors"
                            self._segment_path = lambda: "bmp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp, [], name, value)


                        class ServerSummaries(Entity):
                            """
                            Table of BMP Servers
                            
                            .. attribute:: server_summary
                            
                            	Summary Information about BMP server
                            	**type**\: list of  		 :py:class:`ServerSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries, self).__init__()

                                self.yang_name = "server-summaries"
                                self.yang_parent_name = "bmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("server-summary", ("server_summary", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary))])
                                self._leafs = OrderedDict()

                                self.server_summary = YList(self)
                                self._segment_path = lambda: "server-summaries"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries, [], name, value)


                            class ServerSummary(Entity):
                                """
                                Summary Information about BMP server
                                
                                .. attribute:: server_id  (key)
                                
                                	BMP Server ID
                                	**type**\: int
                                
                                	**range:** 1..8
                                
                                .. attribute:: bmp_server_state_age
                                
                                	Age of current state of BMP Server
                                	**type**\:  :py:class:`BmpServerStateAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge>`
                                
                                .. attribute:: bmp_server_state_time_spec
                                
                                	Timespec of current state of BMP Server
                                	**type**\:  :py:class:`BmpServerStateTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec>`
                                
                                .. attribute:: bmp_server_last_discon_time
                                
                                	Timespec of Last Disconnect event received from BMP server
                                	**type**\:  :py:class:`BmpServerLastDisconTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime>`
                                
                                .. attribute:: update_source_address
                                
                                	Address of Interface configured as Update Source
                                	**type**\:  :py:class:`UpdateSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress>`
                                
                                .. attribute:: bmp_server_id
                                
                                	BMP Server ID
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: bmp_server_host_name
                                
                                	BMP Server Hostname
                                	**type**\: str
                                
                                .. attribute:: bmp_server_port
                                
                                	BMP Server Port Number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_server_state
                                
                                	Connection state of the BMP server
                                	**type**\:  :py:class:`BgpBmpState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpState>`
                                
                                .. attribute:: bmp_server_is_flapping
                                
                                	Connection to the BMP server Flapping
                                	**type**\: bool
                                
                                .. attribute:: bmp_server_nbr_count
                                
                                	Neighbor count for the BMP Server
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_init_msg_count
                                
                                	Number of Initiation Msgs sent by this BMP Server
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_termination_msg_count
                                
                                	Number of Termination Messages sent by this BMP Server
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_status_report_count
                                
                                	Number of Status ReportMessages sent by this BMP Server
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_count
                                
                                	Total number of per peer messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_drop_count
                                
                                	Total number of messages dropped
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count
                                
                                	Total number of bmpQ msgs pending
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos_type
                                
                                	Precedence (0) or DSCP (1) type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_value
                                
                                	Precedence or DSCP value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: update_source_interface_name
                                
                                	Interface configured as Update Source
                                	**type**\: str
                                
                                .. attribute:: update_source_vrf_id
                                
                                	VRF ID of interface configured as Update Source
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_vrf_name
                                
                                	VRF Name configured
                                	**type**\: str
                                
                                .. attribute:: bmp_vrf_id
                                
                                	VRF ID for the vrf name configured
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_update_mode
                                
                                	Update sending mode configured for this BMP server
                                	**type**\:  :py:class:`BgpBmpUpdMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBmpUpdMode>`
                                
                                .. attribute:: tcp_keep_alive_interval
                                
                                	TCP Keep alive interval configured
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_maximum_segment_size
                                
                                	TCP Maximum Segments size configured
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_write_cb_pending
                                
                                	Are we waiting for TCP write callback ?
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_result
                                
                                	Last TCP Socket write status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tcp_last_write_cb_time
                                
                                	Last TCP Write CB time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: tcp_last_write_time
                                
                                	Last TCP Write time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_all_write_pulse_sent_time
                                
                                	Last BMPQ write pulse Sent for all BMP servers 
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmpq_last_write_pulse_cb_time
                                
                                	Last BMPQ write pulse callback time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: path_update_count
                                
                                	Number of path update sent 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_count
                                
                                	Number of path wdraw sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_update_drop
                                
                                	Number of path update drop 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_withdraw_drop
                                
                                	Number of path wdraw drop 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count_max
                                
                                	Total bmpQ msgs pending max
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_peer_msg_pending_count_hwts
                                
                                	Total bmpQ msgs pending max time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_bytes_written_tcp
                                
                                	Total bytes sent to TCP
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: tcp_write_time
                                
                                	Time spent processing sending msg to TCP(milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bmpr_mon_upd_messages
                                
                                	Total bmpQ update msgs 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmpr_mon_wdraw_messages
                                
                                	Total bmpQ withdraw msgs 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_messages_wdraw_discarded
                                
                                	Total bmpQ wdraw msgs discarded because of peer down
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_pfx_wdraw_discarded
                                
                                	Total bmpQ wdraw pfxes discarded because of peer down
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_per_peer_msg_route_mon_count
                                
                                	Total number of per peer route mon messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmpr_mon_update_gen_time
                                
                                	Time spent in update generation(milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bmpr_mon_eo_rmessages
                                
                                	Total bmpQ EOR update msgs 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_rmon_cur_buffer_size
                                
                                	Current Buffer usage per BMP Route Mon
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_maximum_buffer_size_route_mon
                                
                                	Buffer limit used for route mon
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bmp_server_up_count
                                
                                	Number of BMP server that are UP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bmp_upd_gen_in_progress
                                
                                	Update generation in progress
                                	**type**\: bool
                                
                                .. attribute:: bmp_reset_walk_in_progress
                                
                                	Reset walk in progress
                                	**type**\: bool
                                
                                .. attribute:: bmpafi_info
                                
                                	AFI specific info for BMP server
                                	**type**\: list of  		 :py:class:`BmpafiInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary, self).__init__()

                                    self.yang_name = "server-summary"
                                    self.yang_parent_name = "server-summaries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['server_id']
                                    self._child_classes = OrderedDict([("bmp-server-state-age", ("bmp_server_state_age", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge)), ("bmp-server-state-time-spec", ("bmp_server_state_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec)), ("bmp-server-last-discon-time", ("bmp_server_last_discon_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime)), ("update-source-address", ("update_source_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress)), ("bmpafi-info", ("bmpafi_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo))])
                                    self._leafs = OrderedDict([
                                        ('server_id', (YLeaf(YType.uint32, 'server-id'), ['int'])),
                                        ('bmp_server_id', (YLeaf(YType.uint8, 'bmp-server-id'), ['int'])),
                                        ('bmp_server_host_name', (YLeaf(YType.str, 'bmp-server-host-name'), ['str'])),
                                        ('bmp_server_port', (YLeaf(YType.uint32, 'bmp-server-port'), ['int'])),
                                        ('bmp_server_state', (YLeaf(YType.enumeration, 'bmp-server-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBmpState', '')])),
                                        ('bmp_server_is_flapping', (YLeaf(YType.boolean, 'bmp-server-is-flapping'), ['bool'])),
                                        ('bmp_server_nbr_count', (YLeaf(YType.uint32, 'bmp-server-nbr-count'), ['int'])),
                                        ('bmp_init_msg_count', (YLeaf(YType.uint32, 'bmp-init-msg-count'), ['int'])),
                                        ('bmp_termination_msg_count', (YLeaf(YType.uint32, 'bmp-termination-msg-count'), ['int'])),
                                        ('bmp_status_report_count', (YLeaf(YType.uint32, 'bmp-status-report-count'), ['int'])),
                                        ('bmp_per_peer_msg_count', (YLeaf(YType.uint32, 'bmp-per-peer-msg-count'), ['int'])),
                                        ('bmp_peer_msg_drop_count', (YLeaf(YType.uint32, 'bmp-peer-msg-drop-count'), ['int'])),
                                        ('bmp_peer_msg_pending_count', (YLeaf(YType.uint32, 'bmp-peer-msg-pending-count'), ['int'])),
                                        ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                        ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                        ('update_source_interface_name', (YLeaf(YType.str, 'update-source-interface-name'), ['str'])),
                                        ('update_source_vrf_id', (YLeaf(YType.uint32, 'update-source-vrf-id'), ['int'])),
                                        ('bmp_vrf_name', (YLeaf(YType.str, 'bmp-vrf-name'), ['str'])),
                                        ('bmp_vrf_id', (YLeaf(YType.uint32, 'bmp-vrf-id'), ['int'])),
                                        ('bmp_update_mode', (YLeaf(YType.enumeration, 'bmp-update-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBmpUpdMode', '')])),
                                        ('tcp_keep_alive_interval', (YLeaf(YType.uint32, 'tcp-keep-alive-interval'), ['int'])),
                                        ('tcp_maximum_segment_size', (YLeaf(YType.uint32, 'tcp-maximum-segment-size'), ['int'])),
                                        ('tcp_write_cb_pending', (YLeaf(YType.uint32, 'tcp-write-cb-pending'), ['int'])),
                                        ('tcp_last_write_result', (YLeaf(YType.uint32, 'tcp-last-write-result'), ['int'])),
                                        ('tcp_last_write_cb_time', (YLeaf(YType.uint64, 'tcp-last-write-cb-time'), ['int'])),
                                        ('tcp_last_write_time', (YLeaf(YType.uint64, 'tcp-last-write-time'), ['int'])),
                                        ('bmpq_last_write_pulse_sent_time', (YLeaf(YType.uint64, 'bmpq-last-write-pulse-sent-time'), ['int'])),
                                        ('bmpq_last_all_write_pulse_sent_time', (YLeaf(YType.uint64, 'bmpq-last-all-write-pulse-sent-time'), ['int'])),
                                        ('bmpq_last_write_pulse_cb_time', (YLeaf(YType.uint64, 'bmpq-last-write-pulse-cb-time'), ['int'])),
                                        ('path_update_count', (YLeaf(YType.uint32, 'path-update-count'), ['int'])),
                                        ('path_withdraw_count', (YLeaf(YType.uint32, 'path-withdraw-count'), ['int'])),
                                        ('path_update_drop', (YLeaf(YType.uint32, 'path-update-drop'), ['int'])),
                                        ('path_withdraw_drop', (YLeaf(YType.uint32, 'path-withdraw-drop'), ['int'])),
                                        ('bmp_peer_msg_pending_count_max', (YLeaf(YType.uint32, 'bmp-peer-msg-pending-count-max'), ['int'])),
                                        ('bmp_peer_msg_pending_count_hwts', (YLeaf(YType.uint64, 'bmp-peer-msg-pending-count-hwts'), ['int'])),
                                        ('bmp_bytes_written_tcp', (YLeaf(YType.uint64, 'bmp-bytes-written-tcp'), ['int'])),
                                        ('tcp_write_time', (YLeaf(YType.uint32, 'tcp-write-time'), ['int'])),
                                        ('bmpr_mon_upd_messages', (YLeaf(YType.uint32, 'bmpr-mon-upd-messages'), ['int'])),
                                        ('bmpr_mon_wdraw_messages', (YLeaf(YType.uint32, 'bmpr-mon-wdraw-messages'), ['int'])),
                                        ('bmp_messages_wdraw_discarded', (YLeaf(YType.uint32, 'bmp-messages-wdraw-discarded'), ['int'])),
                                        ('bmp_pfx_wdraw_discarded', (YLeaf(YType.uint32, 'bmp-pfx-wdraw-discarded'), ['int'])),
                                        ('bmp_per_peer_msg_route_mon_count', (YLeaf(YType.uint32, 'bmp-per-peer-msg-route-mon-count'), ['int'])),
                                        ('bmpr_mon_update_gen_time', (YLeaf(YType.uint32, 'bmpr-mon-update-gen-time'), ['int'])),
                                        ('bmpr_mon_eo_rmessages', (YLeaf(YType.uint32, 'bmpr-mon-eo-rmessages'), ['int'])),
                                        ('bmp_rmon_cur_buffer_size', (YLeaf(YType.uint64, 'bmp-rmon-cur-buffer-size'), ['int'])),
                                        ('bmp_maximum_buffer_size_route_mon', (YLeaf(YType.uint64, 'bmp-maximum-buffer-size-route-mon'), ['int'])),
                                        ('bmp_server_up_count', (YLeaf(YType.uint32, 'bmp-server-up-count'), ['int'])),
                                        ('bmp_upd_gen_in_progress', (YLeaf(YType.boolean, 'bmp-upd-gen-in-progress'), ['bool'])),
                                        ('bmp_reset_walk_in_progress', (YLeaf(YType.boolean, 'bmp-reset-walk-in-progress'), ['bool'])),
                                    ])
                                    self.server_id = None
                                    self.bmp_server_id = None
                                    self.bmp_server_host_name = None
                                    self.bmp_server_port = None
                                    self.bmp_server_state = None
                                    self.bmp_server_is_flapping = None
                                    self.bmp_server_nbr_count = None
                                    self.bmp_init_msg_count = None
                                    self.bmp_termination_msg_count = None
                                    self.bmp_status_report_count = None
                                    self.bmp_per_peer_msg_count = None
                                    self.bmp_peer_msg_drop_count = None
                                    self.bmp_peer_msg_pending_count = None
                                    self.tos_type = None
                                    self.tos_value = None
                                    self.update_source_interface_name = None
                                    self.update_source_vrf_id = None
                                    self.bmp_vrf_name = None
                                    self.bmp_vrf_id = None
                                    self.bmp_update_mode = None
                                    self.tcp_keep_alive_interval = None
                                    self.tcp_maximum_segment_size = None
                                    self.tcp_write_cb_pending = None
                                    self.tcp_last_write_result = None
                                    self.tcp_last_write_cb_time = None
                                    self.tcp_last_write_time = None
                                    self.bmpq_last_write_pulse_sent_time = None
                                    self.bmpq_last_all_write_pulse_sent_time = None
                                    self.bmpq_last_write_pulse_cb_time = None
                                    self.path_update_count = None
                                    self.path_withdraw_count = None
                                    self.path_update_drop = None
                                    self.path_withdraw_drop = None
                                    self.bmp_peer_msg_pending_count_max = None
                                    self.bmp_peer_msg_pending_count_hwts = None
                                    self.bmp_bytes_written_tcp = None
                                    self.tcp_write_time = None
                                    self.bmpr_mon_upd_messages = None
                                    self.bmpr_mon_wdraw_messages = None
                                    self.bmp_messages_wdraw_discarded = None
                                    self.bmp_pfx_wdraw_discarded = None
                                    self.bmp_per_peer_msg_route_mon_count = None
                                    self.bmpr_mon_update_gen_time = None
                                    self.bmpr_mon_eo_rmessages = None
                                    self.bmp_rmon_cur_buffer_size = None
                                    self.bmp_maximum_buffer_size_route_mon = None
                                    self.bmp_server_up_count = None
                                    self.bmp_upd_gen_in_progress = None
                                    self.bmp_reset_walk_in_progress = None

                                    self.bmp_server_state_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge()
                                    self.bmp_server_state_age.parent = self
                                    self._children_name_map["bmp_server_state_age"] = "bmp-server-state-age"

                                    self.bmp_server_state_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec()
                                    self.bmp_server_state_time_spec.parent = self
                                    self._children_name_map["bmp_server_state_time_spec"] = "bmp-server-state-time-spec"

                                    self.bmp_server_last_discon_time = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime()
                                    self.bmp_server_last_discon_time.parent = self
                                    self._children_name_map["bmp_server_last_discon_time"] = "bmp-server-last-discon-time"

                                    self.update_source_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress()
                                    self.update_source_address.parent = self
                                    self._children_name_map["update_source_address"] = "update-source-address"

                                    self.bmpafi_info = YList(self)
                                    self._segment_path = lambda: "server-summary" + "[server-id='" + str(self.server_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary, ['server_id', u'bmp_server_id', u'bmp_server_host_name', u'bmp_server_port', u'bmp_server_state', u'bmp_server_is_flapping', u'bmp_server_nbr_count', u'bmp_init_msg_count', u'bmp_termination_msg_count', u'bmp_status_report_count', u'bmp_per_peer_msg_count', u'bmp_peer_msg_drop_count', u'bmp_peer_msg_pending_count', u'tos_type', u'tos_value', u'update_source_interface_name', u'update_source_vrf_id', u'bmp_vrf_name', u'bmp_vrf_id', u'bmp_update_mode', u'tcp_keep_alive_interval', u'tcp_maximum_segment_size', u'tcp_write_cb_pending', u'tcp_last_write_result', u'tcp_last_write_cb_time', u'tcp_last_write_time', u'bmpq_last_write_pulse_sent_time', u'bmpq_last_all_write_pulse_sent_time', u'bmpq_last_write_pulse_cb_time', u'path_update_count', u'path_withdraw_count', u'path_update_drop', u'path_withdraw_drop', u'bmp_peer_msg_pending_count_max', u'bmp_peer_msg_pending_count_hwts', u'bmp_bytes_written_tcp', u'tcp_write_time', u'bmpr_mon_upd_messages', u'bmpr_mon_wdraw_messages', u'bmp_messages_wdraw_discarded', u'bmp_pfx_wdraw_discarded', u'bmp_per_peer_msg_route_mon_count', u'bmpr_mon_update_gen_time', u'bmpr_mon_eo_rmessages', u'bmp_rmon_cur_buffer_size', u'bmp_maximum_buffer_size_route_mon', u'bmp_server_up_count', u'bmp_upd_gen_in_progress', u'bmp_reset_walk_in_progress'], name, value)


                                class BmpServerStateAge(Entity):
                                    """
                                    Age of current state of BMP Server
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, self).__init__()

                                        self.yang_name = "bmp-server-state-age"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-server-state-age"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateAge, [u'seconds', u'nanoseconds'], name, value)


                                class BmpServerStateTimeSpec(Entity):
                                    """
                                    Timespec of current state of BMP Server
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, self).__init__()

                                        self.yang_name = "bmp-server-state-time-spec"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-server-state-time-spec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerStateTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class BmpServerLastDisconTime(Entity):
                                    """
                                    Timespec of Last Disconnect event received from
                                    BMP server
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, self).__init__()

                                        self.yang_name = "bmp-server-last-discon-time"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "bmp-server-last-discon-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpServerLastDisconTime, [u'seconds', u'nanoseconds'], name, value)


                                class UpdateSourceAddress(Entity):
                                    """
                                    Address of Interface configured as Update Source
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, self).__init__()

                                        self.yang_name = "update-source-address"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "update-source-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "update-source-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.UpdateSourceAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class BmpafiInfo(Entity):
                                    """
                                    AFI specific info for BMP server
                                    
                                    .. attribute:: bmp_resume_prefix
                                    
                                    	BMP Resume prefix
                                    	**type**\:  :py:class:`BmpResumePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix>`
                                    
                                    .. attribute:: bmp_filter_neighbor_address
                                    
                                    	Filter Neighbor Address
                                    	**type**\:  :py:class:`BmpFilterNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress>`
                                    
                                    .. attribute:: bmpaf_name
                                    
                                    	BMP Address family identifier
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: bmp_resume_prefix_len
                                    
                                    	BMP Resume prefix Len
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_resume_start_version
                                    
                                    	Update Gen ResumeWalk start version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_resume_end_version
                                    
                                    	Update Gen ResumeWalk end version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_walk_stopped
                                    
                                    	Update Gen WalkStopped
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_upd_gen_resume_net_version
                                    
                                    	Update Gen ResumeWalk Net version
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_upd_gen_walk_run_time_stamp
                                    
                                    	Last Update Gen Run time stamp
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_run_count
                                    
                                    	Number of times Update Gen ran
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_stop_time_stamp
                                    
                                    	Last Update Gen Stop time stamp
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_upd_gen_walk_stop_count
                                    
                                    	Number of times Update Gen Stopped
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bmp_init_eor_end_version
                                    
                                    	Version to reach to send EOR
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_init_eor_pending_cnt
                                    
                                    	Count for pending EOR
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_filter_neighbor_address_set
                                    
                                    	Filter Neighbor Address Set ?
                                    	**type**\: bool
                                    
                                    .. attribute:: bmp_filter_nbr_cnt
                                    
                                    	Filter nbr Count for this AFI
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bmp_send_version
                                    
                                    	Table Version that this BMP server has caught upto
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, self).__init__()

                                        self.yang_name = "bmpafi-info"
                                        self.yang_parent_name = "server-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("bmp-resume-prefix", ("bmp_resume_prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix)), ("bmp-filter-neighbor-address", ("bmp_filter_neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress))])
                                        self._leafs = OrderedDict([
                                            ('bmpaf_name', (YLeaf(YType.enumeration, 'bmpaf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('bmp_resume_prefix_len', (YLeaf(YType.uint32, 'bmp-resume-prefix-len'), ['int'])),
                                            ('bmp_upd_gen_resume_start_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-start-version'), ['int'])),
                                            ('bmp_upd_gen_resume_end_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-end-version'), ['int'])),
                                            ('bmp_upd_gen_walk_stopped', (YLeaf(YType.boolean, 'bmp-upd-gen-walk-stopped'), ['bool'])),
                                            ('bmp_upd_gen_resume_net_version', (YLeaf(YType.uint32, 'bmp-upd-gen-resume-net-version'), ['int'])),
                                            ('bmp_upd_gen_walk_run_time_stamp', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-run-time-stamp'), ['int'])),
                                            ('bmp_upd_gen_walk_run_count', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-run-count'), ['int'])),
                                            ('bmp_upd_gen_walk_stop_time_stamp', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-stop-time-stamp'), ['int'])),
                                            ('bmp_upd_gen_walk_stop_count', (YLeaf(YType.uint64, 'bmp-upd-gen-walk-stop-count'), ['int'])),
                                            ('bmp_init_eor_end_version', (YLeaf(YType.uint32, 'bmp-init-eor-end-version'), ['int'])),
                                            ('bmp_init_eor_pending_cnt', (YLeaf(YType.uint32, 'bmp-init-eor-pending-cnt'), ['int'])),
                                            ('bmp_filter_neighbor_address_set', (YLeaf(YType.boolean, 'bmp-filter-neighbor-address-set'), ['bool'])),
                                            ('bmp_filter_nbr_cnt', (YLeaf(YType.uint32, 'bmp-filter-nbr-cnt'), ['int'])),
                                            ('bmp_send_version', (YLeaf(YType.uint32, 'bmp-send-version'), ['int'])),
                                        ])
                                        self.bmpaf_name = None
                                        self.bmp_resume_prefix_len = None
                                        self.bmp_upd_gen_resume_start_version = None
                                        self.bmp_upd_gen_resume_end_version = None
                                        self.bmp_upd_gen_walk_stopped = None
                                        self.bmp_upd_gen_resume_net_version = None
                                        self.bmp_upd_gen_walk_run_time_stamp = None
                                        self.bmp_upd_gen_walk_run_count = None
                                        self.bmp_upd_gen_walk_stop_time_stamp = None
                                        self.bmp_upd_gen_walk_stop_count = None
                                        self.bmp_init_eor_end_version = None
                                        self.bmp_init_eor_pending_cnt = None
                                        self.bmp_filter_neighbor_address_set = None
                                        self.bmp_filter_nbr_cnt = None
                                        self.bmp_send_version = None

                                        self.bmp_resume_prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix()
                                        self.bmp_resume_prefix.parent = self
                                        self._children_name_map["bmp_resume_prefix"] = "bmp-resume-prefix"

                                        self.bmp_filter_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress()
                                        self.bmp_filter_neighbor_address.parent = self
                                        self._children_name_map["bmp_filter_neighbor_address"] = "bmp-filter-neighbor-address"
                                        self._segment_path = lambda: "bmpafi-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo, [u'bmpaf_name', u'bmp_resume_prefix_len', u'bmp_upd_gen_resume_start_version', u'bmp_upd_gen_resume_end_version', u'bmp_upd_gen_walk_stopped', u'bmp_upd_gen_resume_net_version', u'bmp_upd_gen_walk_run_time_stamp', u'bmp_upd_gen_walk_run_count', u'bmp_upd_gen_walk_stop_time_stamp', u'bmp_upd_gen_walk_stop_count', u'bmp_init_eor_end_version', u'bmp_init_eor_pending_cnt', u'bmp_filter_neighbor_address_set', u'bmp_filter_nbr_cnt', u'bmp_send_version'], name, value)


                                    class BmpResumePrefix(Entity):
                                        """
                                        BMP Resume prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix>`
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, self).__init__()

                                            self.yang_name = "bmp-resume-prefix"
                                            self.yang_parent_name = "bmpafi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix", ("prefix", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('prefix_length', (YLeaf(YType.uint16, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix_length = None

                                            self.prefix = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix()
                                            self.prefix.parent = self
                                            self._children_name_map["prefix"] = "prefix"
                                            self._segment_path = lambda: "bmp-resume-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix, [u'prefix_length'], name, value)


                                        class Prefix(Entity):
                                            """
                                            Prefix
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "bmp-resume-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpResumePrefix.Prefix.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                    class BmpFilterNeighborAddress(Entity):
                                        """
                                        Filter Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, self).__init__()

                                            self.yang_name = "bmp-filter-neighbor-address"
                                            self.yang_parent_name = "bmpafi-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "bmp-filter-neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "bmp-filter-neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerSummaries.ServerSummary.BmpafiInfo.BmpFilterNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                        class ServerNeighbors(Entity):
                            """
                            Table of Neighbors for a BMP Server
                            
                            .. attribute:: server_neighbor
                            
                            	BMP Server under which neighbor info are needed
                            	**type**\: list of  		 :py:class:`ServerNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors, self).__init__()

                                self.yang_name = "server-neighbors"
                                self.yang_parent_name = "bmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("server-neighbor", ("server_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor))])
                                self._leafs = OrderedDict()

                                self.server_neighbor = YList(self)
                                self._segment_path = lambda: "server-neighbors"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors, [], name, value)


                            class ServerNeighbor(Entity):
                                """
                                BMP Server under which neighbor info are
                                needed
                                
                                .. attribute:: server_id  (key)
                                
                                	BMP Server ID
                                	**type**\: int
                                
                                	**range:** 1..8
                                
                                .. attribute:: monitored_neighbors
                                
                                	List of Neighbors under which BMP Server is confgiured
                                	**type**\:  :py:class:`MonitoredNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor, self).__init__()

                                    self.yang_name = "server-neighbor"
                                    self.yang_parent_name = "server-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['server_id']
                                    self._child_classes = OrderedDict([("monitored-neighbors", ("monitored_neighbors", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors))])
                                    self._leafs = OrderedDict([
                                        ('server_id', (YLeaf(YType.uint32, 'server-id'), ['int'])),
                                    ])
                                    self.server_id = None

                                    self.monitored_neighbors = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors()
                                    self.monitored_neighbors.parent = self
                                    self._children_name_map["monitored_neighbors"] = "monitored-neighbors"
                                    self._segment_path = lambda: "server-neighbor" + "[server-id='" + str(self.server_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor, ['server_id'], name, value)


                                class MonitoredNeighbors(Entity):
                                    """
                                    List of Neighbors under which BMP Server is
                                    confgiured
                                    
                                    .. attribute:: monitored_neighbor
                                    
                                    	Information about a neighbor monitored by BMP server
                                    	**type**\: list of  		 :py:class:`MonitoredNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, self).__init__()

                                        self.yang_name = "monitored-neighbors"
                                        self.yang_parent_name = "server-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("monitored-neighbor", ("monitored_neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor))])
                                        self._leafs = OrderedDict()

                                        self.monitored_neighbor = YList(self)
                                        self._segment_path = lambda: "monitored-neighbors"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors, [], name, value)


                                    class MonitoredNeighbor(Entity):
                                        """
                                        Information about a neighbor monitored by
                                        BMP server
                                        
                                        .. attribute:: neighbor_address  (key)
                                        
                                        	Neighbor address
                                        	**type**\: union of the below types:
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        		**type**\: str
                                        
                                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: bmp_neighbor_address
                                        
                                        	Address of Nbr that logs to BMP server
                                        	**type**\:  :py:class:`BmpNeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress>`
                                        
                                        .. attribute:: bmp_neighbor_msg_pending
                                        
                                        	Number of messages pending to be sent to BMP Server from this Neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_msg_dropped
                                        
                                        	Number of messages dropped sent from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_up_sent
                                        
                                        	Number of Peer UP Messages sent from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_peer_down_sent
                                        
                                        	Number of Peer DOWN Messages sent from this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_route_monitor_sent
                                        
                                        	Number of Route Monitor Messages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_route_monitor_eor_sent
                                        
                                        	Number of Route Monitor EOR Messages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_sent
                                        
                                        	Number of Path UpdateMessages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_sent
                                        
                                        	Number of Path WithdrawMessages sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_update_drop
                                        
                                        	Number of path update drop 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_path_withdraw_drop
                                        
                                        	Number of path wdraw drop 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_upd_msg_sent
                                        
                                        	Number of update message sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bmp_neighbor_wdraw_msg_sent
                                        
                                        	Number of withdraw message sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, self).__init__()

                                            self.yang_name = "monitored-neighbor"
                                            self.yang_parent_name = "monitored-neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['neighbor_address']
                                            self._child_classes = OrderedDict([("bmp-neighbor-address", ("bmp_neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress))])
                                            self._leafs = OrderedDict([
                                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                                ('bmp_neighbor_msg_pending', (YLeaf(YType.uint32, 'bmp-neighbor-msg-pending'), ['int'])),
                                                ('bmp_neighbor_msg_dropped', (YLeaf(YType.uint32, 'bmp-neighbor-msg-dropped'), ['int'])),
                                                ('bmp_neighbor_peer_up_sent', (YLeaf(YType.uint32, 'bmp-neighbor-peer-up-sent'), ['int'])),
                                                ('bmp_neighbor_peer_down_sent', (YLeaf(YType.uint32, 'bmp-neighbor-peer-down-sent'), ['int'])),
                                                ('bmp_neighbor_route_monitor_sent', (YLeaf(YType.uint32, 'bmp-neighbor-route-monitor-sent'), ['int'])),
                                                ('bmp_neighbor_route_monitor_eor_sent', (YLeaf(YType.uint32, 'bmp-neighbor-route-monitor-eor-sent'), ['int'])),
                                                ('bmp_neighbor_path_update_sent', (YLeaf(YType.uint32, 'bmp-neighbor-path-update-sent'), ['int'])),
                                                ('bmp_neighbor_path_withdraw_sent', (YLeaf(YType.uint32, 'bmp-neighbor-path-withdraw-sent'), ['int'])),
                                                ('bmp_neighbor_path_update_drop', (YLeaf(YType.uint32, 'bmp-neighbor-path-update-drop'), ['int'])),
                                                ('bmp_neighbor_path_withdraw_drop', (YLeaf(YType.uint32, 'bmp-neighbor-path-withdraw-drop'), ['int'])),
                                                ('bmp_neighbor_upd_msg_sent', (YLeaf(YType.uint32, 'bmp-neighbor-upd-msg-sent'), ['int'])),
                                                ('bmp_neighbor_wdraw_msg_sent', (YLeaf(YType.uint32, 'bmp-neighbor-wdraw-msg-sent'), ['int'])),
                                            ])
                                            self.neighbor_address = None
                                            self.bmp_neighbor_msg_pending = None
                                            self.bmp_neighbor_msg_dropped = None
                                            self.bmp_neighbor_peer_up_sent = None
                                            self.bmp_neighbor_peer_down_sent = None
                                            self.bmp_neighbor_route_monitor_sent = None
                                            self.bmp_neighbor_route_monitor_eor_sent = None
                                            self.bmp_neighbor_path_update_sent = None
                                            self.bmp_neighbor_path_withdraw_sent = None
                                            self.bmp_neighbor_path_update_drop = None
                                            self.bmp_neighbor_path_withdraw_drop = None
                                            self.bmp_neighbor_upd_msg_sent = None
                                            self.bmp_neighbor_wdraw_msg_sent = None

                                            self.bmp_neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress()
                                            self.bmp_neighbor_address.parent = self
                                            self._children_name_map["bmp_neighbor_address"] = "bmp-neighbor-address"
                                            self._segment_path = lambda: "monitored-neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor, ['neighbor_address', u'bmp_neighbor_msg_pending', u'bmp_neighbor_msg_dropped', u'bmp_neighbor_peer_up_sent', u'bmp_neighbor_peer_down_sent', u'bmp_neighbor_route_monitor_sent', u'bmp_neighbor_route_monitor_eor_sent', u'bmp_neighbor_path_update_sent', u'bmp_neighbor_path_withdraw_sent', u'bmp_neighbor_path_update_drop', u'bmp_neighbor_path_withdraw_drop', u'bmp_neighbor_upd_msg_sent', u'bmp_neighbor_wdraw_msg_sent'], name, value)


                                        class BmpNeighborAddress(Entity):
                                            """
                                            Address of Nbr that logs to BMP server
                                            
                                            .. attribute:: l2vpn_vpls_address
                                            
                                            	L2VPN VPLS Addr
                                            	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress>`
                                            
                                            .. attribute:: l2vpn_mspw_address
                                            
                                            	L2VPN MSPW Addr
                                            	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress>`
                                            
                                            .. attribute:: ipv4_sr_policy_address
                                            
                                            	IPV4 Policy Addr
                                            	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress>`
                                            
                                            .. attribute:: ipv6_sr_policy_address
                                            
                                            	IPV6 Policy Addr
                                            	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress>`
                                            
                                            .. attribute:: afi
                                            
                                            	AFI
                                            	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_mcast_address
                                            
                                            	IPv4 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_label_address
                                            
                                            	IPv4 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_tunnel_address
                                            
                                            	IPv4 Tunnel
                                            	**type**\: str
                                            
                                            	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4_mdt_address
                                            
                                            	IPv4 MDT Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                            
                                            .. attribute:: ipv4vpn_address
                                            
                                            	IPv4 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4vpna_mcastddress
                                            
                                            	IPv4 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPV6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_mcast_address
                                            
                                            	IPV6 Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_label_address
                                            
                                            	IPv6 Label Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_address
                                            
                                            	IPv6 VPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6vpn_mcast_address
                                            
                                            	IPv6 VPN Mcast Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rt_constraint_address
                                            
                                            	RT Constrt Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{24}
                                            
                                            .. attribute:: ipv6mvpn_address
                                            
                                            	MVPN addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{104}
                                            
                                            .. attribute:: ipv4mvpn_address
                                            
                                            	MVPN4 addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{56}
                                            
                                            .. attribute:: l2vpn_evpn_address
                                            
                                            	L2VPN EVPN Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{58}
                                            
                                            .. attribute:: ls_ls_address
                                            
                                            	LINKSTATE LINKSTATE Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]+
                                            
                                            .. attribute:: ipv4_flowspec_address
                                            
                                            	IPV4 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6_flowspec_address
                                            
                                            	IPV6 Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv4vpn_flowspec_address
                                            
                                            	IPV4 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            .. attribute:: ipv6vpn_flowspec_address
                                            
                                            	IPV6 VPN Flowspec Addr
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4096}
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, self).__init__()

                                                self.yang_name = "bmp-neighbor-address"
                                                self.yang_parent_name = "monitored-neighbor"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress))])
                                                self._leafs = OrderedDict([
                                                    ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                    ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                    ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                    ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                    ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                    ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                    ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                    ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                    ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                    ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                    ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                    ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                    ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                    ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                    ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                    ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                    ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                    ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                    ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                                ])
                                                self.afi = None
                                                self.ipv4_address = None
                                                self.ipv4_mcast_address = None
                                                self.ipv4_label_address = None
                                                self.ipv4_tunnel_address = None
                                                self.ipv4_mdt_address = None
                                                self.ipv4vpn_address = None
                                                self.ipv4vpna_mcastddress = None
                                                self.ipv6_address = None
                                                self.ipv6_mcast_address = None
                                                self.ipv6_label_address = None
                                                self.ipv6vpn_address = None
                                                self.ipv6vpn_mcast_address = None
                                                self.rt_constraint_address = None
                                                self.ipv6mvpn_address = None
                                                self.ipv4mvpn_address = None
                                                self.l2vpn_evpn_address = None
                                                self.ls_ls_address = None
                                                self.ipv4_flowspec_address = None
                                                self.ipv6_flowspec_address = None
                                                self.ipv4vpn_flowspec_address = None
                                                self.ipv6vpn_flowspec_address = None

                                                self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress()
                                                self.l2vpn_vpls_address.parent = self
                                                self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                                self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress()
                                                self.l2vpn_mspw_address.parent = self
                                                self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                                self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress()
                                                self.ipv4_sr_policy_address.parent = self
                                                self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                                self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress()
                                                self.ipv6_sr_policy_address.parent = self
                                                self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                                self._segment_path = lambda: "bmp-neighbor-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                            class L2vpnVplsAddress(Entity):
                                                """
                                                L2VPN VPLS Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress, self).__init__()

                                                    self.yang_name = "l2vpn-vpls-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-vpls-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                            class L2vpnMspwAddress(Entity):
                                                """
                                                L2VPN MSPW Addr
                                                
                                                .. attribute:: l2vpn_address
                                                
                                                	l2vpn address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress, self).__init__()

                                                    self.yang_name = "l2vpn-mspw-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                    ])
                                                    self.l2vpn_address = None
                                                    self._segment_path = lambda: "l2vpn-mspw-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                            class Ipv4SrPolicyAddress(Entity):
                                                """
                                                IPV4 Policy Addr
                                                
                                                .. attribute:: ipv4_srpolicy_address
                                                
                                                	ipv4 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv4-sr-policy-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv4_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv4-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                            class Ipv6SrPolicyAddress(Entity):
                                                """
                                                IPV6 Policy Addr
                                                
                                                .. attribute:: ipv6_srpolicy_address
                                                
                                                	ipv6 srpolicy address
                                                	**type**\: str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                    self.yang_name = "ipv6-sr-policy-address"
                                                    self.yang_parent_name = "bmp-neighbor-address"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                    ])
                                                    self.ipv6_srpolicy_address = None
                                                    self._segment_path = lambda: "ipv6-sr-policy-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Bmp.ServerNeighbors.ServerNeighbor.MonitoredNeighbors.MonitoredNeighbor.BmpNeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                    class ProcessInfo(Entity):
                        """
                        A Process instance table entry
                        
                        .. attribute:: global_
                        
                        	Global information
                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global>`
                        
                        .. attribute:: vrf
                        
                        	VRF information
                        	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf>`
                        
                        .. attribute:: performance_statistics
                        
                        	Performance statistics
                        	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics>`
                        
                        .. attribute:: process_instance
                        
                        	ID for the BGP process instance
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: vrf_name
                        
                        	Name of the VRF
                        	**type**\: str
                        
                        .. attribute:: vrf_totals
                        
                        	per VRF counts aggregated across all VRFs
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo, self).__init__()

                            self.yang_name = "process-info"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics))])
                            self._leafs = OrderedDict([
                                ('process_instance', (YLeaf(YType.uint8, 'process-instance'), ['int'])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('vrf_totals', (YLeaf(YType.boolean, 'vrf-totals'), ['bool'])),
                            ])
                            self.process_instance = None
                            self.vrf_name = None
                            self.vrf_totals = None

                            self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"

                            self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf()
                            self.vrf.parent = self
                            self._children_name_map["vrf"] = "vrf"

                            self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics()
                            self.performance_statistics.parent = self
                            self._children_name_map["performance_statistics"] = "performance-statistics"
                            self._segment_path = lambda: "process-info"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo, [u'process_instance', u'vrf_name', u'vrf_totals'], name, value)


                        class Global(Entity):
                            """
                            Global information
                            
                            .. attribute:: process_instance_node
                            
                            	Node the process instance is on
                            	**type**\: str
                            
                            .. attribute:: restart_count
                            
                            	No. of times BGP has started
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_attributes_entry_count
                            
                            	No. of path attribute entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_attribute_memory
                            
                            	Memory (bytes) used by path attribute entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: as_path_entry_count
                            
                            	Number of AS\-path entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_path_entries_memory
                            
                            	Memory (in bytes) used by AS\-path entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: community_entry_count
                            
                            	Number of community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: community_memory
                            
                            	Memory (in bytes) used by community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: extended_community_entry_count
                            
                            	Number of extended community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_memory
                            
                            	Memory (in bytes) used by extended community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: pe_distinguisher_label_entry_count
                            
                            	Number of PE distinguisher label entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pe_distinguisher_label_memory
                            
                            	Memory (in bytes) used by PE distinguisher labels entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: pta_entry_count
                            
                            	Number of PTA entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pta_memory
                            
                            	Memory (in bytes) used by PTA entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: tunnel_encap_entry_count
                            
                            	Number of Tunnel encap entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_encap_memory
                            
                            	Memory (in bytes) used by tunnel encap entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: ribrnh_entry_count
                            
                            	Number of RIBRNH entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_memory
                            
                            	Memory (in bytes) used by RIBRNH entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: ppmp_entry_count
                            
                            	Number of PPMP entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ppmp_memory
                            
                            	Memory (in bytes) used by PPMP entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: route_reflectors
                            
                            	Number of route reflector info entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_reflector_memory
                            
                            	Memory (in bytes) used by route reflector info entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: nexthop_count
                            
                            	Number of nexthop attribute info entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nexthop_memory
                            
                            	Memory (in bytes) used by nexthop attribute info entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: lsattr_entry_count
                            
                            	Number of LASATTR entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsattr_memory
                            
                            	Memory (in bytes) used by LSATTR entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: attr_set_entry_count
                            
                            	Number of ATTRSET entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attr_set_memory
                            
                            	Memory (in bytes) used by ATTRSET entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: lindex_entry_count
                            
                            	Number of LINDEX entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lindex_memory
                            
                            	Memory (in bytes) used by LINDEX entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: local_as
                            
                            	Local autonomous system number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_vrf_count
                            
                            	total vrf count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbors_count_total
                            
                            	Total number of neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: established_neighbors_count_total
                            
                            	Total umber of established neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs
                            
                            	sn num non dflt vrf nbrs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sn_num_non_dflt_vrf_nbrs_estab
                            
                            	sn num non dflt vrf nbrs estab
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: large_community_entry_count
                            
                            	Number of large community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: large_community_memory
                            
                            	Memory (in bytes) used by large community entries
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: pool_size
                            
                            	pool size
                            	**type**\: list of  		 :py:class:`PoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolSize>`
                            
                            .. attribute:: pool_alloc_count
                            
                            	pool alloc count
                            	**type**\: list of  		 :py:class:`PoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolAllocCount>`
                            
                            .. attribute:: pool_free_count
                            
                            	pool free count
                            	**type**\: list of  		 :py:class:`PoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolFreeCount>`
                            
                            .. attribute:: msg_log_pool_size
                            
                            	msg log pool size
                            	**type**\: list of  		 :py:class:`MsgLogPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolSize>`
                            
                            .. attribute:: msg_log_pool_alloc_count
                            
                            	msg log pool alloc count
                            	**type**\: list of  		 :py:class:`MsgLogPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolAllocCount>`
                            
                            .. attribute:: msg_log_pool_free_count
                            
                            	msg log pool free count
                            	**type**\: list of  		 :py:class:`MsgLogPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolFreeCount>`
                            
                            .. attribute:: bmp_pool_size
                            
                            	bmp pool size
                            	**type**\: list of  		 :py:class:`BmpPoolSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolSize>`
                            
                            .. attribute:: bmp_pool_alloc_count
                            
                            	bmp pool alloc count
                            	**type**\: list of  		 :py:class:`BmpPoolAllocCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolAllocCount>`
                            
                            .. attribute:: bmp_pool_free_count
                            
                            	bmp pool free count
                            	**type**\: list of  		 :py:class:`BmpPoolFreeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolFreeCount>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pool-size", ("pool_size", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolSize)), ("pool-alloc-count", ("pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolAllocCount)), ("pool-free-count", ("pool_free_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolFreeCount)), ("msg-log-pool-size", ("msg_log_pool_size", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolSize)), ("msg-log-pool-alloc-count", ("msg_log_pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolAllocCount)), ("msg-log-pool-free-count", ("msg_log_pool_free_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolFreeCount)), ("bmp-pool-size", ("bmp_pool_size", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolSize)), ("bmp-pool-alloc-count", ("bmp_pool_alloc_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolAllocCount)), ("bmp-pool-free-count", ("bmp_pool_free_count", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolFreeCount))])
                                self._leafs = OrderedDict([
                                    ('process_instance_node', (YLeaf(YType.str, 'process-instance-node'), ['str'])),
                                    ('restart_count', (YLeaf(YType.uint32, 'restart-count'), ['int'])),
                                    ('path_attributes_entry_count', (YLeaf(YType.uint32, 'path-attributes-entry-count'), ['int'])),
                                    ('path_attribute_memory', (YLeaf(YType.uint32, 'path-attribute-memory'), ['int'])),
                                    ('as_path_entry_count', (YLeaf(YType.uint32, 'as-path-entry-count'), ['int'])),
                                    ('as_path_entries_memory', (YLeaf(YType.uint32, 'as-path-entries-memory'), ['int'])),
                                    ('community_entry_count', (YLeaf(YType.uint32, 'community-entry-count'), ['int'])),
                                    ('community_memory', (YLeaf(YType.uint32, 'community-memory'), ['int'])),
                                    ('extended_community_entry_count', (YLeaf(YType.uint32, 'extended-community-entry-count'), ['int'])),
                                    ('extended_community_memory', (YLeaf(YType.uint32, 'extended-community-memory'), ['int'])),
                                    ('pe_distinguisher_label_entry_count', (YLeaf(YType.uint32, 'pe-distinguisher-label-entry-count'), ['int'])),
                                    ('pe_distinguisher_label_memory', (YLeaf(YType.uint32, 'pe-distinguisher-label-memory'), ['int'])),
                                    ('pta_entry_count', (YLeaf(YType.uint32, 'pta-entry-count'), ['int'])),
                                    ('pta_memory', (YLeaf(YType.uint32, 'pta-memory'), ['int'])),
                                    ('tunnel_encap_entry_count', (YLeaf(YType.uint32, 'tunnel-encap-entry-count'), ['int'])),
                                    ('tunnel_encap_memory', (YLeaf(YType.uint32, 'tunnel-encap-memory'), ['int'])),
                                    ('ribrnh_entry_count', (YLeaf(YType.uint32, 'ribrnh-entry-count'), ['int'])),
                                    ('ribrnh_memory', (YLeaf(YType.uint32, 'ribrnh-memory'), ['int'])),
                                    ('ppmp_entry_count', (YLeaf(YType.uint32, 'ppmp-entry-count'), ['int'])),
                                    ('ppmp_memory', (YLeaf(YType.uint32, 'ppmp-memory'), ['int'])),
                                    ('route_reflectors', (YLeaf(YType.uint32, 'route-reflectors'), ['int'])),
                                    ('route_reflector_memory', (YLeaf(YType.uint32, 'route-reflector-memory'), ['int'])),
                                    ('nexthop_count', (YLeaf(YType.uint32, 'nexthop-count'), ['int'])),
                                    ('nexthop_memory', (YLeaf(YType.uint32, 'nexthop-memory'), ['int'])),
                                    ('lsattr_entry_count', (YLeaf(YType.uint32, 'lsattr-entry-count'), ['int'])),
                                    ('lsattr_memory', (YLeaf(YType.uint32, 'lsattr-memory'), ['int'])),
                                    ('attr_set_entry_count', (YLeaf(YType.uint32, 'attr-set-entry-count'), ['int'])),
                                    ('attr_set_memory', (YLeaf(YType.uint32, 'attr-set-memory'), ['int'])),
                                    ('lindex_entry_count', (YLeaf(YType.uint32, 'lindex-entry-count'), ['int'])),
                                    ('lindex_memory', (YLeaf(YType.uint32, 'lindex-memory'), ['int'])),
                                    ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                    ('total_vrf_count', (YLeaf(YType.uint32, 'total-vrf-count'), ['int'])),
                                    ('neighbors_count_total', (YLeaf(YType.uint32, 'neighbors-count-total'), ['int'])),
                                    ('established_neighbors_count_total', (YLeaf(YType.uint32, 'established-neighbors-count-total'), ['int'])),
                                    ('sn_num_non_dflt_vrf_nbrs', (YLeaf(YType.uint32, 'sn-num-non-dflt-vrf-nbrs'), ['int'])),
                                    ('sn_num_non_dflt_vrf_nbrs_estab', (YLeaf(YType.uint32, 'sn-num-non-dflt-vrf-nbrs-estab'), ['int'])),
                                    ('large_community_entry_count', (YLeaf(YType.uint32, 'large-community-entry-count'), ['int'])),
                                    ('large_community_memory', (YLeaf(YType.uint32, 'large-community-memory'), ['int'])),
                                ])
                                self.process_instance_node = None
                                self.restart_count = None
                                self.path_attributes_entry_count = None
                                self.path_attribute_memory = None
                                self.as_path_entry_count = None
                                self.as_path_entries_memory = None
                                self.community_entry_count = None
                                self.community_memory = None
                                self.extended_community_entry_count = None
                                self.extended_community_memory = None
                                self.pe_distinguisher_label_entry_count = None
                                self.pe_distinguisher_label_memory = None
                                self.pta_entry_count = None
                                self.pta_memory = None
                                self.tunnel_encap_entry_count = None
                                self.tunnel_encap_memory = None
                                self.ribrnh_entry_count = None
                                self.ribrnh_memory = None
                                self.ppmp_entry_count = None
                                self.ppmp_memory = None
                                self.route_reflectors = None
                                self.route_reflector_memory = None
                                self.nexthop_count = None
                                self.nexthop_memory = None
                                self.lsattr_entry_count = None
                                self.lsattr_memory = None
                                self.attr_set_entry_count = None
                                self.attr_set_memory = None
                                self.lindex_entry_count = None
                                self.lindex_memory = None
                                self.local_as = None
                                self.total_vrf_count = None
                                self.neighbors_count_total = None
                                self.established_neighbors_count_total = None
                                self.sn_num_non_dflt_vrf_nbrs = None
                                self.sn_num_non_dflt_vrf_nbrs_estab = None
                                self.large_community_entry_count = None
                                self.large_community_memory = None

                                self.pool_size = YList(self)
                                self.pool_alloc_count = YList(self)
                                self.pool_free_count = YList(self)
                                self.msg_log_pool_size = YList(self)
                                self.msg_log_pool_alloc_count = YList(self)
                                self.msg_log_pool_free_count = YList(self)
                                self.bmp_pool_size = YList(self)
                                self.bmp_pool_alloc_count = YList(self)
                                self.bmp_pool_free_count = YList(self)
                                self._segment_path = lambda: "global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global, [u'process_instance_node', u'restart_count', u'path_attributes_entry_count', u'path_attribute_memory', u'as_path_entry_count', u'as_path_entries_memory', u'community_entry_count', u'community_memory', u'extended_community_entry_count', u'extended_community_memory', u'pe_distinguisher_label_entry_count', u'pe_distinguisher_label_memory', u'pta_entry_count', u'pta_memory', u'tunnel_encap_entry_count', u'tunnel_encap_memory', u'ribrnh_entry_count', u'ribrnh_memory', u'ppmp_entry_count', u'ppmp_memory', u'route_reflectors', u'route_reflector_memory', u'nexthop_count', u'nexthop_memory', u'lsattr_entry_count', u'lsattr_memory', u'attr_set_entry_count', u'attr_set_memory', u'lindex_entry_count', u'lindex_memory', u'local_as', u'total_vrf_count', u'neighbors_count_total', u'established_neighbors_count_total', u'sn_num_non_dflt_vrf_nbrs', u'sn_num_non_dflt_vrf_nbrs_estab', u'large_community_entry_count', u'large_community_memory'], name, value)


                            class PoolSize(Entity):
                                """
                                pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolSize, self).__init__()

                                    self.yang_name = "pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "pool-size"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolSize, [u'entry'], name, value)


                            class PoolAllocCount(Entity):
                                """
                                pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolAllocCount, self).__init__()

                                    self.yang_name = "pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "pool-alloc-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolAllocCount, [u'entry'], name, value)


                            class PoolFreeCount(Entity):
                                """
                                pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolFreeCount, self).__init__()

                                    self.yang_name = "pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "pool-free-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.PoolFreeCount, [u'entry'], name, value)


                            class MsgLogPoolSize(Entity):
                                """
                                msg log pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolSize, self).__init__()

                                    self.yang_name = "msg-log-pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "msg-log-pool-size"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolSize, [u'entry'], name, value)


                            class MsgLogPoolAllocCount(Entity):
                                """
                                msg log pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolAllocCount, self).__init__()

                                    self.yang_name = "msg-log-pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "msg-log-pool-alloc-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolAllocCount, [u'entry'], name, value)


                            class MsgLogPoolFreeCount(Entity):
                                """
                                msg log pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolFreeCount, self).__init__()

                                    self.yang_name = "msg-log-pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "msg-log-pool-free-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.MsgLogPoolFreeCount, [u'entry'], name, value)


                            class BmpPoolSize(Entity):
                                """
                                bmp pool size
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolSize, self).__init__()

                                    self.yang_name = "bmp-pool-size"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "bmp-pool-size"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolSize, [u'entry'], name, value)


                            class BmpPoolAllocCount(Entity):
                                """
                                bmp pool alloc count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolAllocCount, self).__init__()

                                    self.yang_name = "bmp-pool-alloc-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "bmp-pool-alloc-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolAllocCount, [u'entry'], name, value)


                            class BmpPoolFreeCount(Entity):
                                """
                                bmp pool free count
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolFreeCount, self).__init__()

                                    self.yang_name = "bmp-pool-free-count"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "bmp-pool-free-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Global.BmpPoolFreeCount, [u'entry'], name, value)


                        class Vrf(Entity):
                            """
                            VRF information
                            
                            .. attribute:: neighbors_count
                            
                            	Number of neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: established_neighbors_count
                            
                            	Number of established neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_received
                            
                            	Number of update messages received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_sent
                            
                            	No. of update messages sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_received
                            
                            	No. of notifications received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: notifications_sent
                            
                            	No. of notifications sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: network_count
                            
                            	Number of networks
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_count
                            
                            	Number of paths
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf, self).__init__()

                                self.yang_name = "vrf"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('neighbors_count', (YLeaf(YType.uint32, 'neighbors-count'), ['int'])),
                                    ('established_neighbors_count', (YLeaf(YType.uint32, 'established-neighbors-count'), ['int'])),
                                    ('update_messages_received', (YLeaf(YType.uint32, 'update-messages-received'), ['int'])),
                                    ('update_messages_sent', (YLeaf(YType.uint32, 'update-messages-sent'), ['int'])),
                                    ('notifications_received', (YLeaf(YType.uint32, 'notifications-received'), ['int'])),
                                    ('notifications_sent', (YLeaf(YType.uint32, 'notifications-sent'), ['int'])),
                                    ('network_count', (YLeaf(YType.uint32, 'network-count'), ['int'])),
                                    ('path_count', (YLeaf(YType.uint32, 'path-count'), ['int'])),
                                ])
                                self.neighbors_count = None
                                self.established_neighbors_count = None
                                self.update_messages_received = None
                                self.update_messages_sent = None
                                self.notifications_received = None
                                self.notifications_sent = None
                                self.network_count = None
                                self.path_count = None
                                self._segment_path = lambda: "vrf"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.Vrf, [u'neighbors_count', u'established_neighbors_count', u'update_messages_received', u'update_messages_sent', u'notifications_received', u'notifications_sent', u'network_count', u'path_count'], name, value)


                        class PerformanceStatistics(Entity):
                            """
                            Performance statistics
                            
                            .. attribute:: global_
                            
                            	Global information
                            	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global>`
                            
                            .. attribute:: vrf
                            
                            	VRF information
                            	**type**\:  :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics, self).__init__()

                                self.yang_name = "performance-statistics"
                                self.yang_parent_name = "process-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("global", ("global_", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global)), ("vrf", ("vrf", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf))])
                                self._leafs = OrderedDict()

                                self.global_ = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global()
                                self.global_.parent = self
                                self._children_name_map["global_"] = "global"

                                self.vrf = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf()
                                self.vrf.parent = self
                                self._children_name_map["vrf"] = "vrf"
                                self._segment_path = lambda: "performance-statistics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics, [], name, value)


                            class Global(Entity):
                                """
                                Global information
                                
                                .. attribute:: ipv4rib_server
                                
                                	IPv4 RIB server global info
                                	**type**\:  :py:class:`Ipv4ribServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer>`
                                
                                .. attribute:: ipv6rib_server
                                
                                	IPv6 RIB server global info
                                	**type**\:  :py:class:`Ipv6ribServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer>`
                                
                                .. attribute:: te_connection
                                
                                	MPLS TE server connection info
                                	**type**\:  :py:class:`TeConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection>`
                                
                                .. attribute:: lsd_connection
                                
                                	MPLS LSD server connection info
                                	**type**\:  :py:class:`LsdConnection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection>`
                                
                                .. attribute:: ds_npl
                                
                                	NSR related DS and NPL information
                                	**type**\:  :py:class:`DsNpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl>`
                                
                                .. attribute:: configuration_items_processed
                                
                                	Number of config items processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configuration_processing_time
                                
                                	Time spent processing config (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: edm_requests_count
                                
                                	Number of EDM requests processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: edm_processing_time
                                
                                	Time spent processing EDM requests (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_messages_sent
                                
                                	bRIB API output messages sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_bytes_sent
                                
                                	bRIB API output bytes sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_bytes_generated
                                
                                	bRIB API output bytes generated
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_output_prefixes_advertised
                                
                                	bRIB API output prefixes advertised
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_prefixes_withdrawn
                                
                                	bRIB API output prefixes withdrawn
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_sending_time
                                
                                	Time spent sending output to bRIB API (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_output_generation_time
                                
                                	Time spent generating output for bRIB API (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: brib_api_output_calls
                                
                                	bRIB API calls to generate output
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_messages
                                
                                	bRIB API input messages
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_bytes
                                
                                	bRIB API input bytes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: brib_api_input_prefixes_received
                                
                                	bRIB API input advertised prefixes received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_withdrawn_prefixes
                                
                                	bRIB API input withdrawn prefixes received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: brib_api_input_processing_time
                                
                                	Time spent processing input from bRIB API (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: instance_node_role
                                
                                	Node role \- active/passive
                                	**type**\: bool
                                
                                .. attribute:: active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: sec_active_nsrtcp_phase_two_enter_time
                                
                                	Time that NSR TCP Init Sync Phase Two entered on active (seconds since Jan 1 1970)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: proc_scoped_sync_state
                                
                                	BGP scoped sync state
                                	**type**\:  :py:class:`BgpScopedSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpScopedSyncState>`
                                
                                .. attribute:: initial_sync_sessions_added
                                
                                	If true, BGP has at least one established session when NSR initial synchronization is started
                                	**type**\: bool
                                
                                .. attribute:: in_event_attach_calls
                                
                                	event\_file\_attach  calls for input
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_event_attach_calls
                                
                                	event\_file\_attach  calls for output
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: in_out_event_attach_calls
                                
                                	event\_file\_attach calls for input
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_timer_id
                                
                                	Updgen master timer ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: updgen_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: current_clock_time
                                
                                	Current time
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: updgen_handler_tm
                                
                                	Timestamp when updgen timer handler got called
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_timer_id
                                
                                	IO master timer ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: io_tree_timer_left
                                
                                	Time left before the QNX timer would expire
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_tree_timer_expiry
                                
                                	Time as per tree\->mtexptime
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: io_handler_tm
                                
                                	Timestamp when IO timer handler got called
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: qad_messages_sent
                                
                                	Messages sent on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadack_sent
                                
                                	Acks sent on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_failure
                                
                                	Send failure on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_ac_ks_failure
                                
                                	Ack failure on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_suspends
                                
                                	QAD send suspend
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_resumes
                                
                                	QAD send resume 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_send_drops
                                
                                	Send packets dropped due to null peer 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_messages_received
                                
                                	Messages received on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_processed
                                
                                	Messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_ac_ks_received
                                
                                	Acks received on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_received
                                
                                	Timeouts received on QAD 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_init_drops
                                
                                	Packets dropped on standby during initialization
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qadoos_drops
                                
                                	Packets dropped due to  out of sequence packetreceived
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_recv_drops
                                
                                	Received packet dropped due to null peer 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: qad_timeout_recvd
                                
                                	Number of packet send timeouts 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_last_reset_reason
                                
                                	Reason for last nsr state  machine reset
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: redcon_nsr_ready
                                
                                	NSR state conveyed to Redcon  by bgp \- nsr ready/unready
                                	**type**\: bool
                                
                                .. attribute:: redcon_state_time
                                
                                	Time when nsr state wasconveyed to Redcon last
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: active_nsr_state
                                
                                	Current Active BGP nsrstate
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sec_active_nsr_state
                                
                                	Current Sec Active BGP nsrstate
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_outstanding_postits
                                
                                	Total outstanding postits across all neighbors
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total_neighbors_with_pending_postits
                                
                                	Total nbrs with pending postits
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tep2p_auto_tunnel_enabled
                                
                                	TE support for P2P auto tunnel
                                	**type**\: bool
                                
                                .. attribute:: active_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of  		 :py:class:`ActiveNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime>`
                                
                                .. attribute:: standby_nsr_mode_enter_time
                                
                                	Time that each mode was entered (seconds since  Jan 1 1970)
                                	**type**\: list of  		 :py:class:`StandbyNsrModeEnterTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime>`
                                
                                .. attribute:: active_nsrfo_time
                                
                                	Time that each thread isdone with its  go\-activeprocessing (seconds since Jan 1 1970)
                                	**type**\: list of  		 :py:class:`ActiveNsrfoTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime>`
                                
                                .. attribute:: postit_count_info
                                
                                	List of neighbors and their postit counts
                                	**type**\: list of  		 :py:class:`PostitCountInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo>`
                                
                                .. attribute:: issu_milestone
                                
                                	ISSU Milestones
                                	**type**\: list of  		 :py:class:`IssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global, self).__init__()

                                    self.yang_name = "global"
                                    self.yang_parent_name = "performance-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4rib-server", ("ipv4rib_server", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer)), ("ipv6rib-server", ("ipv6rib_server", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer)), ("te-connection", ("te_connection", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection)), ("lsd-connection", ("lsd_connection", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection)), ("ds-npl", ("ds_npl", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl)), ("active-nsr-mode-enter-time", ("active_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime)), ("standby-nsr-mode-enter-time", ("standby_nsr_mode_enter_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime)), ("active-nsrfo-time", ("active_nsrfo_time", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime)), ("postit-count-info", ("postit_count_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo)), ("issu-milestone", ("issu_milestone", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone))])
                                    self._leafs = OrderedDict([
                                        ('configuration_items_processed', (YLeaf(YType.uint32, 'configuration-items-processed'), ['int'])),
                                        ('configuration_processing_time', (YLeaf(YType.uint32, 'configuration-processing-time'), ['int'])),
                                        ('edm_requests_count', (YLeaf(YType.uint32, 'edm-requests-count'), ['int'])),
                                        ('edm_processing_time', (YLeaf(YType.uint32, 'edm-processing-time'), ['int'])),
                                        ('brib_api_output_messages_sent', (YLeaf(YType.uint32, 'brib-api-output-messages-sent'), ['int'])),
                                        ('brib_api_output_bytes_sent', (YLeaf(YType.uint32, 'brib-api-output-bytes-sent'), ['int'])),
                                        ('brib_api_output_bytes_generated', (YLeaf(YType.uint32, 'brib-api-output-bytes-generated'), ['int'])),
                                        ('brib_api_output_prefixes_advertised', (YLeaf(YType.uint32, 'brib-api-output-prefixes-advertised'), ['int'])),
                                        ('brib_api_output_prefixes_withdrawn', (YLeaf(YType.uint32, 'brib-api-output-prefixes-withdrawn'), ['int'])),
                                        ('brib_api_output_sending_time', (YLeaf(YType.uint32, 'brib-api-output-sending-time'), ['int'])),
                                        ('brib_api_output_generation_time', (YLeaf(YType.uint32, 'brib-api-output-generation-time'), ['int'])),
                                        ('brib_api_output_calls', (YLeaf(YType.uint32, 'brib-api-output-calls'), ['int'])),
                                        ('brib_api_input_messages', (YLeaf(YType.uint32, 'brib-api-input-messages'), ['int'])),
                                        ('brib_api_input_bytes', (YLeaf(YType.uint32, 'brib-api-input-bytes'), ['int'])),
                                        ('brib_api_input_prefixes_received', (YLeaf(YType.uint32, 'brib-api-input-prefixes-received'), ['int'])),
                                        ('brib_api_input_withdrawn_prefixes', (YLeaf(YType.uint32, 'brib-api-input-withdrawn-prefixes'), ['int'])),
                                        ('brib_api_input_processing_time', (YLeaf(YType.uint32, 'brib-api-input-processing-time'), ['int'])),
                                        ('instance_node_role', (YLeaf(YType.boolean, 'instance-node-role'), ['bool'])),
                                        ('active_nsrtcp_phase_two_enter_time', (YLeaf(YType.uint32, 'active-nsrtcp-phase-two-enter-time'), ['int'])),
                                        ('sec_active_nsrtcp_phase_two_enter_time', (YLeaf(YType.uint32, 'sec-active-nsrtcp-phase-two-enter-time'), ['int'])),
                                        ('proc_scoped_sync_state', (YLeaf(YType.enumeration, 'proc-scoped-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpScopedSyncState', '')])),
                                        ('initial_sync_sessions_added', (YLeaf(YType.boolean, 'initial-sync-sessions-added'), ['bool'])),
                                        ('in_event_attach_calls', (YLeaf(YType.uint32, 'in-event-attach-calls'), ['int'])),
                                        ('out_event_attach_calls', (YLeaf(YType.uint32, 'out-event-attach-calls'), ['int'])),
                                        ('in_out_event_attach_calls', (YLeaf(YType.uint32, 'in-out-event-attach-calls'), ['int'])),
                                        ('updgen_timer_id', (YLeaf(YType.uint32, 'updgen-timer-id'), ['int'])),
                                        ('updgen_tree_timer_left', (YLeaf(YType.uint64, 'updgen-tree-timer-left'), ['int'])),
                                        ('updgen_tree_timer_expiry', (YLeaf(YType.uint64, 'updgen-tree-timer-expiry'), ['int'])),
                                        ('current_clock_time', (YLeaf(YType.uint64, 'current-clock-time'), ['int'])),
                                        ('updgen_handler_tm', (YLeaf(YType.uint64, 'updgen-handler-tm'), ['int'])),
                                        ('io_timer_id', (YLeaf(YType.uint32, 'io-timer-id'), ['int'])),
                                        ('io_tree_timer_left', (YLeaf(YType.uint64, 'io-tree-timer-left'), ['int'])),
                                        ('io_tree_timer_expiry', (YLeaf(YType.uint64, 'io-tree-timer-expiry'), ['int'])),
                                        ('io_handler_tm', (YLeaf(YType.uint64, 'io-handler-tm'), ['int'])),
                                        ('qad_messages_sent', (YLeaf(YType.uint32, 'qad-messages-sent'), ['int'])),
                                        ('qadack_sent', (YLeaf(YType.uint32, 'qadack-sent'), ['int'])),
                                        ('qad_send_failure', (YLeaf(YType.uint32, 'qad-send-failure'), ['int'])),
                                        ('qad_ac_ks_failure', (YLeaf(YType.uint32, 'qad-ac-ks-failure'), ['int'])),
                                        ('qad_suspends', (YLeaf(YType.uint32, 'qad-suspends'), ['int'])),
                                        ('qad_resumes', (YLeaf(YType.uint32, 'qad-resumes'), ['int'])),
                                        ('qad_send_drops', (YLeaf(YType.uint32, 'qad-send-drops'), ['int'])),
                                        ('qad_messages_received', (YLeaf(YType.uint32, 'qad-messages-received'), ['int'])),
                                        ('qad_processed', (YLeaf(YType.uint32, 'qad-processed'), ['int'])),
                                        ('qad_ac_ks_received', (YLeaf(YType.uint32, 'qad-ac-ks-received'), ['int'])),
                                        ('qad_timeout_received', (YLeaf(YType.uint32, 'qad-timeout-received'), ['int'])),
                                        ('qad_init_drops', (YLeaf(YType.uint32, 'qad-init-drops'), ['int'])),
                                        ('qadoos_drops', (YLeaf(YType.uint32, 'qadoos-drops'), ['int'])),
                                        ('qad_recv_drops', (YLeaf(YType.uint32, 'qad-recv-drops'), ['int'])),
                                        ('qad_timeout_recvd', (YLeaf(YType.uint32, 'qad-timeout-recvd'), ['int'])),
                                        ('nsr_last_reset_reason', (YLeaf(YType.uint8, 'nsr-last-reset-reason'), ['int'])),
                                        ('redcon_nsr_ready', (YLeaf(YType.boolean, 'redcon-nsr-ready'), ['bool'])),
                                        ('redcon_state_time', (YLeaf(YType.uint32, 'redcon-state-time'), ['int'])),
                                        ('active_nsr_state', (YLeaf(YType.uint32, 'active-nsr-state'), ['int'])),
                                        ('sec_active_nsr_state', (YLeaf(YType.uint32, 'sec-active-nsr-state'), ['int'])),
                                        ('total_outstanding_postits', (YLeaf(YType.uint32, 'total-outstanding-postits'), ['int'])),
                                        ('total_neighbors_with_pending_postits', (YLeaf(YType.uint32, 'total-neighbors-with-pending-postits'), ['int'])),
                                        ('tep2p_auto_tunnel_enabled', (YLeaf(YType.boolean, 'tep2p-auto-tunnel-enabled'), ['bool'])),
                                    ])
                                    self.configuration_items_processed = None
                                    self.configuration_processing_time = None
                                    self.edm_requests_count = None
                                    self.edm_processing_time = None
                                    self.brib_api_output_messages_sent = None
                                    self.brib_api_output_bytes_sent = None
                                    self.brib_api_output_bytes_generated = None
                                    self.brib_api_output_prefixes_advertised = None
                                    self.brib_api_output_prefixes_withdrawn = None
                                    self.brib_api_output_sending_time = None
                                    self.brib_api_output_generation_time = None
                                    self.brib_api_output_calls = None
                                    self.brib_api_input_messages = None
                                    self.brib_api_input_bytes = None
                                    self.brib_api_input_prefixes_received = None
                                    self.brib_api_input_withdrawn_prefixes = None
                                    self.brib_api_input_processing_time = None
                                    self.instance_node_role = None
                                    self.active_nsrtcp_phase_two_enter_time = None
                                    self.sec_active_nsrtcp_phase_two_enter_time = None
                                    self.proc_scoped_sync_state = None
                                    self.initial_sync_sessions_added = None
                                    self.in_event_attach_calls = None
                                    self.out_event_attach_calls = None
                                    self.in_out_event_attach_calls = None
                                    self.updgen_timer_id = None
                                    self.updgen_tree_timer_left = None
                                    self.updgen_tree_timer_expiry = None
                                    self.current_clock_time = None
                                    self.updgen_handler_tm = None
                                    self.io_timer_id = None
                                    self.io_tree_timer_left = None
                                    self.io_tree_timer_expiry = None
                                    self.io_handler_tm = None
                                    self.qad_messages_sent = None
                                    self.qadack_sent = None
                                    self.qad_send_failure = None
                                    self.qad_ac_ks_failure = None
                                    self.qad_suspends = None
                                    self.qad_resumes = None
                                    self.qad_send_drops = None
                                    self.qad_messages_received = None
                                    self.qad_processed = None
                                    self.qad_ac_ks_received = None
                                    self.qad_timeout_received = None
                                    self.qad_init_drops = None
                                    self.qadoos_drops = None
                                    self.qad_recv_drops = None
                                    self.qad_timeout_recvd = None
                                    self.nsr_last_reset_reason = None
                                    self.redcon_nsr_ready = None
                                    self.redcon_state_time = None
                                    self.active_nsr_state = None
                                    self.sec_active_nsr_state = None
                                    self.total_outstanding_postits = None
                                    self.total_neighbors_with_pending_postits = None
                                    self.tep2p_auto_tunnel_enabled = None

                                    self.ipv4rib_server = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer()
                                    self.ipv4rib_server.parent = self
                                    self._children_name_map["ipv4rib_server"] = "ipv4rib-server"

                                    self.ipv6rib_server = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer()
                                    self.ipv6rib_server.parent = self
                                    self._children_name_map["ipv6rib_server"] = "ipv6rib-server"

                                    self.te_connection = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection()
                                    self.te_connection.parent = self
                                    self._children_name_map["te_connection"] = "te-connection"

                                    self.lsd_connection = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection()
                                    self.lsd_connection.parent = self
                                    self._children_name_map["lsd_connection"] = "lsd-connection"

                                    self.ds_npl = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl()
                                    self.ds_npl.parent = self
                                    self._children_name_map["ds_npl"] = "ds-npl"

                                    self.active_nsr_mode_enter_time = YList(self)
                                    self.standby_nsr_mode_enter_time = YList(self)
                                    self.active_nsrfo_time = YList(self)
                                    self.postit_count_info = YList(self)
                                    self.issu_milestone = YList(self)
                                    self._segment_path = lambda: "global"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global, [u'configuration_items_processed', u'configuration_processing_time', u'edm_requests_count', u'edm_processing_time', u'brib_api_output_messages_sent', u'brib_api_output_bytes_sent', u'brib_api_output_bytes_generated', u'brib_api_output_prefixes_advertised', u'brib_api_output_prefixes_withdrawn', u'brib_api_output_sending_time', u'brib_api_output_generation_time', u'brib_api_output_calls', u'brib_api_input_messages', u'brib_api_input_bytes', u'brib_api_input_prefixes_received', u'brib_api_input_withdrawn_prefixes', u'brib_api_input_processing_time', u'instance_node_role', u'active_nsrtcp_phase_two_enter_time', u'sec_active_nsrtcp_phase_two_enter_time', u'proc_scoped_sync_state', u'initial_sync_sessions_added', u'in_event_attach_calls', u'out_event_attach_calls', u'in_out_event_attach_calls', u'updgen_timer_id', u'updgen_tree_timer_left', u'updgen_tree_timer_expiry', u'current_clock_time', u'updgen_handler_tm', u'io_timer_id', u'io_tree_timer_left', u'io_tree_timer_expiry', u'io_handler_tm', u'qad_messages_sent', u'qadack_sent', u'qad_send_failure', u'qad_ac_ks_failure', u'qad_suspends', u'qad_resumes', u'qad_send_drops', u'qad_messages_received', u'qad_processed', u'qad_ac_ks_received', u'qad_timeout_received', u'qad_init_drops', u'qadoos_drops', u'qad_recv_drops', u'qad_timeout_recvd', u'nsr_last_reset_reason', u'redcon_nsr_ready', u'redcon_state_time', u'active_nsr_state', u'sec_active_nsr_state', u'total_outstanding_postits', u'total_neighbors_with_pending_postits', u'tep2p_auto_tunnel_enabled'], name, value)


                                class Ipv4ribServer(Entity):
                                    """
                                    IPv4 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:  :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:  :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:  :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:  :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer, self).__init__()

                                        self.yang_name = "ipv4rib-server"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("first-rib-connection-up-timestamp", ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp)), ("last-rib-connection-up-timestamp", ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp)), ("first-rib-connection-down-timestamp", ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp)), ("last-rib-connection-down-timestamp", ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('is_rib_connection_up', (YLeaf(YType.boolean, 'is-rib-connection-up'), ['bool'])),
                                            ('rib_connection_up_count', (YLeaf(YType.uint32, 'rib-connection-up-count'), ['int'])),
                                            ('last_rib_connection_up_age', (YLeaf(YType.uint32, 'last-rib-connection-up-age'), ['int'])),
                                            ('rib_connection_down_count', (YLeaf(YType.uint32, 'rib-connection-down-count'), ['int'])),
                                            ('last_rib_connection_down_age', (YLeaf(YType.uint32, 'last-rib-connection-down-age'), ['int'])),
                                        ])
                                        self.is_rib_connection_up = None
                                        self.rib_connection_up_count = None
                                        self.last_rib_connection_up_age = None
                                        self.rib_connection_down_count = None
                                        self.last_rib_connection_down_age = None

                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"

                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"

                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"

                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                        self._segment_path = lambda: "ipv4rib-server"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer, [u'is_rib_connection_up', u'rib_connection_up_count', u'last_rib_connection_up_age', u'rib_connection_down_count', u'last_rib_connection_down_age'], name, value)


                                    class FirstRibConnectionUpTimestamp(Entity):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-rib-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRibConnectionUpTimestamp(Entity):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-rib-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstRibConnectionDownTimestamp(Entity):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-rib-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.FirstRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRibConnectionDownTimestamp(Entity):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv4rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-rib-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv4ribServer.LastRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class Ipv6ribServer(Entity):
                                    """
                                    IPv6 RIB server global info
                                    
                                    .. attribute:: first_rib_connection_up_timestamp
                                    
                                    	First RIB connection Up event timestamp
                                    	**type**\:  :py:class:`FirstRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_up_timestamp
                                    
                                    	Last RIB connection Up event timestamp
                                    	**type**\:  :py:class:`LastRibConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp>`
                                    
                                    .. attribute:: first_rib_connection_down_timestamp
                                    
                                    	First RIB connection Down event timestamp
                                    	**type**\:  :py:class:`FirstRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_rib_connection_down_timestamp
                                    
                                    	Last RIB connection Down event timestamp
                                    	**type**\:  :py:class:`LastRibConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp>`
                                    
                                    .. attribute:: is_rib_connection_up
                                    
                                    	Is RIB Connection Up?
                                    	**type**\: bool
                                    
                                    .. attribute:: rib_connection_up_count
                                    
                                    	Number of RIB connection Up events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_connection_up_age
                                    
                                    	Time since last RIB connection Up event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: rib_connection_down_count
                                    
                                    	Number of RIB connection Down events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_rib_connection_down_age
                                    
                                    	Time since last RIB connection Down event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer, self).__init__()

                                        self.yang_name = "ipv6rib-server"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("first-rib-connection-up-timestamp", ("first_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp)), ("last-rib-connection-up-timestamp", ("last_rib_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp)), ("first-rib-connection-down-timestamp", ("first_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp)), ("last-rib-connection-down-timestamp", ("last_rib_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('is_rib_connection_up', (YLeaf(YType.boolean, 'is-rib-connection-up'), ['bool'])),
                                            ('rib_connection_up_count', (YLeaf(YType.uint32, 'rib-connection-up-count'), ['int'])),
                                            ('last_rib_connection_up_age', (YLeaf(YType.uint32, 'last-rib-connection-up-age'), ['int'])),
                                            ('rib_connection_down_count', (YLeaf(YType.uint32, 'rib-connection-down-count'), ['int'])),
                                            ('last_rib_connection_down_age', (YLeaf(YType.uint32, 'last-rib-connection-down-age'), ['int'])),
                                        ])
                                        self.is_rib_connection_up = None
                                        self.rib_connection_up_count = None
                                        self.last_rib_connection_up_age = None
                                        self.rib_connection_down_count = None
                                        self.last_rib_connection_down_age = None

                                        self.first_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp()
                                        self.first_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_up_timestamp"] = "first-rib-connection-up-timestamp"

                                        self.last_rib_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp()
                                        self.last_rib_connection_up_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_up_timestamp"] = "last-rib-connection-up-timestamp"

                                        self.first_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp()
                                        self.first_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["first_rib_connection_down_timestamp"] = "first-rib-connection-down-timestamp"

                                        self.last_rib_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp()
                                        self.last_rib_connection_down_timestamp.parent = self
                                        self._children_name_map["last_rib_connection_down_timestamp"] = "last-rib-connection-down-timestamp"
                                        self._segment_path = lambda: "ipv6rib-server"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer, [u'is_rib_connection_up', u'rib_connection_up_count', u'last_rib_connection_up_age', u'rib_connection_down_count', u'last_rib_connection_down_age'], name, value)


                                    class FirstRibConnectionUpTimestamp(Entity):
                                        """
                                        First RIB connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-rib-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRibConnectionUpTimestamp(Entity):
                                        """
                                        Last RIB connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-up-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-rib-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstRibConnectionDownTimestamp(Entity):
                                        """
                                        First RIB connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-rib-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.FirstRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastRibConnectionDownTimestamp(Entity):
                                        """
                                        Last RIB connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-rib-connection-down-timestamp"
                                            self.yang_parent_name = "ipv6rib-server"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-rib-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.Ipv6ribServer.LastRibConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class TeConnection(Entity):
                                    """
                                    MPLS TE server connection info
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:  :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:  :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp>`
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:  :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:  :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\: bool
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection, self).__init__()

                                        self.yang_name = "te-connection"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("first-connection-up-timestamp", ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp)), ("last-connection-up-timestamp", ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp)), ("first-connection-down-timestamp", ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp)), ("last-connection-down-timestamp", ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('is_connection_up', (YLeaf(YType.boolean, 'is-connection-up'), ['bool'])),
                                            ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                            ('last_connection_up_age', (YLeaf(YType.uint32, 'last-connection-up-age'), ['int'])),
                                            ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                            ('last_connection_down_age', (YLeaf(YType.uint32, 'last-connection-down-age'), ['int'])),
                                        ])
                                        self.is_connection_up = None
                                        self.connection_up_count = None
                                        self.last_connection_up_age = None
                                        self.connection_down_count = None
                                        self.last_connection_down_age = None

                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"

                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self
                                        self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"

                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"

                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                        self._segment_path = lambda: "te-connection"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection, [u'is_connection_up', u'connection_up_count', u'last_connection_up_age', u'connection_down_count', u'last_connection_down_age'], name, value)


                                    class FirstConnectionUpTimestamp(Entity):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-connection-up-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastConnectionUpTimestamp(Entity):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-connection-up-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstConnectionDownTimestamp(Entity):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-connection-down-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.FirstConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastConnectionDownTimestamp(Entity):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-connection-down-timestamp"
                                            self.yang_parent_name = "te-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.TeConnection.LastConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LsdConnection(Entity):
                                    """
                                    MPLS LSD server connection info
                                    
                                    .. attribute:: first_connection_up_timestamp
                                    
                                    	First connection Up event timestamp
                                    	**type**\:  :py:class:`FirstConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp>`
                                    
                                    .. attribute:: last_connection_up_timestamp
                                    
                                    	Last connection Up event timestamp
                                    	**type**\:  :py:class:`LastConnectionUpTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp>`
                                    
                                    .. attribute:: first_connection_down_timestamp
                                    
                                    	First connection Down event timestamp
                                    	**type**\:  :py:class:`FirstConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp>`
                                    
                                    .. attribute:: last_connection_down_timestamp
                                    
                                    	Last connection Down event timestamp
                                    	**type**\:  :py:class:`LastConnectionDownTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp>`
                                    
                                    .. attribute:: is_connection_up
                                    
                                    	Is Connection Up?
                                    	**type**\: bool
                                    
                                    .. attribute:: connection_up_count
                                    
                                    	Number of connection Up events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_connection_up_age
                                    
                                    	Time since last connection Up event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: connection_down_count
                                    
                                    	Number of connection down events
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_connection_down_age
                                    
                                    	Time since last connection Down event (in seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection, self).__init__()

                                        self.yang_name = "lsd-connection"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("first-connection-up-timestamp", ("first_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp)), ("last-connection-up-timestamp", ("last_connection_up_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp)), ("first-connection-down-timestamp", ("first_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp)), ("last-connection-down-timestamp", ("last_connection_down_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp))])
                                        self._leafs = OrderedDict([
                                            ('is_connection_up', (YLeaf(YType.boolean, 'is-connection-up'), ['bool'])),
                                            ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                            ('last_connection_up_age', (YLeaf(YType.uint32, 'last-connection-up-age'), ['int'])),
                                            ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                            ('last_connection_down_age', (YLeaf(YType.uint32, 'last-connection-down-age'), ['int'])),
                                        ])
                                        self.is_connection_up = None
                                        self.connection_up_count = None
                                        self.last_connection_up_age = None
                                        self.connection_down_count = None
                                        self.last_connection_down_age = None

                                        self.first_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp()
                                        self.first_connection_up_timestamp.parent = self
                                        self._children_name_map["first_connection_up_timestamp"] = "first-connection-up-timestamp"

                                        self.last_connection_up_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp()
                                        self.last_connection_up_timestamp.parent = self
                                        self._children_name_map["last_connection_up_timestamp"] = "last-connection-up-timestamp"

                                        self.first_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp()
                                        self.first_connection_down_timestamp.parent = self
                                        self._children_name_map["first_connection_down_timestamp"] = "first-connection-down-timestamp"

                                        self.last_connection_down_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp()
                                        self.last_connection_down_timestamp.parent = self
                                        self._children_name_map["last_connection_down_timestamp"] = "last-connection-down-timestamp"
                                        self._segment_path = lambda: "lsd-connection"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection, [u'is_connection_up', u'connection_up_count', u'last_connection_up_age', u'connection_down_count', u'last_connection_down_age'], name, value)


                                    class FirstConnectionUpTimestamp(Entity):
                                        """
                                        First connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "first-connection-up-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastConnectionUpTimestamp(Entity):
                                        """
                                        Last connection Up event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp, self).__init__()

                                            self.yang_name = "last-connection-up-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-connection-up-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionUpTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class FirstConnectionDownTimestamp(Entity):
                                        """
                                        First connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "first-connection-down-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "first-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.FirstConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                    class LastConnectionDownTimestamp(Entity):
                                        """
                                        Last connection Down event timestamp
                                        
                                        .. attribute:: seconds
                                        
                                        	Seconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanoseconds
                                        
                                        	Nanoseconds part of time value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp, self).__init__()

                                            self.yang_name = "last-connection-down-timestamp"
                                            self.yang_parent_name = "lsd-connection"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                            ])
                                            self.seconds = None
                                            self.nanoseconds = None
                                            self._segment_path = lambda: "last-connection-down-timestamp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.LsdConnection.LastConnectionDownTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class DsNpl(Entity):
                                    """
                                    NSR related DS and NPL information
                                    
                                    .. attribute:: dir_service_conn_state
                                    
                                    	Current Directory Service connectionstate
                                    	**type**\:  :py:class:`BgpDsConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpDsConnState>`
                                    
                                    .. attribute:: issu_mgr_conn_state
                                    
                                    	Current ISSU Mgr connection state
                                    	**type**\:  :py:class:`BgpIsmConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpIsmConnState>`
                                    
                                    .. attribute:: issu_phase
                                    
                                    	Current ISSU Phase
                                    	**type**\: str
                                    
                                    .. attribute:: issu_type_ng
                                    
                                    	ISSU type is Next Gen
                                    	**type**\: bool
                                    
                                    .. attribute:: issuha_option
                                    
                                    	Current ISSU HA option
                                    	**type**\: str
                                    
                                    .. attribute:: local_ds_handle
                                    
                                    	Local Directory Service handle
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: service_name
                                    
                                    	Local DS service name
                                    	**type**\: str
                                    
                                    .. attribute:: dsissu_status_flag
                                    
                                    	DS ISSU status flag
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: npl_priority_statistic
                                    
                                    	NPL priority statistics
                                    	**type**\: list of  		 :py:class:`NplPriorityStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic>`
                                    
                                    .. attribute:: npl_endpoint
                                    
                                    	NPL endpoint information
                                    	**type**\: list of  		 :py:class:`NplEndpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl, self).__init__()

                                        self.yang_name = "ds-npl"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("npl-priority-statistic", ("npl_priority_statistic", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic)), ("npl-endpoint", ("npl_endpoint", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint))])
                                        self._leafs = OrderedDict([
                                            ('dir_service_conn_state', (YLeaf(YType.enumeration, 'dir-service-conn-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpDsConnState', '')])),
                                            ('issu_mgr_conn_state', (YLeaf(YType.enumeration, 'issu-mgr-conn-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpIsmConnState', '')])),
                                            ('issu_phase', (YLeaf(YType.str, 'issu-phase'), ['str'])),
                                            ('issu_type_ng', (YLeaf(YType.boolean, 'issu-type-ng'), ['bool'])),
                                            ('issuha_option', (YLeaf(YType.str, 'issuha-option'), ['str'])),
                                            ('local_ds_handle', (YLeaf(YType.uint64, 'local-ds-handle'), ['int'])),
                                            ('service_name', (YLeaf(YType.str, 'service-name'), ['str'])),
                                            ('dsissu_status_flag', (YLeaf(YType.uint32, 'dsissu-status-flag'), ['int'])),
                                        ])
                                        self.dir_service_conn_state = None
                                        self.issu_mgr_conn_state = None
                                        self.issu_phase = None
                                        self.issu_type_ng = None
                                        self.issuha_option = None
                                        self.local_ds_handle = None
                                        self.service_name = None
                                        self.dsissu_status_flag = None

                                        self.npl_priority_statistic = YList(self)
                                        self.npl_endpoint = YList(self)
                                        self._segment_path = lambda: "ds-npl"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl, [u'dir_service_conn_state', u'issu_mgr_conn_state', u'issu_phase', u'issu_type_ng', u'issuha_option', u'local_ds_handle', u'service_name', u'dsissu_status_flag'], name, value)


                                    class NplPriorityStatistic(Entity):
                                        """
                                        NPL priority statistics
                                        
                                        .. attribute:: num_sent
                                        
                                        	Total sent
                                        	**type**\: list of  		 :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent>`
                                        
                                        .. attribute:: num_recv
                                        
                                        	Total recvd
                                        	**type**\: list of  		 :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv>`
                                        
                                        .. attribute:: num_sent_drop
                                        
                                        	Sent Error/drops
                                        	**type**\: list of  		 :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop>`
                                        
                                        .. attribute:: num_recv_drop
                                        
                                        	Recv Errors/drops
                                        	**type**\: list of  		 :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic, self).__init__()

                                            self.yang_name = "npl-priority-statistic"
                                            self.yang_parent_name = "ds-npl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("num-sent", ("num_sent", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent)), ("num-recv", ("num_recv", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv)), ("num-sent-drop", ("num_sent_drop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop)), ("num-recv-drop", ("num_recv_drop", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop))])
                                            self._leafs = OrderedDict()

                                            self.num_sent = YList(self)
                                            self.num_recv = YList(self)
                                            self.num_sent_drop = YList(self)
                                            self.num_recv_drop = YList(self)
                                            self._segment_path = lambda: "npl-priority-statistic"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic, [], name, value)


                                        class NumSent(Entity):
                                            """
                                            Total sent
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent, self).__init__()

                                                self.yang_name = "num-sent"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint64, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "num-sent"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSent, [u'entry'], name, value)


                                        class NumRecv(Entity):
                                            """
                                            Total recvd
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv, self).__init__()

                                                self.yang_name = "num-recv"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint64, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "num-recv"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecv, [u'entry'], name, value)


                                        class NumSentDrop(Entity):
                                            """
                                            Sent Error/drops
                                            
                                            .. attribute:: nsr_pl_send_drop_array
                                            
                                            	nsr pl send drop array
                                            	**type**\: list of  		 :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop, self).__init__()

                                                self.yang_name = "num-sent-drop"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nsr-pl-send-drop-array", ("nsr_pl_send_drop_array", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray))])
                                                self._leafs = OrderedDict()

                                                self.nsr_pl_send_drop_array = YList(self)
                                                self._segment_path = lambda: "num-sent-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop, [], name, value)


                                            class NsrPlSendDropArray(Entity):
                                                """
                                                nsr pl send drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                                    self.yang_name = "nsr-pl-send-drop-array"
                                                    self.yang_parent_name = "num-sent-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "nsr-pl-send-drop-array"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumSentDrop.NsrPlSendDropArray, [u'entry'], name, value)


                                        class NumRecvDrop(Entity):
                                            """
                                            Recv Errors/drops
                                            
                                            .. attribute:: nsr_pl_recv_drop_array
                                            
                                            	nsr pl recv drop array
                                            	**type**\: list of  		 :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop, self).__init__()

                                                self.yang_name = "num-recv-drop"
                                                self.yang_parent_name = "npl-priority-statistic"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("nsr-pl-recv-drop-array", ("nsr_pl_recv_drop_array", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray))])
                                                self._leafs = OrderedDict()

                                                self.nsr_pl_recv_drop_array = YList(self)
                                                self._segment_path = lambda: "num-recv-drop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop, [], name, value)


                                            class NsrPlRecvDropArray(Entity):
                                                """
                                                nsr pl recv drop array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                                    self.yang_name = "nsr-pl-recv-drop-array"
                                                    self.yang_parent_name = "num-recv-drop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "nsr-pl-recv-drop-array"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplPriorityStatistic.NumRecvDrop.NsrPlRecvDropArray, [u'entry'], name, value)


                                    class NplEndpoint(Entity):
                                        """
                                        NPL endpoint information
                                        
                                        .. attribute:: endpoint_name
                                        
                                        	Endpoint name
                                        	**type**\: str
                                        
                                        .. attribute:: sync_group_name
                                        
                                        	Syncgroup associated with this endpoint
                                        	**type**\: str
                                        
                                        .. attribute:: node_id
                                        
                                        	Node ID
                                        	**type**\: str
                                        
                                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                        
                                        .. attribute:: endpoint_handle
                                        
                                        	NCD endpoint handle
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: endpoint_stale_flag
                                        
                                        	Endpoint stale flag
                                        	**type**\: bool
                                        
                                        .. attribute:: endpoint_issu_role
                                        
                                        	Endpoint's ISSU Role. Values are 'Primary', 'Secondary' and 'Tertiary'
                                        	**type**\: str
                                        
                                        .. attribute:: endpoint_active_flag
                                        
                                        	Endpoint active flag
                                        	**type**\: bool
                                        
                                        .. attribute:: msg_size
                                        
                                        	Message size for this entity
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: wheel_id
                                        
                                        	Wheel ID for this endpoint
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: expected_sequence_num
                                        
                                        	Expected sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: endpoint
                                        
                                        	NCD endpoint bytestream
                                        	**type**\: list of  		 :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint, self).__init__()

                                            self.yang_name = "npl-endpoint"
                                            self.yang_parent_name = "ds-npl"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("endpoint", ("endpoint", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint))])
                                            self._leafs = OrderedDict([
                                                ('endpoint_name', (YLeaf(YType.str, 'endpoint-name'), ['str'])),
                                                ('sync_group_name', (YLeaf(YType.str, 'sync-group-name'), ['str'])),
                                                ('node_id', (YLeaf(YType.str, 'node-id'), ['str'])),
                                                ('endpoint_handle', (YLeaf(YType.uint64, 'endpoint-handle'), ['int'])),
                                                ('endpoint_stale_flag', (YLeaf(YType.boolean, 'endpoint-stale-flag'), ['bool'])),
                                                ('endpoint_issu_role', (YLeaf(YType.str, 'endpoint-issu-role'), ['str'])),
                                                ('endpoint_active_flag', (YLeaf(YType.boolean, 'endpoint-active-flag'), ['bool'])),
                                                ('msg_size', (YLeaf(YType.uint32, 'msg-size'), ['int'])),
                                                ('wheel_id', (YLeaf(YType.uint32, 'wheel-id'), ['int'])),
                                                ('expected_sequence_num', (YLeaf(YType.uint32, 'expected-sequence-num'), ['int'])),
                                            ])
                                            self.endpoint_name = None
                                            self.sync_group_name = None
                                            self.node_id = None
                                            self.endpoint_handle = None
                                            self.endpoint_stale_flag = None
                                            self.endpoint_issu_role = None
                                            self.endpoint_active_flag = None
                                            self.msg_size = None
                                            self.wheel_id = None
                                            self.expected_sequence_num = None

                                            self.endpoint = YList(self)
                                            self._segment_path = lambda: "npl-endpoint"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint, [u'endpoint_name', u'sync_group_name', u'node_id', u'endpoint_handle', u'endpoint_stale_flag', u'endpoint_issu_role', u'endpoint_active_flag', u'msg_size', u'wheel_id', u'expected_sequence_num'], name, value)


                                        class Endpoint(Entity):
                                            """
                                            NCD endpoint bytestream
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint, self).__init__()

                                                self.yang_name = "endpoint"
                                                self.yang_parent_name = "npl-endpoint"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "endpoint"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.DsNpl.NplEndpoint.Endpoint, [u'entry'], name, value)


                                class ActiveNsrModeEnterTime(Entity):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime, self).__init__()

                                        self.yang_name = "active-nsr-mode-enter-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "active-nsr-mode-enter-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrModeEnterTime, [u'entry'], name, value)


                                class StandbyNsrModeEnterTime(Entity):
                                    """
                                    Time that each mode was entered (seconds since
                                    
                                    Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime, self).__init__()

                                        self.yang_name = "standby-nsr-mode-enter-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "standby-nsr-mode-enter-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.StandbyNsrModeEnterTime, [u'entry'], name, value)


                                class ActiveNsrfoTime(Entity):
                                    """
                                    Time that each thread isdone with its
                                    
                                    go\-activeprocessing (seconds since Jan 1 1970)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime, self).__init__()

                                        self.yang_name = "active-nsrfo-time"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "active-nsrfo-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.ActiveNsrfoTime, [u'entry'], name, value)


                                class PostitCountInfo(Entity):
                                    """
                                    List of neighbors and their postit counts
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor Address
                                    	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress>`
                                    
                                    .. attribute:: postit_count
                                    
                                    	Count of the number of postits for this nbr
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vrf_name
                                    
                                    	Name of the VRF
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo, self).__init__()

                                        self.yang_name = "postit-count-info"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress))])
                                        self._leafs = OrderedDict([
                                            ('postit_count', (YLeaf(YType.uint32, 'postit-count'), ['int'])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                        ])
                                        self.postit_count = None
                                        self.vrf_name = None

                                        self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress()
                                        self.neighbor_address.parent = self
                                        self._children_name_map["neighbor_address"] = "neighbor-address"
                                        self._segment_path = lambda: "postit-count-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo, [u'postit_count', u'vrf_name'], name, value)


                                    class NeighborAddress(Entity):
                                        """
                                        Neighbor Address
                                        
                                        .. attribute:: l2vpn_vpls_address
                                        
                                        	L2VPN VPLS Addr
                                        	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress>`
                                        
                                        .. attribute:: l2vpn_mspw_address
                                        
                                        	L2VPN MSPW Addr
                                        	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress>`
                                        
                                        .. attribute:: ipv4_sr_policy_address
                                        
                                        	IPV4 Policy Addr
                                        	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress>`
                                        
                                        .. attribute:: ipv6_sr_policy_address
                                        
                                        	IPV6 Policy Addr
                                        	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress>`
                                        
                                        .. attribute:: afi
                                        
                                        	AFI
                                        	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_mcast_address
                                        
                                        	IPv4 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_label_address
                                        
                                        	IPv4 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4_tunnel_address
                                        
                                        	IPv4 Tunnel
                                        	**type**\: str
                                        
                                        	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4_mdt_address
                                        
                                        	IPv4 MDT Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                        
                                        .. attribute:: ipv4vpn_address
                                        
                                        	IPv4 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv4vpna_mcastddress
                                        
                                        	IPv4 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_address
                                        
                                        	IPV6 Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_mcast_address
                                        
                                        	IPV6 Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_label_address
                                        
                                        	IPv6 Label Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_address
                                        
                                        	IPv6 VPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6vpn_mcast_address
                                        
                                        	IPv6 VPN Mcast Addr
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rt_constraint_address
                                        
                                        	RT Constrt Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{24}
                                        
                                        .. attribute:: ipv6mvpn_address
                                        
                                        	MVPN addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{104}
                                        
                                        .. attribute:: ipv4mvpn_address
                                        
                                        	MVPN4 addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{56}
                                        
                                        .. attribute:: l2vpn_evpn_address
                                        
                                        	L2VPN EVPN Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{58}
                                        
                                        .. attribute:: ls_ls_address
                                        
                                        	LINKSTATE LINKSTATE Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]+
                                        
                                        .. attribute:: ipv4_flowspec_address
                                        
                                        	IPV4 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6_flowspec_address
                                        
                                        	IPV6 Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv4vpn_flowspec_address
                                        
                                        	IPV4 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        .. attribute:: ipv6vpn_flowspec_address
                                        
                                        	IPV6 VPN Flowspec Addr
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4096}
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress, self).__init__()

                                            self.yang_name = "neighbor-address"
                                            self.yang_parent_name = "postit-count-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress))])
                                            self._leafs = OrderedDict([
                                                ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                                ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                                ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                                ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                                ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                                ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                                ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                                ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                                ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                                ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                                ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                                ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                                ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                                ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                                ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                                ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                                ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                                ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                                ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                                ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                            ])
                                            self.afi = None
                                            self.ipv4_address = None
                                            self.ipv4_mcast_address = None
                                            self.ipv4_label_address = None
                                            self.ipv4_tunnel_address = None
                                            self.ipv4_mdt_address = None
                                            self.ipv4vpn_address = None
                                            self.ipv4vpna_mcastddress = None
                                            self.ipv6_address = None
                                            self.ipv6_mcast_address = None
                                            self.ipv6_label_address = None
                                            self.ipv6vpn_address = None
                                            self.ipv6vpn_mcast_address = None
                                            self.rt_constraint_address = None
                                            self.ipv6mvpn_address = None
                                            self.ipv4mvpn_address = None
                                            self.l2vpn_evpn_address = None
                                            self.ls_ls_address = None
                                            self.ipv4_flowspec_address = None
                                            self.ipv6_flowspec_address = None
                                            self.ipv4vpn_flowspec_address = None
                                            self.ipv6vpn_flowspec_address = None

                                            self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress()
                                            self.l2vpn_vpls_address.parent = self
                                            self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                            self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress()
                                            self.l2vpn_mspw_address.parent = self
                                            self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                            self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress()
                                            self.ipv4_sr_policy_address.parent = self
                                            self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                            self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress()
                                            self.ipv6_sr_policy_address.parent = self
                                            self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                            self._segment_path = lambda: "neighbor-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                        class L2vpnVplsAddress(Entity):
                                            """
                                            L2VPN VPLS Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                                self.yang_name = "l2vpn-vpls-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-vpls-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                        class L2vpnMspwAddress(Entity):
                                            """
                                            L2VPN MSPW Addr
                                            
                                            .. attribute:: l2vpn_address
                                            
                                            	l2vpn address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                                self.yang_name = "l2vpn-mspw-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                                ])
                                                self.l2vpn_address = None
                                                self._segment_path = lambda: "l2vpn-mspw-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                        class Ipv4SrPolicyAddress(Entity):
                                            """
                                            IPV4 Policy Addr
                                            
                                            .. attribute:: ipv4_srpolicy_address
                                            
                                            	ipv4 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv4-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv4_srpolicy_address = None
                                                self._segment_path = lambda: "ipv4-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                        class Ipv6SrPolicyAddress(Entity):
                                            """
                                            IPV6 Policy Addr
                                            
                                            .. attribute:: ipv6_srpolicy_address
                                            
                                            	ipv6 srpolicy address
                                            	**type**\: str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                                self.yang_name = "ipv6-sr-policy-address"
                                                self.yang_parent_name = "neighbor-address"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                                ])
                                                self.ipv6_srpolicy_address = None
                                                self._segment_path = lambda: "ipv6-sr-policy-address"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.PostitCountInfo.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class IssuMilestone(Entity):
                                    """
                                    ISSU Milestones
                                    
                                    .. attribute:: milestone_name
                                    
                                    	Milestone name
                                    	**type**\: str
                                    
                                    .. attribute:: milestone_start_timestamp
                                    
                                    	Milestone start timestamp
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: milestone_met_timestamp
                                    
                                    	Milestone met timestamp
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone, self).__init__()

                                        self.yang_name = "issu-milestone"
                                        self.yang_parent_name = "global"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('milestone_name', (YLeaf(YType.str, 'milestone-name'), ['str'])),
                                            ('milestone_start_timestamp', (YLeaf(YType.uint32, 'milestone-start-timestamp'), ['int'])),
                                            ('milestone_met_timestamp', (YLeaf(YType.uint32, 'milestone-met-timestamp'), ['int'])),
                                        ])
                                        self.milestone_name = None
                                        self.milestone_start_timestamp = None
                                        self.milestone_met_timestamp = None
                                        self._segment_path = lambda: "issu-milestone"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Global.IssuMilestone, [u'milestone_name', u'milestone_start_timestamp', u'milestone_met_timestamp'], name, value)


                            class Vrf(Entity):
                                """
                                VRF information
                                
                                .. attribute:: lpts_set_up_time
                                
                                	Time spent setting up LPTS socket opt (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lpts_calls
                                
                                	Number of times LPTS socket opt set up
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_throttles_count
                                
                                	Number of partial read throttles
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read_count
                                
                                	Number of socket reads for nbrs above low threshold
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high_throttled_read_count
                                
                                	Number of socket reads for nbrs above high threshold
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_written
                                
                                	Number of bytes of data written
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to to funvction to process sub\-group message list
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of Calls to function to process write queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing imbound update messages (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf, self).__init__()

                                    self.yang_name = "vrf"
                                    self.yang_parent_name = "performance-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lpts_set_up_time', (YLeaf(YType.uint32, 'lpts-set-up-time'), ['int'])),
                                        ('lpts_calls', (YLeaf(YType.uint32, 'lpts-calls'), ['int'])),
                                        ('read_throttles_count', (YLeaf(YType.uint32, 'read-throttles-count'), ['int'])),
                                        ('low_throttled_read_count', (YLeaf(YType.uint32, 'low-throttled-read-count'), ['int'])),
                                        ('high_throttled_read_count', (YLeaf(YType.uint32, 'high-throttled-read-count'), ['int'])),
                                        ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                        ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                        ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                        ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                        ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                        ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                        ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                        ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                        ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                        ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                        ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                        ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                        ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                        ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                        ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                    ])
                                    self.lpts_set_up_time = None
                                    self.lpts_calls = None
                                    self.read_throttles_count = None
                                    self.low_throttled_read_count = None
                                    self.high_throttled_read_count = None
                                    self.read_calls_count = None
                                    self.read_messages_count = None
                                    self.data_bytes_read = None
                                    self.io_read_time = None
                                    self.write_calls_count = None
                                    self.data_bytes_written = None
                                    self.io_write_time = None
                                    self.write_subgroup_calls_count = None
                                    self.write_subgroup_messages_count = None
                                    self.subgroup_list_time = None
                                    self.write_queue_calls_count = None
                                    self.write_queue_messages_count = None
                                    self.write_queue_time = None
                                    self.inbound_update_messages = None
                                    self.inbound_update_messages_time = None
                                    self._segment_path = lambda: "vrf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.ProcessInfo.PerformanceStatistics.Vrf, [u'lpts_set_up_time', u'lpts_calls', u'read_throttles_count', u'low_throttled_read_count', u'high_throttled_read_count', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time'], name, value)


                    class Sessions(Entity):
                        """
                        The BGP session table
                        
                        .. attribute:: session
                        
                        	A BGP session table entry
                        	**type**\: list of  		 :py:class:`Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions, self).__init__()

                            self.yang_name = "sessions"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("session", ("session", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session))])
                            self._leafs = OrderedDict()

                            self.session = YList(self)
                            self._segment_path = lambda: "sessions"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions, [], name, value)


                        class Session(Entity):
                            """
                            A BGP session table entry
                            
                            .. attribute:: neighbor_address  (key)
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress>`
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\: str
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\: bool
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\: str
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\: bool
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: postit_pending
                            
                            	Nbr has postits pending
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session, self).__init__()

                                self.yang_name = "session"
                                self.yang_parent_name = "sessions"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                    ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                    ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                    ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                    ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                    ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                    ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                    ('postit_pending', (YLeaf(YType.boolean, 'postit-pending'), ['bool'])),
                                ])
                                self.neighbor_address = None
                                self.speaker_id = None
                                self.description = None
                                self.local_as = None
                                self.remote_as = None
                                self.messages_queued_in = None
                                self.messages_queued_out = None
                                self.connection_state = None
                                self.is_local_address_configured = None
                                self.vrf_name = None
                                self.nsr_enabled = None
                                self.nsr_state = None
                                self.postit_pending = None

                                self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"
                                self._segment_path = lambda: "session" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'messages_queued_in', u'messages_queued_out', u'connection_state', u'is_local_address_configured', u'vrf_name', u'nsr_enabled', u'nsr_state', u'postit_pending'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-local-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-remote-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Sessions.Session.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                    class Neighbors(Entity):
                        """
                        The BGP Neighbor table
                        
                        .. attribute:: neighbor
                        
                        	A BGP Neighbor table entry
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor))])
                            self._leafs = OrderedDict()

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            A BGP Neighbor table entry
                            
                            .. attribute:: neighbor_address  (key)
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress>`
                            
                            .. attribute:: send_notification_info
                            
                            	Information on the last notification sent
                            	**type**\:  :py:class:`SendNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo>`
                            
                            .. attribute:: received_notification_info
                            
                            	Information on the last notification received
                            	**type**\:  :py:class:`ReceivedNotificationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo>`
                            
                            .. attribute:: performance_statistics
                            
                            	Performance statistics
                            	**type**\:  :py:class:`PerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics>`
                            
                            .. attribute:: message_statistics
                            
                            	Message statistics
                            	**type**\:  :py:class:`MessageStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics>`
                            
                            .. attribute:: tcp_init_sync_time_spec
                            
                            	Time When neighbor entered TCP Init Sync
                            	**type**\:  :py:class:`TcpInitSyncTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_phase_two_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Phase Two
                            	**type**\:  :py:class:`TcpInitSyncPhaseTwoTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec>`
                            
                            .. attribute:: tcp_init_sync_done_time_spec
                            
                            	Time when neighbor entered TCP Init Sync Done
                            	**type**\:  :py:class:`TcpInitSyncDoneTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec>`
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance>`
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\: str
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\: bool
                            
                            .. attribute:: is_external_neighbor_not_directly_connected
                            
                            	External neighbor not directly connected
                            	**type**\: bool
                            
                            .. attribute:: messages_received
                            
                            	Number of messages received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_sent
                            
                            	Number of messages sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_in
                            
                            	No. of update msgs received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: update_messages_out
                            
                            	No. of update messages sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_in
                            
                            	No. of msgs on receive queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: messages_queued_out
                            
                            	No. of messages on send queue
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_established_time
                            
                            	Time (in secs) that the connection has been established
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: connection_state
                            
                            	State of connection
                            	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                            
                            .. attribute:: previous_connection_state
                            
                            	Previous state of connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_admin_status
                            
                            	Administrative status of connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: open_check_error_code
                            
                            	Open check error code
                            	**type**\:  :py:class:`BgpOpenCheckErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpOpenCheckErr>`
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\: bool
                            
                            .. attribute:: connection_local_port
                            
                            	Local port for the connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_remote_port
                            
                            	Remote port for the connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_interface_handle
                            
                            	Interface Handle of Neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reset_notification_sent
                            
                            	Notification was sent during last reset
                            	**type**\: bool
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\: bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\: bool
                            
                            .. attribute:: is_out_of_memory_shutdown
                            
                            	Neighbor shut down during a SEVERE low memory condition
                            	**type**\: bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\: bool
                            
                            .. attribute:: is_ebgp_peer_as_league
                            
                            	EBGP peer belongs to AS League
                            	**type**\: bool
                            
                            .. attribute:: is_ebgp_peer_common_admin
                            
                            	EBGP peer with common administation
                            	**type**\: bool
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\: bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\: bool
                            
                            .. attribute:: bfd_session_state
                            
                            	BFD state for this peer
                            	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                            
                            .. attribute:: bfd_session_created_state
                            
                            	BFD state for this peer
                            	**type**\:  :py:class:`BgpBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdState>`
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_state_ts
                            
                            	Timestamp since when nbr is in this bfd state
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: router_id
                            
                            	Router ID for the neighbor
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: negotiated_protocol_version
                            
                            	Negotiated protocol version
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\: bool
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\: bool
                            
                            .. attribute:: is_capability_negotiation_suppressed
                            
                            	Capability negotiation suppressed
                            	**type**\: bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\: bool
                            
                            .. attribute:: is_route_refresh_capability_received
                            
                            	Route refresh capability received
                            	**type**\: bool
                            
                            .. attribute:: is_route_refresh_old_capability_received
                            
                            	Route refresh old capability received
                            	**type**\: bool
                            
                            .. attribute:: is_gr_aware
                            
                            	GR awareness received
                            	**type**\: bool
                            
                            .. attribute:: is4_byte_as_capability_received
                            
                            	4\-byte AScapability received
                            	**type**\: bool
                            
                            .. attribute:: is4_byte_as_capability_sent
                            
                            	4\-byte AScapability Snt
                            	**type**\: bool
                            
                            .. attribute:: multi_protocol_capability_received
                            
                            	Multi\-protocol capability has been received
                            	**type**\: bool
                            
                            .. attribute:: hold_time
                            
                            	Hold time (in secs) negotiated for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: keep_alive_time
                            
                            	Keepalive time (in secs) negotiated for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: connect_retry_interval
                            
                            	Time (in secs) for connect retry timer
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_update
                            
                            	Time (in secs) since last update message was received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read
                            
                            	Time (in secs) since last read
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_since_last_read_reset
                            
                            	Time (in secs) since last read before last reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: time_last_cb
                            
                            	CB
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: time_last_cb_reset
                            
                            	Last CB before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_last_fb
                            
                            	FB
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: count_last_write
                            
                            	Count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_write
                            
                            	Time (in secs) since last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: attempted_last_write_bytes
                            
                            	Attempted size of last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_last_write_bytes
                            
                            	Actual size of last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_second_last_write
                            
                            	Time (in secs) since second  last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: attempted_second_last_write_bytes
                            
                            	Attempted size of second last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_bytes
                            
                            	Actual size of second last write
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: attempted_last_write_reset_bytes
                            
                            	Attempted size of last write before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_last_write_reset_bytes
                            
                            	Actual size of last write before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_second_last_write_reset
                            
                            	Time (in secs) since last write before last reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: attempted_second_last_write_reset_bytes
                            
                            	Attempted size of second last write before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: actual_second_last_write_reset_bytes
                            
                            	Actual size of second last write before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_write_event
                            
                            	Time (in secs) since last write thread event
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_write_event
                            
                            	Time (in secs) since second last write thread event
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_aexpiry_reset
                            
                            	Time (in secs) since last KA timer expiry before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_k_aexpiry_reset
                            
                            	Time (in secs) since second last KA timer expiry before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_anotsent_reset
                            
                            	Duration (in secs) since last time that KA was not sent before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_aerror_reset
                            
                            	Duration (in secs) since last time that an error was encountered after KA expiry
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: last_k_astart_reset
                            
                            	Time (in secs) since the last KA timer start before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: second_last_k_astart_reset
                            
                            	Time (in secs) since the second last KA timer start before reset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: connection_up_count
                            
                            	Number of times the connection was established
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: connection_down_count
                            
                            	Number of times connection was dropped
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_connection_last_dropped
                            
                            	Time since the connection last went down (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: reset_reason
                            
                            	Reason for last connection reset
                            	**type**\:  :py:class:`BgpResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpResetReasonIndex>`
                            
                            .. attribute:: peer_reset_reason
                            
                            	Reason for last peer close event
                            	**type**\:  :py:class:`BgpPeerResetReasonIndex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPeerResetReasonIndex>`
                            
                            .. attribute:: peer_error_code
                            
                            	If peer closed, error received from transport
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_notify_error_code
                            
                            	Code for the last error notification seen on the connection
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: last_notify_error_subcode
                            
                            	Error subcode of the last error notification seen on the connection
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: error_notifies_received
                            
                            	Number of error notifications received on the connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: error_notifies_sent
                            
                            	Number of error notifications sent on the connection
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\: bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\: str
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\: bool
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\: bool
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\: bool
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: fssn_offset
                            
                            	First standby SeqNo offset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fpbsn_offset
                            
                            	First standby PDU boundary SeqNo offset
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_ackd_seq_no
                            
                            	SeqNo of the last Ackd byte
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bytes_written
                            
                            	Total bytes written by write thread
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: bytes_read
                            
                            	Total bytes read
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: socket_read_bytes
                            
                            	Total read bytes value insocket\-lib
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: is_read_disabled
                            
                            	If true, socket read isdisabled
                            	**type**\: bool
                            
                            .. attribute:: update_bytes_read
                            
                            	Total update bytes read
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: nsr_state
                            
                            	NSR state
                            	**type**\:  :py:class:`BgpSyncNbrNsrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSyncNbrNsrState>`
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\: bool
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\: bool
                            
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\: bool
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\: bool
                            
                            .. attribute:: io_armed
                            
                            	If true, socket has beenauto\-armed for io control
                            	**type**\: bool
                            
                            .. attribute:: read_armed
                            
                            	If true, socket has beenauto\-armed for read
                            	**type**\: bool
                            
                            .. attribute:: write_armed
                            
                            	If true, socket has beenauto\-armed for write
                            	**type**\: bool
                            
                            .. attribute:: discard_data_bytes
                            
                            	Remaining discard data (bytes) on Standby
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: byte
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\: bool
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\: bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\: bool
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\: bool
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\: bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\: bool
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\: bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\: bool
                            
                            .. attribute:: dynamic_neighbor
                            
                            	Dynamic neighbor
                            	**type**\: bool
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress)), ("send-notification-info", ("send_notification_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo)), ("received-notification-info", ("received_notification_info", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo)), ("performance-statistics", ("performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics)), ("message-statistics", ("message_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics)), ("tcp-init-sync-time-spec", ("tcp_init_sync_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec)), ("tcp-init-sync-phase-two-time-spec", ("tcp_init_sync_phase_two_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec)), ("tcp-init-sync-done-time-spec", ("tcp_init_sync_done_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                    ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                    ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                    ('is_external_neighbor_not_directly_connected', (YLeaf(YType.boolean, 'is-external-neighbor-not-directly-connected'), ['bool'])),
                                    ('messages_received', (YLeaf(YType.uint32, 'messages-received'), ['int'])),
                                    ('messages_sent', (YLeaf(YType.uint32, 'messages-sent'), ['int'])),
                                    ('update_messages_in', (YLeaf(YType.uint32, 'update-messages-in'), ['int'])),
                                    ('update_messages_out', (YLeaf(YType.uint32, 'update-messages-out'), ['int'])),
                                    ('messages_queued_in', (YLeaf(YType.uint32, 'messages-queued-in'), ['int'])),
                                    ('messages_queued_out', (YLeaf(YType.uint32, 'messages-queued-out'), ['int'])),
                                    ('connection_established_time', (YLeaf(YType.uint32, 'connection-established-time'), ['int'])),
                                    ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                    ('previous_connection_state', (YLeaf(YType.uint32, 'previous-connection-state'), ['int'])),
                                    ('connection_admin_status', (YLeaf(YType.uint32, 'connection-admin-status'), ['int'])),
                                    ('open_check_error_code', (YLeaf(YType.enumeration, 'open-check-error-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpOpenCheckErr', '')])),
                                    ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                    ('connection_local_port', (YLeaf(YType.uint32, 'connection-local-port'), ['int'])),
                                    ('connection_remote_port', (YLeaf(YType.uint32, 'connection-remote-port'), ['int'])),
                                    ('neighbor_interface_handle', (YLeaf(YType.uint32, 'neighbor-interface-handle'), ['int'])),
                                    ('reset_notification_sent', (YLeaf(YType.boolean, 'reset-notification-sent'), ['bool'])),
                                    ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                    ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                    ('is_out_of_memory_shutdown', (YLeaf(YType.boolean, 'is-out-of-memory-shutdown'), ['bool'])),
                                    ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                    ('is_ebgp_peer_as_league', (YLeaf(YType.boolean, 'is-ebgp-peer-as-league'), ['bool'])),
                                    ('is_ebgp_peer_common_admin', (YLeaf(YType.boolean, 'is-ebgp-peer-common-admin'), ['bool'])),
                                    ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                    ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                    ('bfd_session_state', (YLeaf(YType.enumeration, 'bfd-session-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                    ('bfd_session_created_state', (YLeaf(YType.enumeration, 'bfd-session-created-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdState', '')])),
                                    ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                    ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                    ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                    ('bfd_state_ts', (YLeaf(YType.uint64, 'bfd-state-ts'), ['int'])),
                                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                    ('negotiated_protocol_version', (YLeaf(YType.uint16, 'negotiated-protocol-version'), ['int'])),
                                    ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                    ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                    ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                    ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                    ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                    ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                    ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                    ('is_capability_negotiation_suppressed', (YLeaf(YType.boolean, 'is-capability-negotiation-suppressed'), ['bool'])),
                                    ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                    ('is_route_refresh_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-capability-received'), ['bool'])),
                                    ('is_route_refresh_old_capability_received', (YLeaf(YType.boolean, 'is-route-refresh-old-capability-received'), ['bool'])),
                                    ('is_gr_aware', (YLeaf(YType.boolean, 'is-gr-aware'), ['bool'])),
                                    ('is4_byte_as_capability_received', (YLeaf(YType.boolean, 'is4-byte-as-capability-received'), ['bool'])),
                                    ('is4_byte_as_capability_sent', (YLeaf(YType.boolean, 'is4-byte-as-capability-sent'), ['bool'])),
                                    ('multi_protocol_capability_received', (YLeaf(YType.boolean, 'multi-protocol-capability-received'), ['bool'])),
                                    ('hold_time', (YLeaf(YType.uint16, 'hold-time'), ['int'])),
                                    ('keep_alive_time', (YLeaf(YType.uint16, 'keep-alive-time'), ['int'])),
                                    ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                    ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                    ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                    ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                    ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                    ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                    ('connect_retry_interval', (YLeaf(YType.uint16, 'connect-retry-interval'), ['int'])),
                                    ('time_since_last_update', (YLeaf(YType.uint32, 'time-since-last-update'), ['int'])),
                                    ('time_since_last_read', (YLeaf(YType.uint32, 'time-since-last-read'), ['int'])),
                                    ('time_since_last_read_reset', (YLeaf(YType.uint32, 'time-since-last-read-reset'), ['int'])),
                                    ('time_last_cb', (YLeaf(YType.uint64, 'time-last-cb'), ['int'])),
                                    ('time_last_cb_reset', (YLeaf(YType.uint32, 'time-last-cb-reset'), ['int'])),
                                    ('time_last_fb', (YLeaf(YType.uint64, 'time-last-fb'), ['int'])),
                                    ('count_last_write', (YLeaf(YType.uint32, 'count-last-write'), ['int'])),
                                    ('time_since_last_write', (YLeaf(YType.uint32, 'time-since-last-write'), ['int'])),
                                    ('attempted_last_write_bytes', (YLeaf(YType.uint32, 'attempted-last-write-bytes'), ['int'])),
                                    ('actual_last_write_bytes', (YLeaf(YType.uint32, 'actual-last-write-bytes'), ['int'])),
                                    ('time_since_second_last_write', (YLeaf(YType.uint32, 'time-since-second-last-write'), ['int'])),
                                    ('attempted_second_last_write_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-bytes'), ['int'])),
                                    ('actual_second_last_write_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-bytes'), ['int'])),
                                    ('time_since_last_write_reset', (YLeaf(YType.uint32, 'time-since-last-write-reset'), ['int'])),
                                    ('attempted_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-last-write-reset-bytes'), ['int'])),
                                    ('actual_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-last-write-reset-bytes'), ['int'])),
                                    ('time_since_second_last_write_reset', (YLeaf(YType.uint32, 'time-since-second-last-write-reset'), ['int'])),
                                    ('attempted_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'attempted-second-last-write-reset-bytes'), ['int'])),
                                    ('actual_second_last_write_reset_bytes', (YLeaf(YType.uint32, 'actual-second-last-write-reset-bytes'), ['int'])),
                                    ('last_write_event', (YLeaf(YType.uint32, 'last-write-event'), ['int'])),
                                    ('second_last_write_event', (YLeaf(YType.uint32, 'second-last-write-event'), ['int'])),
                                    ('last_k_aexpiry_reset', (YLeaf(YType.uint32, 'last-k-aexpiry-reset'), ['int'])),
                                    ('second_last_k_aexpiry_reset', (YLeaf(YType.uint32, 'second-last-k-aexpiry-reset'), ['int'])),
                                    ('last_k_anotsent_reset', (YLeaf(YType.uint32, 'last-k-anotsent-reset'), ['int'])),
                                    ('last_k_aerror_reset', (YLeaf(YType.uint32, 'last-k-aerror-reset'), ['int'])),
                                    ('last_k_astart_reset', (YLeaf(YType.uint32, 'last-k-astart-reset'), ['int'])),
                                    ('second_last_k_astart_reset', (YLeaf(YType.uint32, 'second-last-k-astart-reset'), ['int'])),
                                    ('connection_up_count', (YLeaf(YType.uint32, 'connection-up-count'), ['int'])),
                                    ('connection_down_count', (YLeaf(YType.uint32, 'connection-down-count'), ['int'])),
                                    ('time_since_connection_last_dropped', (YLeaf(YType.uint32, 'time-since-connection-last-dropped'), ['int'])),
                                    ('reset_reason', (YLeaf(YType.enumeration, 'reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpResetReasonIndex', '')])),
                                    ('peer_reset_reason', (YLeaf(YType.enumeration, 'peer-reset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPeerResetReasonIndex', '')])),
                                    ('peer_error_code', (YLeaf(YType.uint32, 'peer-error-code'), ['int'])),
                                    ('last_notify_error_code', (YLeaf(YType.uint8, 'last-notify-error-code'), ['int'])),
                                    ('last_notify_error_subcode', (YLeaf(YType.uint8, 'last-notify-error-subcode'), ['int'])),
                                    ('error_notifies_received', (YLeaf(YType.uint32, 'error-notifies-received'), ['int'])),
                                    ('error_notifies_sent', (YLeaf(YType.uint32, 'error-notifies-sent'), ['int'])),
                                    ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                    ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                    ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                    ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                    ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                    ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                    ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                    ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                    ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                    ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                    ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                    ('fssn_offset', (YLeaf(YType.uint32, 'fssn-offset'), ['int'])),
                                    ('fpbsn_offset', (YLeaf(YType.uint32, 'fpbsn-offset'), ['int'])),
                                    ('last_ackd_seq_no', (YLeaf(YType.uint32, 'last-ackd-seq-no'), ['int'])),
                                    ('bytes_written', (YLeaf(YType.uint32, 'bytes-written'), ['int'])),
                                    ('bytes_read', (YLeaf(YType.uint32, 'bytes-read'), ['int'])),
                                    ('socket_read_bytes', (YLeaf(YType.uint32, 'socket-read-bytes'), ['int'])),
                                    ('is_read_disabled', (YLeaf(YType.boolean, 'is-read-disabled'), ['bool'])),
                                    ('update_bytes_read', (YLeaf(YType.uint32, 'update-bytes-read'), ['int'])),
                                    ('nsr_state', (YLeaf(YType.enumeration, 'nsr-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSyncNbrNsrState', '')])),
                                    ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                    ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                    ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                    ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                    ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                    ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                    ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                    ('io_armed', (YLeaf(YType.boolean, 'io-armed'), ['bool'])),
                                    ('read_armed', (YLeaf(YType.boolean, 'read-armed'), ['bool'])),
                                    ('write_armed', (YLeaf(YType.boolean, 'write-armed'), ['bool'])),
                                    ('discard_data_bytes', (YLeaf(YType.uint32, 'discard-data-bytes'), ['int'])),
                                    ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                    ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                    ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                    ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                    ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                    ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                    ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                    ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                    ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                    ('dynamic_neighbor', (YLeaf(YType.boolean, 'dynamic-neighbor'), ['bool'])),
                                ])
                                self.neighbor_address = None
                                self.speaker_id = None
                                self.description = None
                                self.local_as = None
                                self.remote_as = None
                                self.has_internal_link = None
                                self.is_external_neighbor_not_directly_connected = None
                                self.messages_received = None
                                self.messages_sent = None
                                self.update_messages_in = None
                                self.update_messages_out = None
                                self.messages_queued_in = None
                                self.messages_queued_out = None
                                self.connection_established_time = None
                                self.connection_state = None
                                self.previous_connection_state = None
                                self.connection_admin_status = None
                                self.open_check_error_code = None
                                self.is_local_address_configured = None
                                self.connection_local_port = None
                                self.connection_remote_port = None
                                self.neighbor_interface_handle = None
                                self.reset_notification_sent = None
                                self.is_administratively_shut_down = None
                                self.is_neighbor_max_prefix_shutdown = None
                                self.is_out_of_memory_shutdown = None
                                self.is_out_of_memory_forced_up = None
                                self.is_ebgp_peer_as_league = None
                                self.is_ebgp_peer_common_admin = None
                                self.ttl_security_enabled = None
                                self.suppress4_byte_as = None
                                self.bfd_session_state = None
                                self.bfd_session_created_state = None
                                self.bfd_session_enable_mode = None
                                self.bfd_minintervalval = None
                                self.bfd_multiplierval = None
                                self.bfd_state_ts = None
                                self.router_id = None
                                self.negotiated_protocol_version = None
                                self.ebgp_time_to_live = None
                                self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                self.tcpmss = None
                                self.msg_log_in = None
                                self.msg_log_out = None
                                self.neighbor_local_as = None
                                self.local_as_no_prepend = None
                                self.is_capability_negotiation_suppressed = None
                                self.is_capability_negotiation_performed = None
                                self.is_route_refresh_capability_received = None
                                self.is_route_refresh_old_capability_received = None
                                self.is_gr_aware = None
                                self.is4_byte_as_capability_received = None
                                self.is4_byte_as_capability_sent = None
                                self.multi_protocol_capability_received = None
                                self.hold_time = None
                                self.keep_alive_time = None
                                self.configured_hold_time = None
                                self.configured_keepalive = None
                                self.configured_min_acc_hold_time = None
                                self.min_advertise_interval = None
                                self.min_advertise_interval_msecs = None
                                self.min_origination_interval = None
                                self.connect_retry_interval = None
                                self.time_since_last_update = None
                                self.time_since_last_read = None
                                self.time_since_last_read_reset = None
                                self.time_last_cb = None
                                self.time_last_cb_reset = None
                                self.time_last_fb = None
                                self.count_last_write = None
                                self.time_since_last_write = None
                                self.attempted_last_write_bytes = None
                                self.actual_last_write_bytes = None
                                self.time_since_second_last_write = None
                                self.attempted_second_last_write_bytes = None
                                self.actual_second_last_write_bytes = None
                                self.time_since_last_write_reset = None
                                self.attempted_last_write_reset_bytes = None
                                self.actual_last_write_reset_bytes = None
                                self.time_since_second_last_write_reset = None
                                self.attempted_second_last_write_reset_bytes = None
                                self.actual_second_last_write_reset_bytes = None
                                self.last_write_event = None
                                self.second_last_write_event = None
                                self.last_k_aexpiry_reset = None
                                self.second_last_k_aexpiry_reset = None
                                self.last_k_anotsent_reset = None
                                self.last_k_aerror_reset = None
                                self.last_k_astart_reset = None
                                self.second_last_k_astart_reset = None
                                self.connection_up_count = None
                                self.connection_down_count = None
                                self.time_since_connection_last_dropped = None
                                self.reset_reason = None
                                self.peer_reset_reason = None
                                self.peer_error_code = None
                                self.last_notify_error_code = None
                                self.last_notify_error_subcode = None
                                self.error_notifies_received = None
                                self.error_notifies_sent = None
                                self.remote_as_number = None
                                self.dmz_link_bandwidth = None
                                self.ebgp_recv_dmz = None
                                self.ebgp_send_dmz_mode = None
                                self.tos_type = None
                                self.tos_value = None
                                self.tcp_session_open_mode = None
                                self.vrf_name = None
                                self.standby_rp = None
                                self.nsr_enabled = None
                                self.graceful_restart_enabled_nbr = None
                                self.gr_restart_time = None
                                self.gr_stale_path_time = None
                                self.fssn_offset = None
                                self.fpbsn_offset = None
                                self.last_ackd_seq_no = None
                                self.bytes_written = None
                                self.bytes_read = None
                                self.socket_read_bytes = None
                                self.is_read_disabled = None
                                self.update_bytes_read = None
                                self.nsr_state = None
                                self.is_passive_close = None
                                self.nbr_enforce_first_as = None
                                self.active_bmp_servers = None
                                self.nbr_cluster_id = None
                                self.nbr_in_cluster = None
                                self.ignore_connected = None
                                self.internal_vpn_client = None
                                self.io_armed = None
                                self.read_armed = None
                                self.write_armed = None
                                self.discard_data_bytes = None
                                self.local_as_replace_as = None
                                self.local_as_dual_as = None
                                self.local_as_dual_as_mode_native = None
                                self.egress_peer_engineering_enabled = None
                                self.discard_as4_path = None
                                self.rpki_disable = None
                                self.rpki_use_validity = None
                                self.rpki_allow_invalid = None
                                self.rpki_signal_ibgp = None
                                self.dynamic_neighbor = None

                                self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                self.send_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo()
                                self.send_notification_info.parent = self
                                self._children_name_map["send_notification_info"] = "send-notification-info"

                                self.received_notification_info = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo()
                                self.received_notification_info.parent = self
                                self._children_name_map["received_notification_info"] = "received-notification-info"

                                self.performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics()
                                self.performance_statistics.parent = self
                                self._children_name_map["performance_statistics"] = "performance-statistics"

                                self.message_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics()
                                self.message_statistics.parent = self
                                self._children_name_map["message_statistics"] = "message-statistics"

                                self.tcp_init_sync_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec()
                                self.tcp_init_sync_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_time_spec"] = "tcp-init-sync-time-spec"

                                self.tcp_init_sync_phase_two_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec()
                                self.tcp_init_sync_phase_two_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_phase_two_time_spec"] = "tcp-init-sync-phase-two-time-spec"

                                self.tcp_init_sync_done_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec()
                                self.tcp_init_sync_done_time_spec.parent = self
                                self._children_name_map["tcp_init_sync_done_time_spec"] = "tcp-init-sync-done-time-spec"

                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                self.af_data = YList(self)
                                self._segment_path = lambda: "neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor, ['neighbor_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_external_neighbor_not_directly_connected', u'messages_received', u'messages_sent', u'update_messages_in', u'update_messages_out', u'messages_queued_in', u'messages_queued_out', u'connection_established_time', u'connection_state', u'previous_connection_state', u'connection_admin_status', u'open_check_error_code', u'is_local_address_configured', u'connection_local_port', u'connection_remote_port', u'neighbor_interface_handle', u'reset_notification_sent', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_shutdown', u'is_out_of_memory_forced_up', u'is_ebgp_peer_as_league', u'is_ebgp_peer_common_admin', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_state', u'bfd_session_created_state', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'bfd_state_ts', u'router_id', u'negotiated_protocol_version', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_suppressed', u'is_capability_negotiation_performed', u'is_route_refresh_capability_received', u'is_route_refresh_old_capability_received', u'is_gr_aware', u'is4_byte_as_capability_received', u'is4_byte_as_capability_sent', u'multi_protocol_capability_received', u'hold_time', u'keep_alive_time', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'connect_retry_interval', u'time_since_last_update', u'time_since_last_read', u'time_since_last_read_reset', u'time_last_cb', u'time_last_cb_reset', u'time_last_fb', u'count_last_write', u'time_since_last_write', u'attempted_last_write_bytes', u'actual_last_write_bytes', u'time_since_second_last_write', u'attempted_second_last_write_bytes', u'actual_second_last_write_bytes', u'time_since_last_write_reset', u'attempted_last_write_reset_bytes', u'actual_last_write_reset_bytes', u'time_since_second_last_write_reset', u'attempted_second_last_write_reset_bytes', u'actual_second_last_write_reset_bytes', u'last_write_event', u'second_last_write_event', u'last_k_aexpiry_reset', u'second_last_k_aexpiry_reset', u'last_k_anotsent_reset', u'last_k_aerror_reset', u'last_k_astart_reset', u'second_last_k_astart_reset', u'connection_up_count', u'connection_down_count', u'time_since_connection_last_dropped', u'reset_reason', u'peer_reset_reason', u'peer_error_code', u'last_notify_error_code', u'last_notify_error_subcode', u'error_notifies_received', u'error_notifies_sent', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'fssn_offset', u'fpbsn_offset', u'last_ackd_seq_no', u'bytes_written', u'bytes_read', u'socket_read_bytes', u'is_read_disabled', u'update_bytes_read', u'nsr_state', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'io_armed', u'read_armed', u'write_armed', u'discard_data_bytes', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'dynamic_neighbor'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-local-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-remote-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class SendNotificationInfo(Entity):
                                """
                                Information on the last notification sent
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo, self).__init__()

                                    self.yang_name = "send-notification-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData))])
                                    self._leafs = OrderedDict([
                                        ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                        ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                        ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                    ])
                                    self.time_since_last_notification = None
                                    self.notification_error_code = None
                                    self.notification_error_subcode = None

                                    self.last_notification_data = YList(self)
                                    self._segment_path = lambda: "send-notification-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                class LastNotificationData(Entity):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, self).__init__()

                                        self.yang_name = "last-notification-data"
                                        self.yang_parent_name = "send-notification-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "last-notification-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.SendNotificationInfo.LastNotificationData, [u'entry'], name, value)


                            class ReceivedNotificationInfo(Entity):
                                """
                                Information on the last notification received
                                
                                .. attribute:: time_since_last_notification
                                
                                	Time since the last notification was sent or received (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: notification_error_code
                                
                                	Error code in last notification
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: notification_error_subcode
                                
                                	Error subcode in last notification
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: last_notification_data
                                
                                	Message data in last notification
                                	**type**\: list of  		 :py:class:`LastNotificationData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo, self).__init__()

                                    self.yang_name = "received-notification-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("last-notification-data", ("last_notification_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData))])
                                    self._leafs = OrderedDict([
                                        ('time_since_last_notification', (YLeaf(YType.uint32, 'time-since-last-notification'), ['int'])),
                                        ('notification_error_code', (YLeaf(YType.uint8, 'notification-error-code'), ['int'])),
                                        ('notification_error_subcode', (YLeaf(YType.uint8, 'notification-error-subcode'), ['int'])),
                                    ])
                                    self.time_since_last_notification = None
                                    self.notification_error_code = None
                                    self.notification_error_subcode = None

                                    self.last_notification_data = YList(self)
                                    self._segment_path = lambda: "received-notification-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo, [u'time_since_last_notification', u'notification_error_code', u'notification_error_subcode'], name, value)


                                class LastNotificationData(Entity):
                                    """
                                    Message data in last notification
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, self).__init__()

                                        self.yang_name = "last-notification-data"
                                        self.yang_parent_name = "received-notification-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "last-notification-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.ReceivedNotificationInfo.LastNotificationData, [u'entry'], name, value)


                            class PerformanceStatistics(Entity):
                                """
                                Performance statistics
                                
                                .. attribute:: read_throttles
                                
                                	Number of partial read throttles
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_throttled_read
                                
                                	Num socket reads after nbrs crossed low threshold
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high_throttled_read
                                
                                	Num of socket reads after nbr crossed high threshold
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_since_last_throttled_read
                                
                                	Time (in secs) since last read after being throttled
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: read_calls_count
                                
                                	No. of calls to function to read inbound data
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: read_messages_count
                                
                                	Number of BGP messages read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_read
                                
                                	No. of bytes of data read
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: io_read_time
                                
                                	Time spent reading inbound data (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_calls_count
                                
                                	No. of calls to function to write outbound data
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: data_bytes_written
                                
                                	No. of data bytes written
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte
                                
                                .. attribute:: io_write_time
                                
                                	Time spent writing outbound data (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: last_sent_seq_no
                                
                                	Seq No of the last sent byte
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_calls_count
                                
                                	No. of calls to function to process sub\-group message list
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_subgroup_messages_count
                                
                                	Number of sub\-group msgs processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: subgroup_list_time
                                
                                	Time spent processing sub\-group message list  (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: write_queue_calls_count
                                
                                	No. of calls to function to process write queue
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_messages_count
                                
                                	Number of write queue messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: write_queue_time
                                
                                	Time spent processing write queue (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: inbound_update_messages
                                
                                	Number of inbound update messages processed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inbound_update_messages_time
                                
                                	Time spent processing inbound update messages (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: maximum_read_size
                                
                                	Size of largest socket (milliseconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: actives
                                
                                	Number of retried Active opens for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: failed_post_actives
                                
                                	Number of Active Opens that failed in the Post Active State for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passives
                                
                                	Number of retried Passive opens for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rejected_passives
                                
                                	Number of rejected Passive opens for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: active_collision
                                
                                	Number of Closed Active connections for this neighbor due to collision 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: passive_collision
                                
                                	Number of Closed Remote opens for this neighborneighbor due to collision 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_read_thread_trigger
                                
                                	Number of times io\-control thread trigger read thread
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: control_to_write_thread_trigger
                                
                                	Number of times io\-control thread trigger write thread
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: network_status
                                
                                	Socket status, TRUE if socket closed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reset_flags
                                
                                	Reset flags, per thread
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_flags
                                
                                	Nbr flags, per thread
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nbr_fd
                                
                                	Primary FD, per nbr
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: reset_retries
                                
                                	Reset Retries, per nbr
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: sync_flags
                                
                                	Sync flags, per nbr
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_oper_down_count
                                
                                	Number of times NSR scoped sync has been done
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_nsr_scoped_sync
                                
                                	Last time NSR scoped syncwas done for the neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics, self).__init__()

                                    self.yang_name = "performance-statistics"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('read_throttles', (YLeaf(YType.uint32, 'read-throttles'), ['int'])),
                                        ('low_throttled_read', (YLeaf(YType.uint32, 'low-throttled-read'), ['int'])),
                                        ('high_throttled_read', (YLeaf(YType.uint32, 'high-throttled-read'), ['int'])),
                                        ('time_since_last_throttled_read', (YLeaf(YType.uint32, 'time-since-last-throttled-read'), ['int'])),
                                        ('read_calls_count', (YLeaf(YType.uint32, 'read-calls-count'), ['int'])),
                                        ('read_messages_count', (YLeaf(YType.uint32, 'read-messages-count'), ['int'])),
                                        ('data_bytes_read', (YLeaf(YType.uint32, 'data-bytes-read'), ['int'])),
                                        ('io_read_time', (YLeaf(YType.uint32, 'io-read-time'), ['int'])),
                                        ('write_calls_count', (YLeaf(YType.uint32, 'write-calls-count'), ['int'])),
                                        ('data_bytes_written', (YLeaf(YType.uint32, 'data-bytes-written'), ['int'])),
                                        ('io_write_time', (YLeaf(YType.uint32, 'io-write-time'), ['int'])),
                                        ('last_sent_seq_no', (YLeaf(YType.uint32, 'last-sent-seq-no'), ['int'])),
                                        ('write_subgroup_calls_count', (YLeaf(YType.uint32, 'write-subgroup-calls-count'), ['int'])),
                                        ('write_subgroup_messages_count', (YLeaf(YType.uint32, 'write-subgroup-messages-count'), ['int'])),
                                        ('subgroup_list_time', (YLeaf(YType.uint32, 'subgroup-list-time'), ['int'])),
                                        ('write_queue_calls_count', (YLeaf(YType.uint32, 'write-queue-calls-count'), ['int'])),
                                        ('write_queue_messages_count', (YLeaf(YType.uint32, 'write-queue-messages-count'), ['int'])),
                                        ('write_queue_time', (YLeaf(YType.uint32, 'write-queue-time'), ['int'])),
                                        ('inbound_update_messages', (YLeaf(YType.uint32, 'inbound-update-messages'), ['int'])),
                                        ('inbound_update_messages_time', (YLeaf(YType.uint32, 'inbound-update-messages-time'), ['int'])),
                                        ('maximum_read_size', (YLeaf(YType.uint32, 'maximum-read-size'), ['int'])),
                                        ('actives', (YLeaf(YType.uint32, 'actives'), ['int'])),
                                        ('failed_post_actives', (YLeaf(YType.uint32, 'failed-post-actives'), ['int'])),
                                        ('passives', (YLeaf(YType.uint32, 'passives'), ['int'])),
                                        ('rejected_passives', (YLeaf(YType.uint32, 'rejected-passives'), ['int'])),
                                        ('active_collision', (YLeaf(YType.uint32, 'active-collision'), ['int'])),
                                        ('passive_collision', (YLeaf(YType.uint32, 'passive-collision'), ['int'])),
                                        ('control_to_read_thread_trigger', (YLeaf(YType.uint32, 'control-to-read-thread-trigger'), ['int'])),
                                        ('control_to_write_thread_trigger', (YLeaf(YType.uint32, 'control-to-write-thread-trigger'), ['int'])),
                                        ('network_status', (YLeaf(YType.uint32, 'network-status'), ['int'])),
                                        ('reset_flags', (YLeaf(YType.uint32, 'reset-flags'), ['int'])),
                                        ('nbr_flags', (YLeaf(YType.uint32, 'nbr-flags'), ['int'])),
                                        ('nbr_fd', (YLeaf(YType.int32, 'nbr-fd'), ['int'])),
                                        ('reset_retries', (YLeaf(YType.uint8, 'reset-retries'), ['int'])),
                                        ('sync_flags', (YLeaf(YType.uint32, 'sync-flags'), ['int'])),
                                        ('nsr_oper_down_count', (YLeaf(YType.uint32, 'nsr-oper-down-count'), ['int'])),
                                        ('last_nsr_scoped_sync', (YLeaf(YType.uint32, 'last-nsr-scoped-sync'), ['int'])),
                                    ])
                                    self.read_throttles = None
                                    self.low_throttled_read = None
                                    self.high_throttled_read = None
                                    self.time_since_last_throttled_read = None
                                    self.read_calls_count = None
                                    self.read_messages_count = None
                                    self.data_bytes_read = None
                                    self.io_read_time = None
                                    self.write_calls_count = None
                                    self.data_bytes_written = None
                                    self.io_write_time = None
                                    self.last_sent_seq_no = None
                                    self.write_subgroup_calls_count = None
                                    self.write_subgroup_messages_count = None
                                    self.subgroup_list_time = None
                                    self.write_queue_calls_count = None
                                    self.write_queue_messages_count = None
                                    self.write_queue_time = None
                                    self.inbound_update_messages = None
                                    self.inbound_update_messages_time = None
                                    self.maximum_read_size = None
                                    self.actives = None
                                    self.failed_post_actives = None
                                    self.passives = None
                                    self.rejected_passives = None
                                    self.active_collision = None
                                    self.passive_collision = None
                                    self.control_to_read_thread_trigger = None
                                    self.control_to_write_thread_trigger = None
                                    self.network_status = None
                                    self.reset_flags = None
                                    self.nbr_flags = None
                                    self.nbr_fd = None
                                    self.reset_retries = None
                                    self.sync_flags = None
                                    self.nsr_oper_down_count = None
                                    self.last_nsr_scoped_sync = None
                                    self._segment_path = lambda: "performance-statistics"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.PerformanceStatistics, [u'read_throttles', u'low_throttled_read', u'high_throttled_read', u'time_since_last_throttled_read', u'read_calls_count', u'read_messages_count', u'data_bytes_read', u'io_read_time', u'write_calls_count', u'data_bytes_written', u'io_write_time', u'last_sent_seq_no', u'write_subgroup_calls_count', u'write_subgroup_messages_count', u'subgroup_list_time', u'write_queue_calls_count', u'write_queue_messages_count', u'write_queue_time', u'inbound_update_messages', u'inbound_update_messages_time', u'maximum_read_size', u'actives', u'failed_post_actives', u'passives', u'rejected_passives', u'active_collision', u'passive_collision', u'control_to_read_thread_trigger', u'control_to_write_thread_trigger', u'network_status', u'reset_flags', u'nbr_flags', u'nbr_fd', u'reset_retries', u'sync_flags', u'nsr_oper_down_count', u'last_nsr_scoped_sync'], name, value)


                            class MessageStatistics(Entity):
                                """
                                Message statistics
                                
                                .. attribute:: open
                                
                                	Open
                                	**type**\:  :py:class:`Open <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open>`
                                
                                .. attribute:: notification
                                
                                	Notification
                                	**type**\:  :py:class:`Notification <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification>`
                                
                                .. attribute:: update
                                
                                	Update
                                	**type**\:  :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update>`
                                
                                .. attribute:: keepalive
                                
                                	Keepalive
                                	**type**\:  :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive>`
                                
                                .. attribute:: route_refresh
                                
                                	Route refresh
                                	**type**\:  :py:class:`RouteRefresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh>`
                                
                                .. attribute:: total
                                
                                	Total
                                	**type**\:  :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics, self).__init__()

                                    self.yang_name = "message-statistics"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("open", ("open", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open)), ("notification", ("notification", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification)), ("update", ("update", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update)), ("keepalive", ("keepalive", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive)), ("route-refresh", ("route_refresh", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh)), ("total", ("total", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total))])
                                    self._leafs = OrderedDict()

                                    self.open = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open()
                                    self.open.parent = self
                                    self._children_name_map["open"] = "open"

                                    self.notification = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification()
                                    self.notification.parent = self
                                    self._children_name_map["notification"] = "notification"

                                    self.update = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update()
                                    self.update.parent = self
                                    self._children_name_map["update"] = "update"

                                    self.keepalive = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive()
                                    self.keepalive.parent = self
                                    self._children_name_map["keepalive"] = "keepalive"

                                    self.route_refresh = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh()
                                    self.route_refresh.parent = self
                                    self._children_name_map["route_refresh"] = "route-refresh"

                                    self.total = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total()
                                    self.total.parent = self
                                    self._children_name_map["total"] = "total"
                                    self._segment_path = lambda: "message-statistics"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics, [], name, value)


                                class Open(Entity):
                                    """
                                    Open
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open, self).__init__()

                                        self.yang_name = "open"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "open"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "open"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "open"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Open.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class Notification(Entity):
                                    """
                                    Notification
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification, self).__init__()

                                        self.yang_name = "notification"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "notification"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "notification"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Notification.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class Update(Entity):
                                    """
                                    Update
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update, self).__init__()

                                        self.yang_name = "update"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "update"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "update"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "update"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Update.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class Keepalive(Entity):
                                    """
                                    Keepalive
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive, self).__init__()

                                        self.yang_name = "keepalive"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "keepalive"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "keepalive"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "keepalive"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Keepalive.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class RouteRefresh(Entity):
                                    """
                                    Route refresh
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, self).__init__()

                                        self.yang_name = "route-refresh"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "route-refresh"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "route-refresh"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "route-refresh"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.RouteRefresh.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                class Total(Entity):
                                    """
                                    Total
                                    
                                    .. attribute:: tx
                                    
                                    	Transmit
                                    	**type**\:  :py:class:`Tx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx>`
                                    
                                    .. attribute:: rx
                                    
                                    	Receive
                                    	**type**\:  :py:class:`Rx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total, self).__init__()

                                        self.yang_name = "total"
                                        self.yang_parent_name = "message-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tx", ("tx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx)), ("rx", ("rx", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx))])
                                        self._leafs = OrderedDict()

                                        self.tx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx()
                                        self.tx.parent = self
                                        self._children_name_map["tx"] = "tx"

                                        self.rx = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx()
                                        self.rx.parent = self
                                        self._children_name_map["rx"] = "rx"
                                        self._segment_path = lambda: "total"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total, [], name, value)


                                    class Tx(Entity):
                                        """
                                        Transmit
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, self).__init__()

                                            self.yang_name = "tx"
                                            self.yang_parent_name = "total"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "tx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "tx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Tx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                                    class Rx(Entity):
                                        """
                                        Receive
                                        
                                        .. attribute:: last_time_spec
                                        
                                        	Last timespec
                                        	**type**\:  :py:class:`LastTimeSpec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec>`
                                        
                                        .. attribute:: count
                                        
                                        	Count
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, self).__init__()

                                            self.yang_name = "rx"
                                            self.yang_parent_name = "total"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("last-time-spec", ("last_time_spec", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec))])
                                            self._leafs = OrderedDict([
                                                ('count', (YLeaf(YType.uint32, 'count'), ['int'])),
                                            ])
                                            self.count = None

                                            self.last_time_spec = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec()
                                            self.last_time_spec.parent = self
                                            self._children_name_map["last_time_spec"] = "last-time-spec"
                                            self._segment_path = lambda: "rx"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx, [u'count'], name, value)


                                        class LastTimeSpec(Entity):
                                            """
                                            Last timespec
                                            
                                            .. attribute:: seconds
                                            
                                            	Seconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nanoseconds
                                            
                                            	Nanoseconds part of time value
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, self).__init__()

                                                self.yang_name = "last-time-spec"
                                                self.yang_parent_name = "rx"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nanoseconds = None
                                                self._segment_path = lambda: "last-time-spec"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.MessageStatistics.Total.Rx.LastTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                            class TcpInitSyncTimeSpec(Entity):
                                """
                                Time When neighbor entered TCP Init Sync
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "tcp-init-sync-time-spec"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                            class TcpInitSyncPhaseTwoTimeSpec(Entity):
                                """
                                Time when neighbor entered TCP Init Sync Phase
                                Two
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-phase-two-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "tcp-init-sync-phase-two-time-spec"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncPhaseTwoTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                            class TcpInitSyncDoneTimeSpec(Entity):
                                """
                                Time when neighbor entered TCP Init Sync Done
                                
                                .. attribute:: seconds
                                
                                	Seconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanoseconds
                                
                                	Nanoseconds part of time value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, self).__init__()

                                    self.yang_name = "tcp-init-sync-done-time-spec"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                        ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                    ])
                                    self.seconds = None
                                    self.nanoseconds = None
                                    self._segment_path = lambda: "tcp-init-sync-done-time-spec"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.TcpInitSyncDoneTimeSpec, [u'seconds', u'nanoseconds'], name, value)


                            class GracefulMaintenance(Entity):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\: bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\: bool
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\: bool
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\: bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance, self).__init__()

                                    self.yang_name = "graceful-maintenance"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                        ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                        ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                        ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                        ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                        ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                    ])
                                    self.gshut_exists = None
                                    self.gshut_local_active = None
                                    self.gshut_active = None
                                    self.gshut_locpref_set = None
                                    self.gshut_locpref = None
                                    self.gshut_prepends = None
                                    self._segment_path = lambda: "graceful-maintenance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                            class AfData(Entity):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: neighbor_af_performance_statistics
                                
                                	Neighbor AF statistics
                                	**type**\:  :py:class:`NeighborAfPerformanceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics>`
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\: bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\: bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\: bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\: bool
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\: bool
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\: str
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_rt_type
                                
                                	Advertise RT type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: advertise_afi_def_vrf_imp_disable
                                
                                	Advertise of default VRF import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_evpnv4_afi_def_vrf_imp_disable
                                
                                	Advertise of v4 default VRF import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_evpnv6_afi_def_vrf_imp_disable
                                
                                	Advertise of v6 default VRF import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_vrf_re_imp_disable
                                
                                	Advertise of VRF re\-import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_evpnv4_afi_vrf_re_imp_disable
                                
                                	Advertise of v4 VRF re\-import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_evpnv6_afi_vrf_re_imp_disable
                                
                                	Advertise of v6 VRF re\-import disable
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_eo_r_ready
                                
                                	EoR Can be sent for Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\: bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\: bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\: bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\: bool
                                
                                .. attribute:: update_group_number
                                
                                	Update group index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: filter_group_index
                                
                                	Filter group index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_update_throttled
                                
                                	Updates Throttled becausewrite limit is reached
                                	**type**\: bool
                                
                                .. attribute:: is_update_leaving
                                
                                	Nbr leaving update\-groupto another
                                	**type**\: bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\: bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\: bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\: bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\: bool
                                
                                .. attribute:: neighbor_version
                                
                                	Neighbor version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: prefixes_accepted
                                
                                	No. of prefixes accepted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_synced
                                
                                	Number of prefixes synced to standby
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn_not_found
                                
                                	No. of prefixes withdrawn but not found
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied
                                
                                	No. of prefixes denied
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_no_policy
                                
                                	No. of prefixes denied because there was no inbound policy
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_rt_permit
                                
                                	No. of prefixes denied because RT extended community is not imported
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_orf_policy
                                
                                	No. of prefixes denied by prefix based ORF policy
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_denied_policy
                                
                                	No. of prefixes denied by inbound policy
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_bestpaths
                                
                                	No. of bestpaths from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_best_externalpaths
                                
                                	No. of best\-external paths from this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_advertised
                                
                                	No. of prefixes advertised
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_be_advertised
                                
                                	No BE prefixes advertised
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_suppressed
                                
                                	No. of prefixes suppressed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefixes_withdrawn
                                
                                	No. of prefixes withdrawn
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\: bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\: bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_received
                                
                                	Extended nexthop encoding capability received
                                	**type**\: bool
                                
                                .. attribute:: is_ext_nh_encoding_capability_sent
                                
                                	Extended nexhop encoding capability Sent
                                	**type**\: bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\: bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\: bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_refreshes_received
                                
                                	Number of route refresh requests received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_refreshes_sent
                                
                                	Number of route refresh requests sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_target_version
                                
                                	Target version for refresh update generation
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_version
                                
                                	Version till which refresh updates have been generated
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: refresh_acked_version
                                
                                	Version acked by the peer for refresh updates sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\: bool
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_default_originate_sent
                                
                                	Default origination update sent
                                	**type**\: bool
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\: str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\: str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\: str
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\: str
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\: bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\: bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\: bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: eo_r_received_in_read_only
                                
                                	An EoR was received while in read\-only mode
                                	**type**\: bool
                                
                                .. attribute:: acked_version
                                
                                	Version mapped from acked seqNo
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: synced_acked_version
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outstanding_version
                                
                                	No. of all outstanding version objects waiting for ack from the peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outstanding_refresh_version
                                
                                	No. of only refresh version objects waiting for ack from the peer
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: outstanding_version_max
                                
                                	Version mapped from acked seqNo that was synced last
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\: bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\: bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\: bool
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\: bool
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\: bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\: bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\: bool
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\: bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\: bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\: bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\: bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\: bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\: bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\: bool
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_local_labeled_route_unicast
                                
                                	Advertise routes with 
                                	**type**\: bool
                                
                                .. attribute:: prefixes_denied_non_cumulative
                                
                                	No. of prefixes exactly denied (non cumulative)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: enable_label_stack
                                
                                	Enable label stack
                                	**type**\: bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData, self).__init__()

                                    self.yang_name = "af-data"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-af-performance-statistics", ("neighbor_af_performance_statistics", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                        ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                        ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                        ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                        ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                        ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                        ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                        ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                        ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                        ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                        ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                        ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                        ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                        ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                        ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                        ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                        ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                        ('encapsulation_type', (YLeaf(YType.uint32, 'encapsulation-type'), ['int'])),
                                        ('advertise_rt_type', (YLeaf(YType.uint8, 'advertise-rt-type'), ['int'])),
                                        ('advertise_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-def-vrf-imp-disable'), ['bool'])),
                                        ('advertise_evpnv4_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-def-vrf-imp-disable'), ['bool'])),
                                        ('advertise_evpnv6_afi_def_vrf_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-def-vrf-imp-disable'), ['bool'])),
                                        ('advertise_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-afi-vrf-re-imp-disable'), ['bool'])),
                                        ('advertise_evpnv4_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv4-afi-vrf-re-imp-disable'), ['bool'])),
                                        ('advertise_evpnv6_afi_vrf_re_imp_disable', (YLeaf(YType.boolean, 'advertise-evpnv6-afi-vrf-re-imp-disable'), ['bool'])),
                                        ('advertise_afi_eo_r_ready', (YLeaf(YType.boolean, 'advertise-afi-eo-r-ready'), ['bool'])),
                                        ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                        ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                        ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                        ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                        ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                        ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                        ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                        ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                        ('update_group_number', (YLeaf(YType.uint32, 'update-group-number'), ['int'])),
                                        ('filter_group_index', (YLeaf(YType.uint32, 'filter-group-index'), ['int'])),
                                        ('is_update_throttled', (YLeaf(YType.boolean, 'is-update-throttled'), ['bool'])),
                                        ('is_update_leaving', (YLeaf(YType.boolean, 'is-update-leaving'), ['bool'])),
                                        ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                        ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                        ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                        ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                        ('neighbor_version', (YLeaf(YType.uint32, 'neighbor-version'), ['int'])),
                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                        ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                        ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                        ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                        ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                        ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                        ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                        ('prefixes_accepted', (YLeaf(YType.uint32, 'prefixes-accepted'), ['int'])),
                                        ('prefixes_synced', (YLeaf(YType.uint32, 'prefixes-synced'), ['int'])),
                                        ('prefixes_withdrawn_not_found', (YLeaf(YType.uint32, 'prefixes-withdrawn-not-found'), ['int'])),
                                        ('prefixes_denied', (YLeaf(YType.uint32, 'prefixes-denied'), ['int'])),
                                        ('prefixes_denied_no_policy', (YLeaf(YType.uint32, 'prefixes-denied-no-policy'), ['int'])),
                                        ('prefixes_denied_rt_permit', (YLeaf(YType.uint32, 'prefixes-denied-rt-permit'), ['int'])),
                                        ('prefixes_denied_orf_policy', (YLeaf(YType.uint32, 'prefixes-denied-orf-policy'), ['int'])),
                                        ('prefixes_denied_policy', (YLeaf(YType.uint32, 'prefixes-denied-policy'), ['int'])),
                                        ('number_of_bestpaths', (YLeaf(YType.uint32, 'number-of-bestpaths'), ['int'])),
                                        ('number_of_best_externalpaths', (YLeaf(YType.uint32, 'number-of-best-externalpaths'), ['int'])),
                                        ('prefixes_advertised', (YLeaf(YType.uint32, 'prefixes-advertised'), ['int'])),
                                        ('prefixes_be_advertised', (YLeaf(YType.uint32, 'prefixes-be-advertised'), ['int'])),
                                        ('prefixes_suppressed', (YLeaf(YType.uint32, 'prefixes-suppressed'), ['int'])),
                                        ('prefixes_withdrawn', (YLeaf(YType.uint32, 'prefixes-withdrawn'), ['int'])),
                                        ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                        ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                        ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                        ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                        ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                        ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                        ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                        ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                        ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                        ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                        ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                        ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                        ('is_ext_nh_encoding_capability_received', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-received'), ['bool'])),
                                        ('is_ext_nh_encoding_capability_sent', (YLeaf(YType.boolean, 'is-ext-nh-encoding-capability-sent'), ['bool'])),
                                        ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                        ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                        ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                        ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                        ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                        ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                        ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                        ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                        ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                        ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                        ('route_refreshes_received', (YLeaf(YType.uint32, 'route-refreshes-received'), ['int'])),
                                        ('route_refreshes_sent', (YLeaf(YType.uint32, 'route-refreshes-sent'), ['int'])),
                                        ('refresh_target_version', (YLeaf(YType.uint32, 'refresh-target-version'), ['int'])),
                                        ('refresh_version', (YLeaf(YType.uint32, 'refresh-version'), ['int'])),
                                        ('refresh_acked_version', (YLeaf(YType.uint32, 'refresh-acked-version'), ['int'])),
                                        ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                        ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                        ('is_default_originate_sent', (YLeaf(YType.boolean, 'is-default-originate-sent'), ['bool'])),
                                        ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                        ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                        ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                        ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                        ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                        ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                        ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                        ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                        ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                        ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                        ('eo_r_received_in_read_only', (YLeaf(YType.boolean, 'eo-r-received-in-read-only'), ['bool'])),
                                        ('acked_version', (YLeaf(YType.uint32, 'acked-version'), ['int'])),
                                        ('synced_acked_version', (YLeaf(YType.uint32, 'synced-acked-version'), ['int'])),
                                        ('outstanding_version', (YLeaf(YType.uint32, 'outstanding-version'), ['int'])),
                                        ('outstanding_refresh_version', (YLeaf(YType.uint32, 'outstanding-refresh-version'), ['int'])),
                                        ('outstanding_version_max', (YLeaf(YType.uint32, 'outstanding-version-max'), ['int'])),
                                        ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                        ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                        ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                        ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                        ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                        ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                        ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                        ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                        ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                        ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                        ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                        ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                        ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                        ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                        ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                        ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                        ('advertise_local_labeled_route_unicast', (YLeaf(YType.boolean, 'advertise-local-labeled-route-unicast'), ['bool'])),
                                        ('prefixes_denied_non_cumulative', (YLeaf(YType.uint32, 'prefixes-denied-non-cumulative'), ['int'])),
                                        ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                    ])
                                    self.af_name = None
                                    self.is_neighbor_route_reflector_client = None
                                    self.is_legacy_pe_rt = None
                                    self.is_neighbor_af_capable = None
                                    self.is_soft_reconfiguration_inbound_allowed = None
                                    self.is_use_soft_reconfiguration_always_on = None
                                    self.remove_private_as_from_updates = None
                                    self.remove_private_as_entire_aspath_from_updates = None
                                    self.remove_private_as_from_inbound_updates = None
                                    self.remove_private_as_entire_aspath_from_inbound_updates = None
                                    self.flowspec_validation_d_isable = None
                                    self.flowspec_redirect_validation_d_isable = None
                                    self.orr_group_name = None
                                    self.orr_group_index = None
                                    self.is_orr_root_address_configured = None
                                    self.advertise_afi = None
                                    self.advertise_afi_reorg = None
                                    self.advertise_afi_disable = None
                                    self.encapsulation_type = None
                                    self.advertise_rt_type = None
                                    self.advertise_afi_def_vrf_imp_disable = None
                                    self.advertise_evpnv4_afi_def_vrf_imp_disable = None
                                    self.advertise_evpnv6_afi_def_vrf_imp_disable = None
                                    self.advertise_afi_vrf_re_imp_disable = None
                                    self.advertise_evpnv4_afi_vrf_re_imp_disable = None
                                    self.advertise_evpnv6_afi_vrf_re_imp_disable = None
                                    self.advertise_afi_eo_r_ready = None
                                    self.always_use_next_hop_local = None
                                    self.sent_community_to_neighbor = None
                                    self.sent_gshut_community_to_neighbor = None
                                    self.sent_extended_community_to_neighbor = None
                                    self.neighbor_default_originate = None
                                    self.is_orf_sent = None
                                    self.is_update_deferred = None
                                    self.is_orf_send_scheduled = None
                                    self.update_group_number = None
                                    self.filter_group_index = None
                                    self.is_update_throttled = None
                                    self.is_update_leaving = None
                                    self.vpn_update_gen_enabled = None
                                    self.vpn_update_gen_trigger_enabled = None
                                    self.is_addpath_send_operational = None
                                    self.is_addpath_receive_operational = None
                                    self.neighbor_version = None
                                    self.weight = None
                                    self.max_prefix_limit = None
                                    self.use_max_prefix_warning_only = None
                                    self.max_prefix_discard_extra_paths = None
                                    self.max_prefix_exceed_discard_paths = None
                                    self.max_prefix_threshold_percent = None
                                    self.max_prefix_restart_time = None
                                    self.prefixes_accepted = None
                                    self.prefixes_synced = None
                                    self.prefixes_withdrawn_not_found = None
                                    self.prefixes_denied = None
                                    self.prefixes_denied_no_policy = None
                                    self.prefixes_denied_rt_permit = None
                                    self.prefixes_denied_orf_policy = None
                                    self.prefixes_denied_policy = None
                                    self.number_of_bestpaths = None
                                    self.number_of_best_externalpaths = None
                                    self.prefixes_advertised = None
                                    self.prefixes_be_advertised = None
                                    self.prefixes_suppressed = None
                                    self.prefixes_withdrawn = None
                                    self.is_peer_orf_capable = None
                                    self.is_advertised_orf_send = None
                                    self.is_received_orf_send_capable = None
                                    self.is_advertised_orf_receive = None
                                    self.is_received_orf_receive_capable = None
                                    self.is_advertised_graceful_restart = None
                                    self.is_graceful_restart_state_flag = None
                                    self.is_received_graceful_restart_capable = None
                                    self.is_add_path_send_capability_advertised = None
                                    self.is_add_path_send_capability_received = None
                                    self.is_add_path_receive_capability_advertised = None
                                    self.is_add_path_receive_capability_received = None
                                    self.is_ext_nh_encoding_capability_received = None
                                    self.is_ext_nh_encoding_capability_sent = None
                                    self.restart_time = None
                                    self.local_restart_time = None
                                    self.stale_path_timeout = None
                                    self.rib_purge_timeout_value = None
                                    self.neighbor_preserved_forwarding_state = None
                                    self.long_lived_graceful_restart_stale_time_configured = None
                                    self.long_lived_graceful_restart_stale_time_sent = None
                                    self.long_lived_graceful_restart_stale_time_accept = None
                                    self.long_lived_graceful_restart_capability_received = None
                                    self.long_lived_graceful_restart_stale_time_received = None
                                    self.neighbor_preserved_long_lived_forwarding_state = None
                                    self.neighbor_long_lived_graceful_restart_capable = None
                                    self.neighbor_long_lived_graceful_restart_time_remaining = None
                                    self.route_refreshes_received = None
                                    self.route_refreshes_sent = None
                                    self.refresh_target_version = None
                                    self.refresh_version = None
                                    self.refresh_acked_version = None
                                    self.is_prefix_orf_present = None
                                    self.orf_entries_received = None
                                    self.is_default_originate_sent = None
                                    self.route_policy_prefix_orf = None
                                    self.route_policy_in = None
                                    self.route_policy_out = None
                                    self.route_policy_default_originate = None
                                    self.is_neighbor_ebgp_without_inbound_policy = None
                                    self.is_neighbor_ebgp_without_outbound_policy = None
                                    self.is_as_override_set = None
                                    self.is_allow_as_in_set = None
                                    self.allow_as_in_count = None
                                    self.address_family_long_lived_time = None
                                    self.eo_r_received_in_read_only = None
                                    self.acked_version = None
                                    self.synced_acked_version = None
                                    self.outstanding_version = None
                                    self.outstanding_refresh_version = None
                                    self.outstanding_version_max = None
                                    self.is_aigp_set = None
                                    self.is_rt_present = None
                                    self.is_rt_present_standby = None
                                    self.accept_own_enabled = None
                                    self.selective_multipath_eligible = None
                                    self.afrpki_disable = None
                                    self.afrpki_use_validity = None
                                    self.afrpki_allow_invalid = None
                                    self.afrpki_signal_ibgp = None
                                    self.is_advertise_permanent_network = None
                                    self.is_send_mcast_attr = None
                                    self.import_stitching = None
                                    self.import_reoriginate = None
                                    self.import_reoriginate_stitching = None
                                    self.advertise_v4_flags = None
                                    self.advertise_v6_flags = None
                                    self.advertise_local_labeled_route_unicast = None
                                    self.prefixes_denied_non_cumulative = None
                                    self.enable_label_stack = None

                                    self.neighbor_af_performance_statistics = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics()
                                    self.neighbor_af_performance_statistics.parent = self
                                    self._children_name_map["neighbor_af_performance_statistics"] = "neighbor-af-performance-statistics"

                                    self.extended_community = YList(self)
                                    self.extended_community_standby = YList(self)
                                    self._segment_path = lambda: "af-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_disable', u'encapsulation_type', u'advertise_rt_type', u'advertise_afi_def_vrf_imp_disable', u'advertise_evpnv4_afi_def_vrf_imp_disable', u'advertise_evpnv6_afi_def_vrf_imp_disable', u'advertise_afi_vrf_re_imp_disable', u'advertise_evpnv4_afi_vrf_re_imp_disable', u'advertise_evpnv6_afi_vrf_re_imp_disable', u'advertise_afi_eo_r_ready', u'always_use_next_hop_local', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'update_group_number', u'filter_group_index', u'is_update_throttled', u'is_update_leaving', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'neighbor_version', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'prefixes_accepted', u'prefixes_synced', u'prefixes_withdrawn_not_found', u'prefixes_denied', u'prefixes_denied_no_policy', u'prefixes_denied_rt_permit', u'prefixes_denied_orf_policy', u'prefixes_denied_policy', u'number_of_bestpaths', u'number_of_best_externalpaths', u'prefixes_advertised', u'prefixes_be_advertised', u'prefixes_suppressed', u'prefixes_withdrawn', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'is_ext_nh_encoding_capability_received', u'is_ext_nh_encoding_capability_sent', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'route_refreshes_received', u'route_refreshes_sent', u'refresh_target_version', u'refresh_version', u'refresh_acked_version', u'is_prefix_orf_present', u'orf_entries_received', u'is_default_originate_sent', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'eo_r_received_in_read_only', u'acked_version', u'synced_acked_version', u'outstanding_version', u'outstanding_refresh_version', u'outstanding_version_max', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'advertise_local_labeled_route_unicast', u'prefixes_denied_non_cumulative', u'enable_label_stack'], name, value)


                                class NeighborAfPerformanceStatistics(Entity):
                                    """
                                    Neighbor AF statistics
                                    
                                    .. attribute:: sub_group_pending_message_count
                                    
                                    	No. of sub\-group messages waiting to be sent out on this neighbor \-\- DEPRECATED \-\- 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: processed_messages
                                    
                                    	Number of messages processed from the neighbor's write queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sent_messages
                                    
                                    	Number of messages sent from the neighbor's write queue
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_transmit
                                    
                                    	No. of update messages with split\-horizon flag that were sent out
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_update_blocked
                                    
                                    	No. of update messages with split\-horizon flag that were blocked
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_transmit
                                    
                                    	No. of withdraw messages with split\-horizon flag that were sent out
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: split_horizon_withdraw_blocked
                                    
                                    	No. of withdraw messages with split\-horizon flag that were blocked
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, self).__init__()

                                        self.yang_name = "neighbor-af-performance-statistics"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sub_group_pending_message_count', (YLeaf(YType.uint32, 'sub-group-pending-message-count'), ['int'])),
                                            ('processed_messages', (YLeaf(YType.uint32, 'processed-messages'), ['int'])),
                                            ('sent_messages', (YLeaf(YType.uint32, 'sent-messages'), ['int'])),
                                            ('split_horizon_update_transmit', (YLeaf(YType.uint32, 'split-horizon-update-transmit'), ['int'])),
                                            ('split_horizon_update_blocked', (YLeaf(YType.uint32, 'split-horizon-update-blocked'), ['int'])),
                                            ('split_horizon_withdraw_transmit', (YLeaf(YType.uint32, 'split-horizon-withdraw-transmit'), ['int'])),
                                            ('split_horizon_withdraw_blocked', (YLeaf(YType.uint32, 'split-horizon-withdraw-blocked'), ['int'])),
                                        ])
                                        self.sub_group_pending_message_count = None
                                        self.processed_messages = None
                                        self.sent_messages = None
                                        self.split_horizon_update_transmit = None
                                        self.split_horizon_update_blocked = None
                                        self.split_horizon_withdraw_transmit = None
                                        self.split_horizon_withdraw_blocked = None
                                        self._segment_path = lambda: "neighbor-af-performance-statistics"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.NeighborAfPerformanceStatistics, [u'sub_group_pending_message_count', u'processed_messages', u'sent_messages', u'split_horizon_update_transmit', u'split_horizon_update_blocked', u'split_horizon_withdraw_transmit', u'split_horizon_withdraw_blocked'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunity, [u'entry'], name, value)


                                class ExtendedCommunityStandby(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, self).__init__()

                                        self.yang_name = "extended-community-standby"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community-standby"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.Neighbors.Neighbor.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                    class NextHopVrf(Entity):
                        """
                        A BGP Next\-hop VRF table entry
                        
                        .. attribute:: total_processing_time
                        
                        	Total time spent in processing
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_proc_notification_time
                        
                        	How long since the maximum processing time notifcation was received
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_deletes
                        
                        	Number of bestpath deletes caused by notification which resulted in maximum processing
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_notification_bestpath_changes
                        
                        	Number of bestpath changes caused by notification which resulted in maximum processing
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_processing_time
                        
                        	Maximum time spent procesing a single batch notification
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_notificationication_time
                        
                        	Time since the last notification was received
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_notification_processing_time
                        
                        	Processing time for the last notification
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf, self).__init__()

                            self.yang_name = "next-hop-vrf"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('total_processing_time', (YLeaf(YType.uint32, 'total-processing-time'), ['int'])),
                                ('max_proc_notification_time', (YLeaf(YType.uint32, 'max-proc-notification-time'), ['int'])),
                                ('max_notification_bestpath_deletes', (YLeaf(YType.uint32, 'max-notification-bestpath-deletes'), ['int'])),
                                ('max_notification_bestpath_changes', (YLeaf(YType.uint32, 'max-notification-bestpath-changes'), ['int'])),
                                ('maximum_processing_time', (YLeaf(YType.uint32, 'maximum-processing-time'), ['int'])),
                                ('last_notificationication_time', (YLeaf(YType.uint32, 'last-notificationication-time'), ['int'])),
                                ('last_notification_processing_time', (YLeaf(YType.uint32, 'last-notification-processing-time'), ['int'])),
                            ])
                            self.total_processing_time = None
                            self.max_proc_notification_time = None
                            self.max_notification_bestpath_deletes = None
                            self.max_notification_bestpath_changes = None
                            self.maximum_processing_time = None
                            self.last_notificationication_time = None
                            self.last_notification_processing_time = None
                            self._segment_path = lambda: "next-hop-vrf"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NextHopVrf, [u'total_processing_time', u'max_proc_notification_time', u'max_notification_bestpath_deletes', u'max_notification_bestpath_changes', u'maximum_processing_time', u'last_notificationication_time', u'last_notification_processing_time'], name, value)


                    class NeighborRanges(Entity):
                        """
                        The BGP Dynamic Neighbor Range table
                        
                        .. attribute:: neighbor_range
                        
                        	A BGP Neighbor Range table entry
                        	**type**\: list of  		 :py:class:`NeighborRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges, self).__init__()

                            self.yang_name = "neighbor-ranges"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-range", ("neighbor_range", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange))])
                            self._leafs = OrderedDict()

                            self.neighbor_range = YList(self)
                            self._segment_path = lambda: "neighbor-ranges"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges, [], name, value)


                        class NeighborRange(Entity):
                            """
                            A BGP Neighbor Range table entry
                            
                            .. attribute:: neighbor_range_address  (key)
                            
                            	Neighbor Range prefix
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                            
                            .. attribute:: connection_local_address
                            
                            	Local address for the connection
                            	**type**\:  :py:class:`ConnectionLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress>`
                            
                            .. attribute:: connection_remote_address
                            
                            	Remote address for the connection
                            	**type**\:  :py:class:`ConnectionRemoteAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress>`
                            
                            .. attribute:: graceful_maintenance
                            
                            	Graceful Maintenance
                            	**type**\:  :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance>`
                            
                            .. attribute:: cfg_local_address
                            
                            	Configured local address
                            	**type**\:  :py:class:`CfgLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress>`
                            
                            .. attribute:: speaker_id
                            
                            	Speaker this neighbor is allocated to
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: description
                            
                            	Description
                            	**type**\: str
                            
                            .. attribute:: local_as
                            
                            	Local AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_as
                            
                            	Remote AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: has_internal_link
                            
                            	Internal link to neighbor
                            	**type**\: bool
                            
                            .. attribute:: is_local_address_configured
                            
                            	Local address configured for the neighbor connection
                            	**type**\: bool
                            
                            .. attribute:: neighbor_range_prefix_length
                            
                            	Neighbor Range Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_administratively_shut_down
                            
                            	Neighbor is administratively shut down
                            	**type**\: bool
                            
                            .. attribute:: is_neighbor_max_prefix_shutdown
                            
                            	Neighbor shut down because it exceeded max prfx count
                            	**type**\: bool
                            
                            .. attribute:: is_out_of_memory_forced_up
                            
                            	Neighbor forced up during a low memory condition
                            	**type**\: bool
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL Security enabled
                            	**type**\: bool
                            
                            .. attribute:: suppress4_byte_as
                            
                            	Suppress 4byteas capability
                            	**type**\: bool
                            
                            .. attribute:: bfd_session_enable_mode
                            
                            	BFD enable mode for this peer
                            	**type**\:  :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBfdEnableMode>`
                            
                            .. attribute:: bfd_minintervalval
                            
                            	BFD Mininterval for this peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_multiplierval
                            
                            	BFD Multiplier for this peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_time_to_live
                            
                            	Maximum number of hops for external BGP neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_ebgp_multihop_bgp_mpls_forwarding_disabled
                            
                            	If true, MPLS and NULL rewrite is disabled; if false, it is enabled
                            	**type**\: bool
                            
                            .. attribute:: tcpmss
                            
                            	Neighbor TCP Maximum Segment                     size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_in
                            
                            	Message in log count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_log_out
                            
                            	Message out log count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_local_as
                            
                            	Local AS configured on the neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_as_no_prepend
                            
                            	Option to not prepend the Local AS to announcements
                            	**type**\: bool
                            
                            .. attribute:: is_capability_negotiation_performed
                            
                            	Capability negotiation performed
                            	**type**\: bool
                            
                            .. attribute:: configured_hold_time
                            
                            	Hold time (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_keepalive
                            
                            	Keepalive time (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: configured_min_acc_hold_time
                            
                            	Minimum acceptable hold time from neighbor (in secs) configured for this connection
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval
                            
                            	Minimum advertisement interval, secs part
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: min_advertise_interval_msecs
                            
                            	Minimum advertisement interval, msecs part
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: millisecond
                            
                            .. attribute:: min_origination_interval
                            
                            	Minimum origination interval (in secs)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: remote_as_number
                            
                            	Remote AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dmz_link_bandwidth
                            
                            	Bandwidth of link to single\-hop eBGP peer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ebgp_recv_dmz
                            
                            	Receive Bandwidth of link to single\-hop eBGP peer
                            	**type**\: bool
                            
                            .. attribute:: ebgp_send_dmz_mode
                            
                            	Ebgp send dmz link bw mode
                            	**type**\:  :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpEbgpSendDmzEnableMode>`
                            
                            .. attribute:: tos_type
                            
                            	Precedence or DSCP type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_value
                            
                            	Precedence or DSCP value
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tcp_session_open_mode
                            
                            	The TCP mode to be used to set up BGP session with the neighbor
                            	**type**\:  :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpTcpMode>`
                            
                            .. attribute:: vrf_name
                            
                            	Name of the VRF
                            	**type**\: str
                            
                            .. attribute:: standby_rp
                            
                            	Standby RP socket inited for Active Open
                            	**type**\: bool
                            
                            .. attribute:: nsr_enabled
                            
                            	Neighbor supports NSR
                            	**type**\: bool
                            
                            .. attribute:: graceful_restart_enabled_nbr
                            
                            	Neighbor supports graceful\-restart
                            	**type**\: bool
                            
                            .. attribute:: gr_restart_time
                            
                            	Neighbor restart time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: gr_stale_path_time
                            
                            	Neighbor stale\-path time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: is_passive_close
                            
                            	If true, active socket canbe closed if passive openis received for a GRcapable neighbor
                            	**type**\: bool
                            
                            .. attribute:: nbr_enforce_first_as
                            
                            	Neighbor enforce first AS
                            	**type**\: bool
                            
                            .. attribute:: active_bmp_servers
                            
                            	BMP Servers to which the neighbor sends logs
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nbr_cluster_id
                            
                            	Cluster id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_in_cluster
                            
                            	Type of cluster\_id\:undefined/number/Ip address
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ignore_connected
                            
                            	If true, the VPN client isan IBGP CE peer
                            	**type**\: bool
                            
                            .. attribute:: internal_vpn_client
                            
                            	If true, don't do NHconnected check for nbr
                            	**type**\: bool
                            
                            .. attribute:: local_as_replace_as
                            
                            	Local AS Replace\-AS option
                            	**type**\: bool
                            
                            .. attribute:: local_as_dual_as
                            
                            	Local AS Dual\-AS option
                            	**type**\: bool
                            
                            .. attribute:: local_as_dual_as_mode_native
                            
                            	Applies only if Local AS Dual\-AS option is enabled. Indicates if Dual\-AS mode is native
                            	**type**\: bool
                            
                            .. attribute:: egress_peer_engineering_enabled
                            
                            	Indicates if Egress Peer Engineering is enabled
                            	**type**\: bool
                            
                            .. attribute:: discard_as4_path
                            
                            	Discard AS4\_PATH in case there is a discrepancy in merging AS\_PATH and AS4\_PATH,retain ASPATH
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rpki_disable
                            
                            	Prefix validation disabled
                            	**type**\: bool
                            
                            .. attribute:: rpki_use_validity
                            
                            	Prefix v. use validity
                            	**type**\: bool
                            
                            .. attribute:: rpki_allow_invalid
                            
                            	Prefix v. allow invalid
                            	**type**\: bool
                            
                            .. attribute:: rpki_signal_ibgp
                            
                            	Prefix v. signal ibgp
                            	**type**\: bool
                            
                            .. attribute:: remote_as_list_name
                            
                            	Remote AS List Name
                            	**type**\: str
                            
                            .. attribute:: nbr_rcv_size
                            
                            	Nbr Receive Size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nbr_send_size
                            
                            	Nbr Send Size
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: islocal_address_cfg
                            
                            	Local address configured
                            	**type**\: bool
                            
                            .. attribute:: update_source
                            
                            	Update Source
                            	**type**\: str
                            
                            .. attribute:: addpath_send_enable
                            
                            	Addpath Send enabled
                            	**type**\: bool
                            
                            .. attribute:: addpath_receive_enable
                            
                            	Addpath Receive enable
                            	**type**\: bool
                            
                            .. attribute:: addpath_send_disable
                            
                            	Addpath Send Disabled
                            	**type**\: bool
                            
                            .. attribute:: addpath_receive_disable
                            
                            	Addpath Receive Disabled
                            	**type**\: bool
                            
                            .. attribute:: upd_errh_noreset
                            
                            	Update errh noreset
                            	**type**\: bool
                            
                            .. attribute:: msg_buf_count
                            
                            	Message Buf Count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msg_bug_circular
                            
                            	Message Buf Circular
                            	**type**\: bool
                            
                            .. attribute:: syslog_enable
                            
                            	syslog enable
                            	**type**\: bool
                            
                            .. attribute:: oper_attrf_enable
                            
                            	Oper attrf Enable
                            	**type**\: bool
                            
                            .. attribute:: attrf_group_name
                            
                            	Attrf Group Name
                            	**type**\: str
                            
                            .. attribute:: max_peers
                            
                            	Max Dynamic nbrs in range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: idle_watch_time
                            
                            	Dynamic Neighbor idle\-watch time (in seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: current_peers
                            
                            	Current Dynamic nbrs in range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_match
                            
                            	Passive open matching range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_open_accepted
                            
                            	open accepted
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_max_drop
                            
                            	open drop due to max peers
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: range_inst_error
                            
                            	Error during instance creation
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: af_data
                            
                            	Address family specific neighbor data
                            	**type**\: list of  		 :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData>`
                            
                            .. attribute:: instance
                            
                            	Dynamic Neighbor Instance List
                            	**type**\: list of  		 :py:class:`Instance_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange, self).__init__()

                                self.yang_name = "neighbor-range"
                                self.yang_parent_name = "neighbor-ranges"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_range_address']
                                self._child_classes = OrderedDict([("connection-local-address", ("connection_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress)), ("connection-remote-address", ("connection_remote_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress)), ("graceful-maintenance", ("graceful_maintenance", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance)), ("cfg-local-address", ("cfg_local_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress)), ("af-data", ("af_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData)), ("instance", ("instance", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_))])
                                self._leafs = OrderedDict([
                                    ('neighbor_range_address', (YLeaf(YType.str, 'neighbor-range-address'), ['str','str'])),
                                    ('speaker_id', (YLeaf(YType.uint8, 'speaker-id'), ['int'])),
                                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                    ('remote_as', (YLeaf(YType.uint32, 'remote-as'), ['int'])),
                                    ('has_internal_link', (YLeaf(YType.boolean, 'has-internal-link'), ['bool'])),
                                    ('is_local_address_configured', (YLeaf(YType.boolean, 'is-local-address-configured'), ['bool'])),
                                    ('neighbor_range_prefix_length', (YLeaf(YType.uint8, 'neighbor-range-prefix-length'), ['int'])),
                                    ('is_administratively_shut_down', (YLeaf(YType.boolean, 'is-administratively-shut-down'), ['bool'])),
                                    ('is_neighbor_max_prefix_shutdown', (YLeaf(YType.boolean, 'is-neighbor-max-prefix-shutdown'), ['bool'])),
                                    ('is_out_of_memory_forced_up', (YLeaf(YType.boolean, 'is-out-of-memory-forced-up'), ['bool'])),
                                    ('ttl_security_enabled', (YLeaf(YType.boolean, 'ttl-security-enabled'), ['bool'])),
                                    ('suppress4_byte_as', (YLeaf(YType.boolean, 'suppress4-byte-as'), ['bool'])),
                                    ('bfd_session_enable_mode', (YLeaf(YType.enumeration, 'bfd-session-enable-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBfdEnableMode', '')])),
                                    ('bfd_minintervalval', (YLeaf(YType.uint32, 'bfd-minintervalval'), ['int'])),
                                    ('bfd_multiplierval', (YLeaf(YType.uint32, 'bfd-multiplierval'), ['int'])),
                                    ('ebgp_time_to_live', (YLeaf(YType.uint32, 'ebgp-time-to-live'), ['int'])),
                                    ('is_ebgp_multihop_bgp_mpls_forwarding_disabled', (YLeaf(YType.boolean, 'is-ebgp-multihop-bgp-mpls-forwarding-disabled'), ['bool'])),
                                    ('tcpmss', (YLeaf(YType.uint32, 'tcpmss'), ['int'])),
                                    ('msg_log_in', (YLeaf(YType.uint32, 'msg-log-in'), ['int'])),
                                    ('msg_log_out', (YLeaf(YType.uint32, 'msg-log-out'), ['int'])),
                                    ('neighbor_local_as', (YLeaf(YType.uint32, 'neighbor-local-as'), ['int'])),
                                    ('local_as_no_prepend', (YLeaf(YType.boolean, 'local-as-no-prepend'), ['bool'])),
                                    ('is_capability_negotiation_performed', (YLeaf(YType.boolean, 'is-capability-negotiation-performed'), ['bool'])),
                                    ('configured_hold_time', (YLeaf(YType.uint16, 'configured-hold-time'), ['int'])),
                                    ('configured_keepalive', (YLeaf(YType.uint16, 'configured-keepalive'), ['int'])),
                                    ('configured_min_acc_hold_time', (YLeaf(YType.uint16, 'configured-min-acc-hold-time'), ['int'])),
                                    ('min_advertise_interval', (YLeaf(YType.uint32, 'min-advertise-interval'), ['int'])),
                                    ('min_advertise_interval_msecs', (YLeaf(YType.uint32, 'min-advertise-interval-msecs'), ['int'])),
                                    ('min_origination_interval', (YLeaf(YType.uint16, 'min-origination-interval'), ['int'])),
                                    ('remote_as_number', (YLeaf(YType.uint32, 'remote-as-number'), ['int'])),
                                    ('dmz_link_bandwidth', (YLeaf(YType.uint32, 'dmz-link-bandwidth'), ['int'])),
                                    ('ebgp_recv_dmz', (YLeaf(YType.boolean, 'ebgp-recv-dmz'), ['bool'])),
                                    ('ebgp_send_dmz_mode', (YLeaf(YType.enumeration, 'ebgp-send-dmz-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpEbgpSendDmzEnableMode', '')])),
                                    ('tos_type', (YLeaf(YType.uint8, 'tos-type'), ['int'])),
                                    ('tos_value', (YLeaf(YType.uint8, 'tos-value'), ['int'])),
                                    ('tcp_session_open_mode', (YLeaf(YType.enumeration, 'tcp-session-open-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpTcpMode', '')])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('standby_rp', (YLeaf(YType.boolean, 'standby-rp'), ['bool'])),
                                    ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                    ('graceful_restart_enabled_nbr', (YLeaf(YType.boolean, 'graceful-restart-enabled-nbr'), ['bool'])),
                                    ('gr_restart_time', (YLeaf(YType.uint32, 'gr-restart-time'), ['int'])),
                                    ('gr_stale_path_time', (YLeaf(YType.uint32, 'gr-stale-path-time'), ['int'])),
                                    ('is_passive_close', (YLeaf(YType.boolean, 'is-passive-close'), ['bool'])),
                                    ('nbr_enforce_first_as', (YLeaf(YType.boolean, 'nbr-enforce-first-as'), ['bool'])),
                                    ('active_bmp_servers', (YLeaf(YType.uint8, 'active-bmp-servers'), ['int'])),
                                    ('nbr_cluster_id', (YLeaf(YType.uint32, 'nbr-cluster-id'), ['int'])),
                                    ('nbr_in_cluster', (YLeaf(YType.uint8, 'nbr-in-cluster'), ['int'])),
                                    ('ignore_connected', (YLeaf(YType.boolean, 'ignore-connected'), ['bool'])),
                                    ('internal_vpn_client', (YLeaf(YType.boolean, 'internal-vpn-client'), ['bool'])),
                                    ('local_as_replace_as', (YLeaf(YType.boolean, 'local-as-replace-as'), ['bool'])),
                                    ('local_as_dual_as', (YLeaf(YType.boolean, 'local-as-dual-as'), ['bool'])),
                                    ('local_as_dual_as_mode_native', (YLeaf(YType.boolean, 'local-as-dual-as-mode-native'), ['bool'])),
                                    ('egress_peer_engineering_enabled', (YLeaf(YType.boolean, 'egress-peer-engineering-enabled'), ['bool'])),
                                    ('discard_as4_path', (YLeaf(YType.uint32, 'discard-as4-path'), ['int'])),
                                    ('rpki_disable', (YLeaf(YType.boolean, 'rpki-disable'), ['bool'])),
                                    ('rpki_use_validity', (YLeaf(YType.boolean, 'rpki-use-validity'), ['bool'])),
                                    ('rpki_allow_invalid', (YLeaf(YType.boolean, 'rpki-allow-invalid'), ['bool'])),
                                    ('rpki_signal_ibgp', (YLeaf(YType.boolean, 'rpki-signal-ibgp'), ['bool'])),
                                    ('remote_as_list_name', (YLeaf(YType.str, 'remote-as-list-name'), ['str'])),
                                    ('nbr_rcv_size', (YLeaf(YType.uint32, 'nbr-rcv-size'), ['int'])),
                                    ('nbr_send_size', (YLeaf(YType.uint32, 'nbr-send-size'), ['int'])),
                                    ('islocal_address_cfg', (YLeaf(YType.boolean, 'islocal-address-cfg'), ['bool'])),
                                    ('update_source', (YLeaf(YType.str, 'update-source'), ['str'])),
                                    ('addpath_send_enable', (YLeaf(YType.boolean, 'addpath-send-enable'), ['bool'])),
                                    ('addpath_receive_enable', (YLeaf(YType.boolean, 'addpath-receive-enable'), ['bool'])),
                                    ('addpath_send_disable', (YLeaf(YType.boolean, 'addpath-send-disable'), ['bool'])),
                                    ('addpath_receive_disable', (YLeaf(YType.boolean, 'addpath-receive-disable'), ['bool'])),
                                    ('upd_errh_noreset', (YLeaf(YType.boolean, 'upd-errh-noreset'), ['bool'])),
                                    ('msg_buf_count', (YLeaf(YType.uint32, 'msg-buf-count'), ['int'])),
                                    ('msg_bug_circular', (YLeaf(YType.boolean, 'msg-bug-circular'), ['bool'])),
                                    ('syslog_enable', (YLeaf(YType.boolean, 'syslog-enable'), ['bool'])),
                                    ('oper_attrf_enable', (YLeaf(YType.boolean, 'oper-attrf-enable'), ['bool'])),
                                    ('attrf_group_name', (YLeaf(YType.str, 'attrf-group-name'), ['str'])),
                                    ('max_peers', (YLeaf(YType.uint32, 'max-peers'), ['int'])),
                                    ('idle_watch_time', (YLeaf(YType.uint32, 'idle-watch-time'), ['int'])),
                                    ('current_peers', (YLeaf(YType.uint32, 'current-peers'), ['int'])),
                                    ('range_open_match', (YLeaf(YType.uint32, 'range-open-match'), ['int'])),
                                    ('range_open_accepted', (YLeaf(YType.uint32, 'range-open-accepted'), ['int'])),
                                    ('range_max_drop', (YLeaf(YType.uint32, 'range-max-drop'), ['int'])),
                                    ('range_inst_error', (YLeaf(YType.uint32, 'range-inst-error'), ['int'])),
                                ])
                                self.neighbor_range_address = None
                                self.speaker_id = None
                                self.description = None
                                self.local_as = None
                                self.remote_as = None
                                self.has_internal_link = None
                                self.is_local_address_configured = None
                                self.neighbor_range_prefix_length = None
                                self.is_administratively_shut_down = None
                                self.is_neighbor_max_prefix_shutdown = None
                                self.is_out_of_memory_forced_up = None
                                self.ttl_security_enabled = None
                                self.suppress4_byte_as = None
                                self.bfd_session_enable_mode = None
                                self.bfd_minintervalval = None
                                self.bfd_multiplierval = None
                                self.ebgp_time_to_live = None
                                self.is_ebgp_multihop_bgp_mpls_forwarding_disabled = None
                                self.tcpmss = None
                                self.msg_log_in = None
                                self.msg_log_out = None
                                self.neighbor_local_as = None
                                self.local_as_no_prepend = None
                                self.is_capability_negotiation_performed = None
                                self.configured_hold_time = None
                                self.configured_keepalive = None
                                self.configured_min_acc_hold_time = None
                                self.min_advertise_interval = None
                                self.min_advertise_interval_msecs = None
                                self.min_origination_interval = None
                                self.remote_as_number = None
                                self.dmz_link_bandwidth = None
                                self.ebgp_recv_dmz = None
                                self.ebgp_send_dmz_mode = None
                                self.tos_type = None
                                self.tos_value = None
                                self.tcp_session_open_mode = None
                                self.vrf_name = None
                                self.standby_rp = None
                                self.nsr_enabled = None
                                self.graceful_restart_enabled_nbr = None
                                self.gr_restart_time = None
                                self.gr_stale_path_time = None
                                self.is_passive_close = None
                                self.nbr_enforce_first_as = None
                                self.active_bmp_servers = None
                                self.nbr_cluster_id = None
                                self.nbr_in_cluster = None
                                self.ignore_connected = None
                                self.internal_vpn_client = None
                                self.local_as_replace_as = None
                                self.local_as_dual_as = None
                                self.local_as_dual_as_mode_native = None
                                self.egress_peer_engineering_enabled = None
                                self.discard_as4_path = None
                                self.rpki_disable = None
                                self.rpki_use_validity = None
                                self.rpki_allow_invalid = None
                                self.rpki_signal_ibgp = None
                                self.remote_as_list_name = None
                                self.nbr_rcv_size = None
                                self.nbr_send_size = None
                                self.islocal_address_cfg = None
                                self.update_source = None
                                self.addpath_send_enable = None
                                self.addpath_receive_enable = None
                                self.addpath_send_disable = None
                                self.addpath_receive_disable = None
                                self.upd_errh_noreset = None
                                self.msg_buf_count = None
                                self.msg_bug_circular = None
                                self.syslog_enable = None
                                self.oper_attrf_enable = None
                                self.attrf_group_name = None
                                self.max_peers = None
                                self.idle_watch_time = None
                                self.current_peers = None
                                self.range_open_match = None
                                self.range_open_accepted = None
                                self.range_max_drop = None
                                self.range_inst_error = None

                                self.connection_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress()
                                self.connection_local_address.parent = self
                                self._children_name_map["connection_local_address"] = "connection-local-address"

                                self.connection_remote_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress()
                                self.connection_remote_address.parent = self
                                self._children_name_map["connection_remote_address"] = "connection-remote-address"

                                self.graceful_maintenance = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance()
                                self.graceful_maintenance.parent = self
                                self._children_name_map["graceful_maintenance"] = "graceful-maintenance"

                                self.cfg_local_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress()
                                self.cfg_local_address.parent = self
                                self._children_name_map["cfg_local_address"] = "cfg-local-address"

                                self.af_data = YList(self)
                                self.instance = YList(self)
                                self._segment_path = lambda: "neighbor-range" + "[neighbor-range-address='" + str(self.neighbor_range_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange, ['neighbor_range_address', u'speaker_id', u'description', u'local_as', u'remote_as', u'has_internal_link', u'is_local_address_configured', u'neighbor_range_prefix_length', u'is_administratively_shut_down', u'is_neighbor_max_prefix_shutdown', u'is_out_of_memory_forced_up', u'ttl_security_enabled', u'suppress4_byte_as', u'bfd_session_enable_mode', u'bfd_minintervalval', u'bfd_multiplierval', u'ebgp_time_to_live', u'is_ebgp_multihop_bgp_mpls_forwarding_disabled', u'tcpmss', u'msg_log_in', u'msg_log_out', u'neighbor_local_as', u'local_as_no_prepend', u'is_capability_negotiation_performed', u'configured_hold_time', u'configured_keepalive', u'configured_min_acc_hold_time', u'min_advertise_interval', u'min_advertise_interval_msecs', u'min_origination_interval', u'remote_as_number', u'dmz_link_bandwidth', u'ebgp_recv_dmz', u'ebgp_send_dmz_mode', u'tos_type', u'tos_value', u'tcp_session_open_mode', u'vrf_name', u'standby_rp', u'nsr_enabled', u'graceful_restart_enabled_nbr', u'gr_restart_time', u'gr_stale_path_time', u'is_passive_close', u'nbr_enforce_first_as', u'active_bmp_servers', u'nbr_cluster_id', u'nbr_in_cluster', u'ignore_connected', u'internal_vpn_client', u'local_as_replace_as', u'local_as_dual_as', u'local_as_dual_as_mode_native', u'egress_peer_engineering_enabled', u'discard_as4_path', u'rpki_disable', u'rpki_use_validity', u'rpki_allow_invalid', u'rpki_signal_ibgp', u'remote_as_list_name', u'nbr_rcv_size', u'nbr_send_size', u'islocal_address_cfg', u'update_source', u'addpath_send_enable', u'addpath_receive_enable', u'addpath_send_disable', u'addpath_receive_disable', u'upd_errh_noreset', u'msg_buf_count', u'msg_bug_circular', u'syslog_enable', u'oper_attrf_enable', u'attrf_group_name', u'max_peers', u'idle_watch_time', u'current_peers', u'range_open_match', u'range_open_accepted', u'range_max_drop', u'range_inst_error'], name, value)


                            class ConnectionLocalAddress(Entity):
                                """
                                Local address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, self).__init__()

                                    self.yang_name = "connection-local-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-local-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class ConnectionRemoteAddress(Entity):
                                """
                                Remote address for the connection
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, self).__init__()

                                    self.yang_name = "connection-remote-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "connection-remote-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "connection-remote-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.ConnectionRemoteAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class GracefulMaintenance(Entity):
                                """
                                Graceful Maintenance
                                
                                .. attribute:: gshut_exists
                                
                                	Graceful Maintenance enabled
                                	**type**\: bool
                                
                                .. attribute:: gshut_local_active
                                
                                	Graceful Maintenance locally activated
                                	**type**\: bool
                                
                                .. attribute:: gshut_active
                                
                                	Graceful Maintenance activated
                                	**type**\: bool
                                
                                .. attribute:: gshut_locpref_set
                                
                                	Graceful Maintenance Local Preference set
                                	**type**\: bool
                                
                                .. attribute:: gshut_locpref
                                
                                	Graceful Maintenance Local Preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: gshut_prepends
                                
                                	Graceful Maintenance number of AS prepends
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance, self).__init__()

                                    self.yang_name = "graceful-maintenance"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('gshut_exists', (YLeaf(YType.boolean, 'gshut-exists'), ['bool'])),
                                        ('gshut_local_active', (YLeaf(YType.boolean, 'gshut-local-active'), ['bool'])),
                                        ('gshut_active', (YLeaf(YType.boolean, 'gshut-active'), ['bool'])),
                                        ('gshut_locpref_set', (YLeaf(YType.boolean, 'gshut-locpref-set'), ['bool'])),
                                        ('gshut_locpref', (YLeaf(YType.uint32, 'gshut-locpref'), ['int'])),
                                        ('gshut_prepends', (YLeaf(YType.uint8, 'gshut-prepends'), ['int'])),
                                    ])
                                    self.gshut_exists = None
                                    self.gshut_local_active = None
                                    self.gshut_active = None
                                    self.gshut_locpref_set = None
                                    self.gshut_locpref = None
                                    self.gshut_prepends = None
                                    self._segment_path = lambda: "graceful-maintenance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.GracefulMaintenance, [u'gshut_exists', u'gshut_local_active', u'gshut_active', u'gshut_locpref_set', u'gshut_locpref', u'gshut_prepends'], name, value)


                            class CfgLocalAddress(Entity):
                                """
                                Configured local address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress, self).__init__()

                                    self.yang_name = "cfg-local-address"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "cfg-local-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "cfg-local-address"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.CfgLocalAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                            class AfData(Entity):
                                """
                                Address family specific neighbor data
                                
                                .. attribute:: af_name
                                
                                	Address family identifier
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: is_neighbor_route_reflector_client
                                
                                	Nbr is a route reflector client
                                	**type**\: bool
                                
                                .. attribute:: is_legacy_pe_rt
                                
                                	Nbr accepts route from legacy PE for RT\-Constraint AF 
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_af_capable
                                
                                	Address family capability received from neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_soft_reconfiguration_inbound_allowed
                                
                                	Inbound soft reconfiguration allowed
                                	**type**\: bool
                                
                                .. attribute:: is_use_soft_reconfiguration_always_on
                                
                                	Soft reconf overrides route refresh
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_from_updates
                                
                                	Private AS numbers removed from updates to this nbr
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_updates
                                
                                	Private AS numbers removed from updates to thisnbr only if the aspath hasonly private ASes
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr
                                	**type**\: bool
                                
                                .. attribute:: remove_private_as_entire_aspath_from_inbound_updates
                                
                                	Private AS numbers removed from updates from this nbr only if the aspath has only private ASes
                                	**type**\: bool
                                
                                .. attribute:: flowspec_validation_d_isable
                                
                                	Flowspec Validation Disabled
                                	**type**\: bool
                                
                                .. attribute:: flowspec_redirect_validation_d_isable
                                
                                	Flowspec Redirect Validation Disabled
                                	**type**\: bool
                                
                                .. attribute:: orr_group_name
                                
                                	ORR Group Name
                                	**type**\: str
                                
                                .. attribute:: orr_group_index
                                
                                	ORR Group Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_orr_root_address_configured
                                
                                	ORR Root address configuredfor the neighbor connection
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_reorg
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_local
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: advertise_afi_disable
                                
                                	Encode in Advertise AFI
                                	**type**\: bool
                                
                                .. attribute:: always_use_next_hop_local
                                
                                	Local router always used for next\-hop
                                	**type**\: bool
                                
                                .. attribute:: next_hop_unchanged
                                
                                	router does not change next\-hop
                                	**type**\: bool
                                
                                .. attribute:: sent_community_to_neighbor
                                
                                	Community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: sent_gshut_community_to_neighbor
                                
                                	GSHUT Community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: sent_extended_community_to_neighbor
                                
                                	Extended community attribute sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: neighbor_default_originate
                                
                                	Neighbor originates default
                                	**type**\: bool
                                
                                .. attribute:: is_orf_sent
                                
                                	Outbound route filter sent to neighbor
                                	**type**\: bool
                                
                                .. attribute:: is_update_deferred
                                
                                	Update deferred until ORF/route refresh received
                                	**type**\: bool
                                
                                .. attribute:: is_orf_send_scheduled
                                
                                	Scheduled to send prefix based ORF
                                	**type**\: bool
                                
                                .. attribute:: vpn_update_gen_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\: bool
                                
                                .. attribute:: vpn_update_gen_trigger_enabled
                                
                                	RT Nbr enabled for updategento another
                                	**type**\: bool
                                
                                .. attribute:: is_addpath_send_operational
                                
                                	Addpath is operational on send\-side
                                	**type**\: bool
                                
                                .. attribute:: is_addpath_receive_operational
                                
                                	Addpath is operational on receive\-side
                                	**type**\: bool
                                
                                .. attribute:: weight
                                
                                	Weight for this AF
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_prefix_limit
                                
                                	Max limit for # of prefixes
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: use_max_prefix_warning_only
                                
                                	Warning only when maximum prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_discard_extra_paths
                                
                                	Discard extra paths when prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_exceed_discard_paths
                                
                                	Did we discard extra paths when prefix limit reached
                                	**type**\: bool
                                
                                .. attribute:: max_prefix_threshold_percent
                                
                                	Percentage of maximum no. of prefixes at which to generate warning
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                	**units**\: percentage
                                
                                .. attribute:: max_prefix_restart_time
                                
                                	Time interval (in minutes) after which peering session will be reestablished
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: minute
                                
                                .. attribute:: is_peer_orf_capable
                                
                                	Peer has outbound route filter capability
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_orf_send
                                
                                	Prefix based ORF send mode capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_received_orf_send_capable
                                
                                	Prefix based ORF send mode capability received
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_orf_receive
                                
                                	Prefix based ORF receive mode capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_received_orf_receive_capable
                                
                                	Prefix based ORF receive mode capability received
                                	**type**\: bool
                                
                                .. attribute:: is_advertised_graceful_restart
                                
                                	Graceful Restart Capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_graceful_restart_state_flag
                                
                                	Restart state flag enabled
                                	**type**\: bool
                                
                                .. attribute:: is_received_graceful_restart_capable
                                
                                	Graceful Restart Capability received
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_send_capability_advertised
                                
                                	Addpath Send capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_send_capability_received
                                
                                	Addpath Send capability received
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_receive_capability_advertised
                                
                                	Addpath Receive capability advertised
                                	**type**\: bool
                                
                                .. attribute:: is_add_path_receive_capability_received
                                
                                	Addpath Receive capability received
                                	**type**\: bool
                                
                                .. attribute:: restart_time
                                
                                	Restart time advertised (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: local_restart_time
                                
                                	Local Restart time (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: stale_path_timeout
                                
                                	Stale path timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: rib_purge_timeout_value
                                
                                	RIB purge timeout time (in seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_preserved_forwarding_state
                                
                                	Neighbor preserved forwarding state
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_configured
                                
                                	Long\-lived graceful\-restart stale time is configured
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_sent
                                
                                	Stale time sent in long\-lived graceful\-restart capability (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_accept
                                
                                	Maximum long\-lived graceful\-restart stale time acceptable from the neighbor (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: long_lived_graceful_restart_capability_received
                                
                                	Long\-lived graceful\-restart capability received from the neighbor
                                	**type**\: bool
                                
                                .. attribute:: long_lived_graceful_restart_stale_time_received
                                
                                	Long\-lived graceful\-restart stale time received from the neighbor (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_preserved_long_lived_forwarding_state
                                
                                	Neighbor preserved long\-lived forwarding state
                                	**type**\: bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_capable
                                
                                	Treat neighbor as long\-lived graceful\-restart capable
                                	**type**\: bool
                                
                                .. attribute:: neighbor_long_lived_graceful_restart_time_remaining
                                
                                	Remaining long\-lived graceful\-restart time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_prefix_orf_present
                                
                                	Outbound route filter prefix ORF present
                                	**type**\: bool
                                
                                .. attribute:: orf_entries_received
                                
                                	Number of outbound route filter entries received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_policy_prefix_orf
                                
                                	Prefix based ORF for incoming updates
                                	**type**\: str
                                
                                .. attribute:: route_policy_in
                                
                                	Incoming route policy name
                                	**type**\: str
                                
                                .. attribute:: route_policy_out
                                
                                	Outgoing route policy name
                                	**type**\: str
                                
                                .. attribute:: route_policy_default_originate
                                
                                	Default\-originate route policy name
                                	**type**\: str
                                
                                .. attribute:: is_neighbor_ebgp_without_inbound_policy
                                
                                	eBGP neighbor with no configured inbound policy
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_ebgp_without_outbound_policy
                                
                                	eBGP neighbor with no configured outbound policy
                                	**type**\: bool
                                
                                .. attribute:: is_as_override_set
                                
                                	As override set 
                                	**type**\: bool
                                
                                .. attribute:: is_allow_as_in_set
                                
                                	Allowas\-in set 
                                	**type**\: bool
                                
                                .. attribute:: allow_as_in_count
                                
                                	Allowas\-in count config
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: address_family_long_lived_time
                                
                                	AF specific Long\-lived\-time config
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_aigp_set
                                
                                	AIGP set 
                                	**type**\: bool
                                
                                .. attribute:: is_rt_present
                                
                                	RT attribute list present
                                	**type**\: bool
                                
                                .. attribute:: is_rt_present_standby
                                
                                	RT attribute list present
                                	**type**\: bool
                                
                                .. attribute:: accept_own_enabled
                                
                                	Accept\-Own enabled
                                	**type**\: bool
                                
                                .. attribute:: selective_multipath_eligible
                                
                                	Selective multipath eligible
                                	**type**\: bool
                                
                                .. attribute:: afrpki_disable
                                
                                	Prefix validation disabled
                                	**type**\: bool
                                
                                .. attribute:: afrpki_use_validity
                                
                                	Prefix v. use validity
                                	**type**\: bool
                                
                                .. attribute:: afrpki_allow_invalid
                                
                                	Prefix v. allow invalid
                                	**type**\: bool
                                
                                .. attribute:: afrpki_signal_ibgp
                                
                                	Prefix v. signal ibgp
                                	**type**\: bool
                                
                                .. attribute:: is_advertise_permanent_network
                                
                                	Advertise Permanent Network
                                	**type**\: bool
                                
                                .. attribute:: is_send_mcast_attr
                                
                                	Send Mcast Attr
                                	**type**\: bool
                                
                                .. attribute:: import_stitching
                                
                                	Import Stitching enabled
                                	**type**\: bool
                                
                                .. attribute:: import_reoriginate
                                
                                	Import Reoriginate enabled
                                	**type**\: bool
                                
                                .. attribute:: import_reoriginate_stitching
                                
                                	Import Reoriginate Stitching enabled
                                	**type**\: bool
                                
                                .. attribute:: advertise_v4_flags
                                
                                	Advertise options for VPNV4
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: advertise_v6_flags
                                
                                	Advertise options for VPNV6
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: enable_label_stack
                                
                                	Enable label stack
                                	**type**\: bool
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity>`
                                
                                .. attribute:: extended_community_standby
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunityStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData, self).__init__()

                                    self.yang_name = "af-data"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity)), ("extended-community-standby", ("extended_community_standby", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('is_neighbor_route_reflector_client', (YLeaf(YType.boolean, 'is-neighbor-route-reflector-client'), ['bool'])),
                                        ('is_legacy_pe_rt', (YLeaf(YType.boolean, 'is-legacy-pe-rt'), ['bool'])),
                                        ('is_neighbor_af_capable', (YLeaf(YType.boolean, 'is-neighbor-af-capable'), ['bool'])),
                                        ('is_soft_reconfiguration_inbound_allowed', (YLeaf(YType.boolean, 'is-soft-reconfiguration-inbound-allowed'), ['bool'])),
                                        ('is_use_soft_reconfiguration_always_on', (YLeaf(YType.boolean, 'is-use-soft-reconfiguration-always-on'), ['bool'])),
                                        ('remove_private_as_from_updates', (YLeaf(YType.boolean, 'remove-private-as-from-updates'), ['bool'])),
                                        ('remove_private_as_entire_aspath_from_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-updates'), ['bool'])),
                                        ('remove_private_as_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-from-inbound-updates'), ['bool'])),
                                        ('remove_private_as_entire_aspath_from_inbound_updates', (YLeaf(YType.boolean, 'remove-private-as-entire-aspath-from-inbound-updates'), ['bool'])),
                                        ('flowspec_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-validation-d-isable'), ['bool'])),
                                        ('flowspec_redirect_validation_d_isable', (YLeaf(YType.boolean, 'flowspec-redirect-validation-d-isable'), ['bool'])),
                                        ('orr_group_name', (YLeaf(YType.str, 'orr-group-name'), ['str'])),
                                        ('orr_group_index', (YLeaf(YType.uint32, 'orr-group-index'), ['int'])),
                                        ('is_orr_root_address_configured', (YLeaf(YType.boolean, 'is-orr-root-address-configured'), ['bool'])),
                                        ('advertise_afi', (YLeaf(YType.boolean, 'advertise-afi'), ['bool'])),
                                        ('advertise_afi_reorg', (YLeaf(YType.boolean, 'advertise-afi-reorg'), ['bool'])),
                                        ('advertise_afi_local', (YLeaf(YType.boolean, 'advertise-afi-local'), ['bool'])),
                                        ('advertise_afi_disable', (YLeaf(YType.boolean, 'advertise-afi-disable'), ['bool'])),
                                        ('always_use_next_hop_local', (YLeaf(YType.boolean, 'always-use-next-hop-local'), ['bool'])),
                                        ('next_hop_unchanged', (YLeaf(YType.boolean, 'next-hop-unchanged'), ['bool'])),
                                        ('sent_community_to_neighbor', (YLeaf(YType.boolean, 'sent-community-to-neighbor'), ['bool'])),
                                        ('sent_gshut_community_to_neighbor', (YLeaf(YType.boolean, 'sent-gshut-community-to-neighbor'), ['bool'])),
                                        ('sent_extended_community_to_neighbor', (YLeaf(YType.boolean, 'sent-extended-community-to-neighbor'), ['bool'])),
                                        ('neighbor_default_originate', (YLeaf(YType.boolean, 'neighbor-default-originate'), ['bool'])),
                                        ('is_orf_sent', (YLeaf(YType.boolean, 'is-orf-sent'), ['bool'])),
                                        ('is_update_deferred', (YLeaf(YType.boolean, 'is-update-deferred'), ['bool'])),
                                        ('is_orf_send_scheduled', (YLeaf(YType.boolean, 'is-orf-send-scheduled'), ['bool'])),
                                        ('vpn_update_gen_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-enabled'), ['bool'])),
                                        ('vpn_update_gen_trigger_enabled', (YLeaf(YType.boolean, 'vpn-update-gen-trigger-enabled'), ['bool'])),
                                        ('is_addpath_send_operational', (YLeaf(YType.boolean, 'is-addpath-send-operational'), ['bool'])),
                                        ('is_addpath_receive_operational', (YLeaf(YType.boolean, 'is-addpath-receive-operational'), ['bool'])),
                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                        ('max_prefix_limit', (YLeaf(YType.uint32, 'max-prefix-limit'), ['int'])),
                                        ('use_max_prefix_warning_only', (YLeaf(YType.boolean, 'use-max-prefix-warning-only'), ['bool'])),
                                        ('max_prefix_discard_extra_paths', (YLeaf(YType.boolean, 'max-prefix-discard-extra-paths'), ['bool'])),
                                        ('max_prefix_exceed_discard_paths', (YLeaf(YType.boolean, 'max-prefix-exceed-discard-paths'), ['bool'])),
                                        ('max_prefix_threshold_percent', (YLeaf(YType.uint8, 'max-prefix-threshold-percent'), ['int'])),
                                        ('max_prefix_restart_time', (YLeaf(YType.uint16, 'max-prefix-restart-time'), ['int'])),
                                        ('is_peer_orf_capable', (YLeaf(YType.boolean, 'is-peer-orf-capable'), ['bool'])),
                                        ('is_advertised_orf_send', (YLeaf(YType.boolean, 'is-advertised-orf-send'), ['bool'])),
                                        ('is_received_orf_send_capable', (YLeaf(YType.boolean, 'is-received-orf-send-capable'), ['bool'])),
                                        ('is_advertised_orf_receive', (YLeaf(YType.boolean, 'is-advertised-orf-receive'), ['bool'])),
                                        ('is_received_orf_receive_capable', (YLeaf(YType.boolean, 'is-received-orf-receive-capable'), ['bool'])),
                                        ('is_advertised_graceful_restart', (YLeaf(YType.boolean, 'is-advertised-graceful-restart'), ['bool'])),
                                        ('is_graceful_restart_state_flag', (YLeaf(YType.boolean, 'is-graceful-restart-state-flag'), ['bool'])),
                                        ('is_received_graceful_restart_capable', (YLeaf(YType.boolean, 'is-received-graceful-restart-capable'), ['bool'])),
                                        ('is_add_path_send_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-send-capability-advertised'), ['bool'])),
                                        ('is_add_path_send_capability_received', (YLeaf(YType.boolean, 'is-add-path-send-capability-received'), ['bool'])),
                                        ('is_add_path_receive_capability_advertised', (YLeaf(YType.boolean, 'is-add-path-receive-capability-advertised'), ['bool'])),
                                        ('is_add_path_receive_capability_received', (YLeaf(YType.boolean, 'is-add-path-receive-capability-received'), ['bool'])),
                                        ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                        ('local_restart_time', (YLeaf(YType.uint32, 'local-restart-time'), ['int'])),
                                        ('stale_path_timeout', (YLeaf(YType.uint32, 'stale-path-timeout'), ['int'])),
                                        ('rib_purge_timeout_value', (YLeaf(YType.uint32, 'rib-purge-timeout-value'), ['int'])),
                                        ('neighbor_preserved_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-forwarding-state'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_configured', (YLeaf(YType.boolean, 'long-lived-graceful-restart-stale-time-configured'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_sent', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-sent'), ['int'])),
                                        ('long_lived_graceful_restart_stale_time_accept', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-accept'), ['int'])),
                                        ('long_lived_graceful_restart_capability_received', (YLeaf(YType.boolean, 'long-lived-graceful-restart-capability-received'), ['bool'])),
                                        ('long_lived_graceful_restart_stale_time_received', (YLeaf(YType.uint32, 'long-lived-graceful-restart-stale-time-received'), ['int'])),
                                        ('neighbor_preserved_long_lived_forwarding_state', (YLeaf(YType.boolean, 'neighbor-preserved-long-lived-forwarding-state'), ['bool'])),
                                        ('neighbor_long_lived_graceful_restart_capable', (YLeaf(YType.boolean, 'neighbor-long-lived-graceful-restart-capable'), ['bool'])),
                                        ('neighbor_long_lived_graceful_restart_time_remaining', (YLeaf(YType.uint32, 'neighbor-long-lived-graceful-restart-time-remaining'), ['int'])),
                                        ('is_prefix_orf_present', (YLeaf(YType.boolean, 'is-prefix-orf-present'), ['bool'])),
                                        ('orf_entries_received', (YLeaf(YType.uint32, 'orf-entries-received'), ['int'])),
                                        ('route_policy_prefix_orf', (YLeaf(YType.str, 'route-policy-prefix-orf'), ['str'])),
                                        ('route_policy_in', (YLeaf(YType.str, 'route-policy-in'), ['str'])),
                                        ('route_policy_out', (YLeaf(YType.str, 'route-policy-out'), ['str'])),
                                        ('route_policy_default_originate', (YLeaf(YType.str, 'route-policy-default-originate'), ['str'])),
                                        ('is_neighbor_ebgp_without_inbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-inbound-policy'), ['bool'])),
                                        ('is_neighbor_ebgp_without_outbound_policy', (YLeaf(YType.boolean, 'is-neighbor-ebgp-without-outbound-policy'), ['bool'])),
                                        ('is_as_override_set', (YLeaf(YType.boolean, 'is-as-override-set'), ['bool'])),
                                        ('is_allow_as_in_set', (YLeaf(YType.boolean, 'is-allow-as-in-set'), ['bool'])),
                                        ('allow_as_in_count', (YLeaf(YType.uint32, 'allow-as-in-count'), ['int'])),
                                        ('address_family_long_lived_time', (YLeaf(YType.uint32, 'address-family-long-lived-time'), ['int'])),
                                        ('is_aigp_set', (YLeaf(YType.boolean, 'is-aigp-set'), ['bool'])),
                                        ('is_rt_present', (YLeaf(YType.boolean, 'is-rt-present'), ['bool'])),
                                        ('is_rt_present_standby', (YLeaf(YType.boolean, 'is-rt-present-standby'), ['bool'])),
                                        ('accept_own_enabled', (YLeaf(YType.boolean, 'accept-own-enabled'), ['bool'])),
                                        ('selective_multipath_eligible', (YLeaf(YType.boolean, 'selective-multipath-eligible'), ['bool'])),
                                        ('afrpki_disable', (YLeaf(YType.boolean, 'afrpki-disable'), ['bool'])),
                                        ('afrpki_use_validity', (YLeaf(YType.boolean, 'afrpki-use-validity'), ['bool'])),
                                        ('afrpki_allow_invalid', (YLeaf(YType.boolean, 'afrpki-allow-invalid'), ['bool'])),
                                        ('afrpki_signal_ibgp', (YLeaf(YType.boolean, 'afrpki-signal-ibgp'), ['bool'])),
                                        ('is_advertise_permanent_network', (YLeaf(YType.boolean, 'is-advertise-permanent-network'), ['bool'])),
                                        ('is_send_mcast_attr', (YLeaf(YType.boolean, 'is-send-mcast-attr'), ['bool'])),
                                        ('import_stitching', (YLeaf(YType.boolean, 'import-stitching'), ['bool'])),
                                        ('import_reoriginate', (YLeaf(YType.boolean, 'import-reoriginate'), ['bool'])),
                                        ('import_reoriginate_stitching', (YLeaf(YType.boolean, 'import-reoriginate-stitching'), ['bool'])),
                                        ('advertise_v4_flags', (YLeaf(YType.uint32, 'advertise-v4-flags'), ['int'])),
                                        ('advertise_v6_flags', (YLeaf(YType.uint32, 'advertise-v6-flags'), ['int'])),
                                        ('enable_label_stack', (YLeaf(YType.boolean, 'enable-label-stack'), ['bool'])),
                                    ])
                                    self.af_name = None
                                    self.is_neighbor_route_reflector_client = None
                                    self.is_legacy_pe_rt = None
                                    self.is_neighbor_af_capable = None
                                    self.is_soft_reconfiguration_inbound_allowed = None
                                    self.is_use_soft_reconfiguration_always_on = None
                                    self.remove_private_as_from_updates = None
                                    self.remove_private_as_entire_aspath_from_updates = None
                                    self.remove_private_as_from_inbound_updates = None
                                    self.remove_private_as_entire_aspath_from_inbound_updates = None
                                    self.flowspec_validation_d_isable = None
                                    self.flowspec_redirect_validation_d_isable = None
                                    self.orr_group_name = None
                                    self.orr_group_index = None
                                    self.is_orr_root_address_configured = None
                                    self.advertise_afi = None
                                    self.advertise_afi_reorg = None
                                    self.advertise_afi_local = None
                                    self.advertise_afi_disable = None
                                    self.always_use_next_hop_local = None
                                    self.next_hop_unchanged = None
                                    self.sent_community_to_neighbor = None
                                    self.sent_gshut_community_to_neighbor = None
                                    self.sent_extended_community_to_neighbor = None
                                    self.neighbor_default_originate = None
                                    self.is_orf_sent = None
                                    self.is_update_deferred = None
                                    self.is_orf_send_scheduled = None
                                    self.vpn_update_gen_enabled = None
                                    self.vpn_update_gen_trigger_enabled = None
                                    self.is_addpath_send_operational = None
                                    self.is_addpath_receive_operational = None
                                    self.weight = None
                                    self.max_prefix_limit = None
                                    self.use_max_prefix_warning_only = None
                                    self.max_prefix_discard_extra_paths = None
                                    self.max_prefix_exceed_discard_paths = None
                                    self.max_prefix_threshold_percent = None
                                    self.max_prefix_restart_time = None
                                    self.is_peer_orf_capable = None
                                    self.is_advertised_orf_send = None
                                    self.is_received_orf_send_capable = None
                                    self.is_advertised_orf_receive = None
                                    self.is_received_orf_receive_capable = None
                                    self.is_advertised_graceful_restart = None
                                    self.is_graceful_restart_state_flag = None
                                    self.is_received_graceful_restart_capable = None
                                    self.is_add_path_send_capability_advertised = None
                                    self.is_add_path_send_capability_received = None
                                    self.is_add_path_receive_capability_advertised = None
                                    self.is_add_path_receive_capability_received = None
                                    self.restart_time = None
                                    self.local_restart_time = None
                                    self.stale_path_timeout = None
                                    self.rib_purge_timeout_value = None
                                    self.neighbor_preserved_forwarding_state = None
                                    self.long_lived_graceful_restart_stale_time_configured = None
                                    self.long_lived_graceful_restart_stale_time_sent = None
                                    self.long_lived_graceful_restart_stale_time_accept = None
                                    self.long_lived_graceful_restart_capability_received = None
                                    self.long_lived_graceful_restart_stale_time_received = None
                                    self.neighbor_preserved_long_lived_forwarding_state = None
                                    self.neighbor_long_lived_graceful_restart_capable = None
                                    self.neighbor_long_lived_graceful_restart_time_remaining = None
                                    self.is_prefix_orf_present = None
                                    self.orf_entries_received = None
                                    self.route_policy_prefix_orf = None
                                    self.route_policy_in = None
                                    self.route_policy_out = None
                                    self.route_policy_default_originate = None
                                    self.is_neighbor_ebgp_without_inbound_policy = None
                                    self.is_neighbor_ebgp_without_outbound_policy = None
                                    self.is_as_override_set = None
                                    self.is_allow_as_in_set = None
                                    self.allow_as_in_count = None
                                    self.address_family_long_lived_time = None
                                    self.is_aigp_set = None
                                    self.is_rt_present = None
                                    self.is_rt_present_standby = None
                                    self.accept_own_enabled = None
                                    self.selective_multipath_eligible = None
                                    self.afrpki_disable = None
                                    self.afrpki_use_validity = None
                                    self.afrpki_allow_invalid = None
                                    self.afrpki_signal_ibgp = None
                                    self.is_advertise_permanent_network = None
                                    self.is_send_mcast_attr = None
                                    self.import_stitching = None
                                    self.import_reoriginate = None
                                    self.import_reoriginate_stitching = None
                                    self.advertise_v4_flags = None
                                    self.advertise_v6_flags = None
                                    self.enable_label_stack = None

                                    self.extended_community = YList(self)
                                    self.extended_community_standby = YList(self)
                                    self._segment_path = lambda: "af-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData, [u'af_name', u'is_neighbor_route_reflector_client', u'is_legacy_pe_rt', u'is_neighbor_af_capable', u'is_soft_reconfiguration_inbound_allowed', u'is_use_soft_reconfiguration_always_on', u'remove_private_as_from_updates', u'remove_private_as_entire_aspath_from_updates', u'remove_private_as_from_inbound_updates', u'remove_private_as_entire_aspath_from_inbound_updates', u'flowspec_validation_d_isable', u'flowspec_redirect_validation_d_isable', u'orr_group_name', u'orr_group_index', u'is_orr_root_address_configured', u'advertise_afi', u'advertise_afi_reorg', u'advertise_afi_local', u'advertise_afi_disable', u'always_use_next_hop_local', u'next_hop_unchanged', u'sent_community_to_neighbor', u'sent_gshut_community_to_neighbor', u'sent_extended_community_to_neighbor', u'neighbor_default_originate', u'is_orf_sent', u'is_update_deferred', u'is_orf_send_scheduled', u'vpn_update_gen_enabled', u'vpn_update_gen_trigger_enabled', u'is_addpath_send_operational', u'is_addpath_receive_operational', u'weight', u'max_prefix_limit', u'use_max_prefix_warning_only', u'max_prefix_discard_extra_paths', u'max_prefix_exceed_discard_paths', u'max_prefix_threshold_percent', u'max_prefix_restart_time', u'is_peer_orf_capable', u'is_advertised_orf_send', u'is_received_orf_send_capable', u'is_advertised_orf_receive', u'is_received_orf_receive_capable', u'is_advertised_graceful_restart', u'is_graceful_restart_state_flag', u'is_received_graceful_restart_capable', u'is_add_path_send_capability_advertised', u'is_add_path_send_capability_received', u'is_add_path_receive_capability_advertised', u'is_add_path_receive_capability_received', u'restart_time', u'local_restart_time', u'stale_path_timeout', u'rib_purge_timeout_value', u'neighbor_preserved_forwarding_state', u'long_lived_graceful_restart_stale_time_configured', u'long_lived_graceful_restart_stale_time_sent', u'long_lived_graceful_restart_stale_time_accept', u'long_lived_graceful_restart_capability_received', u'long_lived_graceful_restart_stale_time_received', u'neighbor_preserved_long_lived_forwarding_state', u'neighbor_long_lived_graceful_restart_capable', u'neighbor_long_lived_graceful_restart_time_remaining', u'is_prefix_orf_present', u'orf_entries_received', u'route_policy_prefix_orf', u'route_policy_in', u'route_policy_out', u'route_policy_default_originate', u'is_neighbor_ebgp_without_inbound_policy', u'is_neighbor_ebgp_without_outbound_policy', u'is_as_override_set', u'is_allow_as_in_set', u'allow_as_in_count', u'address_family_long_lived_time', u'is_aigp_set', u'is_rt_present', u'is_rt_present_standby', u'accept_own_enabled', u'selective_multipath_eligible', u'afrpki_disable', u'afrpki_use_validity', u'afrpki_allow_invalid', u'afrpki_signal_ibgp', u'is_advertise_permanent_network', u'is_send_mcast_attr', u'import_stitching', u'import_reoriginate', u'import_reoriginate_stitching', u'advertise_v4_flags', u'advertise_v6_flags', u'enable_label_stack'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunity, [u'entry'], name, value)


                                class ExtendedCommunityStandby(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, self).__init__()

                                        self.yang_name = "extended-community-standby"
                                        self.yang_parent_name = "af-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community-standby"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.AfData.ExtendedCommunityStandby, [u'entry'], name, value)


                            class Instance_(Entity):
                                """
                                Dynamic Neighbor Instance List
                                
                                .. attribute:: neighbor_address
                                
                                	Dynamic Neighbor address
                                	**type**\:  :py:class:`NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress>`
                                
                                .. attribute:: neighbor_age
                                
                                	Neighbor age
                                	**type**\:  :py:class:`NeighborAge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge>`
                                
                                .. attribute:: idle_watch_timer_remaining_value
                                
                                	Idle watch timer remaining time
                                	**type**\:  :py:class:`IdleWatchTimerRemainingValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue>`
                                
                                .. attribute:: is_idle_watch_timer_running
                                
                                	Is idle watch timer running
                                	**type**\: bool
                                
                                .. attribute:: connection_state
                                
                                	State of connection
                                	**type**\:  :py:class:`BgpConnState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpConnState>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_, self).__init__()

                                    self.yang_name = "instance"
                                    self.yang_parent_name = "neighbor-range"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-address", ("neighbor_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress)), ("neighbor-age", ("neighbor_age", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge)), ("idle-watch-timer-remaining-value", ("idle_watch_timer_remaining_value", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue))])
                                    self._leafs = OrderedDict([
                                        ('is_idle_watch_timer_running', (YLeaf(YType.boolean, 'is-idle-watch-timer-running'), ['bool'])),
                                        ('connection_state', (YLeaf(YType.enumeration, 'connection-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpConnState', '')])),
                                    ])
                                    self.is_idle_watch_timer_running = None
                                    self.connection_state = None

                                    self.neighbor_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress()
                                    self.neighbor_address.parent = self
                                    self._children_name_map["neighbor_address"] = "neighbor-address"

                                    self.neighbor_age = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge()
                                    self.neighbor_age.parent = self
                                    self._children_name_map["neighbor_age"] = "neighbor-age"

                                    self.idle_watch_timer_remaining_value = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue()
                                    self.idle_watch_timer_remaining_value.parent = self
                                    self._children_name_map["idle_watch_timer_remaining_value"] = "idle-watch-timer-remaining-value"
                                    self._segment_path = lambda: "instance"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_, [u'is_idle_watch_timer_running', u'connection_state'], name, value)


                                class NeighborAddress(Entity):
                                    """
                                    Dynamic Neighbor address
                                    
                                    .. attribute:: l2vpn_vpls_address
                                    
                                    	L2VPN VPLS Addr
                                    	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress>`
                                    
                                    .. attribute:: l2vpn_mspw_address
                                    
                                    	L2VPN MSPW Addr
                                    	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress>`
                                    
                                    .. attribute:: ipv4_sr_policy_address
                                    
                                    	IPV4 Policy Addr
                                    	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress>`
                                    
                                    .. attribute:: ipv6_sr_policy_address
                                    
                                    	IPV6 Policy Addr
                                    	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress>`
                                    
                                    .. attribute:: afi
                                    
                                    	AFI
                                    	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_mcast_address
                                    
                                    	IPv4 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_label_address
                                    
                                    	IPv4 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4_tunnel_address
                                    
                                    	IPv4 Tunnel
                                    	**type**\: str
                                    
                                    	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4_mdt_address
                                    
                                    	IPv4 MDT Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                    
                                    .. attribute:: ipv4vpn_address
                                    
                                    	IPv4 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv4vpna_mcastddress
                                    
                                    	IPv4 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_address
                                    
                                    	IPV6 Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_mcast_address
                                    
                                    	IPV6 Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_label_address
                                    
                                    	IPv6 Label Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_address
                                    
                                    	IPv6 VPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6vpn_mcast_address
                                    
                                    	IPv6 VPN Mcast Addr
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rt_constraint_address
                                    
                                    	RT Constrt Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{24}
                                    
                                    .. attribute:: ipv6mvpn_address
                                    
                                    	MVPN addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{104}
                                    
                                    .. attribute:: ipv4mvpn_address
                                    
                                    	MVPN4 addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{56}
                                    
                                    .. attribute:: l2vpn_evpn_address
                                    
                                    	L2VPN EVPN Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{58}
                                    
                                    .. attribute:: ls_ls_address
                                    
                                    	LINKSTATE LINKSTATE Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]+
                                    
                                    .. attribute:: ipv4_flowspec_address
                                    
                                    	IPV4 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6_flowspec_address
                                    
                                    	IPV6 Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv4vpn_flowspec_address
                                    
                                    	IPV4 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    .. attribute:: ipv6vpn_flowspec_address
                                    
                                    	IPV6 VPN Flowspec Addr
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4096}
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress, self).__init__()

                                        self.yang_name = "neighbor-address"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress))])
                                        self._leafs = OrderedDict([
                                            ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                            ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                            ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                            ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                            ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                            ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                            ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                            ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                            ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                            ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                            ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                            ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                            ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                            ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                            ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                            ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                            ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                            ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                            ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                            ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                            ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                        ])
                                        self.afi = None
                                        self.ipv4_address = None
                                        self.ipv4_mcast_address = None
                                        self.ipv4_label_address = None
                                        self.ipv4_tunnel_address = None
                                        self.ipv4_mdt_address = None
                                        self.ipv4vpn_address = None
                                        self.ipv4vpna_mcastddress = None
                                        self.ipv6_address = None
                                        self.ipv6_mcast_address = None
                                        self.ipv6_label_address = None
                                        self.ipv6vpn_address = None
                                        self.ipv6vpn_mcast_address = None
                                        self.rt_constraint_address = None
                                        self.ipv6mvpn_address = None
                                        self.ipv4mvpn_address = None
                                        self.l2vpn_evpn_address = None
                                        self.ls_ls_address = None
                                        self.ipv4_flowspec_address = None
                                        self.ipv6_flowspec_address = None
                                        self.ipv4vpn_flowspec_address = None
                                        self.ipv6vpn_flowspec_address = None

                                        self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress()
                                        self.l2vpn_vpls_address.parent = self
                                        self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                        self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress()
                                        self.l2vpn_mspw_address.parent = self
                                        self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                        self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress()
                                        self.ipv4_sr_policy_address.parent = self
                                        self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                        self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress()
                                        self.ipv6_sr_policy_address.parent = self
                                        self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                        self._segment_path = lambda: "neighbor-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                    class L2vpnVplsAddress(Entity):
                                        """
                                        L2VPN VPLS Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress, self).__init__()

                                            self.yang_name = "l2vpn-vpls-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-vpls-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                    class L2vpnMspwAddress(Entity):
                                        """
                                        L2VPN MSPW Addr
                                        
                                        .. attribute:: l2vpn_address
                                        
                                        	l2vpn address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress, self).__init__()

                                            self.yang_name = "l2vpn-mspw-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                            ])
                                            self.l2vpn_address = None
                                            self._segment_path = lambda: "l2vpn-mspw-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                    class Ipv4SrPolicyAddress(Entity):
                                        """
                                        IPV4 Policy Addr
                                        
                                        .. attribute:: ipv4_srpolicy_address
                                        
                                        	ipv4 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv4-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv4_srpolicy_address = None
                                            self._segment_path = lambda: "ipv4-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                    class Ipv6SrPolicyAddress(Entity):
                                        """
                                        IPV6 Policy Addr
                                        
                                        .. attribute:: ipv6_srpolicy_address
                                        
                                        	ipv6 srpolicy address
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress, self).__init__()

                                            self.yang_name = "ipv6-sr-policy-address"
                                            self.yang_parent_name = "neighbor-address"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                            ])
                                            self.ipv6_srpolicy_address = None
                                            self._segment_path = lambda: "ipv6-sr-policy-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAddress.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                                class NeighborAge(Entity):
                                    """
                                    Neighbor age
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge, self).__init__()

                                        self.yang_name = "neighbor-age"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "neighbor-age"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.NeighborAge, [u'seconds', u'nanoseconds'], name, value)


                                class IdleWatchTimerRemainingValue(Entity):
                                    """
                                    Idle watch timer remaining time
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue, self).__init__()

                                        self.yang_name = "idle-watch-timer-remaining-value"
                                        self.yang_parent_name = "instance"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "idle-watch-timer-remaining-value"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.NeighborRanges.NeighborRange.Instance_.IdleWatchTimerRemainingValue, [u'seconds', u'nanoseconds'], name, value)


                    class MessageLogs(Entity):
                        """
                        The BGP Neighbor Message table
                        
                        .. attribute:: message_log
                        
                        	A BGP Message log entry
                        	**type**\: list of  		 :py:class:`MessageLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs, self).__init__()

                            self.yang_name = "message-logs"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("message-log", ("message_log", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog))])
                            self._leafs = OrderedDict()

                            self.message_log = YList(self)
                            self._segment_path = lambda: "message-logs"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs, [], name, value)


                        class MessageLog(Entity):
                            """
                            A BGP Message log entry
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: direction
                            
                            	Direction
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_message
                            
                            	Array of Neighbor Messages in one direction
                            	**type**\: list of  		 :py:class:`NeighborMessage <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog, self).__init__()

                                self.yang_name = "message-log"
                                self.yang_parent_name = "message-logs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-message", ("neighbor_message", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                    ('direction', (YLeaf(YType.uint32, 'direction'), ['int'])),
                                ])
                                self.neighbor_address = None
                                self.direction = None

                                self.neighbor_message = YList(self)
                                self._segment_path = lambda: "message-log"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog, ['neighbor_address', 'direction'], name, value)


                            class NeighborMessage(Entity):
                                """
                                Array of Neighbor Messages in one direction
                                
                                .. attribute:: message_timestamp
                                
                                	message received time\: time elapsed since 00\:00 \:00 UTC, January 1, 1970
                                	**type**\:  :py:class:`MessageTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp>`
                                
                                .. attribute:: message_type_received
                                
                                	Type of messages Received
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: total_logged_message_count
                                
                                	Total logged messages count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: message_data_length
                                
                                	Message data length
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: logged_message_data
                                
                                	Raw Message data in binary format
                                	**type**\: list of  		 :py:class:`LoggedMessageData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage, self).__init__()

                                    self.yang_name = "neighbor-message"
                                    self.yang_parent_name = "message-log"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("message-timestamp", ("message_timestamp", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp)), ("logged-message-data", ("logged_message_data", Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData))])
                                    self._leafs = OrderedDict([
                                        ('message_type_received', (YLeaf(YType.uint8, 'message-type-received'), ['int'])),
                                        ('total_logged_message_count', (YLeaf(YType.uint32, 'total-logged-message-count'), ['int'])),
                                        ('message_data_length', (YLeaf(YType.uint16, 'message-data-length'), ['int'])),
                                    ])
                                    self.message_type_received = None
                                    self.total_logged_message_count = None
                                    self.message_data_length = None

                                    self.message_timestamp = Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp()
                                    self.message_timestamp.parent = self
                                    self._children_name_map["message_timestamp"] = "message-timestamp"

                                    self.logged_message_data = YList(self)
                                    self._segment_path = lambda: "neighbor-message"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage, [u'message_type_received', u'total_logged_message_count', u'message_data_length'], name, value)


                                class MessageTimestamp(Entity):
                                    """
                                    message received time\: time elapsed since 00\:00
                                    \:00 UTC, January 1, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Seconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanoseconds
                                    
                                    	Nanoseconds part of time value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, self).__init__()

                                        self.yang_name = "message-timestamp"
                                        self.yang_parent_name = "neighbor-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nanoseconds = None
                                        self._segment_path = lambda: "message-timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.MessageTimestamp, [u'seconds', u'nanoseconds'], name, value)


                                class LoggedMessageData(Entity):
                                    """
                                    Raw Message data in binary format
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, self).__init__()

                                        self.yang_name = "logged-message-data"
                                        self.yang_parent_name = "neighbor-message"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "logged-message-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.DefaultVrf.MessageLogs.MessageLog.NeighborMessage.LoggedMessageData, [u'entry'], name, value)


                class UpdateInboundFilterProcess(Entity):
                    """
                    Update inbound filtering information for the
                    process
                    
                    .. attribute:: last_update_filtered_timestamp
                    
                    	Last filtered messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:  :py:class:`LastUpdateFilteredTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp>`
                    
                    .. attribute:: update_filtered_message_count
                    
                    	Filtered messages count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_filtered_neighbor_count
                    
                    	Count of neighbors that received filtered messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_update_filtered_age
                    
                    	Time since last filtered messages received event (in seconds)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess, self).__init__()

                        self.yang_name = "update-inbound-filter-process"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("last-update-filtered-timestamp", ("last_update_filtered_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp))])
                        self._leafs = OrderedDict([
                            ('update_filtered_message_count', (YLeaf(YType.uint32, 'update-filtered-message-count'), ['int'])),
                            ('update_filtered_neighbor_count', (YLeaf(YType.uint32, 'update-filtered-neighbor-count'), ['int'])),
                            ('last_update_filtered_age', (YLeaf(YType.uint32, 'last-update-filtered-age'), ['int'])),
                        ])
                        self.update_filtered_message_count = None
                        self.update_filtered_neighbor_count = None
                        self.last_update_filtered_age = None

                        self.last_update_filtered_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp()
                        self.last_update_filtered_timestamp.parent = self
                        self._children_name_map["last_update_filtered_timestamp"] = "last-update-filtered-timestamp"
                        self._segment_path = lambda: "update-inbound-filter-process"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess, [u'update_filtered_message_count', u'update_filtered_neighbor_count', u'last_update_filtered_age'], name, value)


                    class LastUpdateFilteredTimestamp(Entity):
                        """
                        Last filtered messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp, self).__init__()

                            self.yang_name = "last-update-filtered-timestamp"
                            self.yang_parent_name = "update-inbound-filter-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nanoseconds = None
                            self._segment_path = lambda: "last-update-filtered-timestamp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateInboundFilterProcess.LastUpdateFilteredTimestamp, [u'seconds', u'nanoseconds'], name, value)


                class Attributes(Entity):
                    """
                    The BGP Attribute table
                    
                    .. attribute:: attribute
                    
                    	A BGP Attribute table entry
                    	**type**\: list of  		 :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.Attributes, self).__init__()

                        self.yang_name = "attributes"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attribute", ("attribute", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute))])
                        self._leafs = OrderedDict()

                        self.attribute = YList(self)
                        self._segment_path = lambda: "attributes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes, [], name, value)


                    class Attribute(Entity):
                        """
                        A BGP Attribute table entry
                        
                        .. attribute:: attribute_iid
                        
                        	Attribute IID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_cache_bucket
                        
                        	Attribute cache bucket
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_cache_id
                        
                        	Attribute cache ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_info
                        
                        	Attributes
                        	**type**\:  :py:class:`AttributeInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo>`
                        
                        .. attribute:: process_instance_id
                        
                        	Process instance ID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: attribute_instance_id
                        
                        	Attribute Instance ID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: attribute_structure_id
                        
                        	ID of attribute structure
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_structure_hash_value
                        
                        	Hash value for attribute structure
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reference_count
                        
                        	Number of paths which use this attribute structure
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute, self).__init__()

                            self.yang_name = "attribute"
                            self.yang_parent_name = "attributes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("attribute-info", ("attribute_info", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo))])
                            self._leafs = OrderedDict([
                                ('attribute_iid', (YLeaf(YType.uint32, 'attribute-iid'), ['int'])),
                                ('attribute_cache_bucket', (YLeaf(YType.uint32, 'attribute-cache-bucket'), ['int'])),
                                ('attribute_cache_id', (YLeaf(YType.uint32, 'attribute-cache-id'), ['int'])),
                                ('process_instance_id', (YLeaf(YType.uint8, 'process-instance-id'), ['int'])),
                                ('attribute_instance_id', (YLeaf(YType.uint8, 'attribute-instance-id'), ['int'])),
                                ('attribute_structure_id', (YLeaf(YType.uint32, 'attribute-structure-id'), ['int'])),
                                ('attribute_structure_hash_value', (YLeaf(YType.uint32, 'attribute-structure-hash-value'), ['int'])),
                                ('reference_count', (YLeaf(YType.uint32, 'reference-count'), ['int'])),
                            ])
                            self.attribute_iid = None
                            self.attribute_cache_bucket = None
                            self.attribute_cache_id = None
                            self.process_instance_id = None
                            self.attribute_instance_id = None
                            self.attribute_structure_id = None
                            self.attribute_structure_hash_value = None
                            self.reference_count = None

                            self.attribute_info = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo()
                            self.attribute_info.parent = self
                            self._children_name_map["attribute_info"] = "attribute-info"
                            self._segment_path = lambda: "attribute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute, ['attribute_iid', 'attribute_cache_bucket', 'attribute_cache_id', u'process_instance_id', u'attribute_instance_id', u'attribute_structure_id', u'attribute_structure_hash_value', u'reference_count'], name, value)


                        class AttributeInfo(Entity):
                            """
                            Attributes
                            
                            .. attribute:: common_attributes
                            
                            	Common attributes
                            	**type**\:  :py:class:`CommonAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes>`
                            
                            .. attribute:: attr_set
                            
                            	ATTR\_SET attribute
                            	**type**\:  :py:class:`AttrSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet>`
                            
                            .. attribute:: rnh_addr
                            
                            	RNH Address
                            	**type**\:  :py:class:`RnhAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr>`
                            
                            .. attribute:: ribrnh_ip
                            
                            	RIB RNH IP Address
                            	**type**\:  :py:class:`RibrnhIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp>`
                            
                            .. attribute:: is_as_path2_byte
                            
                            	AS path encoded as 2\-byte
                            	**type**\: bool
                            
                            .. attribute:: is_application_gateway_present
                            
                            	Application gateway present
                            	**type**\: bool
                            
                            .. attribute:: is_attr_set_present
                            
                            	BGP ATTR\_SET attribute present
                            	**type**\: bool
                            
                            .. attribute:: set_aigp_inbound_igp
                            
                            	AIGP set by policy inbound IGP 
                            	**type**\: bool
                            
                            .. attribute:: set_aigp_inbound_metric
                            
                            	AIGP set by policy inbound metric
                            	**type**\: bool
                            
                            .. attribute:: is_rnh_present
                            
                            	RNH Attribute  present
                            	**type**\: bool
                            
                            .. attribute:: is_ribrnh_present
                            
                            	RIB RNH Attribute  present
                            	**type**\: bool
                            
                            .. attribute:: attribute_key_number
                            
                            	Attribute key number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_config
                            
                            	Attribute reuse ID Configured
                            	**type**\: bool
                            
                            .. attribute:: attribute_reuse_id_max_id
                            
                            	Attribute reuse ID maximum ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_node
                            
                            	Attribute reuse ID nodes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_current
                            
                            	Attribute reuse ID current ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_keys
                            
                            	Attribute reuse ID allocated keys
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_reuse_id_recover_sec
                            
                            	Attribute reuse ID timer in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: vpn_distinguisher
                            
                            	VPN Distinguisher
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rnh_type
                            
                            	RNH Type
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: rnh_len
                            
                            	RNH Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: rnh_addr_len
                            
                            	RNH Address Length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_table
                            
                            	RIB RNH Table
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_mac
                            
                            	RIB RNH MAC Address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: ribrnhip_table
                            
                            	RIB RNH IP Table
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_vni
                            
                            	RIB RNH Vni
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ribrnh_encap
                            
                            	RIB RNH Encapsulation Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo, self).__init__()

                                self.yang_name = "attribute-info"
                                self.yang_parent_name = "attribute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("common-attributes", ("common_attributes", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes)), ("attr-set", ("attr_set", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet)), ("rnh-addr", ("rnh_addr", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr)), ("ribrnh-ip", ("ribrnh_ip", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp))])
                                self._leafs = OrderedDict([
                                    ('is_as_path2_byte', (YLeaf(YType.boolean, 'is-as-path2-byte'), ['bool'])),
                                    ('is_application_gateway_present', (YLeaf(YType.boolean, 'is-application-gateway-present'), ['bool'])),
                                    ('is_attr_set_present', (YLeaf(YType.boolean, 'is-attr-set-present'), ['bool'])),
                                    ('set_aigp_inbound_igp', (YLeaf(YType.boolean, 'set-aigp-inbound-igp'), ['bool'])),
                                    ('set_aigp_inbound_metric', (YLeaf(YType.boolean, 'set-aigp-inbound-metric'), ['bool'])),
                                    ('is_rnh_present', (YLeaf(YType.boolean, 'is-rnh-present'), ['bool'])),
                                    ('is_ribrnh_present', (YLeaf(YType.boolean, 'is-ribrnh-present'), ['bool'])),
                                    ('attribute_key_number', (YLeaf(YType.uint32, 'attribute-key-number'), ['int'])),
                                    ('attribute_reuse_id_config', (YLeaf(YType.boolean, 'attribute-reuse-id-config'), ['bool'])),
                                    ('attribute_reuse_id_max_id', (YLeaf(YType.uint32, 'attribute-reuse-id-max-id'), ['int'])),
                                    ('attribute_reuse_id_node', (YLeaf(YType.uint32, 'attribute-reuse-id-node'), ['int'])),
                                    ('attribute_reuse_id_current', (YLeaf(YType.uint32, 'attribute-reuse-id-current'), ['int'])),
                                    ('attribute_reuse_id_keys', (YLeaf(YType.uint32, 'attribute-reuse-id-keys'), ['int'])),
                                    ('attribute_reuse_id_recover_sec', (YLeaf(YType.uint32, 'attribute-reuse-id-recover-sec'), ['int'])),
                                    ('vpn_distinguisher', (YLeaf(YType.uint32, 'vpn-distinguisher'), ['int'])),
                                    ('rnh_type', (YLeaf(YType.uint16, 'rnh-type'), ['int'])),
                                    ('rnh_len', (YLeaf(YType.uint8, 'rnh-len'), ['int'])),
                                    ('rnh_addr_len', (YLeaf(YType.uint32, 'rnh-addr-len'), ['int'])),
                                    ('ribrnh_table', (YLeaf(YType.uint32, 'ribrnh-table'), ['int'])),
                                    ('ribrnh_mac', (YLeaf(YType.str, 'ribrnh-mac'), ['str'])),
                                    ('ribrnhip_table', (YLeaf(YType.uint32, 'ribrnhip-table'), ['int'])),
                                    ('ribrnh_vni', (YLeaf(YType.uint32, 'ribrnh-vni'), ['int'])),
                                    ('ribrnh_encap', (YLeaf(YType.uint8, 'ribrnh-encap'), ['int'])),
                                ])
                                self.is_as_path2_byte = None
                                self.is_application_gateway_present = None
                                self.is_attr_set_present = None
                                self.set_aigp_inbound_igp = None
                                self.set_aigp_inbound_metric = None
                                self.is_rnh_present = None
                                self.is_ribrnh_present = None
                                self.attribute_key_number = None
                                self.attribute_reuse_id_config = None
                                self.attribute_reuse_id_max_id = None
                                self.attribute_reuse_id_node = None
                                self.attribute_reuse_id_current = None
                                self.attribute_reuse_id_keys = None
                                self.attribute_reuse_id_recover_sec = None
                                self.vpn_distinguisher = None
                                self.rnh_type = None
                                self.rnh_len = None
                                self.rnh_addr_len = None
                                self.ribrnh_table = None
                                self.ribrnh_mac = None
                                self.ribrnhip_table = None
                                self.ribrnh_vni = None
                                self.ribrnh_encap = None

                                self.common_attributes = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes()
                                self.common_attributes.parent = self
                                self._children_name_map["common_attributes"] = "common-attributes"

                                self.attr_set = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet()
                                self.attr_set.parent = self
                                self._children_name_map["attr_set"] = "attr-set"

                                self.rnh_addr = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr()
                                self.rnh_addr.parent = self
                                self._children_name_map["rnh_addr"] = "rnh-addr"

                                self.ribrnh_ip = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp()
                                self.ribrnh_ip.parent = self
                                self._children_name_map["ribrnh_ip"] = "ribrnh-ip"
                                self._segment_path = lambda: "attribute-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo, [u'is_as_path2_byte', u'is_application_gateway_present', u'is_attr_set_present', u'set_aigp_inbound_igp', u'set_aigp_inbound_metric', u'is_rnh_present', u'is_ribrnh_present', u'attribute_key_number', u'attribute_reuse_id_config', u'attribute_reuse_id_max_id', u'attribute_reuse_id_node', u'attribute_reuse_id_current', u'attribute_reuse_id_keys', u'attribute_reuse_id_recover_sec', u'vpn_distinguisher', u'rnh_type', u'rnh_len', u'rnh_addr_len', u'ribrnh_table', u'ribrnh_mac', u'ribrnhip_table', u'ribrnh_vni', u'ribrnh_encap'], name, value)


                            class CommonAttributes(Entity):
                                """
                                Common attributes
                                
                                .. attribute:: prefix_sid_attr
                                
                                	Prefix SID attribute
                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr>`
                                
                                .. attribute:: tunnel_encap
                                
                                	Tunnel Encapsulation attribute
                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap>`
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\: bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\: bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\: bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\: bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\: bool
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\: str
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_large_community_present
                                
                                	Large Community attribute present
                                	**type**\: bool
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Community>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity>`
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute>`
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster>`
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie>`
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue>`
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue>`
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr>`
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel>`
                                
                                .. attribute:: large_community
                                
                                	Large Community attribute
                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes, self).__init__()

                                    self.yang_name = "common-attributes"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity))])
                                    self._leafs = OrderedDict([
                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                    ])
                                    self.is_metric_present = None
                                    self.is_local_pref_present = None
                                    self.is_atomic_aggregate_present = None
                                    self.is_aggregator_present = None
                                    self.is_origin_present = None
                                    self.is_as_path_present = None
                                    self.is_community_present = None
                                    self.is_extended_community_present = None
                                    self.is_ssa_present = None
                                    self.is_connector_present = None
                                    self.is_pmsi_present = None
                                    self.is_pppmp_present = None
                                    self.is_aigp_present = None
                                    self.is_pe_distinguisher_label_present = None
                                    self.is_ls_attribute_present = None
                                    self.is_label_index_present = None
                                    self.neighbor_as = None
                                    self.aggregator_as = None
                                    self.aggregator_address = None
                                    self.metric = None
                                    self.local_preference = None
                                    self.origin = None
                                    self.as_path = None
                                    self.extended_community_flags = None
                                    self.originator = None
                                    self.l2tpv3_session_id = None
                                    self.connector_type = None
                                    self.aigp_metric_value = None
                                    self.pmsi_type = None
                                    self.pmsi_flags = None
                                    self.pmsi_label = None
                                    self.ppm_pvalue = None
                                    self.is_large_community_present = None

                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr()
                                    self.prefix_sid_attr.parent = self
                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap()
                                    self.tunnel_encap.parent = self
                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                    self.community = YList(self)
                                    self.extended_community = YList(self)
                                    self.unknown_attribute = YList(self)
                                    self.cluster = YList(self)
                                    self.l2tpv3_cookie = YList(self)
                                    self.connector_value = YList(self)
                                    self.pmsi_value = YList(self)
                                    self.ls_attr = YList(self)
                                    self.pe_distinguisher_label = YList(self)
                                    self.large_community = YList(self)
                                    self._segment_path = lambda: "common-attributes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                class PrefixSidAttr(Entity):
                                    """
                                    Prefix SID attribute
                                    
                                    .. attribute:: prefix_sid_tlv
                                    
                                    	Prefix SID TLV array
                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, self).__init__()

                                        self.yang_name = "prefix-sid-attr"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv))])
                                        self._leafs = OrderedDict()

                                        self.prefix_sid_tlv = YList(self)
                                        self._segment_path = lambda: "prefix-sid-attr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr, [], name, value)


                                    class PrefixSidTlv(Entity):
                                        """
                                        Prefix SID TLV array
                                        
                                        .. attribute:: type
                                        
                                        	Prefix SID TLV type field
                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                        
                                        .. attribute:: len
                                        
                                        	Prefix SID TLV Length in bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: val
                                        
                                        	Prefix SID TLV value string
                                        	**type**\: str
                                        
                                        	**length:** 0..46
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                            self.yang_name = "prefix-sid-tlv"
                                            self.yang_parent_name = "prefix-sid-attr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                            ])
                                            self.type = None
                                            self.len = None
                                            self.val = None
                                            self._segment_path = lambda: "prefix-sid-tlv"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                class TunnelEncap(Entity):
                                    """
                                    Tunnel Encapsulation attribute
                                    
                                    .. attribute:: sr_policy
                                    
                                    	Tunnel encap type SR policy
                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, self).__init__()

                                        self.yang_name = "tunnel-encap"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy))])
                                        self._leafs = OrderedDict()

                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy()
                                        self.sr_policy.parent = self
                                        self._children_name_map["sr_policy"] = "sr-policy"
                                        self._segment_path = lambda: "tunnel-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap, [], name, value)


                                    class SrPolicy(Entity):
                                        """
                                        Tunnel encap type SR policy
                                        
                                        .. attribute:: binding_sid
                                        
                                        	SR Policy incoming Binding sid
                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid>`
                                        
                                        .. attribute:: allocated_binding_sid
                                        
                                        	SR Policy allocated Binding sid by the router
                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                        
                                        .. attribute:: tunnel_encap_type
                                        
                                        	Tunnel Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: preference
                                        
                                        	SR Policy Preference
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state
                                        
                                        	SR Policy active state in forwarding
                                        	**type**\: bool
                                        
                                        .. attribute:: request_state
                                        
                                        	SR Policy programming Status
                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                        
                                        .. attribute:: usable
                                        
                                        	SR Policy is usable on this node
                                        	**type**\: bool
                                        
                                        .. attribute:: segment_list
                                        
                                        	SR Policy Segment Lists
                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, self).__init__()

                                            self.yang_name = "sr-policy"
                                            self.yang_parent_name = "tunnel-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList))])
                                            self._leafs = OrderedDict([
                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                            ])
                                            self.tunnel_encap_type = None
                                            self.preference = None
                                            self.state = None
                                            self.request_state = None
                                            self.usable = None

                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid()
                                            self.binding_sid.parent = self
                                            self._children_name_map["binding_sid"] = "binding-sid"

                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                            self.allocated_binding_sid.parent = self
                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                            self.segment_list = YList(self)
                                            self._segment_path = lambda: "sr-policy"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                        class BindingSid(Entity):
                                            """
                                            SR Policy incoming Binding sid
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                self.yang_name = "binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.type = None
                                                self.label = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "binding-sid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                        class AllocatedBindingSid(Entity):
                                            """
                                            SR Policy allocated Binding sid by the router
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                self.yang_name = "allocated-binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.type = None
                                                self.label = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "allocated-binding-sid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                        class SegmentList(Entity):
                                            """
                                            SR Policy Segment Lists
                                            
                                            .. attribute:: weight
                                            
                                            	Weight of segment list
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: segment
                                            
                                            	Segments in segment list
                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                self.yang_name = "segment-list"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                self._leafs = OrderedDict([
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.weight = None

                                                self.segment = YList(self)
                                                self._segment_path = lambda: "segment-list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                            class Segment(Entity):
                                                """
                                                Segments in segment list
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address value
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address value
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                    self.yang_name = "segment"
                                                    self.yang_parent_name = "segment-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.type = None
                                                    self.label = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "segment"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                class Community(Entity):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Community, [u'entry'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ExtendedCommunity, [u'entry'], name, value)


                                class UnknownAttribute(Entity):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, self).__init__()

                                        self.yang_name = "unknown-attribute"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "unknown-attribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.UnknownAttribute, [u'entry'], name, value)


                                class Cluster(Entity):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, self).__init__()

                                        self.yang_name = "cluster"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "cluster"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.Cluster, [u'entry'], name, value)


                                class L2tpv3Cookie(Entity):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, self).__init__()

                                        self.yang_name = "l2tpv3-cookie"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "l2tpv3-cookie"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.L2tpv3Cookie, [u'entry'], name, value)


                                class ConnectorValue(Entity):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, self).__init__()

                                        self.yang_name = "connector-value"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "connector-value"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.ConnectorValue, [u'entry'], name, value)


                                class PmsiValue(Entity):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, self).__init__()

                                        self.yang_name = "pmsi-value"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "pmsi-value"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PmsiValue, [u'entry'], name, value)


                                class LsAttr(Entity):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, self).__init__()

                                        self.yang_name = "ls-attr"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "ls-attr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LsAttr, [u'entry'], name, value)


                                class PeDistinguisherLabel(Entity):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, self).__init__()

                                        self.yang_name = "pe-distinguisher-label"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                        ])
                                        self.pe_address = None
                                        self.label = None
                                        self._segment_path = lambda: "pe-distinguisher-label"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                class LargeCommunity(Entity):
                                    """
                                    Large Community attribute
                                    
                                    .. attribute:: global_admin
                                    
                                    	Global Administrator
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data1
                                    
                                    	Local Data 1
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data2
                                    
                                    	Local Data 2
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, self).__init__()

                                        self.yang_name = "large-community"
                                        self.yang_parent_name = "common-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                        ])
                                        self.global_admin = None
                                        self.local_data1 = None
                                        self.local_data2 = None
                                        self._segment_path = lambda: "large-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.CommonAttributes.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                            class AttrSet(Entity):
                                """
                                ATTR\_SET attribute
                                
                                .. attribute:: prefix_sid_attr
                                
                                	Prefix SID attribute
                                	**type**\:  :py:class:`PrefixSidAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr>`
                                
                                .. attribute:: tunnel_encap
                                
                                	Tunnel Encapsulation attribute
                                	**type**\:  :py:class:`TunnelEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap>`
                                
                                .. attribute:: is_metric_present
                                
                                	Metric attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_local_pref_present
                                
                                	Local Preference attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_atomic_aggregate_present
                                
                                	Atomic aggregate attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_aggregator_present
                                
                                	Aggregator attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_origin_present
                                
                                	Origin attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_as_path_present
                                
                                	AS path attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_community_present
                                
                                	Community attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_extended_community_present
                                
                                	Extended community attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_ssa_present
                                
                                	SSA attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_connector_present
                                
                                	Connector present
                                	**type**\: bool
                                
                                .. attribute:: is_pmsi_present
                                
                                	PMSI Attribute  present
                                	**type**\: bool
                                
                                .. attribute:: is_pppmp_present
                                
                                	PPMP Attribute  present
                                	**type**\: bool
                                
                                .. attribute:: is_aigp_present
                                
                                	AIGP Present
                                	**type**\: bool
                                
                                .. attribute:: is_pe_distinguisher_label_present
                                
                                	PE distinguisher label  attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_ls_attribute_present
                                
                                	BGP LS attribute present
                                	**type**\: bool
                                
                                .. attribute:: is_label_index_present
                                
                                	Label Index attribute present
                                	**type**\: bool
                                
                                .. attribute:: neighbor_as
                                
                                	Neighbor AS number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aggregator_as
                                
                                	AS where aggregation was last performed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aggregator_address
                                
                                	Address where aggregation was performed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_preference
                                
                                	Local preference
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: origin
                                
                                	Origin
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: as_path
                                
                                	AS path attribute
                                	**type**\: str
                                
                                .. attribute:: extended_community_flags
                                
                                	Extended community Flags
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: originator
                                
                                	Originator attribute
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tpv3_session_id
                                
                                	L2TPv3 session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: connector_type
                                
                                	Connector Type
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: aigp_metric_value
                                
                                	AIGP metric value
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pmsi_type
                                
                                	PMSI Type
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: pmsi_flags
                                
                                	PMSI Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: pmsi_label
                                
                                	PMSI label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ppm_pvalue
                                
                                	PPMP Value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_large_community_present
                                
                                	Large Community attribute present
                                	**type**\: bool
                                
                                .. attribute:: community
                                
                                	Community attribute
                                	**type**\: list of  		 :py:class:`Community <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Community>`
                                
                                .. attribute:: extended_community
                                
                                	Extended community attribute
                                	**type**\: list of  		 :py:class:`ExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity>`
                                
                                .. attribute:: unknown_attribute
                                
                                	Unknown attributes
                                	**type**\: list of  		 :py:class:`UnknownAttribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute>`
                                
                                .. attribute:: cluster
                                
                                	Cluster list attribute
                                	**type**\: list of  		 :py:class:`Cluster <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Cluster>`
                                
                                .. attribute:: l2tpv3_cookie
                                
                                	L2TPv3 Cookie
                                	**type**\: list of  		 :py:class:`L2tpv3Cookie <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie>`
                                
                                .. attribute:: connector_value
                                
                                	Connector Value
                                	**type**\: list of  		 :py:class:`ConnectorValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue>`
                                
                                .. attribute:: pmsi_value
                                
                                	PMSI Value
                                	**type**\: list of  		 :py:class:`PmsiValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue>`
                                
                                .. attribute:: ls_attr
                                
                                	BGP LS attribute
                                	**type**\: list of  		 :py:class:`LsAttr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr>`
                                
                                .. attribute:: pe_distinguisher_label
                                
                                	PE distinguisher label attribute
                                	**type**\: list of  		 :py:class:`PeDistinguisherLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel>`
                                
                                .. attribute:: large_community
                                
                                	Large Community attribute
                                	**type**\: list of  		 :py:class:`LargeCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet, self).__init__()

                                    self.yang_name = "attr-set"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("prefix-sid-attr", ("prefix_sid_attr", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr)), ("tunnel-encap", ("tunnel_encap", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap)), ("community", ("community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Community)), ("extended-community", ("extended_community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity)), ("unknown-attribute", ("unknown_attribute", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute)), ("cluster", ("cluster", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Cluster)), ("l2tpv3-cookie", ("l2tpv3_cookie", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie)), ("connector-value", ("connector_value", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue)), ("pmsi-value", ("pmsi_value", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue)), ("ls-attr", ("ls_attr", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr)), ("pe-distinguisher-label", ("pe_distinguisher_label", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel)), ("large-community", ("large_community", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity))])
                                    self._leafs = OrderedDict([
                                        ('is_metric_present', (YLeaf(YType.boolean, 'is-metric-present'), ['bool'])),
                                        ('is_local_pref_present', (YLeaf(YType.boolean, 'is-local-pref-present'), ['bool'])),
                                        ('is_atomic_aggregate_present', (YLeaf(YType.boolean, 'is-atomic-aggregate-present'), ['bool'])),
                                        ('is_aggregator_present', (YLeaf(YType.boolean, 'is-aggregator-present'), ['bool'])),
                                        ('is_origin_present', (YLeaf(YType.boolean, 'is-origin-present'), ['bool'])),
                                        ('is_as_path_present', (YLeaf(YType.boolean, 'is-as-path-present'), ['bool'])),
                                        ('is_community_present', (YLeaf(YType.boolean, 'is-community-present'), ['bool'])),
                                        ('is_extended_community_present', (YLeaf(YType.boolean, 'is-extended-community-present'), ['bool'])),
                                        ('is_ssa_present', (YLeaf(YType.boolean, 'is-ssa-present'), ['bool'])),
                                        ('is_connector_present', (YLeaf(YType.boolean, 'is-connector-present'), ['bool'])),
                                        ('is_pmsi_present', (YLeaf(YType.boolean, 'is-pmsi-present'), ['bool'])),
                                        ('is_pppmp_present', (YLeaf(YType.boolean, 'is-pppmp-present'), ['bool'])),
                                        ('is_aigp_present', (YLeaf(YType.boolean, 'is-aigp-present'), ['bool'])),
                                        ('is_pe_distinguisher_label_present', (YLeaf(YType.boolean, 'is-pe-distinguisher-label-present'), ['bool'])),
                                        ('is_ls_attribute_present', (YLeaf(YType.boolean, 'is-ls-attribute-present'), ['bool'])),
                                        ('is_label_index_present', (YLeaf(YType.boolean, 'is-label-index-present'), ['bool'])),
                                        ('neighbor_as', (YLeaf(YType.uint32, 'neighbor-as'), ['int'])),
                                        ('aggregator_as', (YLeaf(YType.uint32, 'aggregator-as'), ['int'])),
                                        ('aggregator_address', (YLeaf(YType.str, 'aggregator-address'), ['str'])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('local_preference', (YLeaf(YType.uint32, 'local-preference'), ['int'])),
                                        ('origin', (YLeaf(YType.uint16, 'origin'), ['int'])),
                                        ('as_path', (YLeaf(YType.str, 'as-path'), ['str'])),
                                        ('extended_community_flags', (YLeaf(YType.uint8, 'extended-community-flags'), ['int'])),
                                        ('originator', (YLeaf(YType.str, 'originator'), ['str'])),
                                        ('l2tpv3_session_id', (YLeaf(YType.uint32, 'l2tpv3-session-id'), ['int'])),
                                        ('connector_type', (YLeaf(YType.uint16, 'connector-type'), ['int'])),
                                        ('aigp_metric_value', (YLeaf(YType.uint64, 'aigp-metric-value'), ['int'])),
                                        ('pmsi_type', (YLeaf(YType.uint16, 'pmsi-type'), ['int'])),
                                        ('pmsi_flags', (YLeaf(YType.uint8, 'pmsi-flags'), ['int'])),
                                        ('pmsi_label', (YLeaf(YType.uint32, 'pmsi-label'), ['int'])),
                                        ('ppm_pvalue', (YLeaf(YType.uint32, 'ppm-pvalue'), ['int'])),
                                        ('is_large_community_present', (YLeaf(YType.boolean, 'is-large-community-present'), ['bool'])),
                                    ])
                                    self.is_metric_present = None
                                    self.is_local_pref_present = None
                                    self.is_atomic_aggregate_present = None
                                    self.is_aggregator_present = None
                                    self.is_origin_present = None
                                    self.is_as_path_present = None
                                    self.is_community_present = None
                                    self.is_extended_community_present = None
                                    self.is_ssa_present = None
                                    self.is_connector_present = None
                                    self.is_pmsi_present = None
                                    self.is_pppmp_present = None
                                    self.is_aigp_present = None
                                    self.is_pe_distinguisher_label_present = None
                                    self.is_ls_attribute_present = None
                                    self.is_label_index_present = None
                                    self.neighbor_as = None
                                    self.aggregator_as = None
                                    self.aggregator_address = None
                                    self.metric = None
                                    self.local_preference = None
                                    self.origin = None
                                    self.as_path = None
                                    self.extended_community_flags = None
                                    self.originator = None
                                    self.l2tpv3_session_id = None
                                    self.connector_type = None
                                    self.aigp_metric_value = None
                                    self.pmsi_type = None
                                    self.pmsi_flags = None
                                    self.pmsi_label = None
                                    self.ppm_pvalue = None
                                    self.is_large_community_present = None

                                    self.prefix_sid_attr = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr()
                                    self.prefix_sid_attr.parent = self
                                    self._children_name_map["prefix_sid_attr"] = "prefix-sid-attr"

                                    self.tunnel_encap = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap()
                                    self.tunnel_encap.parent = self
                                    self._children_name_map["tunnel_encap"] = "tunnel-encap"

                                    self.community = YList(self)
                                    self.extended_community = YList(self)
                                    self.unknown_attribute = YList(self)
                                    self.cluster = YList(self)
                                    self.l2tpv3_cookie = YList(self)
                                    self.connector_value = YList(self)
                                    self.pmsi_value = YList(self)
                                    self.ls_attr = YList(self)
                                    self.pe_distinguisher_label = YList(self)
                                    self.large_community = YList(self)
                                    self._segment_path = lambda: "attr-set"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet, [u'is_metric_present', u'is_local_pref_present', u'is_atomic_aggregate_present', u'is_aggregator_present', u'is_origin_present', u'is_as_path_present', u'is_community_present', u'is_extended_community_present', u'is_ssa_present', u'is_connector_present', u'is_pmsi_present', u'is_pppmp_present', u'is_aigp_present', u'is_pe_distinguisher_label_present', u'is_ls_attribute_present', u'is_label_index_present', u'neighbor_as', u'aggregator_as', u'aggregator_address', u'metric', u'local_preference', u'origin', u'as_path', u'extended_community_flags', u'originator', u'l2tpv3_session_id', u'connector_type', u'aigp_metric_value', u'pmsi_type', u'pmsi_flags', u'pmsi_label', u'ppm_pvalue', u'is_large_community_present'], name, value)


                                class PrefixSidAttr(Entity):
                                    """
                                    Prefix SID attribute
                                    
                                    .. attribute:: prefix_sid_tlv
                                    
                                    	Prefix SID TLV array
                                    	**type**\: list of  		 :py:class:`PrefixSidTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, self).__init__()

                                        self.yang_name = "prefix-sid-attr"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-sid-tlv", ("prefix_sid_tlv", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv))])
                                        self._leafs = OrderedDict()

                                        self.prefix_sid_tlv = YList(self)
                                        self._segment_path = lambda: "prefix-sid-attr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr, [], name, value)


                                    class PrefixSidTlv(Entity):
                                        """
                                        Prefix SID TLV array
                                        
                                        .. attribute:: type
                                        
                                        	Prefix SID TLV type field
                                        	**type**\:  :py:class:`BgpPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpPrefixSid>`
                                        
                                        .. attribute:: len
                                        
                                        	Prefix SID TLV Length in bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: val
                                        
                                        	Prefix SID TLV value string
                                        	**type**\: str
                                        
                                        	**length:** 0..46
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, self).__init__()

                                            self.yang_name = "prefix-sid-tlv"
                                            self.yang_parent_name = "prefix-sid-attr"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpPrefixSid', '')])),
                                                ('len', (YLeaf(YType.uint16, 'len'), ['int'])),
                                                ('val', (YLeaf(YType.str, 'val'), ['str'])),
                                            ])
                                            self.type = None
                                            self.len = None
                                            self.val = None
                                            self._segment_path = lambda: "prefix-sid-tlv"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PrefixSidAttr.PrefixSidTlv, [u'type', u'len', u'val'], name, value)


                                class TunnelEncap(Entity):
                                    """
                                    Tunnel Encapsulation attribute
                                    
                                    .. attribute:: sr_policy
                                    
                                    	Tunnel encap type SR policy
                                    	**type**\:  :py:class:`SrPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, self).__init__()

                                        self.yang_name = "tunnel-encap"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sr-policy", ("sr_policy", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy))])
                                        self._leafs = OrderedDict()

                                        self.sr_policy = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy()
                                        self.sr_policy.parent = self
                                        self._children_name_map["sr_policy"] = "sr-policy"
                                        self._segment_path = lambda: "tunnel-encap"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap, [], name, value)


                                    class SrPolicy(Entity):
                                        """
                                        Tunnel encap type SR policy
                                        
                                        .. attribute:: binding_sid
                                        
                                        	SR Policy incoming Binding sid
                                        	**type**\:  :py:class:`BindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid>`
                                        
                                        .. attribute:: allocated_binding_sid
                                        
                                        	SR Policy allocated Binding sid by the router
                                        	**type**\:  :py:class:`AllocatedBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid>`
                                        
                                        .. attribute:: tunnel_encap_type
                                        
                                        	Tunnel Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: preference
                                        
                                        	SR Policy Preference
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: state
                                        
                                        	SR Policy active state in forwarding
                                        	**type**\: bool
                                        
                                        .. attribute:: request_state
                                        
                                        	SR Policy programming Status
                                        	**type**\:  :py:class:`BgpSrpolicyReqState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpSrpolicyReqState>`
                                        
                                        .. attribute:: usable
                                        
                                        	SR Policy is usable on this node
                                        	**type**\: bool
                                        
                                        .. attribute:: segment_list
                                        
                                        	SR Policy Segment Lists
                                        	**type**\: list of  		 :py:class:`SegmentList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, self).__init__()

                                            self.yang_name = "sr-policy"
                                            self.yang_parent_name = "tunnel-encap"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("binding-sid", ("binding_sid", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid)), ("allocated-binding-sid", ("allocated_binding_sid", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid)), ("segment-list", ("segment_list", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList))])
                                            self._leafs = OrderedDict([
                                                ('tunnel_encap_type', (YLeaf(YType.uint16, 'tunnel-encap-type'), ['int'])),
                                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                                ('state', (YLeaf(YType.boolean, 'state'), ['bool'])),
                                                ('request_state', (YLeaf(YType.enumeration, 'request-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpSrpolicyReqState', '')])),
                                                ('usable', (YLeaf(YType.boolean, 'usable'), ['bool'])),
                                            ])
                                            self.tunnel_encap_type = None
                                            self.preference = None
                                            self.state = None
                                            self.request_state = None
                                            self.usable = None

                                            self.binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid()
                                            self.binding_sid.parent = self
                                            self._children_name_map["binding_sid"] = "binding-sid"

                                            self.allocated_binding_sid = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid()
                                            self.allocated_binding_sid.parent = self
                                            self._children_name_map["allocated_binding_sid"] = "allocated-binding-sid"

                                            self.segment_list = YList(self)
                                            self._segment_path = lambda: "sr-policy"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy, [u'tunnel_encap_type', u'preference', u'state', u'request_state', u'usable'], name, value)


                                        class BindingSid(Entity):
                                            """
                                            SR Policy incoming Binding sid
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, self).__init__()

                                                self.yang_name = "binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.type = None
                                                self.label = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "binding-sid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.BindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                        class AllocatedBindingSid(Entity):
                                            """
                                            SR Policy allocated Binding sid by the router
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`BgpBindingSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBindingSid>`
                                            
                                            .. attribute:: label
                                            
                                            	MPLS Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ipv6_address
                                            
                                            	IPv6 Addr
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, self).__init__()

                                                self.yang_name = "allocated-binding-sid"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBindingSid', '')])),
                                                    ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                    ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                ])
                                                self.type = None
                                                self.label = None
                                                self.ipv6_address = None
                                                self._segment_path = lambda: "allocated-binding-sid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.AllocatedBindingSid, [u'type', u'label', u'ipv6_address'], name, value)


                                        class SegmentList(Entity):
                                            """
                                            SR Policy Segment Lists
                                            
                                            .. attribute:: weight
                                            
                                            	Weight of segment list
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: segment
                                            
                                            	Segments in segment list
                                            	**type**\: list of  		 :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, self).__init__()

                                                self.yang_name = "segment-list"
                                                self.yang_parent_name = "sr-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("segment", ("segment", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment))])
                                                self._leafs = OrderedDict([
                                                    ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                ])
                                                self.weight = None

                                                self.segment = YList(self)
                                                self._segment_path = lambda: "segment-list"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList, [u'weight'], name, value)


                                            class Segment(Entity):
                                                """
                                                Segments in segment list
                                                
                                                .. attribute:: type
                                                
                                                	Type
                                                	**type**\:  :py:class:`SrSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.SrSid>`
                                                
                                                .. attribute:: label
                                                
                                                	MPLS Label value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address value
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ipv6_address
                                                
                                                	IPv6 address value
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-bgp-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, self).__init__()

                                                    self.yang_name = "segment"
                                                    self.yang_parent_name = "segment-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.enumeration, 'type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'SrSid', '')])),
                                                        ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                                    ])
                                                    self.type = None
                                                    self.label = None
                                                    self.ipv4_address = None
                                                    self.ipv6_address = None
                                                    self._segment_path = lambda: "segment"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.TunnelEncap.SrPolicy.SegmentList.Segment, [u'type', u'label', u'ipv4_address', u'ipv6_address'], name, value)


                                class Community(Entity):
                                    """
                                    Community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Community, self).__init__()

                                        self.yang_name = "community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Community, [u'entry'], name, value)


                                class ExtendedCommunity(Entity):
                                    """
                                    Extended community attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, self).__init__()

                                        self.yang_name = "extended-community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "extended-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ExtendedCommunity, [u'entry'], name, value)


                                class UnknownAttribute(Entity):
                                    """
                                    Unknown attributes
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, self).__init__()

                                        self.yang_name = "unknown-attribute"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "unknown-attribute"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.UnknownAttribute, [u'entry'], name, value)


                                class Cluster(Entity):
                                    """
                                    Cluster list attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, self).__init__()

                                        self.yang_name = "cluster"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "cluster"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.Cluster, [u'entry'], name, value)


                                class L2tpv3Cookie(Entity):
                                    """
                                    L2TPv3 Cookie
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, self).__init__()

                                        self.yang_name = "l2tpv3-cookie"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "l2tpv3-cookie"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.L2tpv3Cookie, [u'entry'], name, value)


                                class ConnectorValue(Entity):
                                    """
                                    Connector Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, self).__init__()

                                        self.yang_name = "connector-value"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "connector-value"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.ConnectorValue, [u'entry'], name, value)


                                class PmsiValue(Entity):
                                    """
                                    PMSI Value
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, self).__init__()

                                        self.yang_name = "pmsi-value"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "pmsi-value"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PmsiValue, [u'entry'], name, value)


                                class LsAttr(Entity):
                                    """
                                    BGP LS attribute
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, self).__init__()

                                        self.yang_name = "ls-attr"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint8, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "ls-attr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LsAttr, [u'entry'], name, value)


                                class PeDistinguisherLabel(Entity):
                                    """
                                    PE distinguisher label attribute
                                    
                                    .. attribute:: pe_address
                                    
                                    	 PE address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label
                                    
                                    	Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, self).__init__()

                                        self.yang_name = "pe-distinguisher-label"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pe_address', (YLeaf(YType.str, 'pe-address'), ['str'])),
                                            ('label', (YLeaf(YType.uint32, 'label'), ['int'])),
                                        ])
                                        self.pe_address = None
                                        self.label = None
                                        self._segment_path = lambda: "pe-distinguisher-label"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.PeDistinguisherLabel, [u'pe_address', u'label'], name, value)


                                class LargeCommunity(Entity):
                                    """
                                    Large Community attribute
                                    
                                    .. attribute:: global_admin
                                    
                                    	Global Administrator
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data1
                                    
                                    	Local Data 1
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_data2
                                    
                                    	Local Data 2
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, self).__init__()

                                        self.yang_name = "large-community"
                                        self.yang_parent_name = "attr-set"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('global_admin', (YLeaf(YType.uint32, 'global-admin'), ['int'])),
                                            ('local_data1', (YLeaf(YType.uint32, 'local-data1'), ['int'])),
                                            ('local_data2', (YLeaf(YType.uint32, 'local-data2'), ['int'])),
                                        ])
                                        self.global_admin = None
                                        self.local_data1 = None
                                        self.local_data2 = None
                                        self._segment_path = lambda: "large-community"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.AttrSet.LargeCommunity, [u'global_admin', u'local_data1', u'local_data2'], name, value)


                            class RnhAddr(Entity):
                                """
                                RNH Address
                                
                                .. attribute:: len
                                
                                	len
                                	**type**\:  :py:class:`BgpRnhAddrLen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRnhAddrLen>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPv6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_address
                                
                                	MAC Addr
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr, self).__init__()

                                    self.yang_name = "rnh-addr"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('len', (YLeaf(YType.enumeration, 'len'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRnhAddrLen', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                    ])
                                    self.len = None
                                    self.ipv4_address = None
                                    self.ipv6_address = None
                                    self.mac_address = None
                                    self._segment_path = lambda: "rnh-addr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RnhAddr, [u'len', u'ipv4_address', u'ipv6_address', u'mac_address'], name, value)


                            class RibrnhIp(Entity):
                                """
                                RIB RNH IP Address
                                
                                .. attribute:: l2vpn_vpls_address
                                
                                	L2VPN VPLS Addr
                                	**type**\:  :py:class:`L2vpnVplsAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress>`
                                
                                .. attribute:: l2vpn_mspw_address
                                
                                	L2VPN MSPW Addr
                                	**type**\:  :py:class:`L2vpnMspwAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress>`
                                
                                .. attribute:: ipv4_sr_policy_address
                                
                                	IPV4 Policy Addr
                                	**type**\:  :py:class:`Ipv4SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress>`
                                
                                .. attribute:: ipv6_sr_policy_address
                                
                                	IPV6 Policy Addr
                                	**type**\:  :py:class:`Ipv6SrPolicyAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress>`
                                
                                .. attribute:: afi
                                
                                	AFI
                                	**type**\:  :py:class:`BgpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_mcast_address
                                
                                	IPv4 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_label_address
                                
                                	IPv4 Label Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4_tunnel_address
                                
                                	IPv4 Tunnel
                                	**type**\: str
                                
                                	**pattern:** ((0\:\|[1\-9][0\-9]{0,4}\:)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4_mdt_address
                                
                                	IPv4 MDT Addr
                                	**type**\: str
                                
                                	**pattern:** (([a\-f0\-9]{16}\-)(([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([1\-9]?[0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5]))
                                
                                .. attribute:: ipv4vpn_address
                                
                                	IPv4 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv4vpna_mcastddress
                                
                                	IPv4 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_mcast_address
                                
                                	IPV6 Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_label_address
                                
                                	IPv6 Label Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_address
                                
                                	IPv6 VPN Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6vpn_mcast_address
                                
                                	IPv6 VPN Mcast Addr
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rt_constraint_address
                                
                                	RT Constrt Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{24}
                                
                                .. attribute:: ipv6mvpn_address
                                
                                	MVPN addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{104}
                                
                                .. attribute:: ipv4mvpn_address
                                
                                	MVPN4 addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{56}
                                
                                .. attribute:: l2vpn_evpn_address
                                
                                	L2VPN EVPN Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{58}
                                
                                .. attribute:: ls_ls_address
                                
                                	LINKSTATE LINKSTATE Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]+
                                
                                .. attribute:: ipv4_flowspec_address
                                
                                	IPV4 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6_flowspec_address
                                
                                	IPV6 Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv4vpn_flowspec_address
                                
                                	IPV4 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                .. attribute:: ipv6vpn_flowspec_address
                                
                                	IPV6 VPN Flowspec Addr
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4096}
                                
                                

                                """

                                _prefix = 'ipv4-bgp-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp, self).__init__()

                                    self.yang_name = "ribrnh-ip"
                                    self.yang_parent_name = "attribute-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2vpn-vpls-address", ("l2vpn_vpls_address", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress)), ("l2vpn-mspw-address", ("l2vpn_mspw_address", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress)), ("ipv4-sr-policy-address", ("ipv4_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress)), ("ipv6-sr-policy-address", ("ipv6_sr_policy_address", Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress))])
                                    self._leafs = OrderedDict([
                                        ('afi', (YLeaf(YType.enumeration, 'afi'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpAfi', '')])),
                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                        ('ipv4_mcast_address', (YLeaf(YType.str, 'ipv4-mcast-address'), ['str'])),
                                        ('ipv4_label_address', (YLeaf(YType.str, 'ipv4-label-address'), ['str'])),
                                        ('ipv4_tunnel_address', (YLeaf(YType.str, 'ipv4-tunnel-address'), ['str'])),
                                        ('ipv4_mdt_address', (YLeaf(YType.str, 'ipv4-mdt-address'), ['str'])),
                                        ('ipv4vpn_address', (YLeaf(YType.str, 'ipv4vpn-address'), ['str'])),
                                        ('ipv4vpna_mcastddress', (YLeaf(YType.str, 'ipv4vpna-mcastddress'), ['str'])),
                                        ('ipv6_address', (YLeaf(YType.str, 'ipv6-address'), ['str'])),
                                        ('ipv6_mcast_address', (YLeaf(YType.str, 'ipv6-mcast-address'), ['str'])),
                                        ('ipv6_label_address', (YLeaf(YType.str, 'ipv6-label-address'), ['str'])),
                                        ('ipv6vpn_address', (YLeaf(YType.str, 'ipv6vpn-address'), ['str'])),
                                        ('ipv6vpn_mcast_address', (YLeaf(YType.str, 'ipv6vpn-mcast-address'), ['str'])),
                                        ('rt_constraint_address', (YLeaf(YType.str, 'rt-constraint-address'), ['str'])),
                                        ('ipv6mvpn_address', (YLeaf(YType.str, 'ipv6mvpn-address'), ['str'])),
                                        ('ipv4mvpn_address', (YLeaf(YType.str, 'ipv4mvpn-address'), ['str'])),
                                        ('l2vpn_evpn_address', (YLeaf(YType.str, 'l2vpn-evpn-address'), ['str'])),
                                        ('ls_ls_address', (YLeaf(YType.str, 'ls-ls-address'), ['str'])),
                                        ('ipv4_flowspec_address', (YLeaf(YType.str, 'ipv4-flowspec-address'), ['str'])),
                                        ('ipv6_flowspec_address', (YLeaf(YType.str, 'ipv6-flowspec-address'), ['str'])),
                                        ('ipv4vpn_flowspec_address', (YLeaf(YType.str, 'ipv4vpn-flowspec-address'), ['str'])),
                                        ('ipv6vpn_flowspec_address', (YLeaf(YType.str, 'ipv6vpn-flowspec-address'), ['str'])),
                                    ])
                                    self.afi = None
                                    self.ipv4_address = None
                                    self.ipv4_mcast_address = None
                                    self.ipv4_label_address = None
                                    self.ipv4_tunnel_address = None
                                    self.ipv4_mdt_address = None
                                    self.ipv4vpn_address = None
                                    self.ipv4vpna_mcastddress = None
                                    self.ipv6_address = None
                                    self.ipv6_mcast_address = None
                                    self.ipv6_label_address = None
                                    self.ipv6vpn_address = None
                                    self.ipv6vpn_mcast_address = None
                                    self.rt_constraint_address = None
                                    self.ipv6mvpn_address = None
                                    self.ipv4mvpn_address = None
                                    self.l2vpn_evpn_address = None
                                    self.ls_ls_address = None
                                    self.ipv4_flowspec_address = None
                                    self.ipv6_flowspec_address = None
                                    self.ipv4vpn_flowspec_address = None
                                    self.ipv6vpn_flowspec_address = None

                                    self.l2vpn_vpls_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress()
                                    self.l2vpn_vpls_address.parent = self
                                    self._children_name_map["l2vpn_vpls_address"] = "l2vpn-vpls-address"

                                    self.l2vpn_mspw_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress()
                                    self.l2vpn_mspw_address.parent = self
                                    self._children_name_map["l2vpn_mspw_address"] = "l2vpn-mspw-address"

                                    self.ipv4_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress()
                                    self.ipv4_sr_policy_address.parent = self
                                    self._children_name_map["ipv4_sr_policy_address"] = "ipv4-sr-policy-address"

                                    self.ipv6_sr_policy_address = Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress()
                                    self.ipv6_sr_policy_address.parent = self
                                    self._children_name_map["ipv6_sr_policy_address"] = "ipv6-sr-policy-address"
                                    self._segment_path = lambda: "ribrnh-ip"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp, [u'afi', u'ipv4_address', u'ipv4_mcast_address', u'ipv4_label_address', u'ipv4_tunnel_address', u'ipv4_mdt_address', u'ipv4vpn_address', u'ipv4vpna_mcastddress', u'ipv6_address', u'ipv6_mcast_address', u'ipv6_label_address', u'ipv6vpn_address', u'ipv6vpn_mcast_address', u'rt_constraint_address', u'ipv6mvpn_address', u'ipv4mvpn_address', u'l2vpn_evpn_address', u'ls_ls_address', u'ipv4_flowspec_address', u'ipv6_flowspec_address', u'ipv4vpn_flowspec_address', u'ipv6vpn_flowspec_address'], name, value)


                                class L2vpnVplsAddress(Entity):
                                    """
                                    L2VPN VPLS Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, self).__init__()

                                        self.yang_name = "l2vpn-vpls-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-vpls-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnVplsAddress, [u'l2vpn_address'], name, value)


                                class L2vpnMspwAddress(Entity):
                                    """
                                    L2VPN MSPW Addr
                                    
                                    .. attribute:: l2vpn_address
                                    
                                    	l2vpn address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, self).__init__()

                                        self.yang_name = "l2vpn-mspw-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2vpn_address', (YLeaf(YType.str, 'l2vpn-address'), ['str'])),
                                        ])
                                        self.l2vpn_address = None
                                        self._segment_path = lambda: "l2vpn-mspw-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.L2vpnMspwAddress, [u'l2vpn_address'], name, value)


                                class Ipv4SrPolicyAddress(Entity):
                                    """
                                    IPV4 Policy Addr
                                    
                                    .. attribute:: ipv4_srpolicy_address
                                    
                                    	ipv4 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv4-sr-policy-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_srpolicy_address', (YLeaf(YType.str, 'ipv4-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv4_srpolicy_address = None
                                        self._segment_path = lambda: "ipv4-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv4SrPolicyAddress, [u'ipv4_srpolicy_address'], name, value)


                                class Ipv6SrPolicyAddress(Entity):
                                    """
                                    IPV6 Policy Addr
                                    
                                    .. attribute:: ipv6_srpolicy_address
                                    
                                    	ipv6 srpolicy address
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, self).__init__()

                                        self.yang_name = "ipv6-sr-policy-address"
                                        self.yang_parent_name = "ribrnh-ip"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv6_srpolicy_address', (YLeaf(YType.str, 'ipv6-srpolicy-address'), ['str'])),
                                        ])
                                        self.ipv6_srpolicy_address = None
                                        self._segment_path = lambda: "ipv6-sr-policy-address"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.Attributes.Attribute.AttributeInfo.RibrnhIp.Ipv6SrPolicyAddress, [u'ipv6_srpolicy_address'], name, value)


                class RtEntries(Entity):
                    """
                    BGP Route Target Sets Table
                    
                    .. attribute:: rt_entry
                    
                    	BGP Route Target Set Entry
                    	**type**\: list of  		 :py:class:`RtEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.RtEntries, self).__init__()

                        self.yang_name = "rt-entries"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rt-entry", ("rt_entry", Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry))])
                        self._leafs = OrderedDict()

                        self.rt_entry = YList(self)
                        self._segment_path = lambda: "rt-entries"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RtEntries, [], name, value)


                    class RtEntry(Entity):
                        """
                        BGP Route Target Set Entry
                        
                        .. attribute:: route_target_lower_bytes
                        
                        	Lower 4 bytes of RT
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_target_upper_bytes
                        
                        	Upper 4 bytes of RT
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:  :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                        
                        .. attribute:: request_id
                        
                        	Random Request ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rt
                        
                        	rt
                        	**type**\:  :py:class:`Rt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt>`
                        
                        .. attribute:: afs
                        
                        	afs
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry, self).__init__()

                            self.yang_name = "rt-entry"
                            self.yang_parent_name = "rt-entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rt", ("rt", Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt))])
                            self._leafs = OrderedDict([
                                ('route_target_lower_bytes', (YLeaf(YType.uint32, 'route-target-lower-bytes'), ['int'])),
                                ('route_target_upper_bytes', (YLeaf(YType.uint32, 'route-target-upper-bytes'), ['int'])),
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes', 'BgpAddressFamily', '')])),
                                ('request_id', (YLeaf(YType.uint32, 'request-id'), ['int'])),
                                ('afs', (YLeaf(YType.str, 'afs'), ['str'])),
                            ])
                            self.route_target_lower_bytes = None
                            self.route_target_upper_bytes = None
                            self.af_name = None
                            self.request_id = None
                            self.afs = None

                            self.rt = Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt()
                            self.rt.parent = self
                            self._children_name_map["rt"] = "rt"
                            self._segment_path = lambda: "rt-entry"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry, ['route_target_lower_bytes', 'route_target_upper_bytes', 'af_name', 'request_id', u'afs'], name, value)


                        class Rt(Entity):
                            """
                            rt
                            
                            .. attribute:: route_target
                            
                            	route target
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt, self).__init__()

                                self.yang_name = "rt"
                                self.yang_parent_name = "rt-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('route_target', (YLeaf(YType.str, 'route-target'), ['str'])),
                                ])
                                self.route_target = None
                                self._segment_path = lambda: "rt"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RtEntries.RtEntry.Rt, [u'route_target'], name, value)


                class AttributeFilterGroups(Entity):
                    """
                    All attribute\-filter groups in this instance
                    
                    .. attribute:: attribute_filter_group
                    
                    	Attribute\-filter group
                    	**type**\: list of  		 :py:class:`AttributeFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups, self).__init__()

                        self.yang_name = "attribute-filter-groups"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attribute-filter-group", ("attribute_filter_group", Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup))])
                        self._leafs = OrderedDict()

                        self.attribute_filter_group = YList(self)
                        self._segment_path = lambda: "attribute-filter-groups"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups, [], name, value)


                    class AttributeFilterGroup(Entity):
                        """
                        Attribute\-filter group
                        
                        .. attribute:: group_name  (key)
                        
                        	Attribute\-filter group name
                        	**type**\: str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: attribute_filter_group_name
                        
                        	Attribute\-filter group name
                        	**type**\: str
                        
                        .. attribute:: attribute_filter_total_group_count
                        
                        	Total number of attriute\-filter groups
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: attribute_filter_entry
                        
                        	List of attriute\-filter entries
                        	**type**\: list of  		 :py:class:`AttributeFilterEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup, self).__init__()

                            self.yang_name = "attribute-filter-group"
                            self.yang_parent_name = "attribute-filter-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['group_name']
                            self._child_classes = OrderedDict([("attribute-filter-entry", ("attribute_filter_entry", Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry))])
                            self._leafs = OrderedDict([
                                ('group_name', (YLeaf(YType.str, 'group-name'), ['str'])),
                                ('attribute_filter_group_name', (YLeaf(YType.str, 'attribute-filter-group-name'), ['str'])),
                                ('attribute_filter_total_group_count', (YLeaf(YType.uint32, 'attribute-filter-total-group-count'), ['int'])),
                            ])
                            self.group_name = None
                            self.attribute_filter_group_name = None
                            self.attribute_filter_total_group_count = None

                            self.attribute_filter_entry = YList(self)
                            self._segment_path = lambda: "attribute-filter-group" + "[group-name='" + str(self.group_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup, ['group_name', u'attribute_filter_group_name', u'attribute_filter_total_group_count'], name, value)


                        class AttributeFilterEntry(Entity):
                            """
                            List of attriute\-filter entries
                            
                            .. attribute:: attribute_filter_entry_requested_action
                            
                            	Requested filtering action
                            	**type**\:  :py:class:`BgpBagUpdFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpBagUpdFilterAction>`
                            
                            .. attribute:: attribute_filter_entry_range_start
                            
                            	Start of attribute range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_filter_entry_range_end
                            
                            	End of attribute range
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry, self).__init__()

                                self.yang_name = "attribute-filter-entry"
                                self.yang_parent_name = "attribute-filter-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('attribute_filter_entry_requested_action', (YLeaf(YType.enumeration, 'attribute-filter-entry-requested-action'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpBagUpdFilterAction', '')])),
                                    ('attribute_filter_entry_range_start', (YLeaf(YType.uint32, 'attribute-filter-entry-range-start'), ['int'])),
                                    ('attribute_filter_entry_range_end', (YLeaf(YType.uint32, 'attribute-filter-entry-range-end'), ['int'])),
                                ])
                                self.attribute_filter_entry_requested_action = None
                                self.attribute_filter_entry_range_start = None
                                self.attribute_filter_entry_range_end = None
                                self._segment_path = lambda: "attribute-filter-entry"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.AttributeFilterGroups.AttributeFilterGroup.AttributeFilterEntry, [u'attribute_filter_entry_requested_action', u'attribute_filter_entry_range_start', u'attribute_filter_entry_range_end'], name, value)


                class RpkiServerList(Entity):
                    """
                    RPKI Server Table
                    
                    .. attribute:: rpki_server
                    
                    	Array of RPKI servers
                    	**type**\: list of  		 :py:class:`RpkiServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiServerList.RpkiServer>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.RpkiServerList, self).__init__()

                        self.yang_name = "rpki-server-list"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpki-server", ("rpki_server", Bgp.Instances.Instance.InstanceStandby.RpkiServerList.RpkiServer))])
                        self._leafs = OrderedDict()

                        self.rpki_server = YList(self)
                        self._segment_path = lambda: "rpki-server-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiServerList, [], name, value)


                    class RpkiServer(Entity):
                        """
                        Array of RPKI servers
                        
                        .. attribute:: name
                        
                        	Server Name
                        	**type**\: str
                        
                        .. attribute:: preference
                        
                        	Server Preference
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: port
                        
                        	Server TCP Port number
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Server Internal State
                        	**type**\:  :py:class:`BgpRpkiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiState>`
                        
                        .. attribute:: state_time
                        
                        	Server Internal State timestamp (unix time)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: shutdown
                        
                        	Server Shutdown
                        	**type**\: bool
                        
                        .. attribute:: retries
                        
                        	Number of connection retries
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: close_reason
                        
                        	Server close reason
                        	**type**\:  :py:class:`BgpRpkiCreason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiCreason>`
                        
                        .. attribute:: close_time
                        
                        	Server close elapsed time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: close_time_real
                        
                        	Server close real timestamp (unix time)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: read_bytes
                        
                        	Number of bytes read from the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: write_bytes
                        
                        	Number of bytes written to the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: transport
                        
                        	Server transport type
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: username
                        
                        	Server SSH username
                        	**type**\: str
                        
                        .. attribute:: password
                        
                        	Server SSH password
                        	**type**\: str
                        
                        .. attribute:: sshpid
                        
                        	Server SSH process ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proto_state
                        
                        	Server Protocol state
                        	**type**\:  :py:class:`BgpRpkiPstate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPstate>`
                        
                        .. attribute:: proto_state_time
                        
                        	Server Protocol state timestamp (unix time)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: serial
                        
                        	Server serial number
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nonce
                        
                        	Server nonce
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: refresh_time
                        
                        	Server refresh time (seconds)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: response_time
                        
                        	Server response time (seconds)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: purge_time
                        
                        	Server purge time (seconds)
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: ipv4roa
                        
                        	Total IPv4 ROAs currently recv'd from server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_announce
                        
                        	Total IPv4 ROAs announced by the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4roa_withdraw
                        
                        	Total IPv4 ROAs withdrawn by the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa
                        
                        	Total IPv6 ROAs currently recv'd from server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_announce
                        
                        	Total IPv6 ROAs announced by the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6roa_withdraw
                        
                        	Total IPv6 ROAs withdrawn by the server
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proto_error
                        
                        	Protocol Error Reason
                        	**type**\:  :py:class:`BgpRpkiPerror <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiPerror>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.RpkiServerList.RpkiServer, self).__init__()

                            self.yang_name = "rpki-server"
                            self.yang_parent_name = "rpki-server-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ('preference', (YLeaf(YType.uint32, 'preference'), ['int'])),
                                ('port', (YLeaf(YType.uint32, 'port'), ['int'])),
                                ('state', (YLeaf(YType.enumeration, 'state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiState', '')])),
                                ('state_time', (YLeaf(YType.uint32, 'state-time'), ['int'])),
                                ('shutdown', (YLeaf(YType.boolean, 'shutdown'), ['bool'])),
                                ('retries', (YLeaf(YType.uint32, 'retries'), ['int'])),
                                ('close_reason', (YLeaf(YType.enumeration, 'close-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiCreason', '')])),
                                ('close_time', (YLeaf(YType.uint32, 'close-time'), ['int'])),
                                ('close_time_real', (YLeaf(YType.uint32, 'close-time-real'), ['int'])),
                                ('read_bytes', (YLeaf(YType.uint32, 'read-bytes'), ['int'])),
                                ('write_bytes', (YLeaf(YType.uint32, 'write-bytes'), ['int'])),
                                ('transport', (YLeaf(YType.uint32, 'transport'), ['int'])),
                                ('username', (YLeaf(YType.str, 'username'), ['str'])),
                                ('password', (YLeaf(YType.str, 'password'), ['str'])),
                                ('sshpid', (YLeaf(YType.uint32, 'sshpid'), ['int'])),
                                ('proto_state', (YLeaf(YType.enumeration, 'proto-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiPstate', '')])),
                                ('proto_state_time', (YLeaf(YType.uint32, 'proto-state-time'), ['int'])),
                                ('serial', (YLeaf(YType.uint32, 'serial'), ['int'])),
                                ('nonce', (YLeaf(YType.uint32, 'nonce'), ['int'])),
                                ('refresh_time', (YLeaf(YType.int32, 'refresh-time'), ['int'])),
                                ('response_time', (YLeaf(YType.int32, 'response-time'), ['int'])),
                                ('purge_time', (YLeaf(YType.int32, 'purge-time'), ['int'])),
                                ('ipv4roa', (YLeaf(YType.uint32, 'ipv4roa'), ['int'])),
                                ('ipv4roa_announce', (YLeaf(YType.uint32, 'ipv4roa-announce'), ['int'])),
                                ('ipv4roa_withdraw', (YLeaf(YType.uint32, 'ipv4roa-withdraw'), ['int'])),
                                ('ipv6roa', (YLeaf(YType.uint32, 'ipv6roa'), ['int'])),
                                ('ipv6roa_announce', (YLeaf(YType.uint32, 'ipv6roa-announce'), ['int'])),
                                ('ipv6roa_withdraw', (YLeaf(YType.uint32, 'ipv6roa-withdraw'), ['int'])),
                                ('proto_error', (YLeaf(YType.enumeration, 'proto-error'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiPerror', '')])),
                            ])
                            self.name = None
                            self.preference = None
                            self.port = None
                            self.state = None
                            self.state_time = None
                            self.shutdown = None
                            self.retries = None
                            self.close_reason = None
                            self.close_time = None
                            self.close_time_real = None
                            self.read_bytes = None
                            self.write_bytes = None
                            self.transport = None
                            self.username = None
                            self.password = None
                            self.sshpid = None
                            self.proto_state = None
                            self.proto_state_time = None
                            self.serial = None
                            self.nonce = None
                            self.refresh_time = None
                            self.response_time = None
                            self.purge_time = None
                            self.ipv4roa = None
                            self.ipv4roa_announce = None
                            self.ipv4roa_withdraw = None
                            self.ipv6roa = None
                            self.ipv6roa_announce = None
                            self.ipv6roa_withdraw = None
                            self.proto_error = None
                            self._segment_path = lambda: "rpki-server"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiServerList.RpkiServer, [u'name', u'preference', u'port', u'state', u'state_time', u'shutdown', u'retries', u'close_reason', u'close_time', u'close_time_real', u'read_bytes', u'write_bytes', u'transport', u'username', u'password', u'sshpid', u'proto_state', u'proto_state_time', u'serial', u'nonce', u'refresh_time', u'response_time', u'purge_time', u'ipv4roa', u'ipv4roa_announce', u'ipv4roa_withdraw', u'ipv6roa', u'ipv6roa_announce', u'ipv6roa_withdraw', u'proto_error'], name, value)


                class RpkiRoutes(Entity):
                    """
                    BGP RPKI ROA table
                    
                    .. attribute:: rpki_route
                    
                    	RPKI Path Group
                    	**type**\: list of  		 :py:class:`RpkiRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes, self).__init__()

                        self.yang_name = "rpki-routes"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rpki-route", ("rpki_route", Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute))])
                        self._leafs = OrderedDict()

                        self.rpki_route = YList(self)
                        self._segment_path = lambda: "rpki-routes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes, [], name, value)


                    class RpkiRoute(Entity):
                        """
                        RPKI Path Group
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:  :py:class:`BgpRpkiEdmAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiEdmAf>`
                        
                        .. attribute:: address
                        
                        	Route Address (IPv4 / IPv6)
                        	**type**\: str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: minimum
                        
                        	Minimum Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum
                        
                        	Maximum Prefix Length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rpki_route
                        
                        	Array or RPKI routes
                        	**type**\: list of  		 :py:class:`RpkiRoute_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute.RpkiRoute_>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute, self).__init__()

                            self.yang_name = "rpki-route"
                            self.yang_parent_name = "rpki-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rpki-route", ("rpki_route", Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute.RpkiRoute_))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiEdmAf', '')])),
                                ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ('minimum', (YLeaf(YType.uint32, 'minimum'), ['int'])),
                                ('maximum', (YLeaf(YType.uint32, 'maximum'), ['int'])),
                            ])
                            self.af_name = None
                            self.address = None
                            self.minimum = None
                            self.maximum = None

                            self.rpki_route = YList(self)
                            self._segment_path = lambda: "rpki-route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute, ['af_name', 'address', 'minimum', 'maximum'], name, value)


                        class RpkiRoute_(Entity):
                            """
                            Array or RPKI routes
                            
                            .. attribute:: af_name
                            
                            	Address Family
                            	**type**\:  :py:class:`BgpRpkiAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.BgpRpkiAf>`
                            
                            .. attribute:: address
                            
                            	Address Prefix
                            	**type**\: str
                            
                            .. attribute:: min_prefix_len
                            
                            	Minimum Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: max_prefix_len
                            
                            	Maximum Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: as_
                            
                            	AS number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: refcount
                            
                            	Refcount
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: server
                            
                            	Source Server
                            	**type**\: str
                            
                            .. attribute:: stale
                            
                            	ROA is stale
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute.RpkiRoute_, self).__init__()

                                self.yang_name = "rpki-route"
                                self.yang_parent_name = "rpki-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper', 'BgpRpkiAf', '')])),
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                    ('min_prefix_len', (YLeaf(YType.uint8, 'min-prefix-len'), ['int'])),
                                    ('max_prefix_len', (YLeaf(YType.uint8, 'max-prefix-len'), ['int'])),
                                    ('as_', (YLeaf(YType.uint32, 'as'), ['int'])),
                                    ('refcount', (YLeaf(YType.uint16, 'refcount'), ['int'])),
                                    ('server', (YLeaf(YType.str, 'server'), ['str'])),
                                    ('stale', (YLeaf(YType.boolean, 'stale'), ['bool'])),
                                ])
                                self.af_name = None
                                self.address = None
                                self.min_prefix_len = None
                                self.max_prefix_len = None
                                self.as_ = None
                                self.refcount = None
                                self.server = None
                                self.stale = None
                                self._segment_path = lambda: "rpki-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiRoutes.RpkiRoute.RpkiRoute_, [u'af_name', u'address', u'min_prefix_len', u'max_prefix_len', u'as_', u'refcount', u'server', u'stale'], name, value)


                class UpdateInboundErrorProcess(Entity):
                    """
                    Update inbound error information for the process
                    
                    .. attribute:: last_update_malformed_timestamp
                    
                    	Last malformed messages received time\: time elapsed since 00\:00\:00 UTC, January 1, 1970
                    	**type**\:  :py:class:`LastUpdateMalformedTimestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp>`
                    
                    .. attribute:: update_error_handling_basic_ebgp
                    
                    	Is basic error\-handling for EBGP enabled
                    	**type**\: bool
                    
                    .. attribute:: update_error_handling_basic_ibgp
                    
                    	Is basic error\-handling for IBGP enabled
                    	**type**\: bool
                    
                    .. attribute:: update_error_handling_extended_ebgp
                    
                    	Is extended error\-handling for EBGP enabled
                    	**type**\: bool
                    
                    .. attribute:: update_error_handling_extended_ibgp
                    
                    	Is extended error\-handling for IBGP enabled
                    	**type**\: bool
                    
                    .. attribute:: update_malformed_message_count
                    
                    	Malformed messages count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_malformed_neighbor_count
                    
                    	Count of neighbors that received malformed messages
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_update_malformed_age
                    
                    	Time since last malformed messages received event (in seconds)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess, self).__init__()

                        self.yang_name = "update-inbound-error-process"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("last-update-malformed-timestamp", ("last_update_malformed_timestamp", Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp))])
                        self._leafs = OrderedDict([
                            ('update_error_handling_basic_ebgp', (YLeaf(YType.boolean, 'update-error-handling-basic-ebgp'), ['bool'])),
                            ('update_error_handling_basic_ibgp', (YLeaf(YType.boolean, 'update-error-handling-basic-ibgp'), ['bool'])),
                            ('update_error_handling_extended_ebgp', (YLeaf(YType.boolean, 'update-error-handling-extended-ebgp'), ['bool'])),
                            ('update_error_handling_extended_ibgp', (YLeaf(YType.boolean, 'update-error-handling-extended-ibgp'), ['bool'])),
                            ('update_malformed_message_count', (YLeaf(YType.uint32, 'update-malformed-message-count'), ['int'])),
                            ('update_malformed_neighbor_count', (YLeaf(YType.uint32, 'update-malformed-neighbor-count'), ['int'])),
                            ('last_update_malformed_age', (YLeaf(YType.uint32, 'last-update-malformed-age'), ['int'])),
                        ])
                        self.update_error_handling_basic_ebgp = None
                        self.update_error_handling_basic_ibgp = None
                        self.update_error_handling_extended_ebgp = None
                        self.update_error_handling_extended_ibgp = None
                        self.update_malformed_message_count = None
                        self.update_malformed_neighbor_count = None
                        self.last_update_malformed_age = None

                        self.last_update_malformed_timestamp = Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp()
                        self.last_update_malformed_timestamp.parent = self
                        self._children_name_map["last_update_malformed_timestamp"] = "last-update-malformed-timestamp"
                        self._segment_path = lambda: "update-inbound-error-process"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess, [u'update_error_handling_basic_ebgp', u'update_error_handling_basic_ibgp', u'update_error_handling_extended_ebgp', u'update_error_handling_extended_ibgp', u'update_malformed_message_count', u'update_malformed_neighbor_count', u'last_update_malformed_age'], name, value)


                    class LastUpdateMalformedTimestamp(Entity):
                        """
                        Last malformed messages received time\: time
                        elapsed since 00\:00\:00 UTC, January 1, 1970
                        
                        .. attribute:: seconds
                        
                        	Seconds part of time value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nanoseconds
                        
                        	Nanoseconds part of time value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'ipv4-bgp-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp, self).__init__()

                            self.yang_name = "last-update-malformed-timestamp"
                            self.yang_parent_name = "update-inbound-error-process"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nanoseconds', (YLeaf(YType.uint32, 'nanoseconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nanoseconds = None
                            self._segment_path = lambda: "last-update-malformed-timestamp"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.UpdateInboundErrorProcess.LastUpdateMalformedTimestamp, [u'seconds', u'nanoseconds'], name, value)


                class RpkiSummary(Entity):
                    """
                    RPKI Summary Info
                    
                    .. attribute:: servers
                    
                    	Number of RPKI Servers configured
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv4roa_nets
                    
                    	Number of IPv4 ROA Nets
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv4roa_paths
                    
                    	Number of IPv4 ROA Paths
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_nets
                    
                    	Number of IPv6 ROA Nets
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ipv6roa_paths
                    
                    	Number of IPv6 ROA Paths
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.Instances.Instance.InstanceStandby.RpkiSummary, self).__init__()

                        self.yang_name = "rpki-summary"
                        self.yang_parent_name = "instance-standby"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('servers', (YLeaf(YType.uint32, 'servers'), ['int'])),
                            ('ipv4roa_nets', (YLeaf(YType.uint32, 'ipv4roa-nets'), ['int'])),
                            ('ipv4roa_paths', (YLeaf(YType.uint32, 'ipv4roa-paths'), ['int'])),
                            ('ipv6roa_nets', (YLeaf(YType.uint32, 'ipv6roa-nets'), ['int'])),
                            ('ipv6roa_paths', (YLeaf(YType.uint32, 'ipv6roa-paths'), ['int'])),
                        ])
                        self.servers = None
                        self.ipv4roa_nets = None
                        self.ipv4roa_paths = None
                        self.ipv6roa_nets = None
                        self.ipv6roa_paths = None
                        self._segment_path = lambda: "rpki-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instances.Instance.InstanceStandby.RpkiSummary, [u'servers', u'ipv4roa_nets', u'ipv4roa_paths', u'ipv6roa_nets', u'ipv6roa_paths'], name, value)


    class BpmInstancesTable(Entity):
        """
        BGP instances information
        
        .. attribute:: bpm_instances
        
        	BGP instances information
        	**type**\:  :py:class:`BpmInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable.BpmInstances>`
        
        

        """

        _prefix = 'ipv4-bgp-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(Bgp.BpmInstancesTable, self).__init__()

            self.yang_name = "bpm-instances-table"
            self.yang_parent_name = "bgp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("bpm-instances", ("bpm_instances", Bgp.BpmInstancesTable.BpmInstances))])
            self._leafs = OrderedDict()

            self.bpm_instances = Bgp.BpmInstancesTable.BpmInstances()
            self.bpm_instances.parent = self
            self._children_name_map["bpm_instances"] = "bpm-instances"
            self._segment_path = lambda: "bpm-instances-table"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Bgp.BpmInstancesTable, [], name, value)


        class BpmInstances(Entity):
            """
            BGP instances information
            
            .. attribute:: instance
            
            	Array of instance information
            	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable.BpmInstances.Instance>`
            
            

            """

            _prefix = 'ipv4-bgp-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(Bgp.BpmInstancesTable.BpmInstances, self).__init__()

                self.yang_name = "bpm-instances"
                self.yang_parent_name = "bpm-instances-table"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("instance", ("instance", Bgp.BpmInstancesTable.BpmInstances.Instance))])
                self._leafs = OrderedDict()

                self.instance = YList(self)
                self._segment_path = lambda: "bpm-instances"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/bpm-instances-table/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Bgp.BpmInstancesTable.BpmInstances, [], name, value)


            class Instance(Entity):
                """
                Array of instance information
                
                .. attribute:: instance_identifier
                
                	Instance Identifier
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: placed_group_id
                
                	Placed Group Identifier
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: instance_name_str
                
                	Instance Name
                	**type**\: str
                
                .. attribute:: as_number
                
                	AS Number
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_vrfs
                
                	Number of VRFs
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: read_only_enabled
                
                	Read\-only is enabled
                	**type**\: bool
                
                .. attribute:: install_diversion_enabled
                
                	Install diversion is enabled
                	**type**\: bool
                
                .. attribute:: srgb_start_configured
                
                	Configured start value of Segment\-routing global block
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: srgb_end_configured
                
                	Configured end value of Segment\-routing global block
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: af_array
                
                	Array of Address Families
                	**type**\: list of  		 :py:class:`AfArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_oper.Bgp.BpmInstancesTable.BpmInstances.Instance.AfArray>`
                
                

                """

                _prefix = 'ipv4-bgp-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(Bgp.BpmInstancesTable.BpmInstances.Instance, self).__init__()

                    self.yang_name = "instance"
                    self.yang_parent_name = "bpm-instances"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("af-array", ("af_array", Bgp.BpmInstancesTable.BpmInstances.Instance.AfArray))])
                    self._leafs = OrderedDict([
                        ('instance_identifier', (YLeaf(YType.uint16, 'instance-identifier'), ['int'])),
                        ('placed_group_id', (YLeaf(YType.uint16, 'placed-group-id'), ['int'])),
                        ('instance_name_str', (YLeaf(YType.str, 'instance-name-str'), ['str'])),
                        ('as_number', (YLeaf(YType.uint32, 'as-number'), ['int'])),
                        ('number_of_vrfs', (YLeaf(YType.uint32, 'number-of-vrfs'), ['int'])),
                        ('read_only_enabled', (YLeaf(YType.boolean, 'read-only-enabled'), ['bool'])),
                        ('install_diversion_enabled', (YLeaf(YType.boolean, 'install-diversion-enabled'), ['bool'])),
                        ('srgb_start_configured', (YLeaf(YType.uint32, 'srgb-start-configured'), ['int'])),
                        ('srgb_end_configured', (YLeaf(YType.uint32, 'srgb-end-configured'), ['int'])),
                    ])
                    self.instance_identifier = None
                    self.placed_group_id = None
                    self.instance_name_str = None
                    self.as_number = None
                    self.number_of_vrfs = None
                    self.read_only_enabled = None
                    self.install_diversion_enabled = None
                    self.srgb_start_configured = None
                    self.srgb_end_configured = None

                    self.af_array = YList(self)
                    self._segment_path = lambda: "instance"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/bpm-instances-table/bpm-instances/%s" % self._segment_path()
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Bgp.BpmInstancesTable.BpmInstances.Instance, [u'instance_identifier', u'placed_group_id', u'instance_name_str', u'as_number', u'number_of_vrfs', u'read_only_enabled', u'install_diversion_enabled', u'srgb_start_configured', u'srgb_end_configured'], name, value)


                class AfArray(Entity):
                    """
                    Array of Address Families
                    
                    .. attribute:: entry
                    
                    	Array entry
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'ipv4-bgp-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(Bgp.BpmInstancesTable.BpmInstances.Instance.AfArray, self).__init__()

                        self.yang_name = "af-array"
                        self.yang_parent_name = "instance"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "af-array"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-oper:bgp/bpm-instances-table/bpm-instances/instance/%s" % self._segment_path()
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.BpmInstancesTable.BpmInstances.Instance.AfArray, [u'entry'], name, value)

    def clone_ptr(self):
        self._top_entity = Bgp()
        return self._top_entity

